@@ -17,7 +17,6 @@
  * Author: Sidharth Nabar <snabar@uw.edu>, He Wu <mdzz@u.washington.edu>
  */
 
-#include "ns3/config-store-module.h"
 #include "ns3/core-module.h"
 #include "ns3/energy-module.h"
 #include "ns3/internet-module.h"
@@ -289,9 +288,7 @@ main(int argc, char* argv[])
     Simulator::Stop(Seconds(10.0));
     Simulator::Run();
 
-    for (DeviceEnergyModelContainer::Iterator iter = deviceModels.Begin();
-         iter != deviceModels.End();
-         iter++)
+    for (auto iter = deviceModels.Begin(); iter != deviceModels.End(); iter++)
     {
         double energyConsumed = (*iter)->GetTotalEnergyConsumption();
         NS_LOG_UNCOND("End of simulation ("
