@@ -46,7 +46,6 @@
  *
  */
 
-#include "ns3/config-store-module.h"
 #include "ns3/core-module.h"
 #include "ns3/energy-module.h"
 #include "ns3/internet-module.h"
@@ -354,9 +353,7 @@ main(int argc, char* argv[])
     Simulator::Stop(Seconds(10.0));
     Simulator::Run();
 
-    for (DeviceEnergyModelContainer::Iterator iter = deviceModels.Begin();
-         iter != deviceModels.End();
-         iter++)
+    for (auto iter = deviceModels.Begin(); iter != deviceModels.End(); iter++)
     {
         double energyConsumed = (*iter)->GetTotalEnergyConsumption();
         NS_LOG_UNCOND("End of simulation ("
