@@ -217,7 +217,7 @@ main(int argc, char* argv[])
     if (!outputValidated)
     {
         std::cerr << "Program internal checking failed; returning with error" << std::endl;
-        return (1);
+        return 1;
     }
 
     return 0;
