@@ -210,10 +210,9 @@ main(int argc, char* argv[])
     Simulator::Schedule(Seconds(14), &Ipv4::SetUp, ipv41, ipv4ifIndex1);
 
     // Trace routing tables
-    Ipv4GlobalRoutingHelper g;
     Ptr<OutputStreamWrapper> routingStream =
         Create<OutputStreamWrapper>("dynamic-global-routing.routes", std::ios::out);
-    g.PrintRoutingTableAllAt(Seconds(12), routingStream);
+    Ipv4RoutingHelper::PrintRoutingTableAllAt(Seconds(12), routingStream);
 
     NS_LOG_INFO("Run Simulation.");
     Simulator::Run();
