@@ -28,6 +28,7 @@
 #include "ns3/ssid.h"
 #include "ns3/string.h"
 #include "ns3/udp-client-server-helper.h"
+#include "ns3/udp-server.h"
 #include "ns3/wifi-mac.h"
 #include "ns3/wifi-net-device.h"
 #include "ns3/yans-wifi-channel.h"
@@ -96,8 +97,8 @@ main(int argc, char* argv[])
     uint32_t payloadSize = 1472; // bytes
     double simulationTime = 10;  // seconds
     double distance = 5;         // meters
-    bool enablePcap = 0;
-    bool verifyResults = 0; // used for regression
+    bool enablePcap = false;
+    bool verifyResults = false; // used for regression
     Time txopLimit = MicroSeconds(4096);
 
     CommandLine cmd(__FILE__);
