@@ -32,6 +32,7 @@
 #include "ns3/ssid.h"
 #include "ns3/string.h"
 #include "ns3/udp-client-server-helper.h"
+#include "ns3/udp-server.h"
 #include "ns3/wifi-mac.h"
 #include "ns3/wifi-net-device.h"
 #include "ns3/yans-wifi-channel.h"
@@ -370,7 +371,7 @@ main(int argc, char* argv[])
     params.payloadSize = 1472;  // bytes
     params.simulationTime = 10; // seconds
 
-    bool verifyResults = 0; // used for regression
+    bool verifyResults = false; // used for regression
 
     CommandLine cmd(__FILE__);
     cmd.AddValue("payloadSize", "Payload size in bytes", params.payloadSize);
