@@ -116,7 +116,7 @@ class Experiment
      */
     bool IsRouting() const
     {
-        return (m_enableRouting == 1) ? 1 : 0;
+        return m_enableRouting;
     }
 
     /**
@@ -126,7 +126,7 @@ class Experiment
      */
     bool IsMobility() const
     {
-        return (m_enableMobility == 1) ? 1 : 0;
+        return m_enableMobility;
     }
 
     /**
@@ -239,7 +239,7 @@ class Experiment
     uint32_t m_gridSize;     //!< Grid size.
     uint32_t m_nodeDistance; //!< Node distance.
     uint32_t m_port;         //!< Listening port.
-    uint32_t m_scenario;     //!< Scnario number.
+    uint32_t m_scenario;     //!< Scenario number.
 
     bool m_enablePcap;     //!< True if PCAP output is enabled.
     bool m_enableTracing;  //!< True if tracing output is enabled.
