@@ -30,6 +30,7 @@
 #include "ns3/ssid.h"
 #include "ns3/string.h"
 #include "ns3/udp-client-server-helper.h"
+#include "ns3/udp-server.h"
 #include "ns3/uinteger.h"
 #include "ns3/wifi-mac.h"
 #include "ns3/wifi-net-device.h"
@@ -111,9 +112,9 @@ main(int argc, char* argv[])
     double simulationTime = 10;  // seconds
     double txopLimit = 3520;     // microseconds
     double distance = 5;         // meters
-    bool enableRts = 0;
-    bool enablePcap = 0;
-    bool verifyResults = 0; // used for regression
+    bool enableRts = false;
+    bool enablePcap = false;
+    bool verifyResults = false; // used for regression
 
     CommandLine cmd(__FILE__);
     cmd.AddValue("payloadSize", "Payload size in bytes", payloadSize);
