@@ -32,6 +32,7 @@
 #include "ns3/ssid.h"
 #include "ns3/string.h"
 #include "ns3/udp-client-server-helper.h"
+#include "ns3/udp-server.h"
 #include "ns3/uinteger.h"
 #include "ns3/vht-phy.h"
 #include "ns3/yans-wifi-channel.h"
@@ -117,7 +118,7 @@ main(int argc, char* argv[])
                 channelWidth *= 2;
                 continue;
             }
-            for (int sgi = 0; sgi < 2; sgi++)
+            for (auto sgi : {false, true})
             {
                 uint32_t payloadSize; // 1500 byte IP packet
                 if (udp)
@@ -265,11 +266,11 @@ main(int argc, char* argv[])
 
                 Simulator::Destroy();
 
-                std::cout << mcs << "\t\t\t" << channelWidth << " MHz\t\t\t" << sgi << "\t\t\t"
-                          << throughput << " Mbit/s" << std::endl;
+                std::cout << mcs << "\t\t\t" << channelWidth << " MHz\t\t\t" << std::boolalpha
+                          << sgi << "\t\t\t" << throughput << " Mbit/s" << std::endl;
 
                 // test first element
-                if (mcs == 0 && channelWidth == 20 && sgi == 0)
+                if (mcs == 0 && channelWidth == 20 && !sgi)
                 {
                     if (throughput < minExpectedThroughput)
                     {
@@ -278,7 +279,7 @@ main(int argc, char* argv[])
                     }
                 }
                 // test last element
-                if (mcs == 9 && channelWidth == 160 && sgi == 1)
+                if (mcs == 9 && channelWidth == 160 && sgi)
                 {
                     if (maxExpectedThroughput > 0 && throughput > maxExpectedThroughput)
                     {
