@@ -20,7 +20,8 @@
 #ifndef ISOTROPIC_ANTENNA_MODEL_H
 #define ISOTROPIC_ANTENNA_MODEL_H
 
-#include <ns3/antenna-model.h>
+#include "antenna-model.h"
+
 #include <ns3/object.h>
 
 namespace ns3
