@@ -18,7 +18,8 @@
 #ifndef THREE_GPP_ANTENNA_MODEL_H
 #define THREE_GPP_ANTENNA_MODEL_H
 
-#include <ns3/antenna-model.h>
+#include "antenna-model.h"
+
 #include <ns3/object.h>
 
 namespace ns3
