@@ -134,6 +134,156 @@ TwoVectorsConstructorTestCase::DoRun()
     NS_TEST_EXPECT_MSG_EQ_TOL(a.GetInclination(), m_a.GetInclination(), 1e-10, "incorrect theta");
 }
 
+using WrapToRangeFunction = std::function<double(double)>;
+
+/**
+ * \ingroup tests
+ *
+ * \brief  Test bounds for various WrapTo... methods (WrapTo180, WrapTo360, WrapToPi, and WrapTo2Pi)
+ * by using a std::function wrapper
+ */
+class WrapToRangeTestCase : public TestCase
+{
+  public:
+    /**
+     * Build the test name
+     * \param lowerBound the lower bound of the WrapTo... function
+     * \param upperBound the upper bound of the WrapTo... function
+     * \return the test name
+     */
+    static std::string BuildNameString(double lowerBound, double upperBound);
+    /**
+     * Constructor
+     * \param wrapper for one of WrapTo180, WrapTo360, WrapToPi, and WrapTo2Pi
+     * \param lowerBound the corresponding lower bound
+     * \param upperBound the corresponding upper bound
+     */
+    WrapToRangeTestCase(WrapToRangeFunction wrapper, double lowerBound, double upperBound);
+
+  protected:
+    /**
+     * The given wrapper shall wrap an angle into the expected range
+     * \param wrapPoint an angle
+     */
+    void CheckWrappingPoint(double wrapPoint);
+
+  private:
+    void DoRun() override;
+
+    WrapToRangeFunction m_wrapper; //!< the wrapper function
+    double m_lowerBound;           //!< the corresponding lower bound
+    double m_upperBound;           //!< the corresponding upper bound
+};
+
+std::string
+WrapToRangeTestCase::BuildNameString(double lowerBound, double upperBound)
+{
+    std::ostringstream oss;
+    oss << "WrapTo [" << lowerBound << ", " << upperBound << ")";
+    return oss.str();
+}
+
+WrapToRangeTestCase::WrapToRangeTestCase(WrapToRangeFunction wrapper,
+                                         double lowerBound,
+                                         double upperBound)
+    : TestCase(BuildNameString(lowerBound, upperBound)),
+      m_wrapper(wrapper),
+      m_lowerBound(lowerBound),
+      m_upperBound(upperBound)
+{
+}
+
+void
+WrapToRangeTestCase::DoRun()
+{
+    CheckWrappingPoint(m_lowerBound);
+    CheckWrappingPoint(m_upperBound);
+}
+
+void
+WrapToRangeTestCase::CheckWrappingPoint(double wrapPoint)
+{
+    constexpr int STEP_NUM = 100;
+    double directions[] = {std::numeric_limits<double>::lowest(),
+                           std::numeric_limits<double>::max()};
+    for (double dir : directions)
+    {
+        int i = 0;
+        for (double x = wrapPoint; i < STEP_NUM; x = std::nextafter(x, dir), ++i)
+        {
+            // If asserts are enabled, this test will crash with an assert instead of failing
+            double result = m_wrapper(x);
+            NS_TEST_EXPECT_MSG_EQ((m_lowerBound <= result),
+                                  true,
+                                  "Invalid wrap (too low) " << x << " maps to " << result << " and "
+                                                            << result - m_lowerBound);
+            NS_TEST_EXPECT_MSG_EQ((result < m_upperBound),
+                                  true,
+                                  "Invalid wrap (too high) " << x << " maps to " << result
+                                                             << " and " << result - m_lowerBound);
+        }
+    }
+}
+
+/**
+ * \ingroup tests
+ *
+ * \brief Test the output for WrapToRangeFunction
+ */
+class WrapToRangeFunctionalTestCase : public TestCase
+{
+  public:
+    /**
+     * Build the test name
+     * \param angle the angle
+     * \param wrappedAngle the expected result
+     * \return the test name
+     */
+    static std::string BuildNameString(double angle, double wrappedAngle);
+    /**
+     * Constructor
+     * \param wrapper one WrapToRangeFunction
+     * \param angle the angle
+     * \param wrappedAngle the expected result
+     */
+    WrapToRangeFunctionalTestCase(WrapToRangeFunction wrapper, double angle, double wrappedAngle);
+
+  private:
+    void DoRun() override;
+
+    WrapToRangeFunction m_wrapper; //!< the wrapper function
+    double m_angle;                //!< the input angle
+    double m_wrappedAngle;         //!< the expected wrapper angle
+};
+
+std::string
+WrapToRangeFunctionalTestCase::BuildNameString(double angle, double wrappedAngle)
+{
+    std::ostringstream oss;
+    oss << "Wrap " << angle << " to " << wrappedAngle;
+    return oss.str();
+}
+
+WrapToRangeFunctionalTestCase::WrapToRangeFunctionalTestCase(WrapToRangeFunction wrapper,
+                                                             double angle,
+                                                             double wrappedAngle)
+    : TestCase(BuildNameString(angle, wrappedAngle)),
+      m_wrapper(wrapper),
+      m_angle(angle),
+      m_wrappedAngle(wrappedAngle)
+{
+}
+
+void
+WrapToRangeFunctionalTestCase::DoRun()
+{
+    NS_TEST_EXPECT_MSG_EQ_TOL(m_wrapper(m_angle),
+                              m_wrappedAngle,
+                              1e-6,
+                              "Invalid wrap " << m_angle << " wrapped to " << m_wrapper(m_angle)
+                                              << " instead of " << m_wrappedAngle);
+}
+
 /**
  * \ingroup tests
  *
@@ -355,6 +505,18 @@ AnglesTestSuite::AnglesTestSuite()
                                                   Vector(-0.5, 12.45, -1),
                                                   Angles(-M_PI_4, M_PI_4)),
                 TestCase::QUICK);
+    AddTestCase(new WrapToRangeTestCase(WrapTo180, -180, 180), TestCase::QUICK);
+    AddTestCase(new WrapToRangeTestCase(WrapToPi, -M_PI, M_PI), TestCase::QUICK);
+    AddTestCase(new WrapToRangeTestCase(WrapTo360, 0, 360), TestCase::QUICK);
+    AddTestCase(new WrapToRangeTestCase(WrapTo2Pi, 0, 2 * M_PI), TestCase::QUICK);
+    AddTestCase(new WrapToRangeFunctionalTestCase(WrapTo180, -182.2, 177.8), TestCase::QUICK);
+    AddTestCase(new WrapToRangeFunctionalTestCase(WrapTo180, -179, -179), TestCase::QUICK);
+    AddTestCase(new WrapToRangeFunctionalTestCase(WrapTo180, 181, -179), TestCase::QUICK);
+    AddTestCase(new WrapToRangeFunctionalTestCase(WrapTo180, 360.6, 0.6), TestCase::QUICK);
+    AddTestCase(new WrapToRangeFunctionalTestCase(WrapTo360, -182.8, 177.2), TestCase::QUICK);
+    AddTestCase(new WrapToRangeFunctionalTestCase(WrapTo360, -179, 181), TestCase::QUICK);
+    AddTestCase(new WrapToRangeFunctionalTestCase(WrapTo360, 181, 181), TestCase::QUICK);
+    AddTestCase(new WrapToRangeFunctionalTestCase(WrapTo360, 360.2, 0.2), TestCase::QUICK);
 }
 
 /// Static variable for test initialization
