@@ -153,11 +153,9 @@ UniformPlanarArrayTestCase::ComputeGain(Ptr<UniformPlanarArray> a)
 {
     // compute gain
     PhasedArrayModel::ComplexVector sv = a->GetSteeringVector(m_direction);
-    NS_TEST_EXPECT_MSG_EQ(sv.GetSize(), a->GetNumberOfElements(), "steering vector of wrong size");
+    NS_TEST_EXPECT_MSG_EQ(sv.GetSize(), a->GetNumElems(), "steering vector of wrong size");
     PhasedArrayModel::ComplexVector bf = a->GetBeamformingVector(m_direction);
-    NS_TEST_EXPECT_MSG_EQ(bf.GetSize(),
-                          a->GetNumberOfElements(),
-                          "beamforming vector of wrong size");
+    NS_TEST_EXPECT_MSG_EQ(bf.GetSize(), a->GetNumElems(), "beamforming vector of wrong size");
     std::pair<double, double> fp = a->GetElementFieldPattern(m_direction);
 
     // scalar product dot (sv, bf)
