@@ -362,15 +362,12 @@ void
 RoutingProtocol::DoDispose()
 {
     m_ipv4 = nullptr;
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::iterator iter = m_socketAddresses.begin();
-         iter != m_socketAddresses.end();
-         iter++)
+    for (auto iter = m_socketAddresses.begin(); iter != m_socketAddresses.end(); iter++)
     {
         iter->first->Close();
     }
     m_socketAddresses.clear();
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::iterator iter =
-             m_socketSubnetBroadcastAddresses.begin();
+    for (auto iter = m_socketSubnetBroadcastAddresses.begin();
          iter != m_socketSubnetBroadcastAddresses.end();
          iter++)
     {
@@ -541,9 +538,7 @@ RoutingProtocol::RouteInput(Ptr<const Packet> p,
     }
 
     // Broadcast local delivery/forwarding
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
-         j != m_socketAddresses.end();
-         ++j)
+    for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
     {
         Ipv4InterfaceAddress iface = j->second;
         if (m_ipv4->GetInterfaceForAddress(iface.GetLocal()) == iif)
@@ -984,9 +979,7 @@ bool
 RoutingProtocol::IsMyOwnAddress(Ipv4Address src)
 {
     NS_LOG_FUNCTION(this << src);
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
-         j != m_socketAddresses.end();
-         ++j)
+    for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
     {
         Ipv4InterfaceAddress iface = j->second;
         if (src == iface.GetLocal())
@@ -1020,7 +1013,7 @@ RoutingProtocol::LoopbackRoute(const Ipv4Header& hdr, Ptr<NetDevice> oif) const
     // If RouteOutput() caller specified an outgoing interface, that
     // further constrains the selection of source address
     //
-    std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
+    auto j = m_socketAddresses.begin();
     if (oif)
     {
         // Iterate to find an address on the oif device
@@ -1136,9 +1129,7 @@ RoutingProtocol::SendRequest(Ipv4Address dst)
     rreqHeader.SetId(m_requestId);
 
     // Send RREQ as subnet directed broadcast from each interface used by aodv
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
-         j != m_socketAddresses.end();
-         ++j)
+    for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
     {
         Ptr<Socket> socket = j->first;
         Ipv4InterfaceAddress iface = j->second;
@@ -1388,7 +1379,7 @@ RoutingProtocol::RecvRequest(Ptr<Packet> p, Ipv4Address receiver, Ipv4Address sr
             /*iface=*/m_ipv4->GetAddress(m_ipv4->GetInterfaceForAddress(receiver), 0),
             /*hops=*/hop,
             /*nextHop=*/src,
-            /*lifetime=*/Time((2 * m_netTraversalTime - 2 * hop * m_nodeTraversalTime)));
+            /*lifetime=*/Time(2 * m_netTraversalTime - 2 * hop * m_nodeTraversalTime));
         m_routingTable.AddRoute(newEntry);
     }
     else
@@ -1505,9 +1496,7 @@ RoutingProtocol::RecvRequest(Ptr<Packet> p, Ipv4Address receiver, Ipv4Address sr
         return;
     }
 
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
-         j != m_socketAddresses.end();
-         ++j)
+    for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
     {
         Ptr<Socket> socket = j->first;
         Ipv4InterfaceAddress iface = j->second;
@@ -1868,9 +1857,7 @@ RoutingProtocol::RecvError(Ptr<Packet> p, Ipv4Address src)
     std::pair<Ipv4Address, uint32_t> un;
     while (rerrHeader.RemoveUnDestination(un))
     {
-        for (std::map<Ipv4Address, uint32_t>::const_iterator i = dstWithNextHopSrc.begin();
-             i != dstWithNextHopSrc.end();
-             ++i)
+        for (auto i = dstWithNextHopSrc.begin(); i != dstWithNextHopSrc.end(); ++i)
         {
             if (i->first == un.first)
             {
@@ -1880,8 +1867,7 @@ RoutingProtocol::RecvError(Ptr<Packet> p, Ipv4Address src)
     }
 
     std::vector<Ipv4Address> precursors;
-    for (std::map<Ipv4Address, uint32_t>::const_iterator i = unreachable.begin();
-         i != unreachable.end();)
+    for (auto i = unreachable.begin(); i != unreachable.end();)
     {
         if (!rerrHeader.AddUnDestination(i->first, i->second))
         {
@@ -2013,9 +1999,7 @@ RoutingProtocol::SendHello()
      *   Hop Count                      0
      *   Lifetime                       AllowedHelloLoss * HelloInterval
      */
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
-         j != m_socketAddresses.end();
-         ++j)
+    for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
     {
         Ptr<Socket> socket = j->first;
         Ipv4InterfaceAddress iface = j->second;
@@ -2087,8 +2071,7 @@ RoutingProtocol::SendRerrWhenBreaksLinkToNextHop(Ipv4Address nextHop)
     toNextHop.GetPrecursors(precursors);
     rerrHeader.AddUnDestination(nextHop, toNextHop.GetSeqNo());
     m_routingTable.GetListOfDestinationWithNextHop(nextHop, unreachable);
-    for (std::map<Ipv4Address, uint32_t>::const_iterator i = unreachable.begin();
-         i != unreachable.end();)
+    for (auto i = unreachable.begin(); i != unreachable.end();)
     {
         if (!rerrHeader.AddUnDestination(i->first, i->second))
         {
@@ -2161,10 +2144,7 @@ RoutingProtocol::SendRerrWhenNoRouteToForward(Ipv4Address dst,
     }
     else
     {
-        for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator i =
-                 m_socketAddresses.begin();
-             i != m_socketAddresses.end();
-             ++i)
+        for (auto i = m_socketAddresses.begin(); i != m_socketAddresses.end(); ++i)
         {
             Ptr<Socket> socket = i->first;
             Ipv4InterfaceAddress iface = i->second;
@@ -2232,8 +2212,7 @@ RoutingProtocol::SendRerrMessage(Ptr<Packet> packet, std::vector<Ipv4Address> pr
     //  route
     std::vector<Ipv4InterfaceAddress> ifaces;
     RoutingTableEntry toPrecursor;
-    for (std::vector<Ipv4Address>::const_iterator i = precursors.begin(); i != precursors.end();
-         ++i)
+    for (auto i = precursors.begin(); i != precursors.end(); ++i)
     {
         if (m_routingTable.LookupValidRoute(*i, toPrecursor) &&
             std::find(ifaces.begin(), ifaces.end(), toPrecursor.GetInterface()) == ifaces.end())
@@ -2242,8 +2221,7 @@ RoutingProtocol::SendRerrMessage(Ptr<Packet> packet, std::vector<Ipv4Address> pr
         }
     }
 
-    for (std::vector<Ipv4InterfaceAddress>::const_iterator i = ifaces.begin(); i != ifaces.end();
-         ++i)
+    for (auto i = ifaces.begin(); i != ifaces.end(); ++i)
     {
         Ptr<Socket> socket = FindSocketWithInterfaceAddress(*i);
         NS_ASSERT(socket);
@@ -2273,9 +2251,7 @@ Ptr<Socket>
 RoutingProtocol::FindSocketWithInterfaceAddress(Ipv4InterfaceAddress addr) const
 {
     NS_LOG_FUNCTION(this << addr);
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
-         j != m_socketAddresses.end();
-         ++j)
+    for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
     {
         Ptr<Socket> socket = j->first;
         Ipv4InterfaceAddress iface = j->second;
@@ -2292,8 +2268,7 @@ Ptr<Socket>
 RoutingProtocol::FindSubnetBroadcastSocketWithInterfaceAddress(Ipv4InterfaceAddress addr) const
 {
     NS_LOG_FUNCTION(this << addr);
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j =
-             m_socketSubnetBroadcastAddresses.begin();
+    for (auto j = m_socketSubnetBroadcastAddresses.begin();
          j != m_socketSubnetBroadcastAddresses.end();
          ++j)
     {
