@@ -20,6 +20,8 @@
 
 #include "three-gpp-http-client.h"
 
+#include "three-gpp-http-variables.h"
+
 #include <ns3/callback.h>
 #include <ns3/double.h>
 #include <ns3/inet-socket-address.h>
@@ -30,7 +32,6 @@
 #include <ns3/simulator.h>
 #include <ns3/socket.h>
 #include <ns3/tcp-socket-factory.h>
-#include <ns3/three-gpp-http-variables.h>
 #include <ns3/uinteger.h>
 
 NS_LOG_COMPONENT_DEFINE("ThreeGppHttpClient");
