@@ -80,8 +80,7 @@ void
 BridgeNetDevice::DoDispose()
 {
     NS_LOG_FUNCTION_NOARGS();
-    for (std::vector<Ptr<NetDevice>>::iterator iter = m_ports.begin(); iter != m_ports.end();
-         iter++)
+    for (auto iter = m_ports.begin(); iter != m_ports.end(); iter++)
     {
         *iter = nullptr;
     }
@@ -163,8 +162,7 @@ BridgeNetDevice::ForwardUnicast(Ptr<NetDevice> incomingPort,
     else
     {
         NS_LOG_LOGIC("No learned state: send through all ports");
-        for (std::vector<Ptr<NetDevice>>::iterator iter = m_ports.begin(); iter != m_ports.end();
-             iter++)
+        for (auto iter = m_ports.begin(); iter != m_ports.end(); iter++)
         {
             Ptr<NetDevice> port = *iter;
             if (port != incomingPort)
@@ -193,8 +191,7 @@ BridgeNetDevice::ForwardBroadcast(Ptr<NetDevice> incomingPort,
                  << ", protocol=" << protocol << ", src=" << src << ", dst=" << dst << ")");
     Learn(src, incomingPort);
 
-    for (std::vector<Ptr<NetDevice>>::iterator iter = m_ports.begin(); iter != m_ports.end();
-         iter++)
+    for (auto iter = m_ports.begin(); iter != m_ports.end(); iter++)
     {
         Ptr<NetDevice> port = *iter;
         if (port != incomingPort)
@@ -227,7 +224,7 @@ BridgeNetDevice::GetLearnedState(Mac48Address source)
     if (m_enableLearning)
     {
         Time now = Simulator::Now();
-        std::map<Mac48Address, LearnedState>::iterator iter = m_learnState.find(source);
+        auto iter = m_learnState.find(source);
         if (iter != m_learnState.end())
         {
             LearnedState& state = iter->second;
@@ -420,8 +417,7 @@ BridgeNetDevice::SendFrom(Ptr<Packet> packet,
     // data was not unicast or no state has been learned for that mac
     // address => flood through all ports.
     Ptr<Packet> pktCopy;
-    for (std::vector<Ptr<NetDevice>>::iterator iter = m_ports.begin(); iter != m_ports.end();
-         iter++)
+    for (auto iter = m_ports.begin(); iter != m_ports.end(); iter++)
     {
         pktCopy = packet->Copy();
         Ptr<NetDevice> port = *iter;
