@@ -22,7 +22,8 @@
 #ifndef BUILDING_ALLOCATOR_H
 #define BUILDING_ALLOCATOR_H
 
-#include "ns3/building-container.h"
+#include "building-container.h"
+
 #include "ns3/object-factory.h"
 #include "ns3/object.h"
 #include "ns3/position-allocator.h"
