@@ -20,8 +20,9 @@
  */
 #include "random-walk-2d-outdoor-mobility-model.h"
 
-#include "ns3/building-list.h"
-#include "ns3/building.h"
+#include "building-list.h"
+#include "building.h"
+
 #include "ns3/double.h"
 #include "ns3/enum.h"
 #include "ns3/log.h"
@@ -31,6 +32,7 @@
 #include "ns3/uinteger.h"
 
 #include <cmath>
+#include <limits>
 
 namespace ns3
 {
@@ -66,7 +68,7 @@ RandomWalk2dOutdoorMobilityModel::GetTypeId()
                           "The mode indicates the condition used to "
                           "change the current speed and direction",
                           EnumValue(RandomWalk2dOutdoorMobilityModel::MODE_DISTANCE),
-                          MakeEnumAccessor(&RandomWalk2dOutdoorMobilityModel::m_mode),
+                          MakeEnumAccessor<Mode>(&RandomWalk2dOutdoorMobilityModel::m_mode),
                           MakeEnumChecker(RandomWalk2dOutdoorMobilityModel::MODE_DISTANCE,
                                           "Distance",
                                           RandomWalk2dOutdoorMobilityModel::MODE_TIME,
@@ -132,6 +134,11 @@ RandomWalk2dOutdoorMobilityModel::DoInitializePrivate()
 void
 RandomWalk2dOutdoorMobilityModel::DoWalk(Time delayLeft)
 {
+    if (delayLeft.IsNegative())
+    {
+        NS_LOG_INFO(this << " Ran out of time");
+        return;
+    }
     NS_LOG_FUNCTION(this << delayLeft.GetSeconds());
 
     Vector position = m_helper.GetCurrentPosition();
@@ -160,7 +167,18 @@ RandomWalk2dOutdoorMobilityModel::DoWalk(Time delayLeft)
             NS_LOG_LOGIC("NextPosition would lead into a building");
             nextPosition =
                 CalculateIntersectionFromOutside(position, nextPosition, building->GetBoundaries());
-            Time delay = Seconds((nextPosition.x - position.x) / speed.x);
+
+            double delaySecondsX = std::numeric_limits<double>::max();
+            double delaySecondsY = std::numeric_limits<double>::max();
+            if (speed.x != 0)
+            {
+                delaySecondsX = std::abs((nextPosition.x - position.x) / speed.x);
+            }
+            if (speed.y != 0)
+            {
+                delaySecondsY = std::abs((nextPosition.y - position.y) / speed.y);
+            }
+            Time delay = Seconds(std::min(delaySecondsX, delaySecondsY));
             m_event = Simulator::Schedule(delay,
                                           &RandomWalk2dOutdoorMobilityModel::AvoidBuilding,
                                           this,
@@ -179,7 +197,24 @@ RandomWalk2dOutdoorMobilityModel::DoWalk(Time delayLeft)
 
         if (outdoor)
         {
-            Time delay = Seconds((nextPosition.x - position.x) / speed.x);
+            double delaySeconds = std::numeric_limits<double>::max();
+            if (speed.x != 0)
+            {
+                delaySeconds =
+                    std::min(delaySeconds, std::abs((nextPosition.x - position.x) / speed.x));
+            }
+            else if (speed.y != 0)
+            {
+                delaySeconds =
+                    std::min(delaySeconds, std::abs((nextPosition.y - position.y) / speed.y));
+            }
+            else
+            {
+                NS_ABORT_MSG("RandomWalk2dOutdoorMobilityModel::DoWalk: unable to calculate the "
+                             "rebound time "
+                             "(the node is stationary).");
+            }
+            Time delay = Seconds(delaySeconds);
             m_event = Simulator::Schedule(delay,
                                           &RandomWalk2dOutdoorMobilityModel::Rebound,
                                           this,
@@ -190,7 +225,28 @@ RandomWalk2dOutdoorMobilityModel::DoWalk(Time delayLeft)
             NS_LOG_LOGIC("NextPosition would lead into a building");
             nextPosition =
                 CalculateIntersectionFromOutside(position, nextPosition, building->GetBoundaries());
-            Time delay = Seconds((nextPosition.x - position.x) / speed.x);
+
+            double delaySecondsX = std::numeric_limits<double>::max();
+            double delaySecondsY = std::numeric_limits<double>::max();
+            if (speed.x != 0)
+            {
+                delaySecondsX =
+                    std::min(delaySecondsX, std::abs((nextPosition.x - position.x) / speed.x));
+            }
+            if (speed.y != 0)
+            {
+                delaySecondsY =
+                    std::min(delaySecondsY, std::abs((nextPosition.y - position.y) / speed.y));
+            }
+            if (delaySecondsX == std::numeric_limits<double>::max() &&
+                delaySecondsY == std::numeric_limits<double>::max())
+            {
+                NS_ABORT_MSG("RandomWalk2dOutdoorMobilityModel::DoWalk: unable to calculate the "
+                             "rebound time "
+                             "(the node is stationary).");
+            }
+
+            Time delay = Seconds(std::min(delaySecondsX, delaySecondsY));
             m_event = Simulator::Schedule(delay,
                                           &RandomWalk2dOutdoorMobilityModel::AvoidBuilding,
                                           this,
@@ -215,7 +271,7 @@ RandomWalk2dOutdoorMobilityModel::IsLineClearOfBuildings(Vector currentPosition,
     double minIntersectionDistance = std::numeric_limits<double>::max();
     Ptr<Building> minIntersectionDistanceBuilding;
 
-    for (BuildingList::Iterator bit = BuildingList::Begin(); bit != BuildingList::End(); ++bit)
+    for (auto bit = BuildingList::Begin(); bit != BuildingList::End(); ++bit)
     {
         // check if this building intersects the line between the current and next positions
         // this checks also if the next position is inside the building
@@ -250,44 +306,72 @@ RandomWalk2dOutdoorMobilityModel::CalculateIntersectionFromOutside(const Vector&
 
     // get the closest side
     Rectangle rect = Rectangle(boundaries.xMin, boundaries.xMax, boundaries.yMin, boundaries.yMax);
-    NS_LOG_INFO("rect " << rect);
-    Rectangle::Side closestSide = rect.GetClosestSide(current);
+    NS_LOG_DEBUG("rect " << rect);
+    Rectangle::Side closestSide = rect.GetClosestSideOrCorner(current);
 
     double xIntersect = 0;
     double yIntersect = 0;
 
     switch (closestSide)
     {
-    case Rectangle::RIGHT:
-        NS_LOG_INFO("The closest side is RIGHT");
-        NS_ABORT_MSG_IF(next.x - current.x == 0, "x position not updated");
+    case Rectangle::RIGHTSIDE:
+        NS_LOG_DEBUG("The closest side is RIGHT");
         xIntersect = boundaries.xMax + m_epsilon;
+        NS_ABORT_MSG_IF(next.x - current.x == 0, "x position not updated");
         yIntersect =
             (next.y - current.y) / (next.x - current.x) * (xIntersect - current.x) + current.y;
         break;
-    case Rectangle::LEFT:
-        NS_LOG_INFO("The closest side is LEFT");
+    case Rectangle::LEFTSIDE:
+        NS_LOG_DEBUG("The closest side is LEFT");
         xIntersect = boundaries.xMin - m_epsilon;
         NS_ABORT_MSG_IF(next.x - current.x == 0, "x position not updated");
         yIntersect =
             (next.y - current.y) / (next.x - current.x) * (xIntersect - current.x) + current.y;
         break;
-    case Rectangle::TOP:
-        NS_LOG_INFO("The closest side is TOP");
+    case Rectangle::TOPSIDE:
+        NS_LOG_DEBUG("The closest side is TOP");
         yIntersect = boundaries.yMax + m_epsilon;
         NS_ABORT_MSG_IF(next.y - current.y == 0, "y position not updated");
         xIntersect =
             (next.x - current.x) / (next.y - current.y) * (yIntersect - current.y) + current.x;
         break;
-    case Rectangle::BOTTOM:
-        NS_LOG_INFO("The closest side is BOTTOM");
+    case Rectangle::BOTTOMSIDE:
+        NS_LOG_DEBUG("The closest side is BOTTOM");
         yIntersect = boundaries.yMin - m_epsilon;
         NS_ABORT_MSG_IF(next.y - current.y == 0, "y position not updated");
         xIntersect =
             (next.x - current.x) / (next.y - current.y) * (yIntersect - current.y) + current.x;
         break;
+    case Rectangle::TOPRIGHTCORNER:
+        NS_LOG_DEBUG("The closest side is TOPRIGHT");
+        xIntersect = boundaries.xMax + m_epsilon;
+        NS_ABORT_MSG_IF(next.x - current.x == 0, "x position not updated");
+        yIntersect = boundaries.yMax + m_epsilon;
+        NS_ABORT_MSG_IF(next.y - current.y == 0, "y position not updated");
+        break;
+    case Rectangle::TOPLEFTCORNER:
+        NS_LOG_DEBUG("The closest side is TOPLEFT");
+        xIntersect = boundaries.xMin - m_epsilon;
+        NS_ABORT_MSG_IF(next.x - current.x == 0, "x position not updated");
+        yIntersect = boundaries.yMax + m_epsilon;
+        NS_ABORT_MSG_IF(next.y - current.y == 0, "y position not updated");
+        break;
+    case Rectangle::BOTTOMRIGHTCORNER:
+        NS_LOG_DEBUG("The closest side is BOTTOMRIGHT");
+        xIntersect = boundaries.xMax + m_epsilon;
+        NS_ABORT_MSG_IF(next.x - current.x == 0, "x position not updated");
+        yIntersect = boundaries.yMin - m_epsilon;
+        NS_ABORT_MSG_IF(next.y - current.y == 0, "y position not updated");
+        break;
+    case Rectangle::BOTTOMLEFTCORNER:
+        NS_LOG_DEBUG("The closest side is BOTTOMLEFT");
+        xIntersect = boundaries.xMin - m_epsilon;
+        NS_ABORT_MSG_IF(next.x - current.x == 0, "x position not updated");
+        yIntersect = boundaries.yMin - m_epsilon;
+        NS_ABORT_MSG_IF(next.y - current.y == 0, "y position not updated");
+        break;
     }
-    NS_LOG_INFO("xIntersect " << xIntersect << " yIntersect " << yIntersect);
+    NS_LOG_DEBUG("xIntersect " << xIntersect << " yIntersect " << yIntersect);
     return Vector(xIntersect, yIntersect, 0);
 }
 
@@ -298,20 +382,27 @@ RandomWalk2dOutdoorMobilityModel::Rebound(Time delayLeft)
     m_helper.UpdateWithBounds(m_bounds);
     Vector position = m_helper.GetCurrentPosition();
     Vector speed = m_helper.GetVelocity();
-    switch (m_bounds.GetClosestSide(position))
+    switch (m_bounds.GetClosestSideOrCorner(position))
     {
-    case Rectangle::RIGHT:
-        NS_LOG_INFO("The closest side is RIGHT");
-    case Rectangle::LEFT:
-        NS_LOG_INFO("The closest side is LEFT");
+    case Rectangle::RIGHTSIDE:
+    case Rectangle::LEFTSIDE:
+        NS_LOG_DEBUG("The closest side is RIGHT or LEFT");
         speed.x = -speed.x;
         break;
-    case Rectangle::TOP:
-        NS_LOG_INFO("The closest side is TOP");
-    case Rectangle::BOTTOM:
-        NS_LOG_INFO("The closest side is BOTTOM");
+    case Rectangle::TOPSIDE:
+    case Rectangle::BOTTOMSIDE:
+        NS_LOG_DEBUG("The closest side is TOP or BOTTOM");
         speed.y = -speed.y;
         break;
+    case Rectangle::TOPRIGHTCORNER:
+    case Rectangle::BOTTOMRIGHTCORNER:
+    case Rectangle::TOPLEFTCORNER:
+    case Rectangle::BOTTOMLEFTCORNER:
+        NS_LOG_DEBUG("The closest side is a corner");
+        auto temp = speed.x;
+        speed.x = -speed.y;
+        speed.y = -temp;
+        break;
     }
     m_helper.SetVelocity(speed);
     m_helper.Unpause();
