@@ -43,7 +43,6 @@ ReceivePacket(Ptr<Socket> socket)
 int
 main(int argc, char* argv[])
 {
-#ifdef NS3_CLICK
     std::string clickConfigFolder = "src/click/examples";
 
     CommandLine cmd(__FILE__);
@@ -104,9 +103,6 @@ main(int argc, char* argv[])
     Simulator::Run();
 
     Simulator::Destroy();
-#else
-    NS_FATAL_ERROR("Can't use ns-3-click without NSCLICK compiled in");
-#endif
 
     return 0;
 }
