@@ -227,8 +227,7 @@ AttributeIterator::DoIterate(Ptr<Object> object)
         for (uint32_t i = 0; i < tid.GetAttributeN(); ++i)
         {
             TypeId::AttributeInformation info = tid.GetAttribute(i);
-            const PointerChecker* ptrChecker =
-                dynamic_cast<const PointerChecker*>(PeekPointer(info.checker));
+            const auto ptrChecker = dynamic_cast<const PointerChecker*>(PeekPointer(info.checker));
             if (ptrChecker != nullptr)
             {
                 NS_LOG_DEBUG("pointer attribute " << info.name);
@@ -246,7 +245,7 @@ AttributeIterator::DoIterate(Ptr<Object> object)
                 continue;
             }
             // attempt to cast to an object container
-            const ObjectPtrContainerChecker* vectorChecker =
+            const auto vectorChecker =
                 dynamic_cast<const ObjectPtrContainerChecker*>(PeekPointer(info.checker));
             if (vectorChecker != nullptr)
             {
