@@ -271,7 +271,7 @@ void
 XmlConfigSave::Global()
 {
     int rc;
-    for (GlobalValue::Iterator i = GlobalValue::Begin(); i != GlobalValue::End(); ++i)
+    for (auto i = GlobalValue::Begin(); i != GlobalValue::End(); ++i)
     {
         StringValue value;
         (*i)->GetValue(value);
