@@ -20,8 +20,8 @@
 #ifndef ATTRIBUTE_CONTAINER_H
 #define ATTRIBUTE_CONTAINER_H
 
-#include <ns3/attribute-helper.h>
-#include <ns3/string.h>
+#include "attribute-helper.h"
+#include "string.h"
 
 #include <algorithm>
 #include <iterator>
