@@ -103,7 +103,7 @@ void
 MatchContainer::Set(std::string name, const AttributeValue& value)
 {
     NS_LOG_FUNCTION(this << name << &value);
-    for (Iterator tmp = Begin(); tmp != End(); ++tmp)
+    for (auto tmp = Begin(); tmp != End(); ++tmp)
     {
         Ptr<Object> object = *tmp;
         // Let ObjectBase::SetAttribute raise any errors
@@ -116,7 +116,7 @@ MatchContainer::SetFailSafe(std::string name, const AttributeValue& value)
 {
     NS_LOG_FUNCTION(this << name << &value);
     bool ok = false;
-    for (Iterator tmp = Begin(); tmp != End(); ++tmp)
+    for (auto tmp = Begin(); tmp != End(); ++tmp)
     {
         Ptr<Object> object = *tmp;
         ok |= object->SetAttributeFailSafe(name, value);
@@ -162,7 +162,7 @@ MatchContainer::ConnectWithoutContextFailSafe(std::string name, const CallbackBa
 {
     NS_LOG_FUNCTION(this << name << &cb);
     bool ok = false;
-    for (Iterator tmp = Begin(); tmp != End(); ++tmp)
+    for (auto tmp = Begin(); tmp != End(); ++tmp)
     {
         Ptr<Object> object = *tmp;
         ok |= object->TraceConnectWithoutContext(name, cb);
@@ -187,7 +187,7 @@ void
 MatchContainer::DisconnectWithoutContext(std::string name, const CallbackBase& cb)
 {
     NS_LOG_FUNCTION(this << name << &cb);
-    for (Iterator tmp = Begin(); tmp != End(); ++tmp)
+    for (auto tmp = Begin(); tmp != End(); ++tmp)
     {
         Ptr<Object> object = *tmp;
         object->TraceDisconnectWithoutContext(name, cb);
@@ -423,8 +423,7 @@ Resolver::GetResolvedPath() const
     NS_LOG_FUNCTION(this);
 
     std::string fullPath = "/";
-    for (std::vector<std::string>::const_iterator i = m_workStack.begin(); i != m_workStack.end();
-         i++)
+    for (auto i = m_workStack.begin(); i != m_workStack.end(); i++)
     {
         fullPath += *i + "/";
     }
@@ -549,7 +548,7 @@ Resolver::DoResolve(std::string path, Ptr<Object> root)
                     continue;
                 }
                 // attempt to cast to a pointer checker.
-                const PointerChecker* pChecker =
+                const auto pChecker =
                     dynamic_cast<const PointerChecker*>(PeekPointer(info.checker));
                 if (pChecker != nullptr)
                 {
@@ -572,7 +571,7 @@ Resolver::DoResolve(std::string path, Ptr<Object> root)
                     m_workStack.pop_back();
                 }
                 // attempt to cast to an object vector.
-                const ObjectPtrContainerChecker* vectorChecker =
+                const auto vectorChecker =
                     dynamic_cast<const ObjectPtrContainerChecker*>(PeekPointer(info.checker));
                 if (vectorChecker != nullptr)
                 {
@@ -801,7 +800,7 @@ ConfigImpl::LookupMatches(std::string path)
         std::vector<std::string> m_contexts;
     } resolver = LookupMatchesResolver(path);
 
-    for (Roots::const_iterator i = m_roots.begin(); i != m_roots.end(); i++)
+    for (auto i = m_roots.begin(); i != m_roots.end(); i++)
     {
         resolver.Resolve(*i);
     }
@@ -828,7 +827,7 @@ ConfigImpl::UnregisterRootNamespaceObject(Ptr<Object> obj)
 {
     NS_LOG_FUNCTION(this << obj);
 
-    for (std::vector<Ptr<Object>>::iterator i = m_roots.begin(); i != m_roots.end(); i++)
+    for (auto i = m_roots.begin(); i != m_roots.end(); i++)
     {
         if (*i == obj)
         {
@@ -867,7 +866,7 @@ Reset()
         }
     }
     // now, let's reset the initial value of every global value.
-    for (GlobalValue::Iterator i = GlobalValue::Begin(); i != GlobalValue::End(); ++i)
+    for (auto i = GlobalValue::Begin(); i != GlobalValue::End(); ++i)
     {
         (*i)->ResetInitialValue();
     }
