@@ -271,9 +271,10 @@ class Time
      * - `d`  (days)
      * - `y`  (years)
      *
-     * There can be no white space between the numerical portion
-     * and the units.  Any otherwise malformed string causes a fatal error to
-     * occur.
+     * There must be no whitespace between the numerical portion
+     * and the unit. If the string only contains a number, it is treated as seconds.
+     * Any otherwise malformed string causes a fatal error to occur.
+     *
      * \param [in] s The string to parse into a Time
      */
     explicit Time(const std::string& s);
@@ -580,7 +581,7 @@ class Time
 
         NS_ASSERT_MSG(info->isValid, "Attempted a conversion to an unavailable unit.");
 
-        int64x64_t retval = int64x64_t(m_data);
+        int64x64_t retval(m_data);
         if (info->toMul)
         {
             retval *= info->timeTo;
@@ -792,21 +793,15 @@ class Time
     friend Time Rem(const Time& lhs, const Time& rhs);
 
     template <class T>
-    friend typename std::enable_if<std::is_integral<T>::value, Time>::type operator*(
-        const Time& lhs,
-        T rhs);
+    friend std::enable_if_t<std::is_integral_v<T>, Time> operator*(const Time& lhs, T rhs);
 
     // Reversed arg version (forwards to `rhs * lhs`)
     // Accepts both integers and decimal types
     template <class T>
-    friend typename std::enable_if<std::is_arithmetic<T>::value, Time>::type operator*(
-        T lhs,
-        const Time& rhs);
+    friend std::enable_if_t<std::is_arithmetic_v<T>, Time> operator*(T lhs, const Time& rhs);
 
     template <class T>
-    friend typename std::enable_if<std::is_integral<T>::value, Time>::type operator/(
-        const Time& lhs,
-        T rhs);
+    friend std::enable_if_t<std::is_integral_v<T>, Time> operator/(const Time& lhs, T rhs);
 
     friend Time Abs(const Time& time);
     friend Time Max(const Time& timeA, const Time& timeB);
@@ -816,13 +811,9 @@ class Time
 
     // Leave undocumented
     template <class T>
-    friend typename std::enable_if<std::is_floating_point<T>::value, Time>::type operator*(
-        const Time& lhs,
-        T rhs);
+    friend std::enable_if_t<std::is_floating_point_v<T>, Time> operator*(const Time& lhs, T rhs);
     template <class T>
-    friend typename std::enable_if<std::is_floating_point<T>::value, Time>::type operator/(
-        const Time& lhs,
-        T rhs);
+    friend std::enable_if_t<std::is_floating_point_v<T>, Time> operator/(const Time& lhs, T rhs);
 
     /**
      * \name Compound assignment operators
@@ -1017,18 +1008,17 @@ operator*(const int64x64_t& lhs, const Time& rhs)
  * \returns A new Time instance containing the scaled value
  */
 template <class T>
-typename std::enable_if<std::is_integral<T>::value, Time>::type
+std::enable_if_t<std::is_integral_v<T>, Time>
 operator*(const Time& lhs, T rhs)
 {
-    static_assert(!std::is_same<T, bool>::value,
-                  "Multiplying a Time by a boolean is not supported");
+    static_assert(!std::is_same_v<T, bool>, "Multiplying a Time by a boolean is not supported");
 
     return Time(lhs.m_data * rhs);
 }
 
 // Leave undocumented
 template <class T>
-typename std::enable_if<std::is_floating_point<T>::value, Time>::type
+std::enable_if_t<std::is_floating_point_v<T>, Time>
 operator*(const Time& lhs, T rhs)
 {
     return lhs * int64x64_t(rhs);
@@ -1048,7 +1038,7 @@ operator*(const Time& lhs, T rhs)
  * \returns A new Time instance containing the scaled value
  */
 template <class T>
-typename std::enable_if<std::is_arithmetic<T>::value, Time>::type
+std::enable_if_t<std::is_arithmetic_v<T>, Time>
 operator*(T lhs, const Time& rhs)
 {
     return rhs * lhs;
@@ -1104,17 +1094,17 @@ operator/(const Time& lhs, const int64x64_t& rhs)
  * \returns A new Time instance containing the scaled value
  */
 template <class T>
-typename std::enable_if<std::is_integral<T>::value, Time>::type
+std::enable_if_t<std::is_integral_v<T>, Time>
 operator/(const Time& lhs, T rhs)
 {
-    static_assert(!std::is_same<T, bool>::value, "Dividing a Time by a boolean is not supported");
+    static_assert(!std::is_same_v<T, bool>, "Dividing a Time by a boolean is not supported");
 
     return Time(lhs.m_data / rhs);
 }
 
 // Leave undocumented
 template <class T>
-typename std::enable_if<std::is_floating_point<T>::value, Time>::type
+std::enable_if_t<std::is_floating_point_v<T>, Time>
 operator/(const Time& lhs, T rhs)
 {
     return lhs / int64x64_t(rhs);
