@@ -208,8 +208,8 @@ class ObjectPtrContainerChecker : public ns3::ObjectPtrContainerChecker
 
     bool Copy(const AttributeValue& source, AttributeValue& destination) const override
     {
-        const ObjectPtrContainerValue* src = dynamic_cast<const ObjectPtrContainerValue*>(&source);
-        ObjectPtrContainerValue* dst = dynamic_cast<ObjectPtrContainerValue*>(&destination);
+        const auto src = dynamic_cast<const ObjectPtrContainerValue*>(&source);
+        auto dst = dynamic_cast<ObjectPtrContainerValue*>(&destination);
         if (src == nullptr || dst == nullptr)
         {
             return false;
