@@ -18,6 +18,7 @@
  * Authors: Rajib Bhattacharjea<raj.b@gatech.edu>
  *          Hadi Arbabi<marbabi@cs.odu.edu>
  *          Mathieu Lacage <mathieu.lacage@gmail.com>
+ *          Alessio Bugetti <alessiobugetti98@gmail.com>
  *
  * Modified by Mitch Watrous <watrous@u.washington.edu>
  *
@@ -29,6 +30,7 @@
 #include "object.h"
 #include "type-id.h"
 
+#include <map>
 #include <stdint.h>
 
 /**
@@ -1983,7 +1985,6 @@ class EmpiricalRandomVariable : public RandomVariableStream
 
     /**
      * \brief Specifies a point in the empirical distribution
-     * \note These *MUST* be inserted in ascending order of \p c
      *
      * \param [in] v The function value for this point
      * \param [in] c Probability that the function is less than or equal to \p v
@@ -2018,26 +2019,6 @@ class EmpiricalRandomVariable : public RandomVariableStream
     bool SetInterpolate(bool interpolate);
 
   private:
-    /** \brief Helper to hold one point of the CDF. */
-    class ValueCDF
-    {
-      public:
-        /** \brief Constructor. */
-        ValueCDF();
-        /**
-         * \brief Construct from values.
-         *
-         * \param [in] v The argument value.
-         * \param [in] c The CDF at the argument value \pname{v}
-         */
-        ValueCDF(double v, double c);
-
-        /** The argument value. */
-        double value;
-        /** The CDF at \pname{value}  */
-        double cdf;
-    }; // class ValueCDF
-
     /**
      * \brief Check that the CDF is valid.
      *
@@ -2078,18 +2059,14 @@ class EmpiricalRandomVariable : public RandomVariableStream
      */
     double DoInterpolate(double r);
 
-    /**
-     * \brief Comparison operator, for use by std::upper_bound
-     * \param a [in] the first value
-     * \param b [in] the second value
-     * \returns \c true if \c a.cdf < \c b.cdf
-     */
-    friend bool operator<(ValueCDF a, ValueCDF b);
-
     /** \c true once the CDF has been validated. */
     bool m_validated;
-    /** The vector of CDF points. */
-    std::vector<ValueCDF> m_emp;
+    /**
+     * The map of CDF points (x, F(x)).
+     * The CDF points are stored in the std::map in reverse order, as follows:
+     * Key: CDF F(x) [0, 1] | Value: domain value (x) [-inf, inf].
+     */
+    std::map<double, double> m_empCdf;
     /**
      * If \c true GetValue will interpolate,
      * otherwise treat CDF as normal histogram.
@@ -2098,6 +2075,202 @@ class EmpiricalRandomVariable : public RandomVariableStream
 
 }; // class EmpiricalRandomVariable
 
+/**
+ * \ingroup randomvariable
+ * \brief The binomial distribution Random Number Generator (RNG).
+ *
+ * This class supports the creation of objects that return random numbers
+ * from a fixed binomial distribution. It also supports the generation of
+ * single random numbers from various binomial distributions.
+ *
+ * The probability mass function of a binomial variable
+ * is defined as:
+ *
+ *   \f[
+ *      P(k; n, p) = \binom{n}{k} p^k (1-p)^{n-k}, \\
+ *          \quad k \in [0, n]
+ *   \f]
+ *
+ * where \f$ n \f$ is the number of trials and \f$ p \f$ is the probability
+ * of success in each trial. The mean of this distribution
+ * is \f$ \mu = np \f$ and the variance is \f$ \sigma^2 = np(1-p) \f$.
+ *
+ * The Binomial RNG value \f$n\f$ for a given number of trials \f$ n \f$
+ * and success probability \f$ p \f$ is generated by
+ *
+ *   \f[
+ *    k = \sum_{i=1}^{n} I(u_i \leq p)
+ *   \f]
+ *
+ * where \f$u_i\f$ is a uniform random variable on [0,1) for each trial,
+ * and \f$I\f$ is an indicator function that is 1 if \f$u_i \leq p\f$ and 0 otherwise.
+ * The sum of these indicator functions over all trials gives the total
+ * number of successes, which is the value of the binomial random variable.
+ *
+ * \par Example
+ *
+ * Here is an example of how to use this class:
+ * \code{.cc}
+ *   uint32_t trials = 10;
+ *   double probability = 0.5;
+ *
+ *   Ptr<BinomialRandomVariable> x = CreateObject<BinomialRandomVariable> ();
+ *   x->SetAttribute ("Trials", UintegerValue (trials));
+ *   x->SetAttribute ("Probability", DoubleValue (probability));
+ *
+ *   double successes = x->GetValue ();
+ * \endcode
+ *
+ * \par Antithetic Values.
+ *
+ * If an instance of this RNG is configured to return antithetic values,
+ * the actual value returned, \f$n'\f$, for the Binomial process is determined by:
+ *
+ *   \f[
+ *      k' = \sum_{i=1}^{n} I((1 - u_i) \leq p)
+ *   \f]
+ *
+ * where \f$u_i\f$ is a uniform random variable on [0,1) for each trial.
+ * The antithetic approach uses \f$(1 - u_i)\f$ instead of \f$u_i\f$ in the indicator function.
+ *
+ * @par Efficiency and Alternative Methods
+ *
+ * There are alternative methods for generating binomial distributions that may offer greater
+ * efficiency. However, this implementation opts for a simpler approach. Although not as efficient,
+ * this method was chosen for its simplicity and sufficiency in most applications.
+ */
+class BinomialRandomVariable : public RandomVariableStream
+{
+  public:
+    /**
+     * \brief Register this type.
+     * \return The object TypeId.
+     */
+    static TypeId GetTypeId();
+
+    BinomialRandomVariable();
+
+    /**
+     * \copydoc GetValue()
+     * \param [in] trials Number of trials.
+     * \param [in] probability Probability of success in each trial.
+     * \return Returns a number within the range [0, trials] indicating the number of successful
+     * trials.
+     */
+    double GetValue(uint32_t trials, double probability);
+
+    /**
+     * \copydoc GetValue(uint32_t,double)
+     * This function is similar to GetValue(), but it returns a uint32_t instead of a double.
+     */
+    uint32_t GetInteger(uint32_t trials, uint32_t probability);
+
+    // Inherited
+    double GetValue() override;
+    using RandomVariableStream::GetInteger;
+
+  private:
+    /** The number of trials. */
+    uint32_t m_trials;
+
+    /** The probability of success in each trial. */
+    double m_probability;
+
+}; // class BinomialRandomVariable
+
+/**
+ * \ingroup randomvariable
+ * \brief The Bernoulli distribution Random Number Generator (RNG).
+ *
+ * This class supports the creation of objects that return random numbers
+ * from a fixed Bernoulli distribution. It also supports the generation of
+ * single random numbers from various Bernoulli distributions.
+ *
+ * The probability mass function of a Bernoulli variable
+ * is defined as:
+ *
+ *   \f[
+ *      P(n; p) = p^n (1-p)^{1-n}, \\
+ *          \quad n \in \{0, 1\}
+ *   \f]
+ *
+ * where \f$ p \f$ is the probability of success and n is the indicator of success, with n=1
+ * representing success and n=0 representing failure. The mean of this distribution is \f$ \mu = p
+ * \f$ and the variance is \f$ \sigma^2 = p(1-p) \f$.
+ *
+ * The Bernoulli RNG value \f$n\f$ is generated by
+ *
+ *   \f[
+ *    n =
+ *    \begin{cases}
+ *    1 & \text{if } u \leq p \\
+ *    0 & \text{otherwise}
+ *    \end{cases}
+ *   \f]
+ *
+ * where \f$u\f$ is a uniform random variable on [0,1) and \f$p\f$ is the probability of success.
+ *
+ * \par Example
+ *
+ * Here is an example of how to use this class:
+ * \code{.cc}
+ *   double probability = 0.5;
+ *
+ *   Ptr<BernoulliRandomVariable> x = CreateObject<BernoulliRandomVariable> ();
+ *   x->SetAttribute ("Probability", DoubleValue (probability));
+ *
+ *   double success = x->GetValue ();
+ * \endcode
+ *
+ * \par Antithetic Values.
+ *
+ * If an instance of this RNG is configured to return antithetic values,
+ * the actual value returned, \f$x'\f$, is determined by:
+ *
+ *   \f[
+ *      x' =
+ *      \begin{cases}
+ *      1 & \text{if } (1 - u) \leq p \\
+ *      0 & \text{otherwise}
+ *      \end{cases}
+ *   \f]
+ *
+ * where \f$u\f$ is a uniform random variable on [0,1) and \f$p\f$ is the probability of success.
+ */
+class BernoulliRandomVariable : public RandomVariableStream
+{
+  public:
+    /**
+     * \brief Register this type.
+     * \return The object TypeId.
+     */
+    static TypeId GetTypeId();
+
+    BernoulliRandomVariable();
+
+    /**
+     * \copydoc GetValue()
+     * \param [in] probability Probability of success.
+     * \return Returns 1 if the trial is successful, or 0 if it is not.
+     */
+    double GetValue(double probability);
+
+    /**
+     * \copydoc GetValue(double)
+     * This function is similar to GetValue(), but it returns a uint32_t instead of a double.
+     */
+    uint32_t GetInteger(uint32_t probability);
+
+    // Inherited
+    double GetValue() override;
+    using RandomVariableStream::GetInteger;
+
+  private:
+    /** The probability of success. */
+    double m_probability;
+
+}; // class BernoulliRandomVariable
+
 } // namespace ns3
 
 #endif /* RANDOM_VARIABLE_STREAM_H */
