@@ -61,7 +61,7 @@ class SimulatorImpl : public Object
     /** \copydoc Simulator::Stop() */
     virtual void Stop() = 0;
     /** \copydoc Simulator::Stop(const Time&) */
-    virtual void Stop(const Time& delay) = 0;
+    virtual EventId Stop(const Time& delay) = 0;
     /** \copydoc Simulator::Schedule(const Time&,const Ptr<EventImpl>&) */
     virtual EventId Schedule(const Time& delay, EventImpl* event) = 0;
     /** \copydoc Simulator::ScheduleWithContext(uint32_t,const Time&,EventImpl*) */
