@@ -22,6 +22,7 @@
 #include "attribute-helper.h"
 
 #include <string>
+#include <vector>
 
 /**
  * \file
@@ -32,6 +33,19 @@
 namespace ns3
 {
 
+/** Return type of SplitString. */
+using StringVector = std::vector<std::string>;
+
+/**
+ * Split a string on a delimiter.
+ * The input string is ummodified.
+ * \param [in] str The string.
+ * \param [in] delim The delimiter.
+ * \returns A vector of the components of \p str which were separated
+ * by \p delim.
+ */
+StringVector SplitString(const std::string& str, const std::string& delim);
+
 //  Additional docs for class StringValue:
 /**
  * Hold variables of type string
