@@ -97,7 +97,7 @@ class Backoff
     /**
      * \return True if the maximum number of retries has been reached
      */
-    bool MaxRetriesReached();
+    bool MaxRetriesReached() const;
 
     /**
      * Increments the number of retries by 1.
@@ -116,7 +116,7 @@ class Backoff
 
   private:
     /**
-     * Number of times that the transmitter has tried to unsuccessfully transmit the current packet.
+     * Number of times that the transmitter has tried to unsuccessfuly transmit the current packet.
      */
     uint32_t m_numBackoffRetries;
 
