@@ -241,9 +241,7 @@ void
 RoutingProtocol::DoDispose()
 {
     m_ipv4 = nullptr;
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::iterator iter = m_socketAddresses.begin();
-         iter != m_socketAddresses.end();
-         iter++)
+    for (auto iter = m_socketAddresses.begin(); iter != m_socketAddresses.end(); iter++)
     {
         iter->first->Close();
     }
@@ -304,9 +302,7 @@ RoutingProtocol::RouteOutput(Ptr<Packet> p,
                                  << ", Destination address in Packet: " << dst);
     RoutingTableEntry rt;
     m_routingTable.Purge(removedAddresses);
-    for (std::map<Ipv4Address, RoutingTableEntry>::iterator rmItr = removedAddresses.begin();
-         rmItr != removedAddresses.end();
-         ++rmItr)
+    for (auto rmItr = removedAddresses.begin(); rmItr != removedAddresses.end(); ++rmItr)
     {
         rmItr->second.SetEntriesChanged(true);
         rmItr->second.SetSeqNo(rmItr->second.GetSeqNo() + 1);
@@ -428,9 +424,7 @@ RoutingProtocol::RouteInput(Ptr<const Packet> p,
             return true;
         }
     }
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
-         j != m_socketAddresses.end();
-         ++j)
+    for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
     {
         Ipv4InterfaceAddress iface = j->second;
         if (origin == iface.GetLocal())
@@ -439,9 +433,7 @@ RoutingProtocol::RouteInput(Ptr<const Packet> p,
         }
     }
     // LOCAL DELIVARY TO DSDV INTERFACES
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
-         j != m_socketAddresses.end();
-         ++j)
+    for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
     {
         Ipv4InterfaceAddress iface = j->second;
         if (m_ipv4->GetInterfaceForAddress(iface.GetLocal()) == iif)
@@ -545,7 +537,7 @@ RoutingProtocol::LoopbackRoute(const Ipv4Header& hdr, Ptr<NetDevice> oif) const
     // If RouteOutput() caller specified an outgoing interface, that
     // further constrains the selection of source address
     //
-    std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
+    auto j = m_socketAddresses.begin();
     if (oif)
     {
         // Iterate to find an address on the oif device
@@ -592,10 +584,7 @@ RoutingProtocol::RecvDsdv(Ptr<Socket> socket)
         packet->RemoveHeader(dsdvHeader);
         NS_LOG_DEBUG("Processing new update for " << dsdvHeader.GetDst());
         /*Verifying if the packets sent by me were returned back to me. If yes, discarding them!*/
-        for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j =
-                 m_socketAddresses.begin();
-             j != m_socketAddresses.end();
-             ++j)
+        for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
         {
             Ipv4InterfaceAddress interface = j->second;
             if (dsdvHeader.GetDst() == interface.GetLocal())
@@ -661,9 +650,7 @@ RoutingProtocol::RecvDsdv(Ptr<Socket> socket)
                 RoutingTableEntry tr;
                 std::map<Ipv4Address, RoutingTableEntry> allRoutes;
                 m_advRoutingTable.GetListOfAllRoutes(allRoutes);
-                for (std::map<Ipv4Address, RoutingTableEntry>::const_iterator i = allRoutes.begin();
-                     i != allRoutes.end();
-                     ++i)
+                for (auto i = allRoutes.begin(); i != allRoutes.end(); ++i)
                 {
                     NS_LOG_DEBUG("ADV table routes are:" << i->second.GetDestination());
                 }
@@ -800,10 +787,7 @@ RoutingProtocol::RecvDsdv(Ptr<Socket> socket)
                     advTableEntry.SetSeqNo(dsdvHeader.GetDstSeqno());
                     advTableEntry.SetEntriesChanged(true);
                     m_advRoutingTable.Update(advTableEntry);
-                    for (std::map<Ipv4Address, RoutingTableEntry>::iterator i =
-                             dstsWithNextHopSrc.begin();
-                         i != dstsWithNextHopSrc.end();
-                         ++i)
+                    for (auto i = dstsWithNextHopSrc.begin(); i != dstsWithNextHopSrc.end(); ++i)
                     {
                         i->second.SetSeqNo(i->second.GetSeqNo() + 1);
                         i->second.SetEntriesChanged(true);
@@ -844,17 +828,13 @@ RoutingProtocol::SendTriggeredUpdate()
     NS_LOG_FUNCTION(m_mainAddress << " is sending a triggered update");
     std::map<Ipv4Address, RoutingTableEntry> allRoutes;
     m_advRoutingTable.GetListOfAllRoutes(allRoutes);
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
-         j != m_socketAddresses.end();
-         ++j)
+    for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
     {
         DsdvHeader dsdvHeader;
         Ptr<Socket> socket = j->first;
         Ipv4InterfaceAddress iface = j->second;
         Ptr<Packet> packet = Create<Packet>();
-        for (std::map<Ipv4Address, RoutingTableEntry>::const_iterator i = allRoutes.begin();
-             i != allRoutes.end();
-             ++i)
+        for (auto i = allRoutes.begin(); i != allRoutes.end(); ++i)
         {
             NS_LOG_LOGIC("Destination: " << i->second.GetDestination()
                                          << " SeqNo:" << i->second.GetSeqNo()
@@ -930,16 +910,12 @@ RoutingProtocol::SendPeriodicUpdate()
         return;
     }
     NS_LOG_FUNCTION(m_mainAddress << " is sending out its periodic update");
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
-         j != m_socketAddresses.end();
-         ++j)
+    for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
     {
         Ptr<Socket> socket = j->first;
         Ipv4InterfaceAddress iface = j->second;
         Ptr<Packet> packet = Create<Packet>();
-        for (std::map<Ipv4Address, RoutingTableEntry>::const_iterator i = allRoutes.begin();
-             i != allRoutes.end();
-             ++i)
+        for (auto i = allRoutes.begin(); i != allRoutes.end(); ++i)
         {
             DsdvHeader dsdvHeader;
             if (i->second.GetHop() == 0)
@@ -956,7 +932,7 @@ RoutingProtocol::SendPeriodicUpdate()
             else
             {
                 dsdvHeader.SetDst(i->second.GetDestination());
-                dsdvHeader.SetDstSeqno((i->second.GetSeqNo()));
+                dsdvHeader.SetDstSeqno(i->second.GetSeqNo());
                 dsdvHeader.SetHopCount(i->second.GetHop() + 1);
                 packet->AddHeader(dsdvHeader);
             }
@@ -966,10 +942,7 @@ RoutingProtocol::SendPeriodicUpdate()
                          << ", HopCount:" << dsdvHeader.GetHopCount()
                          << ", LifeTime: " << i->second.GetLifeTime().As(Time::S));
         }
-        for (std::map<Ipv4Address, RoutingTableEntry>::const_iterator rmItr =
-                 removedAddresses.begin();
-             rmItr != removedAddresses.end();
-             ++rmItr)
+        for (auto rmItr = removedAddresses.begin(); rmItr != removedAddresses.end(); ++rmItr)
         {
             DsdvHeader removedHeader;
             removedHeader.SetDst(rmItr->second.GetDestination());
@@ -1143,9 +1116,7 @@ RoutingProtocol::NotifyRemoveAddress(uint32_t i, Ipv4InterfaceAddress address)
 Ptr<Socket>
 RoutingProtocol::FindSocketWithInterfaceAddress(Ipv4InterfaceAddress addr) const
 {
-    for (std::map<Ptr<Socket>, Ipv4InterfaceAddress>::const_iterator j = m_socketAddresses.begin();
-         j != m_socketAddresses.end();
-         ++j)
+    for (auto j = m_socketAddresses.begin(); j != m_socketAddresses.end(); ++j)
     {
         Ptr<Socket> socket = j->first;
         Ipv4InterfaceAddress iface = j->second;
@@ -1181,9 +1152,7 @@ RoutingProtocol::LookForQueuedPackets()
     Ptr<Ipv4Route> route;
     std::map<Ipv4Address, RoutingTableEntry> allRoutes;
     m_routingTable.GetListOfAllRoutes(allRoutes);
-    for (std::map<Ipv4Address, RoutingTableEntry>::const_iterator i = allRoutes.begin();
-         i != allRoutes.end();
-         ++i)
+    for (auto i = allRoutes.begin(); i != allRoutes.end(); ++i)
     {
         RoutingTableEntry rt;
         rt = i->second;
@@ -1192,20 +1161,20 @@ RoutingProtocol::LookForQueuedPackets()
             if (rt.GetHop() == 1)
             {
                 route = rt.GetRoute();
+                NS_ASSERT(route);
                 NS_LOG_LOGIC("A route exists from " << route->GetSource()
                                                     << " to neighboring destination "
                                                     << route->GetDestination());
-                NS_ASSERT(route);
             }
             else
             {
                 RoutingTableEntry newrt;
                 m_routingTable.LookupRoute(rt.GetNextHop(), newrt);
                 route = newrt.GetRoute();
+                NS_ASSERT(route);
                 NS_LOG_LOGIC("A route exists from " << route->GetSource() << " to destination "
                                                     << route->GetDestination() << " via "
                                                     << rt.GetNextHop());
-                NS_ASSERT(route);
             }
             SendPacketFromQueue(rt.GetDestination(), route);
         }
@@ -1282,9 +1251,7 @@ RoutingProtocol::MergeTriggerPeriodicUpdates()
     m_advRoutingTable.GetListOfAllRoutes(allRoutes);
     if (!allRoutes.empty())
     {
-        for (std::map<Ipv4Address, RoutingTableEntry>::const_iterator i = allRoutes.begin();
-             i != allRoutes.end();
-             ++i)
+        for (auto i = allRoutes.begin(); i != allRoutes.end(); ++i)
         {
             RoutingTableEntry advEntry = i->second;
             if (advEntry.GetEntriesChanged() &&
