@@ -443,7 +443,7 @@ DsrCacheEntryTest::DoRun()
         Ipv4Address("0.0.0.1"),
     };
 
-    Ipv4Address dst = Ipv4Address("0.0.0.1");
+    Ipv4Address dst("0.0.0.1");
     dsr::DsrRouteCacheEntry entry(ip, dst, Seconds(1));
     NS_TEST_EXPECT_MSG_EQ(entry.GetVector().size(), 2, "trivial");
     NS_TEST_EXPECT_MSG_EQ(entry.GetDestination(), Ipv4Address("0.0.0.1"), "trivial");
@@ -464,7 +464,7 @@ DsrCacheEntryTest::DoRun()
         Ipv4Address("1.1.1.1"),
     };
 
-    Ipv4Address dst2 = Ipv4Address("1.1.1.1");
+    Ipv4Address dst2("1.1.1.1");
     dsr::DsrRouteCacheEntry entry2(ip2, dst2, Seconds(2));
     dsr::DsrRouteCacheEntry newEntry;
     NS_TEST_EXPECT_MSG_EQ(rcache->AddRoute(entry2), true, "trivial");
@@ -516,7 +516,7 @@ DsrSendBuffTest::DoRun()
     NS_TEST_EXPECT_MSG_EQ(q.GetSendBufferTimeout(), Seconds(10), "trivial");
 
     Ptr<const Packet> packet = Create<Packet>();
-    Ipv4Address dst1 = Ipv4Address("0.0.0.1");
+    Ipv4Address dst1("0.0.0.1");
     dsr::DsrSendBuffEntry e1(packet, dst1, Seconds(1));
     q.Enqueue(e1);
     q.Enqueue(e1);
@@ -528,7 +528,7 @@ DsrSendBuffTest::DoRun()
     NS_TEST_EXPECT_MSG_EQ(q.Find(Ipv4Address("0.0.0.1")), false, "trivial");
     NS_TEST_EXPECT_MSG_EQ(q.GetSize(), 0, "trivial");
 
-    Ipv4Address dst2 = Ipv4Address("0.0.0.2");
+    Ipv4Address dst2("0.0.0.2");
     dsr::DsrSendBuffEntry e2(packet, dst2, Seconds(1));
     q.Enqueue(e1);
     q.Enqueue(e2);
@@ -541,7 +541,7 @@ DsrSendBuffTest::DoRun()
     q.Enqueue(e3);
     NS_TEST_EXPECT_MSG_EQ(q.GetSize(), 2, "trivial");
     Ptr<Packet> packet4 = Create<Packet>();
-    Ipv4Address dst4 = Ipv4Address("0.0.0.4");
+    Ipv4Address dst4("0.0.0.4");
     dsr::DsrSendBuffEntry e4(packet4, dst4, Seconds(20));
     q.Enqueue(e4);
     NS_TEST_EXPECT_MSG_EQ(q.GetSize(), 3, "trivial");
