@@ -20,7 +20,9 @@
 #ifndef LI_ION_ENERGY_SOURCE_H
 #define LI_ION_ENERGY_SOURCE_H
 
-#include "ns3/energy-source.h"
+#include "energy-source.h"
+
+#include "ns3/deprecated.h"
 #include "ns3/event-id.h"
 #include "ns3/nstime.h"
 #include "ns3/traced-value.h"
@@ -32,6 +34,9 @@ namespace ns3
  * \ingroup energy
  * \brief Model a generic Lithium Ion Battery basing on [1][2].
  *
+ * \deprecated The LiIonEnergySource was deprecated in ns-3.40 in favor of GenericBatteryModel, and
+ * will be removed in a future release.
+ *
  * The model can be fitted to any type of Li-Ion Battery, simply changing the
  * model parameters.
  * The default values are fitted for the Panasonic CGR18650DA Li-Ion Battery [3].
@@ -131,6 +136,7 @@ class LiIonEnergySource : public EnergySource
      *
      * Implements DecreaseRemainingEnergy.
      */
+    NS_DEPRECATED_3_40("Use GenericBatteryModel instead")
     virtual void DecreaseRemainingEnergy(double energyJ);
 
     /**
@@ -138,6 +144,7 @@ class LiIonEnergySource : public EnergySource
      *
      * Implements IncreaseRemainingEnergy.
      */
+    NS_DEPRECATED_3_40("Use GenericBatteryModel instead")
     virtual void IncreaseRemainingEnergy(double energyJ);
 
     /**
