@@ -19,7 +19,8 @@
 
 #include "simple-device-energy-model.h"
 
-#include "ns3/energy-source.h"
+#include "energy-source.h"
+
 #include "ns3/log.h"
 #include "ns3/simulator.h"
 #include "ns3/trace-source-accessor.h"
