@@ -57,15 +57,15 @@ Send(Ptr<NetDevice> dev, int level, std::string emuMode)
 
     int packets = 10000000;
 
-    Mac48Address sender = Mac48Address("00:00:00:aa:00:01");
-    Mac48Address receiver = Mac48Address("ff:ff:ff:ff:ff:ff");
+    Mac48Address sender("00:00:00:aa:00:01");
+    Mac48Address receiver("ff:ff:ff:ff:ff:ff");
 
     int packetsSize = 64;
     Ptr<Packet> packet = Create<Packet>(packetsSize);
     EthernetHeader header;
 
     ssize_t len = (size_t)packet->GetSize();
-    uint8_t* buffer = (uint8_t*)malloc(len);
+    auto buffer = (uint8_t*)malloc(len);
     packet->CopyData(buffer, len);
 
     int sent = 0;
@@ -166,7 +166,7 @@ main(int argc, char* argv[])
 #ifdef HAVE_PACKET_H
     if (emuMode == "raw")
     {
-        EmuFdNetDeviceHelper* raw = new EmuFdNetDeviceHelper;
+        auto raw = new EmuFdNetDeviceHelper;
         raw->SetDeviceName(deviceName);
         helper = raw;
     }
