@@ -20,8 +20,9 @@
 #ifndef IPV4_FLOW_PROBE_H
 #define IPV4_FLOW_PROBE_H
 
-#include "ns3/flow-probe.h"
-#include "ns3/ipv4-flow-classifier.h"
+#include "flow-probe.h"
+#include "ipv4-flow-classifier.h"
+
 #include "ns3/ipv4-l3-protocol.h"
 #include "ns3/queue-item.h"
 
