@@ -146,8 +146,7 @@ Ipv6FlowClassifier::Classify(const Ipv6Header& ipHeader,
     tuple.destinationPort = dstPort;
 
     // try to insert the tuple, but check if it already exists
-    std::pair<std::map<FiveTuple, FlowId>::iterator, bool> insert =
-        m_flowMap.insert(std::pair<FiveTuple, FlowId>(tuple, 0));
+    auto insert = m_flowMap.insert(std::pair<FiveTuple, FlowId>(tuple, 0));
 
     // if the insertion succeeded, we need to assign this tuple a new flow identifier
     if (insert.second)
@@ -164,9 +163,8 @@ Ipv6FlowClassifier::Classify(const Ipv6Header& ipHeader,
 
     // increment the counter of packets with the same DSCP value
     Ipv6Header::DscpType dscp = ipHeader.GetDscp();
-    std::pair<std::map<Ipv6Header::DscpType, uint32_t>::iterator, bool> dscpInserter =
-        m_flowDscpMap[insert.first->second].insert(
-            std::pair<Ipv6Header::DscpType, uint32_t>(dscp, 1));
+    auto dscpInserter = m_flowDscpMap[insert.first->second].insert(
+        std::pair<Ipv6Header::DscpType, uint32_t>(dscp, 1));
 
     // if the insertion did not succeed, we need to increment the counter
     if (!dscpInserter.second)
@@ -183,9 +181,7 @@ Ipv6FlowClassifier::Classify(const Ipv6Header& ipHeader,
 Ipv6FlowClassifier::FiveTuple
 Ipv6FlowClassifier::FindFlow(FlowId flowId) const
 {
-    for (std::map<FiveTuple, FlowId>::const_iterator iter = m_flowMap.begin();
-         iter != m_flowMap.end();
-         iter++)
+    for (auto iter = m_flowMap.begin(); iter != m_flowMap.end(); iter++)
     {
         if (iter->second == flowId)
         {
@@ -207,8 +203,7 @@ Ipv6FlowClassifier::SortByCount::operator()(std::pair<Ipv6Header::DscpType, uint
 std::vector<std::pair<Ipv6Header::DscpType, uint32_t>>
 Ipv6FlowClassifier::GetDscpCounts(FlowId flowId) const
 {
-    std::map<FlowId, std::map<Ipv6Header::DscpType, uint32_t>>::const_iterator flow =
-        m_flowDscpMap.find(flowId);
+    auto flow = m_flowDscpMap.find(flowId);
 
     if (flow == m_flowDscpMap.end())
     {
@@ -228,9 +223,7 @@ Ipv6FlowClassifier::SerializeToXmlStream(std::ostream& os, uint16_t indent) cons
     os << "<Ipv6FlowClassifier>\n";
 
     indent += 2;
-    for (std::map<FiveTuple, FlowId>::const_iterator iter = m_flowMap.begin();
-         iter != m_flowMap.end();
-         iter++)
+    for (auto iter = m_flowMap.begin(); iter != m_flowMap.end(); iter++)
     {
         Indent(os, indent);
         os << "<Flow flowId=\"" << iter->second << "\""
@@ -241,14 +234,11 @@ Ipv6FlowClassifier::SerializeToXmlStream(std::ostream& os, uint16_t indent) cons
            << " destinationPort=\"" << iter->first.destinationPort << "\">\n";
 
         indent += 2;
-        std::map<FlowId, std::map<Ipv6Header::DscpType, uint32_t>>::const_iterator flow =
-            m_flowDscpMap.find(iter->second);
+        auto flow = m_flowDscpMap.find(iter->second);
 
         if (flow != m_flowDscpMap.end())
         {
-            for (std::map<Ipv6Header::DscpType, uint32_t>::const_iterator i = flow->second.begin();
-                 i != flow->second.end();
-                 i++)
+            for (auto i = flow->second.begin(); i != flow->second.end(); i++)
             {
                 Indent(os, indent);
                 os << "<Dscp value=\"0x" << std::hex << static_cast<uint32_t>(i->first) << "\""
