@@ -20,7 +20,8 @@
 #ifndef RIPNG_HELPER_H
 #define RIPNG_HELPER_H
 
-#include "ns3/ipv6-routing-helper.h"
+#include "ipv6-routing-helper.h"
+
 #include "ns3/node-container.h"
 #include "ns3/node.h"
 #include "ns3/object-factory.h"
