@@ -199,7 +199,7 @@ ArpCache::HandleWaitReplyTimeout()
     NS_LOG_FUNCTION(this);
     ArpCache::Entry* entry;
     bool restartWaitReplyTimer = false;
-    for (CacheI i = m_arpCache.begin(); i != m_arpCache.end(); i++)
+    for (auto i = m_arpCache.begin(); i != m_arpCache.end(); i++)
     {
         entry = (*i).second;
         if (entry != nullptr && entry->IsWaitReply())
@@ -245,7 +245,7 @@ void
 ArpCache::Flush()
 {
     NS_LOG_FUNCTION(this);
-    for (CacheI i = m_arpCache.begin(); i != m_arpCache.end(); i++)
+    for (auto i = m_arpCache.begin(); i != m_arpCache.end(); i++)
     {
         delete (*i).second;
     }
@@ -264,7 +264,7 @@ ArpCache::PrintArpCache(Ptr<OutputStreamWrapper> stream)
     NS_LOG_FUNCTION(this << stream);
     std::ostream* os = stream->GetStream();
 
-    for (CacheI i = m_arpCache.begin(); i != m_arpCache.end(); i++)
+    for (auto i = m_arpCache.begin(); i != m_arpCache.end(); i++)
     {
         *os << i->first << " dev ";
         std::string found = Names::FindName(m_device);
@@ -306,7 +306,7 @@ void
 ArpCache::RemoveAutoGeneratedEntries()
 {
     NS_LOG_FUNCTION(this);
-    for (CacheI i = m_arpCache.begin(); i != m_arpCache.end();)
+    for (auto i = m_arpCache.begin(); i != m_arpCache.end();)
     {
         if (i->second->IsAutoGenerated())
         {
@@ -325,7 +325,7 @@ ArpCache::LookupInverse(Address to)
     NS_LOG_FUNCTION(this << to);
 
     std::list<ArpCache::Entry*> entryList;
-    for (CacheI i = m_arpCache.begin(); i != m_arpCache.end(); i++)
+    for (auto i = m_arpCache.begin(); i != m_arpCache.end(); i++)
     {
         ArpCache::Entry* entry = (*i).second;
         if (entry->GetMacAddress() == to)
@@ -340,7 +340,7 @@ ArpCache::Entry*
 ArpCache::Lookup(Ipv4Address to)
 {
     NS_LOG_FUNCTION(this << to);
-    CacheI it = m_arpCache.find(to);
+    auto it = m_arpCache.find(to);
     if (it != m_arpCache.end())
     {
         return it->second;
@@ -354,7 +354,7 @@ ArpCache::Add(Ipv4Address to)
     NS_LOG_FUNCTION(this << to);
     NS_ASSERT(m_arpCache.find(to) == m_arpCache.end());
 
-    ArpCache::Entry* entry = new ArpCache::Entry(this);
+    auto entry = new ArpCache::Entry(this);
     m_arpCache[to] = entry;
     entry->SetIpv4Address(to);
     return entry;
@@ -365,7 +365,7 @@ ArpCache::Remove(ArpCache::Entry* entry)
 {
     NS_LOG_FUNCTION(this << entry);
 
-    for (CacheI i = m_arpCache.begin(); i != m_arpCache.end(); i++)
+    for (auto i = m_arpCache.begin(); i != m_arpCache.end(); i++)
     {
         if ((*i).second == entry)
         {
