@@ -682,20 +682,6 @@ class Icmpv6RA : public Icmpv6Header
      */
     void Print(std::ostream& os) const override;
 
-    /**
-     * \brief Getflags.
-     * \return the flags value
-     */
-    NS_DEPRECATED_3_34
-    uint8_t GetFlags() const;
-
-    /**
-     * \brief Setflags.
-     * \param f the flags value
-     */
-    NS_DEPRECATED_3_34
-    void SetFlags(uint8_t f);
-
     /**
      * \brief Get the serialized size.
      * \return serialized size
@@ -1474,13 +1460,13 @@ class Icmpv6OptionPrefixInformation : public Icmpv6OptionHeader
     /**
      * \brief Icmpv6 Option Prefix Information flag field values
      */
-    typedef enum
+    enum Flags_t
     {
         NONE = 0,         //!< No flags
         ROUTERADDR = 32,  //!< Router Address
         AUTADDRCONF = 64, //!< Autonomous Address Configuration
         ONLINK = 128      //!< On-link
-    } Flags_t;
+    };
 
     /**
      * \brief Get the prefix length.
