@@ -168,7 +168,7 @@ void
 Icmpv6L4Protocol::DoDispose()
 {
     NS_LOG_FUNCTION(this);
-    for (CacheList::const_iterator it = m_cacheList.begin(); it != m_cacheList.end(); it++)
+    for (auto it = m_cacheList.begin(); it != m_cacheList.end(); it++)
     {
         Ptr<NdiscCache> cache = *it;
         cache->Dispose();
@@ -397,7 +397,7 @@ Icmpv6L4Protocol::HandleEchoRequest(Ptr<Packet> packet,
 {
     NS_LOG_FUNCTION(this << packet << src << dst << interface);
     Icmpv6Echo request;
-    uint8_t* buf = new uint8_t[packet->GetSize()];
+    auto buf = new uint8_t[packet->GetSize()];
 
     packet->RemoveHeader(request);
     /* XXX IPv6 extension: obtain a fresh copy of data otherwise it crash... */
@@ -522,9 +522,7 @@ Icmpv6L4Protocol::ReceiveLLA(Icmpv6OptionLinkLayerAddress lla,
             waiting = entry->MarkReachable(lla.GetAddress());
             entry->StartReachableTimer();
             // send out waiting packet
-            for (std::list<NdiscCache::Ipv6PayloadHeaderPair>::const_iterator it = waiting.begin();
-                 it != waiting.end();
-                 it++)
+            for (auto it = waiting.begin(); it != waiting.end(); it++)
             {
                 cache->GetInterface()->Send(it->first, it->second, src);
             }
@@ -558,10 +556,7 @@ Icmpv6L4Protocol::ReceiveLLA(Icmpv6OptionLinkLayerAddress lla,
             {
                 entry->StopNudTimer();
                 waiting = entry->MarkReachable(lla.GetAddress());
-                for (std::list<NdiscCache::Ipv6PayloadHeaderPair>::const_iterator it =
-                         waiting.begin();
-                     it != waiting.end();
-                     it++)
+                for (auto it = waiting.begin(); it != waiting.end(); it++)
                 {
                     cache->GetInterface()->Send(it->first, it->second, src);
                 }
@@ -605,7 +600,7 @@ Icmpv6L4Protocol::HandleRS(Ptr<Packet> packet,
     Icmpv6RS rsHeader;
     packet->RemoveHeader(rsHeader);
     Address hardwareAddress;
-    Icmpv6OptionLinkLayerAddress lla(1);
+    Icmpv6OptionLinkLayerAddress lla(true);
     NdiscCache::Entry* entry = nullptr;
     Ptr<NdiscCache> cache = FindCache(interface->GetDevice());
 
@@ -786,7 +781,7 @@ Icmpv6L4Protocol::ForgeRS(Ipv6Address src, Ipv6Address dst, Address hardwareAddr
     if (!src.IsAny())
     {
         Icmpv6OptionLinkLayerAddress llOption(
-            1,
+            true,
             hardwareAddress); /* we give our mac address in response */
         p->AddHeader(llOption);
     }
@@ -813,7 +808,7 @@ Icmpv6L4Protocol::ForgeEchoRequest(Ipv6Address src,
     NS_LOG_FUNCTION(this << src << dst << id << seq << data);
     Ptr<Packet> p = data->Copy();
     Ipv6Header ipHeader;
-    Icmpv6Echo req(1);
+    Icmpv6Echo req(true);
 
     req.SetId(id);
     req.SetSeq(seq);
@@ -841,7 +836,7 @@ Icmpv6L4Protocol::HandleNA(Ptr<Packet> packet,
 {
     NS_LOG_FUNCTION(this << packet << src << dst << interface);
     Icmpv6NA naHeader;
-    Icmpv6OptionLinkLayerAddress lla(1);
+    Icmpv6OptionLinkLayerAddress lla(true);
 
     packet->RemoveHeader(naHeader);
     Ipv6Address target = naHeader.GetIpv6Target();
@@ -911,9 +906,7 @@ Icmpv6L4Protocol::HandleNA(Ptr<Packet> packet,
             waiting = entry->MarkReachable(lla.GetAddress());
             entry->StartReachableTimer();
             /* send out waiting packet */
-            for (std::list<NdiscCache::Ipv6PayloadHeaderPair>::const_iterator it = waiting.begin();
-                 it != waiting.end();
-                 it++)
+            for (auto it = waiting.begin(); it != waiting.end(); it++)
             {
                 cache->GetInterface()->Send(it->first, it->second, src);
             }
@@ -978,10 +971,7 @@ Icmpv6L4Protocol::HandleNA(Ptr<Packet> packet,
             if (naHeader.GetFlagS())
             {
                 waiting = entry->MarkReachable(lla.GetAddress());
-                for (std::list<NdiscCache::Ipv6PayloadHeaderPair>::const_iterator it =
-                         waiting.begin();
-                     it != waiting.end();
-                     it++)
+                for (auto it = waiting.begin(); it != waiting.end(); it++)
                 {
                     cache->GetInterface()->Send(it->first, it->second, src);
                 }
@@ -1022,7 +1012,7 @@ Icmpv6L4Protocol::HandleRedirection(Ptr<Packet> packet,
     NS_LOG_FUNCTION(this << packet << src << dst << interface);
     bool hasLla = false;
     Ptr<Packet> p = packet->Copy();
-    Icmpv6OptionLinkLayerAddress llOptionHeader(0);
+    Icmpv6OptionLinkLayerAddress llOptionHeader(false);
 
     Icmpv6Redirection redirectionHeader;
     p->RemoveHeader(redirectionHeader);
@@ -1255,12 +1245,12 @@ Icmpv6L4Protocol::SendNA(Ipv6Address src, Ipv6Address dst, Address* hardwareAddr
     NS_LOG_FUNCTION(this << src << dst << hardwareAddress << static_cast<uint32_t>(flags));
     Ptr<Packet> p = Create<Packet>();
     Icmpv6NA na;
-    Icmpv6OptionLinkLayerAddress llOption(0, *hardwareAddress); /* not a source link layer */
+    Icmpv6OptionLinkLayerAddress llOption(false, *hardwareAddress); /* not a source link layer */
 
     NS_LOG_LOGIC("Send NA ( from " << src << " to " << dst << " target " << src << ")");
     na.SetIpv6Target(src);
 
-    if ((flags & 1))
+    if (flags & 1)
     {
         na.SetFlagO(true);
     }
@@ -1268,7 +1258,7 @@ Icmpv6L4Protocol::SendNA(Ipv6Address src, Ipv6Address dst, Address* hardwareAddr
     {
         na.SetFlagS(true);
     }
-    if ((flags & 4))
+    if (flags & 4)
     {
         na.SetFlagR(true);
     }
@@ -1289,7 +1279,7 @@ Icmpv6L4Protocol::SendEchoReply(Ipv6Address src,
 {
     NS_LOG_FUNCTION(this << src << dst << id << seq << data);
     Ptr<Packet> p = data->Copy();
-    Icmpv6Echo reply(0); /* echo reply */
+    Icmpv6Echo reply(false); /* echo reply */
 
     reply.SetId(id);
     reply.SetSeq(seq);
@@ -1313,7 +1303,7 @@ Icmpv6L4Protocol::SendNS(Ipv6Address src,
     /* Ipv6Header ipHeader; */
     Icmpv6NS ns(target);
     Icmpv6OptionLinkLayerAddress llOption(
-        1,
+        true,
         hardwareAddress); /* we give our mac address in response */
 
     /* if the source is unspec, multicast the NA to all-nodes multicast */
@@ -1356,10 +1346,21 @@ Icmpv6L4Protocol::SendRS(Ipv6Address src, Ipv6Address dst, Address hardwareAddre
     // unspecified address. Otherwise, it SHOULD be included on link layers that have addresses.
     if (!src.IsAny())
     {
-        Icmpv6OptionLinkLayerAddress llOption(1, hardwareAddress);
+        Icmpv6OptionLinkLayerAddress llOption(true, hardwareAddress);
         p->AddHeader(llOption);
     }
 
+    if (!src.IsAny())
+    {
+        Ptr<Ipv6L3Protocol> ipv6 = m_node->GetObject<Ipv6L3Protocol>();
+        if (ipv6->GetInterfaceForAddress(src) == -1)
+        {
+            NS_LOG_INFO("Preventing RS from being sent or rescheduled because the source address "
+                        << src << " has been removed");
+            return;
+        }
+    }
+
     NS_LOG_LOGIC("Send RS (from " << src << " to " << dst << ")");
 
     rs.CalculatePseudoHeaderChecksum(src, dst, p->GetSize() + rs.GetSerializedSize(), PROT_NUMBER);
@@ -1548,7 +1549,7 @@ Icmpv6L4Protocol::SendRedirection(Ptr<Packet> redirectedPacket,
     uint32_t llaSize = 0;
     Ptr<Packet> p = Create<Packet>();
     uint32_t redirectedPacketSize = redirectedPacket->GetSize();
-    Icmpv6OptionLinkLayerAddress llOption(0);
+    Icmpv6OptionLinkLayerAddress llOption(false);
 
     NS_LOG_LOGIC("Send Redirection ( to " << dst << " target " << redirTarget << " destination "
                                           << redirDestination << " )");
@@ -1606,7 +1607,7 @@ Icmpv6L4Protocol::ForgeNA(Ipv6Address src, Ipv6Address dst, Address* hardwareAdd
     Ipv6Header ipHeader;
     Icmpv6NA na;
     Icmpv6OptionLinkLayerAddress llOption(
-        0,
+        false,
         *hardwareAddress); /* we give our mac address in response */
 
     NS_LOG_LOGIC("Send NA ( from " << src << " to " << dst << ")");
@@ -1617,7 +1618,7 @@ Icmpv6L4Protocol::ForgeNA(Ipv6Address src, Ipv6Address dst, Address* hardwareAdd
     p->AddHeader(llOption);
     na.SetIpv6Target(src);
 
-    if ((flags & 1))
+    if (flags & 1)
     {
         na.SetFlagO(true);
     }
@@ -1625,7 +1626,7 @@ Icmpv6L4Protocol::ForgeNA(Ipv6Address src, Ipv6Address dst, Address* hardwareAdd
     {
         na.SetFlagS(true);
     }
-    if ((flags & 4))
+    if (flags & 4)
     {
         na.SetFlagR(true);
     }
@@ -1653,7 +1654,7 @@ Icmpv6L4Protocol::ForgeNS(Ipv6Address src,
     Ipv6Header ipHeader;
     Icmpv6NS ns(target);
     Icmpv6OptionLinkLayerAddress llOption(
-        1,
+        true,
         hardwareAddress); /* we give our mac address in response */
 
     NS_LOG_LOGIC("Send NS ( from " << src << " to " << dst << " target " << target << ")");
@@ -1676,7 +1677,7 @@ Icmpv6L4Protocol::FindCache(Ptr<NetDevice> device)
 {
     NS_LOG_FUNCTION(this << device);
 
-    for (CacheList::const_iterator i = m_cacheList.begin(); i != m_cacheList.end(); i++)
+    for (auto i = m_cacheList.begin(); i != m_cacheList.end(); i++)
     {
         if ((*i)->GetDevice() == device)
         {
