@@ -20,10 +20,11 @@
 #ifndef IPV4_END_POINT_H
 #define IPV4_END_POINT_H
 
+#include "ipv4-header.h"
+#include "ipv4-interface.h"
+
 #include "ns3/callback.h"
 #include "ns3/ipv4-address.h"
-#include "ns3/ipv4-header.h"
-#include "ns3/ipv4-interface.h"
 #include "ns3/net-device.h"
 
 #include <stdint.h>
