@@ -80,7 +80,7 @@ void
 Ipv4GlobalRouting::AddHostRouteTo(Ipv4Address dest, Ipv4Address nextHop, uint32_t interface)
 {
     NS_LOG_FUNCTION(this << dest << nextHop << interface);
-    Ipv4RoutingTableEntry* route = new Ipv4RoutingTableEntry();
+    auto route = new Ipv4RoutingTableEntry();
     *route = Ipv4RoutingTableEntry::CreateHostRouteTo(dest, nextHop, interface);
     m_hostRoutes.push_back(route);
 }
@@ -89,7 +89,7 @@ void
 Ipv4GlobalRouting::AddHostRouteTo(Ipv4Address dest, uint32_t interface)
 {
     NS_LOG_FUNCTION(this << dest << interface);
-    Ipv4RoutingTableEntry* route = new Ipv4RoutingTableEntry();
+    auto route = new Ipv4RoutingTableEntry();
     *route = Ipv4RoutingTableEntry::CreateHostRouteTo(dest, interface);
     m_hostRoutes.push_back(route);
 }
@@ -101,7 +101,7 @@ Ipv4GlobalRouting::AddNetworkRouteTo(Ipv4Address network,
                                      uint32_t interface)
 {
     NS_LOG_FUNCTION(this << network << networkMask << nextHop << interface);
-    Ipv4RoutingTableEntry* route = new Ipv4RoutingTableEntry();
+    auto route = new Ipv4RoutingTableEntry();
     *route = Ipv4RoutingTableEntry::CreateNetworkRouteTo(network, networkMask, nextHop, interface);
     m_networkRoutes.push_back(route);
 }
@@ -110,7 +110,7 @@ void
 Ipv4GlobalRouting::AddNetworkRouteTo(Ipv4Address network, Ipv4Mask networkMask, uint32_t interface)
 {
     NS_LOG_FUNCTION(this << network << networkMask << interface);
-    Ipv4RoutingTableEntry* route = new Ipv4RoutingTableEntry();
+    auto route = new Ipv4RoutingTableEntry();
     *route = Ipv4RoutingTableEntry::CreateNetworkRouteTo(network, networkMask, interface);
     m_networkRoutes.push_back(route);
 }
@@ -122,7 +122,7 @@ Ipv4GlobalRouting::AddASExternalRouteTo(Ipv4Address network,
                                         uint32_t interface)
 {
     NS_LOG_FUNCTION(this << network << networkMask << nextHop << interface);
-    Ipv4RoutingTableEntry* route = new Ipv4RoutingTableEntry();
+    auto route = new Ipv4RoutingTableEntry();
     *route = Ipv4RoutingTableEntry::CreateNetworkRouteTo(network, networkMask, nextHop, interface);
     m_ASexternalRoutes.push_back(route);
 }
@@ -138,7 +138,7 @@ Ipv4GlobalRouting::LookupGlobal(Ipv4Address dest, Ptr<NetDevice> oif)
     RouteVec_t allRoutes;
 
     NS_LOG_LOGIC("Number of m_hostRoutes = " << m_hostRoutes.size());
-    for (HostRoutesCI i = m_hostRoutes.begin(); i != m_hostRoutes.end(); i++)
+    for (auto i = m_hostRoutes.begin(); i != m_hostRoutes.end(); i++)
     {
         NS_ASSERT((*i)->IsHost());
         if ((*i)->GetDest() == dest)
@@ -158,7 +158,7 @@ Ipv4GlobalRouting::LookupGlobal(Ipv4Address dest, Ptr<NetDevice> oif)
     if (allRoutes.empty()) // if no host route is found
     {
         NS_LOG_LOGIC("Number of m_networkRoutes" << m_networkRoutes.size());
-        for (NetworkRoutesI j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j++)
+        for (auto j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j++)
         {
             Ipv4Mask mask = (*j)->GetDestNetworkMask();
             Ipv4Address entry = (*j)->GetDestNetwork();
@@ -179,7 +179,7 @@ Ipv4GlobalRouting::LookupGlobal(Ipv4Address dest, Ptr<NetDevice> oif)
     }
     if (allRoutes.empty()) // consider external if no host/network found
     {
-        for (ASExternalRoutesI k = m_ASexternalRoutes.begin(); k != m_ASexternalRoutes.end(); k++)
+        for (auto k = m_ASexternalRoutes.begin(); k != m_ASexternalRoutes.end(); k++)
         {
             Ipv4Mask mask = (*k)->GetDestNetworkMask();
             Ipv4Address entry = (*k)->GetDestNetwork();
@@ -248,7 +248,7 @@ Ipv4GlobalRouting::GetRoute(uint32_t index) const
     if (index < m_hostRoutes.size())
     {
         uint32_t tmp = 0;
-        for (HostRoutesCI i = m_hostRoutes.begin(); i != m_hostRoutes.end(); i++)
+        for (auto i = m_hostRoutes.begin(); i != m_hostRoutes.end(); i++)
         {
             if (tmp == index)
             {
@@ -261,7 +261,7 @@ Ipv4GlobalRouting::GetRoute(uint32_t index) const
     uint32_t tmp = 0;
     if (index < m_networkRoutes.size())
     {
-        for (NetworkRoutesCI j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j++)
+        for (auto j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j++)
         {
             if (tmp == index)
             {
@@ -272,7 +272,7 @@ Ipv4GlobalRouting::GetRoute(uint32_t index) const
     }
     index -= m_networkRoutes.size();
     tmp = 0;
-    for (ASExternalRoutesCI k = m_ASexternalRoutes.begin(); k != m_ASexternalRoutes.end(); k++)
+    for (auto k = m_ASexternalRoutes.begin(); k != m_ASexternalRoutes.end(); k++)
     {
         if (tmp == index)
         {
@@ -292,7 +292,7 @@ Ipv4GlobalRouting::RemoveRoute(uint32_t index)
     if (index < m_hostRoutes.size())
     {
         uint32_t tmp = 0;
-        for (HostRoutesI i = m_hostRoutes.begin(); i != m_hostRoutes.end(); i++)
+        for (auto i = m_hostRoutes.begin(); i != m_hostRoutes.end(); i++)
         {
             if (tmp == index)
             {
@@ -308,7 +308,7 @@ Ipv4GlobalRouting::RemoveRoute(uint32_t index)
     }
     index -= m_hostRoutes.size();
     uint32_t tmp = 0;
-    for (NetworkRoutesI j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j++)
+    for (auto j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j++)
     {
         if (tmp == index)
         {
@@ -323,7 +323,7 @@ Ipv4GlobalRouting::RemoveRoute(uint32_t index)
     }
     index -= m_networkRoutes.size();
     tmp = 0;
-    for (ASExternalRoutesI k = m_ASexternalRoutes.begin(); k != m_ASexternalRoutes.end(); k++)
+    for (auto k = m_ASexternalRoutes.begin(); k != m_ASexternalRoutes.end(); k++)
     {
         if (tmp == index)
         {
@@ -351,16 +351,15 @@ void
 Ipv4GlobalRouting::DoDispose()
 {
     NS_LOG_FUNCTION(this);
-    for (HostRoutesI i = m_hostRoutes.begin(); i != m_hostRoutes.end(); i = m_hostRoutes.erase(i))
+    for (auto i = m_hostRoutes.begin(); i != m_hostRoutes.end(); i = m_hostRoutes.erase(i))
     {
         delete (*i);
     }
-    for (NetworkRoutesI j = m_networkRoutes.begin(); j != m_networkRoutes.end();
-         j = m_networkRoutes.erase(j))
+    for (auto j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j = m_networkRoutes.erase(j))
     {
         delete (*j);
     }
-    for (ASExternalRoutesI l = m_ASexternalRoutes.begin(); l != m_ASexternalRoutes.end();
+    for (auto l = m_ASexternalRoutes.begin(); l != m_ASexternalRoutes.end();
          l = m_ASexternalRoutes.erase(l))
     {
         delete (*l);
