@@ -176,7 +176,7 @@ Ipv4L3Protocol::Remove(Ptr<IpL4Protocol> protocol)
     NS_LOG_FUNCTION(this << protocol);
 
     L4ListKey_t key = std::make_pair(protocol->GetProtocolNumber(), -1);
-    L4List_t::iterator iter = m_protocols.find(key);
+    auto iter = m_protocols.find(key);
     if (iter == m_protocols.end())
     {
         NS_LOG_WARN("Trying to remove an non-existent default protocol "
@@ -194,7 +194,7 @@ Ipv4L3Protocol::Remove(Ptr<IpL4Protocol> protocol, uint32_t interfaceIndex)
     NS_LOG_FUNCTION(this << protocol << interfaceIndex);
 
     L4ListKey_t key = std::make_pair(protocol->GetProtocolNumber(), interfaceIndex);
-    L4List_t::iterator iter = m_protocols.find(key);
+    auto iter = m_protocols.find(key);
     if (iter == m_protocols.end())
     {
         NS_LOG_WARN("Trying to remove an non-existent protocol "
@@ -220,21 +220,19 @@ Ipv4L3Protocol::GetProtocol(int protocolNumber, int32_t interfaceIndex) const
 {
     NS_LOG_FUNCTION(this << protocolNumber << interfaceIndex);
 
-    L4ListKey_t key;
-    L4List_t::const_iterator i;
     if (interfaceIndex >= 0)
     {
         // try the interface-specific protocol.
-        key = std::make_pair(protocolNumber, interfaceIndex);
-        i = m_protocols.find(key);
+        auto key = std::make_pair(protocolNumber, interfaceIndex);
+        auto i = m_protocols.find(key);
         if (i != m_protocols.end())
         {
             return i->second;
         }
     }
     // try the generic protocol.
-    key = std::make_pair(protocolNumber, -1);
-    i = m_protocols.find(key);
+    auto key = std::make_pair(protocolNumber, -1);
+    auto i = m_protocols.find(key);
     if (i != m_protocols.end())
     {
         return i->second;
@@ -266,7 +264,7 @@ void
 Ipv4L3Protocol::DeleteRawSocket(Ptr<Socket> socket)
 {
     NS_LOG_FUNCTION(this << socket);
-    for (SocketList::iterator i = m_sockets.begin(); i != m_sockets.end(); ++i)
+    for (auto i = m_sockets.begin(); i != m_sockets.end(); ++i)
     {
         if ((*i) == socket)
         {
@@ -316,13 +314,13 @@ void
 Ipv4L3Protocol::DoDispose()
 {
     NS_LOG_FUNCTION(this);
-    for (L4List_t::iterator i = m_protocols.begin(); i != m_protocols.end(); ++i)
+    for (auto i = m_protocols.begin(); i != m_protocols.end(); ++i)
     {
         i->second = nullptr;
     }
     m_protocols.clear();
 
-    for (Ipv4InterfaceList::iterator i = m_interfaces.begin(); i != m_interfaces.end(); ++i)
+    for (auto i = m_interfaces.begin(); i != m_interfaces.end(); ++i)
     {
         *i = nullptr;
     }
@@ -333,7 +331,7 @@ Ipv4L3Protocol::DoDispose()
     m_node = nullptr;
     m_routingProtocol = nullptr;
 
-    for (MapFragments_t::iterator it = m_fragments.begin(); it != m_fragments.end(); it++)
+    for (auto it = m_fragments.begin(); it != m_fragments.end(); it++)
     {
         it->second = nullptr;
     }
@@ -464,8 +462,7 @@ Ipv4L3Protocol::GetInterfaceForAddress(Ipv4Address address) const
 {
     NS_LOG_FUNCTION(this << address);
     int32_t interface = 0;
-    for (Ipv4InterfaceList::const_iterator i = m_interfaces.begin(); i != m_interfaces.end();
-         i++, interface++)
+    for (auto i = m_interfaces.begin(); i != m_interfaces.end(); i++, interface++)
     {
         for (uint32_t j = 0; j < (*i)->GetNAddresses(); j++)
         {
@@ -484,8 +481,7 @@ Ipv4L3Protocol::GetInterfaceForPrefix(Ipv4Address address, Ipv4Mask mask) const
 {
     NS_LOG_FUNCTION(this << address << mask);
     int32_t interface = 0;
-    for (Ipv4InterfaceList::const_iterator i = m_interfaces.begin(); i != m_interfaces.end();
-         i++, interface++)
+    for (auto i = m_interfaces.begin(); i != m_interfaces.end(); i++, interface++)
     {
         for (uint32_t j = 0; j < (*i)->GetNAddresses(); j++)
         {
@@ -504,7 +500,7 @@ Ipv4L3Protocol::GetInterfaceForDevice(Ptr<const NetDevice> device) const
 {
     NS_LOG_FUNCTION(this << device);
 
-    Ipv4InterfaceReverseContainer::const_iterator iter = m_reverseInterfacesContainer.find(device);
+    auto iter = m_reverseInterfacesContainer.find(device);
     if (iter != m_reverseInterfacesContainer.end())
     {
         return (*iter).second;
@@ -550,7 +546,7 @@ Ipv4L3Protocol::IsDestinationAddress(Ipv4Address address, uint32_t iif) const
         return true;
     }
 
-    if (GetWeakEsModel()) // Check other interfaces
+    if (!GetStrongEndSystemModel()) // Check other interfaces
     {
         for (uint32_t j = 0; j < GetNInterfaces(); j++)
         {
@@ -650,8 +646,7 @@ Ipv4L3Protocol::Receive(Ptr<NetDevice> device,
             // addresses. In doubt, update all of them. Note: it's a confirmed behavior for Linux
             // routers.
             std::list<ArpCache::Entry*> entryList = arpCache->LookupInverse(from);
-            std::list<ArpCache::Entry*>::iterator iter;
-            for (iter = entryList.begin(); iter != entryList.end(); iter++)
+            for (auto iter = entryList.begin(); iter != entryList.end(); iter++)
             {
                 if ((*iter)->IsAlive())
                 {
@@ -661,7 +656,7 @@ Ipv4L3Protocol::Receive(Ptr<NetDevice> device,
         }
     }
 
-    for (SocketList::iterator i = m_sockets.begin(); i != m_sockets.end(); ++i)
+    for (auto i = m_sockets.begin(); i != m_sockets.end(); ++i)
     {
         NS_LOG_LOGIC("Forwarding to raw socket");
         Ptr<Ipv4RawSocketImpl> socket = *i;
@@ -834,8 +829,7 @@ Ipv4L3Protocol::Send(Ptr<Packet> packet,
     {
         NS_LOG_LOGIC("Ipv4L3Protocol::Send case 2:  limited broadcast - no route");
         uint32_t ifaceIndex = 0;
-        for (Ipv4InterfaceList::iterator ifaceIter = m_interfaces.begin();
-             ifaceIter != m_interfaces.end();
+        for (auto ifaceIter = m_interfaces.begin(); ifaceIter != m_interfaces.end();
              ifaceIter++, ifaceIndex++)
         {
             Ptr<Ipv4Interface> outInterface = *ifaceIter;
@@ -866,9 +860,7 @@ Ipv4L3Protocol::Send(Ptr<Packet> packet,
     }
 
     // 3) check: packet is destined to a subnet-directed broadcast address
-    for (Ipv4InterfaceList::iterator ifaceIter = m_interfaces.begin();
-         ifaceIter != m_interfaces.end();
-         ifaceIter++)
+    for (auto ifaceIter = m_interfaces.begin(); ifaceIter != m_interfaces.end(); ifaceIter++)
     {
         Ptr<Ipv4Interface> outInterface = *ifaceIter;
         uint32_t ifaceIndex = GetInterfaceForDevice(outInterface->GetDevice());
@@ -1019,9 +1011,7 @@ Ipv4L3Protocol::SendRealOut(Ptr<Ipv4Route> route, Ptr<Packet> packet, const Ipv4
         {
             std::list<Ipv4PayloadHeaderPair> listFragments;
             DoFragmentation(packet, ipHeader, outInterface->GetDevice()->GetMtu(), listFragments);
-            for (std::list<Ipv4PayloadHeaderPair>::iterator it = listFragments.begin();
-                 it != listFragments.end();
-                 it++)
+            for (auto it = listFragments.begin(); it != listFragments.end(); it++)
             {
                 NS_LOG_LOGIC("Sending fragment " << *(it->first));
                 CallTxTrace(it->second, it->first, this, interface);
@@ -1046,9 +1036,8 @@ Ipv4L3Protocol::IpMulticastForward(Ptr<Ipv4MulticastRoute> mrtentry,
     NS_LOG_LOGIC("Multicast forwarding logic for node: " << m_node->GetId());
 
     std::map<uint32_t, uint32_t> ttlMap = mrtentry->GetOutputTtlMap();
-    std::map<uint32_t, uint32_t>::iterator mapIter;
 
-    for (mapIter = ttlMap.begin(); mapIter != ttlMap.end(); mapIter++)
+    for (auto mapIter = ttlMap.begin(); mapIter != ttlMap.end(); mapIter++)
     {
         uint32_t interface = mapIter->first;
         // uint32_t outputTtl = mapIter->second;  // Unused for now
@@ -1435,7 +1424,7 @@ Ipv4L3Protocol::SetIpForward(bool forward)
 {
     NS_LOG_FUNCTION(this << forward);
     m_ipForward = forward;
-    for (Ipv4InterfaceList::const_iterator i = m_interfaces.begin(); i != m_interfaces.end(); i++)
+    for (auto i = m_interfaces.begin(); i != m_interfaces.end(); i++)
     {
         (*i)->SetForwarding(forward);
     }
@@ -1452,14 +1441,28 @@ void
 Ipv4L3Protocol::SetWeakEsModel(bool model)
 {
     NS_LOG_FUNCTION(this << model);
-    m_weakEsModel = model;
+    m_strongEndSystemModel = !model;
 }
 
 bool
 Ipv4L3Protocol::GetWeakEsModel() const
 {
     NS_LOG_FUNCTION(this);
-    return m_weakEsModel;
+    return !m_strongEndSystemModel;
+}
+
+void
+Ipv4L3Protocol::SetStrongEndSystemModel(bool model)
+{
+    NS_LOG_FUNCTION(this << model);
+    m_strongEndSystemModel = model;
+}
+
+bool
+Ipv4L3Protocol::GetStrongEndSystemModel() const
+{
+    NS_LOG_FUNCTION(this);
+    return m_strongEndSystemModel;
 }
 
 void
@@ -1577,13 +1580,13 @@ Ipv4L3Protocol::ProcessFragment(Ptr<Packet>& packet, Ipv4Header& ipHeader, uint3
 
     Ptr<Fragments> fragments;
 
-    MapFragments_t::iterator it = m_fragments.find(key);
+    auto it = m_fragments.find(key);
     if (it == m_fragments.end())
     {
         fragments = Create<Fragments>();
         m_fragments.insert(std::make_pair(key, fragments));
 
-        FragmentsTimeoutsListI_t iter = SetTimeout(key, ipHeader, iif);
+        auto iter = SetTimeout(key, ipHeader, iif);
         fragments->SetTimeoutIter(iter);
     }
     else
@@ -1609,7 +1612,7 @@ Ipv4L3Protocol::ProcessFragment(Ptr<Packet>& packet, Ipv4Header& ipHeader, uint3
 }
 
 Ipv4L3Protocol::Fragments::Fragments()
-    : m_moreFragment(0)
+    : m_moreFragment(false)
 {
     NS_LOG_FUNCTION(this);
 }
@@ -1650,9 +1653,7 @@ Ipv4L3Protocol::Fragments::IsEntire() const
     {
         uint16_t lastEndOffset = 0;
 
-        for (std::list<std::pair<Ptr<Packet>, uint16_t>>::const_iterator it = m_fragments.begin();
-             it != m_fragments.end();
-             it++)
+        for (auto it = m_fragments.begin(); it != m_fragments.end(); it++)
         {
             // overlapping fragments do exist
             NS_LOG_LOGIC("Checking overlaps " << lastEndOffset << " - " << it->second);
@@ -1676,7 +1677,7 @@ Ipv4L3Protocol::Fragments::GetPacket() const
 {
     NS_LOG_FUNCTION(this);
 
-    std::list<std::pair<Ptr<Packet>, uint16_t>>::const_iterator it = m_fragments.begin();
+    auto it = m_fragments.begin();
 
     Ptr<Packet> p = it->first->Copy();
     uint16_t lastEndOffset = p->GetSize();
@@ -1714,7 +1715,7 @@ Ipv4L3Protocol::Fragments::GetPartialPacket() const
 {
     NS_LOG_FUNCTION(this);
 
-    std::list<std::pair<Ptr<Packet>, uint16_t>>::const_iterator it = m_fragments.begin();
+    auto it = m_fragments.begin();
 
     Ptr<Packet> p = Create<Packet>();
     uint16_t lastEndOffset = 0;
@@ -1761,7 +1762,7 @@ Ipv4L3Protocol::HandleFragmentsTimeout(FragmentKey_t key, Ipv4Header& ipHeader,
 {
     NS_LOG_FUNCTION(this << &key << &ipHeader << iif);
 
-    MapFragments_t::iterator it = m_fragments.find(key);
+    auto it = m_fragments.find(key);
     Ptr<Packet> packet = it->second->GetPartialPacket();
 
     // if we have at least 8 bytes, we can send an ICMP.
@@ -1837,11 +1838,8 @@ Ipv4L3Protocol::UpdateDuplicate(Ptr<const Packet> p, const Ipv4Header& header)
                            << std::get<3>(key) << ")");
 
     // place a new entry, on collision the existing entry iterator is returned
-    DupMap_t::iterator iter;
-    bool inserted;
-    bool isDup;
-    std::tie(iter, inserted) = m_dups.emplace(key, Seconds(0));
-    isDup = !inserted && iter->second > Simulator::Now();
+    auto [iter, inserted] = m_dups.emplace(key, Seconds(0));
+    bool isDup = !inserted && iter->second > Simulator::Now();
 
     // set the expiration event
     iter->second = Simulator::Now() + m_expire;
@@ -1894,9 +1892,9 @@ Ipv4L3Protocol::SetTimeout(FragmentKey_t key, Ipv4Header ipHeader, uint32_t iif)
     }
     m_timeoutEventList.emplace_back(now, key, ipHeader, iif);
 
-    Ipv4L3Protocol::FragmentsTimeoutsListI_t iter = --m_timeoutEventList.end();
+    auto iter = --m_timeoutEventList.end();
 
-    return (iter);
+    return iter;
 }
 
 void
