@@ -20,10 +20,12 @@
 #ifndef IPV4_L3_PROTOCOL_H
 #define IPV4_L3_PROTOCOL_H
 
+#include "ipv4-header.h"
+#include "ipv4-routing-protocol.h"
+#include "ipv4.h"
+
+#include "ns3/deprecated.h"
 #include "ns3/ipv4-address.h"
-#include "ns3/ipv4-header.h"
-#include "ns3/ipv4-routing-protocol.h"
-#include "ns3/ipv4.h"
 #include "ns3/net-device.h"
 #include "ns3/nstime.h"
 #include "ns3/ptr.h"
@@ -294,9 +296,15 @@ class Ipv4L3Protocol : public Ipv4
     // class Ipv4 attributes
     void SetIpForward(bool forward) override;
     bool GetIpForward() const override;
+
+    NS_DEPRECATED_3_41("Use SetStrongEndSystemModel instead")
     void SetWeakEsModel(bool model) override;
+    NS_DEPRECATED_3_41("Use GetStrongEndSystemModel instead")
     bool GetWeakEsModel() const override;
 
+    void SetStrongEndSystemModel(bool model) override;
+    bool GetStrongEndSystemModel() const override;
+
     /**
      * \brief Decrease the identification value for a dropped or recursed packet
      * \param source source IPv4 address
@@ -459,7 +467,7 @@ class Ipv4L3Protocol : public Ipv4
     typedef std::map<L4ListKey_t, Ptr<IpL4Protocol>> L4List_t;
 
     bool m_ipForward;               //!< Forwarding packets (i.e. router mode) state.
-    bool m_weakEsModel;             //!< Weak ES model state
+    bool m_strongEndSystemModel;    //!< Strong End System Model state
     L4List_t m_protocols;           //!< List of transport protocol.
     Ipv4InterfaceList m_interfaces; //!< List of IPv4 interfaces.
     Ipv4InterfaceReverseContainer
