@@ -20,7 +20,7 @@
 #ifndef IPV4_RAW_SOCKET_FACTORY_IMPL_H
 #define IPV4_RAW_SOCKET_FACTORY_IMPL_H
 
-#include "ns3/ipv4-raw-socket-factory.h"
+#include "ipv4-raw-socket-factory.h"
 
 namespace ns3
 {
