@@ -135,7 +135,7 @@ int
 Ipv4RawSocketImpl::Bind6()
 {
     NS_LOG_FUNCTION(this);
-    return (-1);
+    return -1;
 }
 
 int
@@ -400,7 +400,7 @@ Ipv4RawSocketImpl::GetRxAvailable() const
 {
     NS_LOG_FUNCTION(this);
     uint32_t rx = 0;
-    for (std::list<Data>::const_iterator i = m_recv.begin(); i != m_recv.end(); ++i)
+    for (auto i = m_recv.begin(); i != m_recv.end(); ++i)
     {
         rx += (i->packet)->GetSize();
     }
