@@ -39,7 +39,7 @@ Ipv6EndPointDemux::Ipv6EndPointDemux()
 Ipv6EndPointDemux::~Ipv6EndPointDemux()
 {
     NS_LOG_FUNCTION(this);
-    for (EndPointsI i = m_endPoints.begin(); i != m_endPoints.end(); i++)
+    for (auto i = m_endPoints.begin(); i != m_endPoints.end(); i++)
     {
         Ipv6EndPoint* endPoint = *i;
         delete endPoint;
@@ -51,7 +51,7 @@ bool
 Ipv6EndPointDemux::LookupPortLocal(uint16_t port)
 {
     NS_LOG_FUNCTION(this << port);
-    for (EndPointsI i = m_endPoints.begin(); i != m_endPoints.end(); i++)
+    for (auto i = m_endPoints.begin(); i != m_endPoints.end(); i++)
     {
         if ((*i)->GetLocalPort() == port)
         {
@@ -65,7 +65,7 @@ bool
 Ipv6EndPointDemux::LookupLocal(Ptr<NetDevice> boundNetDevice, Ipv6Address addr, uint16_t port)
 {
     NS_LOG_FUNCTION(this << addr << port);
-    for (EndPointsI i = m_endPoints.begin(); i != m_endPoints.end(); i++)
+    for (auto i = m_endPoints.begin(); i != m_endPoints.end(); i++)
     {
         if ((*i)->GetLocalPort() == port && (*i)->GetLocalAddress() == addr &&
             (*i)->GetBoundNetDevice() == boundNetDevice)
@@ -86,7 +86,7 @@ Ipv6EndPointDemux::Allocate()
         NS_LOG_WARN("Ephemeral port allocation failed.");
         return nullptr;
     }
-    Ipv6EndPoint* endPoint = new Ipv6EndPoint(Ipv6Address::GetAny(), port);
+    auto endPoint = new Ipv6EndPoint(Ipv6Address::GetAny(), port);
     m_endPoints.push_back(endPoint);
     NS_LOG_DEBUG("Now have >>" << m_endPoints.size() << "<< endpoints.");
     return endPoint;
@@ -102,7 +102,7 @@ Ipv6EndPointDemux::Allocate(Ipv6Address address)
         NS_LOG_WARN("Ephemeral port allocation failed.");
         return nullptr;
     }
-    Ipv6EndPoint* endPoint = new Ipv6EndPoint(address, port);
+    auto endPoint = new Ipv6EndPoint(address, port);
     m_endPoints.push_back(endPoint);
     NS_LOG_DEBUG("Now have >>" << m_endPoints.size() << "<< endpoints.");
     return endPoint;
@@ -125,7 +125,7 @@ Ipv6EndPointDemux::Allocate(Ptr<NetDevice> boundNetDevice, Ipv6Address address,
         NS_LOG_WARN("Duplicated endpoint.");
         return nullptr;
     }
-    Ipv6EndPoint* endPoint = new Ipv6EndPoint(address, port);
+    auto endPoint = new Ipv6EndPoint(address, port);
     m_endPoints.push_back(endPoint);
     NS_LOG_DEBUG("Now have >>" << m_endPoints.size() << "<< endpoints.");
     return endPoint;
@@ -139,7 +139,7 @@ Ipv6EndPointDemux::Allocate(Ptr<NetDevice> boundNetDevice,
                             uint16_t peerPort)
 {
     NS_LOG_FUNCTION(this << boundNetDevice << localAddress << localPort << peerAddress << peerPort);
-    for (EndPointsI i = m_endPoints.begin(); i != m_endPoints.end(); i++)
+    for (auto i = m_endPoints.begin(); i != m_endPoints.end(); i++)
     {
         if ((*i)->GetLocalPort() == localPort && (*i)->GetLocalAddress() == localAddress &&
             (*i)->GetPeerPort() == peerPort && (*i)->GetPeerAddress() == peerAddress &&
@@ -149,7 +149,7 @@ Ipv6EndPointDemux::Allocate(Ptr<NetDevice> boundNetDevice,
             return nullptr;
         }
     }
-    Ipv6EndPoint* endPoint = new Ipv6EndPoint(localAddress, localPort);
+    auto endPoint = new Ipv6EndPoint(localAddress, localPort);
     endPoint->SetPeer(peerAddress, peerPort);
     m_endPoints.push_back(endPoint);
 
@@ -162,7 +162,7 @@ void
 Ipv6EndPointDemux::DeAllocate(Ipv6EndPoint* endPoint)
 {
     NS_LOG_FUNCTION(this);
-    for (EndPointsI i = m_endPoints.begin(); i != m_endPoints.end(); i++)
+    for (auto i = m_endPoints.begin(); i != m_endPoints.end(); i++)
     {
         if (*i == endPoint)
         {
@@ -193,7 +193,7 @@ Ipv6EndPointDemux::Lookup(Ipv6Address daddr,
     EndPoints retval4; /* Exact match on all 4 */
 
     NS_LOG_DEBUG("Looking up endpoint for destination address " << daddr);
-    for (EndPointsI i = m_endPoints.begin(); i != m_endPoints.end(); i++)
+    for (auto i = m_endPoints.begin(); i != m_endPoints.end(); i++)
     {
         Ipv6EndPoint* endP = *i;
 
@@ -313,7 +313,7 @@ Ipv6EndPointDemux::SimpleLookup(Ipv6Address dst, uint16_t dport, Ipv6Address src
     uint32_t genericity = 3;
     Ipv6EndPoint* generic = nullptr;
 
-    for (EndPointsI i = m_endPoints.begin(); i != m_endPoints.end(); i++)
+    for (auto i = m_endPoints.begin(); i != m_endPoints.end(); i++)
     {
         uint32_t tmp = 0;
 
