@@ -20,11 +20,12 @@
 #ifndef IPV6_L3_PROTOCOL_H
 #define IPV6_L3_PROTOCOL_H
 
+#include "ipv6-header.h"
+#include "ipv6-pmtu-cache.h"
+#include "ipv6-routing-protocol.h"
+#include "ipv6.h"
+
 #include "ns3/ipv6-address.h"
-#include "ns3/ipv6-header.h"
-#include "ns3/ipv6-pmtu-cache.h"
-#include "ns3/ipv6-routing-protocol.h"
-#include "ns3/ipv6.h"
 #include "ns3/net-device.h"
 #include "ns3/traced-callback.h"
 
@@ -706,6 +707,9 @@ class Ipv6L3Protocol : public Ipv6
      */
     virtual bool GetSendIcmpv6Redirect() const;
 
+    void SetStrongEndSystemModel(bool model) override;
+    bool GetStrongEndSystemModel() const override;
+
     /**
      * \brief Node attached to stack.
      */
