@@ -139,7 +139,7 @@ Ipv6RawSocketImpl::Bind()
 int
 Ipv6RawSocketImpl::Bind6()
 {
-    return (Bind());
+    return Bind();
 }
 
 int
@@ -293,7 +293,7 @@ Ipv6RawSocketImpl::SendTo(Ptr<Packet> p, uint32_t flags, const Address& toAddres
                 p->CopyData(&type, sizeof(type));
                 if (type == Icmpv6Header::ICMPV6_ECHO_REQUEST)
                 {
-                    Icmpv6Echo hdr(1);
+                    Icmpv6Echo hdr(true);
                     p->RemoveHeader(hdr);
                     hdr.CalculatePseudoHeaderChecksum(route->GetSource(),
                                                       dst,
@@ -421,7 +421,7 @@ Ipv6RawSocketImpl::GetRxAvailable() const
     NS_LOG_FUNCTION(this);
     uint32_t rx = 0;
 
-    for (std::list<Data>::const_iterator it = m_data.begin(); it != m_data.end(); ++it)
+    for (auto it = m_data.begin(); it != m_data.end(); ++it)
     {
         rx += (it->packet)->GetSize();
     }
@@ -534,25 +534,25 @@ Ipv6RawSocketImpl::Icmpv6FilterSetBlockAll()
 void
 Ipv6RawSocketImpl::Icmpv6FilterSetPass(uint8_t type)
 {
-    (m_icmpFilter.icmpv6Filt[(type) >> 5]) |= (uint32_t(1) << ((type)&31));
+    m_icmpFilter.icmpv6Filt[type >> 5] |= (uint32_t(1) << (type & 31));
 }
 
 void
 Ipv6RawSocketImpl::Icmpv6FilterSetBlock(uint8_t type)
 {
-    (m_icmpFilter.icmpv6Filt[(type) >> 5]) &= ~(uint32_t(1) << ((type)&31));
+    m_icmpFilter.icmpv6Filt[(type) >> 5] &= ~(uint32_t(1) << (type & 31));
 }
 
 bool
 Ipv6RawSocketImpl::Icmpv6FilterWillPass(uint8_t type)
 {
-    return (((m_icmpFilter.icmpv6Filt[(type) >> 5]) & (uint32_t(1) << ((type)&31))) != 0);
+    return ((m_icmpFilter.icmpv6Filt[type >> 5]) & (uint32_t(1) << (type & 31))) != 0;
 }
 
 bool
 Ipv6RawSocketImpl::Icmpv6FilterWillBlock(uint8_t type)
 {
-    return (((m_icmpFilter.icmpv6Filt[(type) >> 5]) & (uint32_t(1) << ((type)&31))) == 0);
+    return ((m_icmpFilter.icmpv6Filt[type >> 5]) & (uint32_t(1) << (type & 31))) == 0;
 }
 
 } /* namespace ns3 */
