@@ -181,7 +181,7 @@ Ipv6StaticRouting::AddNetworkRouteTo(Ipv6Address network,
 
     if (!LookupRoute(route, metric))
     {
-        Ipv6RoutingTableEntry* routePtr = new Ipv6RoutingTableEntry(route);
+        auto routePtr = new Ipv6RoutingTableEntry(route);
         m_networkRoutes.emplace_back(routePtr, metric);
     }
 }
@@ -208,7 +208,7 @@ Ipv6StaticRouting::AddNetworkRouteTo(Ipv6Address network,
                                                                               prefixToUse);
     if (!LookupRoute(route, metric))
     {
-        Ipv6RoutingTableEntry* routePtr = new Ipv6RoutingTableEntry(route);
+        auto routePtr = new Ipv6RoutingTableEntry(route);
         m_networkRoutes.emplace_back(routePtr, metric);
     }
 }
@@ -225,7 +225,7 @@ Ipv6StaticRouting::AddNetworkRouteTo(Ipv6Address network,
         Ipv6RoutingTableEntry::CreateNetworkRouteTo(network, networkPrefix, interface);
     if (!LookupRoute(route, metric))
     {
-        Ipv6RoutingTableEntry* routePtr = new Ipv6RoutingTableEntry(route);
+        auto routePtr = new Ipv6RoutingTableEntry(route);
         m_networkRoutes.emplace_back(routePtr, metric);
     }
 }
@@ -252,7 +252,7 @@ Ipv6StaticRouting::AddMulticastRoute(Ipv6Address origin,
                                      std::vector<uint32_t> outputInterfaces)
 {
     NS_LOG_FUNCTION(this << origin << group << inputInterface);
-    Ipv6MulticastRoutingTableEntry* route = new Ipv6MulticastRoutingTableEntry();
+    auto route = new Ipv6MulticastRoutingTableEntry();
     *route = Ipv6MulticastRoutingTableEntry::CreateMulticastRoute(origin,
                                                                   group,
                                                                   inputInterface,
@@ -264,7 +264,7 @@ void
 Ipv6StaticRouting::SetDefaultMulticastRoute(uint32_t outputInterface)
 {
     NS_LOG_FUNCTION(this << outputInterface);
-    Ipv6RoutingTableEntry* route = new Ipv6RoutingTableEntry();
+    auto route = new Ipv6RoutingTableEntry();
     Ipv6Address network = Ipv6Address("ff00::"); /* RFC 3513 */
     Ipv6Prefix networkMask = Ipv6Prefix(8);
     *route = Ipv6RoutingTableEntry::CreateNetworkRouteTo(network, networkMask, outputInterface);
@@ -288,7 +288,7 @@ Ipv6StaticRouting::GetMulticastRoute(uint32_t index) const
     if (index < m_multicastRoutes.size())
     {
         uint32_t tmp = 0;
-        for (MulticastRoutesCI i = m_multicastRoutes.begin(); i != m_multicastRoutes.end(); i++)
+        for (auto i = m_multicastRoutes.begin(); i != m_multicastRoutes.end(); i++)
         {
             if (tmp == index)
             {
@@ -306,7 +306,7 @@ Ipv6StaticRouting::RemoveMulticastRoute(Ipv6Address origin,
                                         uint32_t inputInterface)
 {
     NS_LOG_FUNCTION(this << origin << group << inputInterface);
-    for (MulticastRoutesI i = m_multicastRoutes.begin(); i != m_multicastRoutes.end(); i++)
+    for (auto i = m_multicastRoutes.begin(); i != m_multicastRoutes.end(); i++)
     {
         Ipv6MulticastRoutingTableEntry* route = *i;
         if (origin == route->GetOrigin() && group == route->GetGroup() &&
@@ -326,7 +326,7 @@ Ipv6StaticRouting::RemoveMulticastRoute(uint32_t index)
     NS_LOG_FUNCTION(this << index);
     uint32_t tmp = 0;
 
-    for (MulticastRoutesI i = m_multicastRoutes.begin(); i != m_multicastRoutes.end(); i++)
+    for (auto i = m_multicastRoutes.begin(); i != m_multicastRoutes.end(); i++)
     {
         if (tmp == index)
         {
@@ -344,7 +344,7 @@ Ipv6StaticRouting::HasNetworkDest(Ipv6Address network, uint32_t interfaceIndex)
     NS_LOG_FUNCTION(this << network << interfaceIndex);
 
     /* in the network table */
-    for (NetworkRoutesI j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j++)
+    for (auto j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j++)
     {
         Ipv6RoutingTableEntry* rtentry = j->first;
         Ipv6Prefix prefix = rtentry->GetDestNetworkPrefix();
@@ -363,7 +363,7 @@ Ipv6StaticRouting::HasNetworkDest(Ipv6Address network, uint32_t interfaceIndex)
 bool
 Ipv6StaticRouting::LookupRoute(const Ipv6RoutingTableEntry& route, uint32_t metric)
 {
-    for (NetworkRoutesI j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j++)
+    for (auto j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j++)
     {
         Ipv6RoutingTableEntry* rtentry = j->first;
 
@@ -402,7 +402,7 @@ Ipv6StaticRouting::LookupStatic(Ipv6Address dst, Ptr<NetDevice> interface)
         return rtentry;
     }
 
-    for (NetworkRoutesI it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
+    for (auto it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
     {
         Ipv6RoutingTableEntry* j = it->first;
         uint32_t metric = it->second;
@@ -485,14 +485,13 @@ Ipv6StaticRouting::DoDispose()
 {
     NS_LOG_FUNCTION(this);
 
-    for (NetworkRoutesI j = m_networkRoutes.begin(); j != m_networkRoutes.end();
-         j = m_networkRoutes.erase(j))
+    for (auto j = m_networkRoutes.begin(); j != m_networkRoutes.end(); j = m_networkRoutes.erase(j))
     {
         delete j->first;
     }
     m_networkRoutes.clear();
 
-    for (MulticastRoutesI i = m_multicastRoutes.begin(); i != m_multicastRoutes.end();
+    for (auto i = m_multicastRoutes.begin(); i != m_multicastRoutes.end();
          i = m_multicastRoutes.erase(i))
     {
         delete (*i);
@@ -509,7 +508,7 @@ Ipv6StaticRouting::LookupStatic(Ipv6Address origin, Ipv6Address group, uint32_t
     NS_LOG_FUNCTION(this << origin << group << interface);
     Ptr<Ipv6MulticastRoute> mrtentry = nullptr;
 
-    for (MulticastRoutesI i = m_multicastRoutes.begin(); i != m_multicastRoutes.end(); i++)
+    for (auto i = m_multicastRoutes.begin(); i != m_multicastRoutes.end(); i++)
     {
         Ipv6MulticastRoutingTableEntry* route = *i;
 
@@ -569,7 +568,7 @@ Ipv6StaticRouting::GetDefaultRoute()
     uint32_t shortestMetric = 0xffffffff;
     Ipv6RoutingTableEntry* result = nullptr;
 
-    for (NetworkRoutesI it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
+    for (auto it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
     {
         Ipv6RoutingTableEntry* j = it->first;
         uint32_t metric = it->second;
@@ -606,7 +605,7 @@ Ipv6StaticRouting::GetRoute(uint32_t index) const
     NS_LOG_FUNCTION(this << index);
     uint32_t tmp = 0;
 
-    for (NetworkRoutesCI it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
+    for (auto it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
     {
         if (tmp == index)
         {
@@ -625,7 +624,7 @@ Ipv6StaticRouting::GetMetric(uint32_t index) const
     NS_LOG_FUNCTION(this << index);
     uint32_t tmp = 0;
 
-    for (NetworkRoutesCI it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
+    for (auto it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
     {
         if (tmp == index)
         {
@@ -644,7 +643,7 @@ Ipv6StaticRouting::RemoveRoute(uint32_t index)
     NS_LOG_FUNCTION(this << index);
     uint32_t tmp = 0;
 
-    for (NetworkRoutesI it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
+    for (auto it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
     {
         if (tmp == index)
         {
@@ -665,7 +664,7 @@ Ipv6StaticRouting::RemoveRoute(Ipv6Address network,
 {
     NS_LOG_FUNCTION(this << network << prefix << ifIndex);
 
-    for (NetworkRoutesI it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
+    for (auto it = m_networkRoutes.begin(); it != m_networkRoutes.end(); it++)
     {
         Ipv6RoutingTableEntry* rtentry = it->first;
         if (network == rtentry->GetDest() && rtentry->GetInterface() == ifIndex &&
@@ -809,7 +808,7 @@ Ipv6StaticRouting::NotifyInterfaceDown(uint32_t i)
     NS_LOG_FUNCTION(this << i);
 
     /* remove all static routes that are going through this interface */
-    for (NetworkRoutesI it = m_networkRoutes.begin(); it != m_networkRoutes.end();)
+    for (auto it = m_networkRoutes.begin(); it != m_networkRoutes.end();)
     {
         if (it->first->GetInterface() == i)
         {
@@ -845,7 +844,7 @@ Ipv6StaticRouting::NotifyRemoveAddress(uint32_t interface, Ipv6InterfaceAddress
 
     // Remove all static routes that are going through this interface
     // which reference this network
-    for (NetworkRoutesI it = m_networkRoutes.begin(); it != m_networkRoutes.end();)
+    for (auto it = m_networkRoutes.begin(); it != m_networkRoutes.end();)
     {
         if (it->first->GetInterface() == interface && it->first->IsNetwork() &&
             it->first->GetDestNetwork() == networkAddress &&
@@ -868,7 +867,7 @@ Ipv6StaticRouting::NotifyAddRoute(Ipv6Address dst,
                                   uint32_t interface,
                                   Ipv6Address prefixToUse)
 {
-    NS_LOG_INFO(this << dst << mask << nextHop << interface << prefixToUse);
+    NS_LOG_FUNCTION(this << dst << mask << nextHop << interface << prefixToUse);
     if (nextHop == Ipv6Address::GetZero())
     {
         AddNetworkRouteTo(dst, mask, interface);
@@ -901,7 +900,7 @@ Ipv6StaticRouting::NotifyRemoveRoute(Ipv6Address dst,
     NS_LOG_FUNCTION(this << dst << mask << nextHop << interface);
     if (dst != Ipv6Address::GetZero())
     {
-        for (NetworkRoutesI j = m_networkRoutes.begin(); j != m_networkRoutes.end();)
+        for (auto j = m_networkRoutes.begin(); j != m_networkRoutes.end();)
         {
             Ipv6RoutingTableEntry* rtentry = j->first;
             Ipv6Prefix prefix = rtentry->GetDestNetworkPrefix();
