@@ -118,7 +118,7 @@ NdiscCache::LookupInverse(Address dst)
     NS_LOG_FUNCTION(this << dst);
 
     std::list<NdiscCache::Entry*> entryList;
-    for (CacheI i = m_ndCache.begin(); i != m_ndCache.end(); i++)
+    for (auto i = m_ndCache.begin(); i != m_ndCache.end(); i++)
     {
         NdiscCache::Entry* entry = (*i).second;
         if (entry->GetMacAddress() == dst)
@@ -136,7 +136,7 @@ NdiscCache::Add(Ipv6Address to)
     NS_LOG_FUNCTION(this << to);
     NS_ASSERT(m_ndCache.find(to) == m_ndCache.end());
 
-    NdiscCache::Entry* entry = new NdiscCache::Entry(this);
+    auto entry = new NdiscCache::Entry(this);
     entry->SetIpv6Address(to);
     m_ndCache[to] = entry;
     return entry;
@@ -147,7 +147,7 @@ NdiscCache::Remove(NdiscCache::Entry* entry)
 {
     NS_LOG_FUNCTION(this << entry);
 
-    for (CacheI i = m_ndCache.begin(); i != m_ndCache.end(); i++)
+    for (auto i = m_ndCache.begin(); i != m_ndCache.end(); i++)
     {
         if ((*i).second == entry)
         {
@@ -164,7 +164,7 @@ NdiscCache::Flush()
 {
     NS_LOG_FUNCTION(this);
 
-    for (CacheI i = m_ndCache.begin(); i != m_ndCache.end(); i++)
+    for (auto i = m_ndCache.begin(); i != m_ndCache.end(); i++)
     {
         delete (*i).second; /* delete the pointer NdiscCache::Entry */
     }
@@ -192,7 +192,7 @@ NdiscCache::PrintNdiscCache(Ptr<OutputStreamWrapper> stream)
     NS_LOG_FUNCTION(this << stream);
     std::ostream* os = stream->GetStream();
 
-    for (CacheI i = m_ndCache.begin(); i != m_ndCache.end(); i++)
+    for (auto i = m_ndCache.begin(); i != m_ndCache.end(); i++)
     {
         *os << i->first << " dev ";
         std::string found = Names::FindName(m_device);
@@ -717,7 +717,7 @@ void
 NdiscCache::RemoveAutoGeneratedEntries()
 {
     NS_LOG_FUNCTION(this);
-    for (CacheI i = m_ndCache.begin(); i != m_ndCache.end();)
+    for (auto i = m_ndCache.begin(); i != m_ndCache.end();)
     {
         if (i->second->IsAutoGenerated())
         {
