@@ -20,13 +20,14 @@
 #ifndef RIP_H
 #define RIP_H
 
+#include "ipv4-interface.h"
+#include "ipv4-l3-protocol.h"
+#include "ipv4-routing-protocol.h"
+#include "ipv4-routing-table-entry.h"
+#include "rip-header.h"
+
 #include "ns3/inet-socket-address.h"
-#include "ns3/ipv4-interface.h"
-#include "ns3/ipv4-l3-protocol.h"
-#include "ns3/ipv4-routing-protocol.h"
-#include "ns3/ipv4-routing-table-entry.h"
 #include "ns3/random-variable-stream.h"
-#include "ns3/rip-header.h"
 
 #include <list>
 
