@@ -62,7 +62,7 @@ class TcpSocket : public Socket
      * \brief Names of the 11 TCP states
      *
      */
-    typedef enum
+    enum TcpStates_t
     {
         CLOSED = 0,  /**< Socket is finished                                     */
         LISTEN,      /**< Listening for a connection                             */
@@ -87,7 +87,7 @@ class TcpSocket : public Socket
                       *  may not have gotten our last ACK causing it
                       *  to retransmit the data packet (which we ignore)        */
         LAST_STATE   /**< Last state, used only in debug messages                */
-    } TcpStates_t;
+    };
 
     /**
      * \brief Literal names of TCP states for use in log messages
