@@ -21,10 +21,11 @@
 #ifndef TCP_TX_BUFFER_H
 #define TCP_TX_BUFFER_H
 
+#include "tcp-option-sack.h"
+#include "tcp-tx-item.h"
+
 #include "ns3/object.h"
 #include "ns3/sequence-number.h"
-#include "ns3/tcp-option-sack.h"
-#include "ns3/tcp-tx-item.h"
 #include "ns3/traced-value.h"
 
 namespace ns3
