@@ -399,7 +399,7 @@ void
 IcmpV6EchoReplyTestCase::SendData(Ptr<Socket> socket, Ipv6Address dst)
 {
     Ptr<Packet> p = Create<Packet>();
-    Icmpv6Echo echo(1);
+    Icmpv6Echo echo(true);
     echo.SetSeq(1);
     echo.SetId(0XB1ED);
     p->AddHeader(echo);
@@ -537,7 +537,7 @@ void
 IcmpV6TimeExceedTestCase::SendData(Ptr<Socket> socket, Ipv6Address dst)
 {
     Ptr<Packet> p = Create<Packet>();
-    Icmpv6Echo echo(1);
+    Icmpv6Echo echo(true);
     echo.SetSeq(1);
     echo.SetId(0XB1ED);
     p->AddHeader(echo);
