@@ -20,11 +20,11 @@
 #include "ns3/ipv4-routing-protocol.h"
 #include "ns3/test.h"
 
-using namespace ns3;
+namespace ns3
+{
 
 /**
  * \ingroup internet-test
- * \ingroup tests
  *
  * \brief IPv4 dummy routing class (A)
  */
@@ -42,10 +42,10 @@ class Ipv4ARouting : public Ipv4RoutingProtocol
     bool RouteInput(Ptr<const Packet> p,
                     const Ipv4Header& header,
                     Ptr<const NetDevice> idev,
-                    UnicastForwardCallback ucb,
-                    MulticastForwardCallback mcb,
-                    LocalDeliverCallback lcb,
-                    ErrorCallback ecb) override
+                    const UnicastForwardCallback& ucb,
+                    const MulticastForwardCallback& mcb,
+                    const LocalDeliverCallback& lcb,
+                    const ErrorCallback& ecb) override
     {
         return false;
     }
@@ -77,7 +77,6 @@ class Ipv4ARouting : public Ipv4RoutingProtocol
 
 /**
  * \ingroup internet-test
- * \ingroup tests
  *
  * \brief IPv4 dummy routing class (B)
  */
@@ -95,10 +94,10 @@ class Ipv4BRouting : public Ipv4RoutingProtocol
     bool RouteInput(Ptr<const Packet> p,
                     const Ipv4Header& header,
                     Ptr<const NetDevice> idev,
-                    UnicastForwardCallback ucb,
-                    MulticastForwardCallback mcb,
-                    LocalDeliverCallback lcb,
-                    ErrorCallback ecb) override
+                    const UnicastForwardCallback& ucb,
+                    const MulticastForwardCallback& mcb,
+                    const LocalDeliverCallback& lcb,
+                    const ErrorCallback& ecb) override
     {
         return false;
     }
@@ -130,7 +129,6 @@ class Ipv4BRouting : public Ipv4RoutingProtocol
 
 /**
  * \ingroup internet-test
- * \ingroup tests
  *
  * \brief IPv4 ListRouting negative test.
  */
@@ -165,7 +163,6 @@ Ipv4ListRoutingNegativeTestCase::DoRun()
 
 /**
  * \ingroup internet-test
- * \ingroup tests
  *
  * \brief IPv4 ListRouting positive test.
  */
@@ -205,7 +202,6 @@ Ipv4ListRoutingPositiveTestCase::DoRun()
 
 /**
  * \ingroup internet-test
- * \ingroup tests
  *
  * \brief IPv4 ListRouting TestSuite
  */
@@ -222,3 +218,5 @@ class Ipv4ListRoutingTestSuite : public TestSuite
 
 static Ipv4ListRoutingTestSuite
     g_ipv4ListRoutingTestSuite; //!< Static variable for test initialization
+
+} // namespace ns3
