@@ -232,11 +232,9 @@ TcpRttEstimationWithLossTest::CreateReceiverErrorModel()
 {
     Ptr<TcpSeqErrorModel> errorModel = CreateObject<TcpSeqErrorModel>();
 
-    std::vector<uint32_t>::iterator it;
-
-    for (it = m_toDrop.begin(); it != m_toDrop.end(); ++it)
+    for (auto it = m_toDrop.begin(); it != m_toDrop.end(); ++it)
     {
-        errorModel->AddSeqToKill(SequenceNumber32((*it)));
+        errorModel->AddSeqToKill(SequenceNumber32(*it));
     }
 
     return errorModel;
