@@ -50,9 +50,9 @@ class BeaconPayloadHeader : public Header
     void Print(std::ostream& os) const override;
     /**
      * Set the superframe specification field to the beacon payload header.
-     * \param sfrmField The superframe specification field
+     * \param sfrmField The superframe specification field (bitmap)
      */
-    void SetSuperframeSpecField(SuperframeField sfrmField);
+    void SetSuperframeSpecField(uint16_t sfrmField);
     /**
      * Set the superframe Guaranteed Time Slot (GTS) fields to the beacon payload header.
      * \param gtsFields The GTS fields.
@@ -65,9 +65,9 @@ class BeaconPayloadHeader : public Header
     void SetPndAddrFields(PendingAddrFields pndAddrFields);
     /**
      * Get the superframe specification field from the beacon payload header.
-     * \return The superframe specification field
+     * \return The superframe specification field (bitmap)
      */
-    SuperframeField GetSuperframeSpecField() const;
+    uint16_t GetSuperframeSpecField() const;
     /**
      * Get the Guaranteed Time Slots (GTS) fields from the beacon payload header.
      * \return The GTS fields.
@@ -83,7 +83,7 @@ class BeaconPayloadHeader : public Header
     /**
      * Superframe Specification Field
      */
-    SuperframeField m_superframeField;
+    uint16_t m_superframeField;
     /**
      * GTS Fields
      */
@@ -123,17 +123,6 @@ class CommandPayloadHeader : public Header
         CMD_RESERVED = 0xff          //!< Reserved
     };
 
-    /**
-     *  Association Status Field values.
-     *  See IEEE 802.15.4-2011, Table 6
-     */
-    enum AssocStatus
-    {
-        SUCCESSFUL = 0x00,    //!< Association successful
-        FULL_CAPACITY = 0x01, //!< PAN at capacity
-        ACCESS_DENIED = 0x02  //!< PAN access denied
-    };
-
     CommandPayloadHeader();
     /**
      * Constructor
@@ -161,7 +150,7 @@ class CommandPayloadHeader : public Header
      * Command).
      * \param cap The capability Information field
      */
-    void SetCapabilityField(CapabilityField cap);
+    void SetCapabilityField(uint8_t cap);
     /**
      *  Set the coordinator short address (16 bit address).
      * \param addr The coordinator short address.
@@ -192,7 +181,7 @@ class CommandPayloadHeader : public Header
      * Set status resulting from the association attempt (Association Response Command).
      * \param status The status resulting from the association attempt
      */
-    void SetAssociationStatus(AssocStatus status);
+    void SetAssociationStatus(uint8_t status);
     /**
      * Get the Short address assigned by the coordinator
      * (Association Response and Coordinator Realigment commands).
@@ -203,7 +192,7 @@ class CommandPayloadHeader : public Header
      * Get the status resulting from an association request (Association Response Command).
      * \return The resulting status from an association request
      */
-    AssocStatus GetAssociationStatus() const;
+    uint8_t GetAssociationStatus() const;
     /**
      * Get the command frame type ID
      * \return The command type ID from the command payload header
@@ -212,9 +201,9 @@ class CommandPayloadHeader : public Header
     /**
      * Get the Capability Information Field from the command payload header.
      * (Association Request Command)
-     * \return The Capability Information Field
+     * \return The Capability Information Field (8 bit bitmap)
      */
-    CapabilityField GetCapabilityField() const;
+    uint8_t GetCapabilityField() const;
     /**
      *  Get the coordinator short address.
      * \return The coordinator short address (16 bit address)
@@ -237,17 +226,17 @@ class CommandPayloadHeader : public Header
     uint16_t GetPanId() const;
 
   private:
-    MacCommand m_cmdFrameId;          //!< The command Frame Identifier (Used by all commands)
-    CapabilityField m_capabilityInfo; //!< Capability Information Field
-                                      //!< (Association Request Command)
-    Mac16Address m_shortAddr;         //!< Contains the short address assigned by the coordinator
-                              //!< (Association Response and Coordinator Realiagment Command)
+    MacCommand m_cmdFrameId;       //!< The command Frame Identifier (Used by all commands)
+    uint8_t m_capabilityInfo;      //!< Capability Information Field
+                                   //!< (Association Request Command)
+    Mac16Address m_shortAddr;      //!< Contains the short address assigned by the coordinator
+                                   //!< (Association Response and Coordinator Realiagment Command)
     Mac16Address m_coordShortAddr; //!< The coordinator short address
                                    //!< (Coordinator realigment command)
     uint16_t m_panid;              //!< The PAN identifier (Coordinator realigment command)
     uint8_t m_logCh;               //!< The channel number (Coordinator realigment command)
     uint8_t m_logChPage;           //!< The channel page number (Coordinator realigment command)
-    AssocStatus m_assocStatus;     //!< Association Status (Association Response Command)
+    uint8_t m_assocStatus;         //!< Association Status (Association Response Command)
 };
 
 } // namespace ns3
