@@ -103,11 +103,11 @@ TestRxOffWhenIdleAfterCsmaFailure::DataIndication(McpsDataIndicationParams param
 void
 TestRxOffWhenIdleAfterCsmaFailure::DataConfirm(McpsDataConfirmParams params)
 {
-    if (params.m_status == LrWpanMcpsDataConfirmStatus::IEEE_802_15_4_SUCCESS)
+    if (params.m_status == LrWpanMacStatus::SUCCESS)
     {
         NS_LOG_DEBUG("LrWpanMcpsDataConfirmStatus = Success");
     }
-    else if (params.m_status == LrWpanMcpsDataConfirmStatus::IEEE_802_15_4_CHANNEL_ACCESS_FAILURE)
+    else if (params.m_status == LrWpanMacStatus::CHANNEL_ACCESS_FAILURE)
     {
         NS_LOG_DEBUG("LrWpanMcpsDataConfirmStatus =  Channel Access Failure");
     }
@@ -308,6 +308,7 @@ class TestActiveScanPanDescriptors : public TestCase
      * \param params MLME scan confirm parameters
      */
     void ScanConfirm(MlmeScanConfirmParams params);
+
     /**
      * Function used to notify the reception of a beacon with payload.
      *
@@ -335,7 +336,7 @@ TestActiveScanPanDescriptors::~TestActiveScanPanDescriptors()
 void
 TestActiveScanPanDescriptors::ScanConfirm(MlmeScanConfirmParams params)
 {
-    if (params.m_status == MLMESCAN_SUCCESS)
+    if (params.m_status == LrWpanMacStatus::SUCCESS)
     {
         m_panDescriptorList = params.m_panDescList;
     }
@@ -380,9 +381,16 @@ TestActiveScanPanDescriptors::DoRun()
     Ptr<LrWpanNetDevice> endNodeNetDevice = CreateObject<LrWpanNetDevice>();
     Ptr<LrWpanNetDevice> coord2NetDevice = CreateObject<LrWpanNetDevice>();
 
-    coord1NetDevice->SetAddress(Mac16Address("00:01"));
-    endNodeNetDevice->SetAddress(Mac16Address("00:02"));
-    coord2NetDevice->SetAddress(Mac16Address("00:03"));
+    // PAN coordinators typically have a short address = 00:00 (e.g. Zigbee networks)
+    coord1NetDevice->GetMac()->SetExtendedAddress("00:00:00:00:00:00:CA:FE");
+    coord1NetDevice->GetMac()->SetShortAddress(Mac16Address("00:00"));
+
+    coord2NetDevice->GetMac()->SetExtendedAddress("00:00:00:00:00:00:BE:BE");
+    coord2NetDevice->GetMac()->SetShortAddress(Mac16Address("00:00"));
+
+    // An end device currently not associated (short address = ff:ff)
+    endNodeNetDevice->GetMac()->SetExtendedAddress("00:00:00:00:00:00:00:03");
+    endNodeNetDevice->GetMac()->SetShortAddress(Mac16Address("ff:ff"));
 
     // Configure Spectrum channel
     Ptr<SingleModelSpectrumChannel> channel = CreateObject<SingleModelSpectrumChannel>();
@@ -565,7 +573,7 @@ TestOrphanScan::~TestOrphanScan()
 void
 TestOrphanScan::ScanConfirm(MlmeScanConfirmParams params)
 {
-    if (params.m_status == MLMESCAN_SUCCESS)
+    if (params.m_status == LrWpanMacStatus::SUCCESS)
     {
         m_orphanScanSuccess = true;
     }
