@@ -49,7 +49,7 @@ uint32_t oldByteCounter = 0;             //!< Old Byte counter,
 void
 PrintUePosition(uint64_t imsi)
 {
-    for (NodeList::Iterator it = NodeList::Begin(); it != NodeList::End(); ++it)
+    for (auto it = NodeList::Begin(); it != NodeList::End(); ++it)
     {
         Ptr<Node> node = *it;
         int nDevs = node->GetNDevices();
@@ -381,7 +381,7 @@ main(int argc, char* argv[])
 
     if (enableNsLogs)
     {
-        LogLevel logLevel =
+        auto logLevel =
             (LogLevel)(LOG_PREFIX_FUNC | LOG_PREFIX_NODE | LOG_PREFIX_TIME | LOG_LEVEL_ALL);
         LogComponentEnable("LteUeRrc", logLevel);
         LogComponentEnable("LteUeMac", logLevel);
@@ -632,7 +632,7 @@ main(int argc, char* argv[])
     Config::ConnectWithoutContext(oss.str(), MakeCallback(&ReceivePacket));
 
     bool firstWrite = true;
-    std::string rrcType = useIdealRrc == 1 ? "ideal_rrc" : "real_rrc";
+    std::string rrcType = useIdealRrc ? "ideal_rrc" : "real_rrc";
     std::string fileName = "rlf_dl_thrput_" + std::to_string(enbNodes.GetN()) + "_eNB_" + rrcType;
     Time binSize = Seconds(0.2);
     Simulator::Schedule(Seconds(0.47), &Throughput, firstWrite, binSize, fileName);
