@@ -135,8 +135,7 @@ A3RsrpHandoverAlgorithm::DoReportUeMeas(uint16_t rnti, LteRrcSap::MeasResults me
         uint16_t bestNeighbourCellId = 0;
         uint8_t bestNeighbourRsrp = 0;
 
-        for (std::list<LteRrcSap::MeasResultEutra>::iterator it =
-                 measResults.measResultListEutra.begin();
+        for (auto it = measResults.measResultListEutra.begin();
              it != measResults.measResultListEutra.end();
              ++it)
         {
