@@ -164,9 +164,7 @@ EpcEnbApplication::DoPathSwitchRequest(EpcEnbS1SapProvider::PathSwitchRequestPar
 
     uint16_t gci = params.cellId;
     std::list<EpcS1apSapMme::ErabSwitchedInDownlinkItem> erabToBeSwitchedInDownlinkList;
-    for (std::list<EpcEnbS1SapProvider::BearerToBeSwitched>::iterator bit =
-             params.bearersToBeSwitched.begin();
-         bit != params.bearersToBeSwitched.end();
+    for (auto bit = params.bearersToBeSwitched.begin(); bit != params.bearersToBeSwitched.end();
          ++bit)
     {
         EpsFlowId_t flowId;
@@ -193,12 +191,10 @@ void
 EpcEnbApplication::DoUeContextRelease(uint16_t rnti)
 {
     NS_LOG_FUNCTION(this << rnti);
-    std::map<uint16_t, std::map<uint8_t, uint32_t>>::iterator rntiIt = m_rbidTeidMap.find(rnti);
+    auto rntiIt = m_rbidTeidMap.find(rnti);
     if (rntiIt != m_rbidTeidMap.end())
     {
-        for (std::map<uint8_t, uint32_t>::iterator bidIt = rntiIt->second.begin();
-             bidIt != rntiIt->second.end();
-             ++bidIt)
+        for (auto bidIt = rntiIt->second.begin(); bidIt != rntiIt->second.end(); ++bidIt)
         {
             uint32_t teid = bidIt->second;
             m_teidRbidMap.erase(teid);
@@ -218,13 +214,11 @@ EpcEnbApplication::DoInitialContextSetupRequest(
     NS_LOG_FUNCTION(this);
 
     uint64_t imsi = mmeUeS1Id;
-    std::map<uint64_t, uint16_t>::iterator imsiIt = m_imsiRntiMap.find(imsi);
+    auto imsiIt = m_imsiRntiMap.find(imsi);
     NS_ASSERT_MSG(imsiIt != m_imsiRntiMap.end(), "unknown IMSI");
     uint16_t rnti = imsiIt->second;
 
-    for (std::list<EpcS1apSapEnb::ErabToBeSetupItem>::iterator erabIt = erabToBeSetupList.begin();
-         erabIt != erabToBeSetupList.end();
-         ++erabIt)
+    for (auto erabIt = erabToBeSetupList.begin(); erabIt != erabToBeSetupList.end(); ++erabIt)
     {
         // request the RRC to setup a radio bearer
         EpcEnbS1SapUser::DataRadioBearerSetupRequestParameters params;
@@ -256,7 +250,7 @@ EpcEnbApplication::DoPathSwitchRequestAcknowledge(
     NS_LOG_FUNCTION(this);
 
     uint64_t imsi = mmeUeS1Id;
-    std::map<uint64_t, uint16_t>::iterator imsiIt = m_imsiRntiMap.find(imsi);
+    auto imsiIt = m_imsiRntiMap.find(imsi);
     NS_ASSERT_MSG(imsiIt != m_imsiRntiMap.end(), "unknown IMSI");
     uint16_t rnti = imsiIt->second;
     EpcEnbS1SapUser::PathSwitchRequestAcknowledgeParameters params;
@@ -283,15 +277,15 @@ EpcEnbApplication::RecvFromLteSocket(Ptr<Socket> socket)
     NS_ASSERT(found);
     uint16_t rnti = tag.GetRnti();
     uint8_t bid = tag.GetBid();
-    NS_LOG_LOGIC("received packet with RNTI=" << (uint32_t)rnti << ", BID=" << (uint32_t)bid);
-    std::map<uint16_t, std::map<uint8_t, uint32_t>>::iterator rntiIt = m_rbidTeidMap.find(rnti);
+    NS_LOG_INFO("Received packet with RNTI: " << rnti << ", BID: " << +bid);
+    auto rntiIt = m_rbidTeidMap.find(rnti);
     if (rntiIt == m_rbidTeidMap.end())
     {
         NS_LOG_WARN("UE context not found, discarding packet");
     }
     else
     {
-        std::map<uint8_t, uint32_t>::iterator bidIt = rntiIt->second.find(bid);
+        auto bidIt = rntiIt->second.find(bid);
         NS_ASSERT(bidIt != rntiIt->second.end());
         uint32_t teid = bidIt->second;
         m_rxLteSocketPktTrace(packet->Copy());
@@ -308,7 +302,8 @@ EpcEnbApplication::RecvFromS1uSocket(Ptr<Socket> socket)
     GtpuHeader gtpu;
     packet->RemoveHeader(gtpu);
     uint32_t teid = gtpu.GetTeid();
-    std::map<uint32_t, EpsFlowId_t>::iterator it = m_teidRbidMap.find(teid);
+    NS_LOG_INFO("Received packet from S1-U interface with GTP TEID: " << teid);
+    auto it = m_teidRbidMap.find(teid);
     if (it == m_teidRbidMap.end())
     {
         NS_LOG_WARN("UE context at cell id " << m_cellId << " not found, discarding packet");
@@ -323,9 +318,10 @@ EpcEnbApplication::RecvFromS1uSocket(Ptr<Socket> socket)
 void
 EpcEnbApplication::SendToLteSocket(Ptr<Packet> packet, uint16_t rnti, uint8_t bid)
 {
-    NS_LOG_FUNCTION(this << packet << rnti << (uint16_t)bid << packet->GetSize());
+    NS_LOG_FUNCTION(this << packet << rnti << bid << packet->GetSize());
     EpsBearerTag tag(rnti, bid);
     packet->AddPacketTag(tag);
+    NS_LOG_INFO("Add EpsBearerTag with RNTI " << rnti << " and bearer ID " << +bid);
     uint8_t ipType;
 
     packet->CopyData(&ipType, 1);
@@ -334,10 +330,12 @@ EpcEnbApplication::SendToLteSocket(Ptr<Packet> packet, uint16_t rnti, uint8_t bi
     int sentBytes;
     if (ipType == 0x04)
     {
+        NS_LOG_INFO("Forward packet from eNB's S1-U to LTE stack via IPv4 socket.");
         sentBytes = m_lteSocket->Send(packet);
     }
     else if (ipType == 0x06)
     {
+        NS_LOG_INFO("Forward packet from eNB's S1-U to LTE stack via IPv6 socket.");
         sentBytes = m_lteSocket6->Send(packet);
     }
     else
@@ -359,6 +357,7 @@ EpcEnbApplication::SendToS1uSocket(Ptr<Packet> packet, uint32_t teid)
     gtpu.SetLength(packet->GetSize() + gtpu.GetSerializedSize() - 8);
     packet->AddHeader(gtpu);
     uint32_t flags = 0;
+    NS_LOG_INFO("Forward packet from eNB's LTE to S1-U stack with TEID: " << teid);
     m_s1uSocket->SendTo(packet, flags, InetSocketAddress(m_sgwS1uAddress, m_gtpuUdpPort));
 }
 
