@@ -20,7 +20,8 @@
 #ifndef EPC_X2_SAP_H
 #define EPC_X2_SAP_H
 
-#include "ns3/eps-bearer.h"
+#include "eps-bearer.h"
+
 #include "ns3/ipv4-address.h"
 #include "ns3/packet.h"
 
@@ -232,8 +233,8 @@ class EpcX2Sap
         uint16_t sourceCellId;                  ///< source cell ID
         uint16_t targetCellId;                  ///< target cell ID
         uint32_t mmeUeS1apId;                   ///< MME UE S1 AP ID
-        uint64_t ueAggregateMaxBitRateDownlink; ///< UE aggregrate max bit rate downlink
-        uint64_t ueAggregateMaxBitRateUplink;   ///< UE aggregrate max bit rate uplink
+        uint64_t ueAggregateMaxBitRateDownlink; ///< UE aggregate max bit rate downlink
+        uint64_t ueAggregateMaxBitRateUplink;   ///< UE aggregate max bit rate uplink
         std::vector<ErabToBeSetupItem> bearers; ///< bearers
         Ptr<Packet> rrcContext;                 ///< RRC context
     };
@@ -503,6 +504,9 @@ class EpcX2SpecificEpcX2SapProvider : public EpcX2SapProvider
      */
     EpcX2SpecificEpcX2SapProvider(C* x2);
 
+    // Delete default constructor to avoid misuse
+    EpcX2SpecificEpcX2SapProvider() = delete;
+
     //
     // Interface implemented from EpcX2SapProvider
     //
@@ -562,7 +566,6 @@ class EpcX2SpecificEpcX2SapProvider : public EpcX2SapProvider
     void SendHandoverCancel(HandoverCancelParams params) override;
 
   private:
-    EpcX2SpecificEpcX2SapProvider();
     C* m_x2; ///< owner class
 };
 
@@ -572,11 +575,6 @@ EpcX2SpecificEpcX2SapProvider<C>::EpcX2SpecificEpcX2SapProvider(C* x2)
 {
 }
 
-template <class C>
-EpcX2SpecificEpcX2SapProvider<C>::EpcX2SpecificEpcX2SapProvider()
-{
-}
-
 template <class C>
 void
 EpcX2SpecificEpcX2SapProvider<C>::SendHandoverRequest(HandoverRequestParams params)
@@ -655,6 +653,9 @@ class EpcX2SpecificEpcX2SapUser : public EpcX2SapUser
      */
     EpcX2SpecificEpcX2SapUser(C* rrc);
 
+    // Delete default constructor to avoid misuse
+    EpcX2SpecificEpcX2SapUser() = delete;
+
     //
     // Interface implemented from EpcX2SapUser
     //
@@ -715,7 +716,6 @@ class EpcX2SpecificEpcX2SapUser : public EpcX2SapUser
     void RecvHandoverCancel(HandoverCancelParams params) override;
 
   private:
-    EpcX2SpecificEpcX2SapUser();
     C* m_rrc; ///< owner class
 };
 
@@ -725,11 +725,6 @@ EpcX2SpecificEpcX2SapUser<C>::EpcX2SpecificEpcX2SapUser(C* rrc)
 {
 }
 
-template <class C>
-EpcX2SpecificEpcX2SapUser<C>::EpcX2SpecificEpcX2SapUser()
-{
-}
-
 template <class C>
 void
 EpcX2SpecificEpcX2SapUser<C>::RecvHandoverRequest(HandoverRequestParams params)
