@@ -481,7 +481,7 @@ LteAmc::GetTypeId()
                 "AmcModel",
                 "AMC model used to assign CQI",
                 EnumValue(LteAmc::MiErrorModel),
-                MakeEnumAccessor(&LteAmc::m_amcModel),
+                MakeEnumAccessor<AmcModel>(&LteAmc::m_amcModel),
                 MakeEnumChecker(LteAmc::MiErrorModel, "Vienna", LteAmc::PiroEW2010, "PiroEW2010"));
     return tid;
 }
@@ -524,7 +524,7 @@ LteAmc::GetDlTbSizeFromMcs(int mcs, int nprb)
     NS_ASSERT_MSG(nprb > 0 && nprb < 111, "NPRB=" << nprb);
 
     int itbs = McsToItbsDl[mcs];
-    return (TransportBlockSizeTable[nprb - 1][itbs]);
+    return TransportBlockSizeTable[nprb - 1][itbs];
 }
 
 int
@@ -536,7 +536,7 @@ LteAmc::GetUlTbSizeFromMcs(int mcs, int nprb)
     NS_ASSERT_MSG(nprb > 0 && nprb < 111, "NPRB=" << nprb);
 
     int itbs = McsToItbsUl[mcs];
-    return (TransportBlockSizeTable[nprb - 1][itbs]);
+    return TransportBlockSizeTable[nprb - 1][itbs];
 }
 
 double
@@ -554,11 +554,10 @@ LteAmc::CreateCqiFeedbacks(const SpectrumValue& sinr, uint8_t rbgSize)
     NS_LOG_FUNCTION(this);
 
     std::vector<int> cqi;
-    Values::const_iterator it;
 
     if (m_amcModel == PiroEW2010)
     {
-        for (it = sinr.ConstValuesBegin(); it != sinr.ConstValuesEnd(); it++)
+        for (auto it = sinr.ConstValuesBegin(); it != sinr.ConstValuesEnd(); it++)
         {
             double sinr_ = (*it);
             if (sinr_ == 0.0)
@@ -594,7 +593,7 @@ LteAmc::CreateCqiFeedbacks(const SpectrumValue& sinr, uint8_t rbgSize)
         NS_ASSERT_MSG(rbgSize > 0, " LteAmc-Vienna: RBG size must be greater than 0");
         std::vector<int> rbgMap;
         int rbId = 0;
-        for (it = sinr.ConstValuesBegin(); it != sinr.ConstValuesEnd(); it++)
+        for (auto it = sinr.ConstValuesBegin(); it != sinr.ConstValuesEnd(); it++)
         {
             rbgMap.push_back(rbId++);
             if ((rbId % rbgSize == 0) || ((it + 1) == sinr.ConstValuesEnd()))
