@@ -144,7 +144,7 @@ class SequenceNumber10
     uint16_t operator-(const SequenceNumber10& other) const
     {
         uint16_t diff = m_value - other.m_value;
-        return (diff);
+        return diff;
     }
 
     /**
