@@ -154,9 +154,7 @@ EpcS1uDlTestCase::DoRun()
     uint16_t cellIdCounter = 0;
     uint64_t imsiCounter = 0;
 
-    for (std::vector<EnbDlTestData>::iterator enbit = m_enbDlTestData.begin();
-         enbit < m_enbDlTestData.end();
-         ++enbit)
+    for (auto enbit = m_enbDlTestData.begin(); enbit < m_enbDlTestData.end(); ++enbit)
     {
         Ptr<Node> enb = CreateObject<Node>();
         enbs.Add(enb);
@@ -245,12 +243,9 @@ EpcS1uDlTestCase::DoRun()
 
     Simulator::Run();
 
-    for (std::vector<EnbDlTestData>::iterator enbit = m_enbDlTestData.begin();
-         enbit < m_enbDlTestData.end();
-         ++enbit)
+    for (auto enbit = m_enbDlTestData.begin(); enbit < m_enbDlTestData.end(); ++enbit)
     {
-        for (std::vector<UeDlTestData>::iterator ueit = enbit->ues.begin(); ueit < enbit->ues.end();
-             ++ueit)
+        for (auto ueit = enbit->ues.begin(); ueit < enbit->ues.end(); ++ueit)
         {
             NS_TEST_ASSERT_MSG_EQ(ueit->serverApp->GetTotalRx(),
                                   (ueit->numPkts) * (ueit->pktSize),
