@@ -25,7 +25,6 @@
 #include "ns3/radio-bearer-stats-calculator.h"
 #include "ns3/string.h"
 #include <ns3/boolean.h>
-#include <ns3/config-store-module.h>
 #include <ns3/constant-position-mobility-model.h>
 #include <ns3/enum.h>
 #include <ns3/eps-bearer.h>
@@ -425,8 +424,7 @@ CarrierAggregationTestCase::DoRun()
 
     bool testDownlinkShare = true;
 
-    for (std::map<uint8_t, uint32_t>::iterator itDownlink = m_ccDownlinkTraffic.begin();
-         itDownlink != m_ccDownlinkTraffic.end();
+    for (auto itDownlink = m_ccDownlinkTraffic.begin(); itDownlink != m_ccDownlinkTraffic.end();
          itDownlink++)
     {
         if (itDownlink == m_ccDownlinkTraffic.begin())
@@ -445,9 +443,7 @@ CarrierAggregationTestCase::DoRun()
 
     bool testUplinkShare = true;
 
-    for (std::map<uint8_t, uint32_t>::iterator itUplink = m_ccUplinkTraffic.begin();
-         itUplink != m_ccUplinkTraffic.end();
-         itUplink++)
+    for (auto itUplink = m_ccUplinkTraffic.begin(); itUplink != m_ccUplinkTraffic.end(); itUplink++)
     {
         if (itUplink == m_ccUplinkTraffic.begin())
         {
