@@ -383,7 +383,7 @@ LenaFdBetFfMacSchedulerTestCase2::BuildNameString(uint16_t nUser, std::vector<do
 {
     std::ostringstream oss;
     oss << "distances (m) = [ ";
-    for (std::vector<double>::iterator it = dist.begin(); it != dist.end(); ++it)
+    for (auto it = dist.begin(); it != dist.end(); ++it)
     {
         oss << *it << " ";
     }
