@@ -14,17 +14,21 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Authors: Nicola Baldo <nbaldo@cttc.es>
- *          Manuel Requena <manuel.requena@cttc.es>
+ * Authors:
+ *   Nicola Baldo <nbaldo@cttc.es>
+ *   Manuel Requena <manuel.requena@cttc.es>
  */
 
-#include <ns3/applications-module.h>
+#include <ns3/bulk-send-helper.h>
 #include <ns3/core-module.h>
 #include <ns3/internet-module.h>
 #include <ns3/lte-module.h>
 #include <ns3/mobility-module.h>
 #include <ns3/network-module.h>
+#include <ns3/packet-sink-helper.h>
+#include <ns3/packet-sink.h>
 #include <ns3/point-to-point-module.h>
+#include <ns3/udp-client-server-helper.h>
 
 using namespace ns3;
 
@@ -342,7 +346,7 @@ LteX2HandoverMeasuresTestCase::DoRun()
     NetDeviceContainer enbDevices;
     enbDevices = m_lteHelper->InstallEnbDevice(enbNodes);
     stream += m_lteHelper->AssignStreams(enbDevices, stream);
-    for (NetDeviceContainer::Iterator it = enbDevices.Begin(); it != enbDevices.End(); ++it)
+    for (auto it = enbDevices.Begin(); it != enbDevices.End(); ++it)
     {
         Ptr<LteEnbRrc> enbRrc = (*it)->GetObject<LteEnbNetDevice>()->GetRrc();
         enbRrc->SetAttribute("AdmitHandoverRequest", BooleanValue(m_admitHo));
@@ -538,7 +542,7 @@ LteX2HandoverMeasuresTestCase::DoRun()
 
     // check initial RRC connection
     const Time maxRrcConnectionEstablishmentDuration = Seconds(0.080);
-    for (NetDeviceContainer::Iterator it = ueDevices.Begin(); it != ueDevices.End(); ++it)
+    for (auto it = ueDevices.Begin(); it != ueDevices.End(); ++it)
     {
         NS_LOG_FUNCTION(maxRrcConnectionEstablishmentDuration);
         Simulator::Schedule(maxRrcConnectionEstablishmentDuration,
@@ -551,7 +555,7 @@ LteX2HandoverMeasuresTestCase::DoRun()
     // schedule the checkpoint events
 
     Time stopTime = Seconds(0);
-    for (std::list<CheckPointEvent>::iterator checkPointEventIt = m_checkPointEventList.begin();
+    for (auto checkPointEventIt = m_checkPointEventList.begin();
          checkPointEventIt != m_checkPointEventList.end();
          ++checkPointEventIt)
     {
@@ -639,8 +643,8 @@ LteX2HandoverMeasuresTestCase::CheckConnected(Ptr<NetDevice> ueDevice, Ptr<NetDe
                           m_nDedicatedBearers + 1,
                           "wrong num bearers at UE");
 
-    ObjectMapValue::Iterator enbBearerIt = enbDataRadioBearerMapValue.Begin();
-    ObjectMapValue::Iterator ueBearerIt = ueDataRadioBearerMapValue.Begin();
+    auto enbBearerIt = enbDataRadioBearerMapValue.Begin();
+    auto ueBearerIt = ueDataRadioBearerMapValue.Begin();
     while (enbBearerIt != enbDataRadioBearerMapValue.End() &&
            ueBearerIt != ueDataRadioBearerMapValue.End())
     {
@@ -675,7 +679,7 @@ void
 LteX2HandoverMeasuresTestCase::SaveStats(uint32_t ueIndex)
 {
     NS_LOG_FUNCTION(ueIndex);
-    for (std::list<BearerData>::iterator it = m_ueDataVector.at(ueIndex).bearerDataList.begin();
+    for (auto it = m_ueDataVector.at(ueIndex).bearerDataList.begin();
          it != m_ueDataVector.at(ueIndex).bearerDataList.end();
          ++it)
     {
@@ -695,7 +699,7 @@ LteX2HandoverMeasuresTestCase::CheckStats(uint32_t ueIndex)
 {
     NS_LOG_FUNCTION(ueIndex);
     uint32_t b = 1;
-    for (std::list<BearerData>::iterator it = m_ueDataVector.at(ueIndex).bearerDataList.begin();
+    for (auto it = m_ueDataVector.at(ueIndex).bearerDataList.begin();
          it != m_ueDataVector.at(ueIndex).bearerDataList.end();
          ++it)
     {
@@ -770,10 +774,9 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
         CheckPointEvent(Seconds(25), Seconds(37), checkInterval, 0, 3),
     };
 
-    int32_t useIdealRrc;
     std::string sched = "ns3::PfFfMacScheduler";
     std::string ho = "ns3::A2A4RsrqHandoverAlgorithm";
-    for (useIdealRrc = 1; useIdealRrc >= 0; --useIdealRrc)
+    for (auto useIdealRrc : {true, false})
     {
         // nEnbs, nUes, nDBearers, celist, name, useUdp, sched, ho, admitHo, idealRrc
         AddTestCase(new LteX2HandoverMeasuresTestCase(2,
@@ -878,7 +881,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
     }
 
     sched = "ns3::RrFfMacScheduler";
-    for (useIdealRrc = 1; useIdealRrc >= 0; --useIdealRrc)
+    for (auto useIdealRrc : {true, false})
     {
         // nEnbs, nUes, nDBearers, celist, name, useUdp, sched, admitHo, idealRrc
         AddTestCase(new LteX2HandoverMeasuresTestCase(2,
@@ -918,7 +921,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
 
     ho = "ns3::A3RsrpHandoverAlgorithm";
     sched = "ns3::PfFfMacScheduler";
-    for (useIdealRrc = 1; useIdealRrc >= 0; --useIdealRrc)
+    for (auto useIdealRrc : {true, false})
     {
         // nEnbs, nUes, nDBearers, celist, name, useUdp, sched, admitHo, idealRrc
         AddTestCase(new LteX2HandoverMeasuresTestCase(2,
@@ -957,7 +960,7 @@ LteX2HandoverMeasuresTestSuite::LteX2HandoverMeasuresTestSuite()
     }
 
     sched = "ns3::RrFfMacScheduler";
-    for (useIdealRrc = 1; useIdealRrc >= 0; --useIdealRrc)
+    for (auto useIdealRrc : {true, false})
     {
         // nEnbs, nUes, nDBearers, celist, name, useUdp, sched, admitHo, idealRrc
         AddTestCase(new LteX2HandoverMeasuresTestCase(2,
