@@ -17,13 +17,15 @@
  * Author: Nicola Baldo <nbaldo@cttc.es>
  */
 
-#include <ns3/applications-module.h>
 #include <ns3/core-module.h>
 #include <ns3/internet-module.h>
 #include <ns3/lte-module.h>
 #include <ns3/mobility-module.h>
 #include <ns3/network-module.h>
+#include <ns3/packet-sink-helper.h>
+#include <ns3/packet-sink.h>
 #include <ns3/point-to-point-module.h>
+#include <ns3/udp-client-server-helper.h>
 
 using namespace ns3;
 
@@ -274,7 +276,7 @@ LteX2HandoverTestCase::DoRun()
     NetDeviceContainer enbDevices;
     enbDevices = m_lteHelper->InstallEnbDevice(enbNodes);
     stream += m_lteHelper->AssignStreams(enbDevices, stream);
-    for (NetDeviceContainer::Iterator it = enbDevices.Begin(); it != enbDevices.End(); ++it)
+    for (auto it = enbDevices.Begin(); it != enbDevices.End(); ++it)
     {
         Ptr<LteEnbRrc> enbRrc = (*it)->GetObject<LteEnbNetDevice>()->GetRrc();
         enbRrc->SetAttribute("AdmitHandoverRequest", BooleanValue(m_admitHo));
@@ -438,7 +440,7 @@ LteX2HandoverTestCase::DoRun()
 
     // check initial RRC connection
     const Time maxRrcConnectionEstablishmentDuration = Seconds(0.080);
-    for (NetDeviceContainer::Iterator it = ueDevices.Begin(); it != ueDevices.End(); ++it)
+    for (auto it = ueDevices.Begin(); it != ueDevices.End(); ++it)
     {
         Simulator::Schedule(maxRrcConnectionEstablishmentDuration,
                             &LteX2HandoverTestCase::CheckConnected,
@@ -450,8 +452,7 @@ LteX2HandoverTestCase::DoRun()
     // schedule handover events and corresponding checks
 
     Time stopTime = Seconds(0);
-    for (std::list<HandoverEvent>::iterator hoEventIt = m_handoverEventList.begin();
-         hoEventIt != m_handoverEventList.end();
+    for (auto hoEventIt = m_handoverEventList.begin(); hoEventIt != m_handoverEventList.end();
          ++hoEventIt)
     {
         // Teleport the UE between both eNBs just before the handover starts
@@ -567,8 +568,8 @@ LteX2HandoverTestCase::CheckConnected(Ptr<NetDevice> ueDevice, Ptr<NetDevice> en
                           m_nDedicatedBearers + 1,
                           "wrong num bearers at UE");
 
-    ObjectMapValue::Iterator enbBearerIt = enbDataRadioBearerMapValue.Begin();
-    ObjectMapValue::Iterator ueBearerIt = ueDataRadioBearerMapValue.Begin();
+    auto enbBearerIt = enbDataRadioBearerMapValue.Begin();
+    auto ueBearerIt = ueDataRadioBearerMapValue.Begin();
     while (enbBearerIt != enbDataRadioBearerMapValue.End() &&
            ueBearerIt != ueDataRadioBearerMapValue.End())
     {
@@ -619,7 +620,7 @@ LteX2HandoverTestCase::TeleportUeNearTargetEnb(Ptr<Node> ueNode, Ptr<Node> enbNo
 void
 LteX2HandoverTestCase::SaveStatsAfterHandover(uint32_t ueIndex)
 {
-    for (std::list<BearerData>::iterator it = m_ueDataVector.at(ueIndex).bearerDataList.begin();
+    for (auto it = m_ueDataVector.at(ueIndex).bearerDataList.begin();
          it != m_ueDataVector.at(ueIndex).bearerDataList.end();
          ++it)
     {
@@ -632,7 +633,7 @@ void
 LteX2HandoverTestCase::CheckStatsAWhileAfterHandover(uint32_t ueIndex)
 {
     uint32_t b = 1;
-    for (std::list<BearerData>::iterator it = m_ueDataVector.at(ueIndex).bearerDataList.begin();
+    for (auto it = m_ueDataVector.at(ueIndex).bearerDataList.begin();
          it != m_ueDataVector.at(ueIndex).bearerDataList.end();
          ++it)
     {
@@ -759,11 +760,9 @@ LteX2HandoverTestSuite::LteX2HandoverTestSuite()
         "ns3::PfFfMacScheduler",
     };
 
-    for (std::vector<std::string>::iterator schedIt = schedulers.begin();
-         schedIt != schedulers.end();
-         ++schedIt)
+    for (auto schedIt = schedulers.begin(); schedIt != schedulers.end(); ++schedIt)
     {
-        for (int32_t useIdealRrc = 1; useIdealRrc >= 0; --useIdealRrc)
+        for (auto useIdealRrc : {true, false})
         {
             // nUes, nDBearers, helist, name, sched, admitHo, idealRrc
             AddTestCase(new LteX2HandoverTestCase(1,
