@@ -201,9 +201,7 @@ void
 HwmpProtocol::DoDispose()
 {
     NS_LOG_FUNCTION(this);
-    for (std::map<Mac48Address, PreqEvent>::iterator i = m_preqTimeouts.begin();
-         i != m_preqTimeouts.end();
-         i++)
+    for (auto i = m_preqTimeouts.begin(); i != m_preqTimeouts.end(); i++)
     {
         i->second.preqTimeout.Cancel();
     }
@@ -263,14 +261,10 @@ HwmpProtocol::RequestRoute(uint32_t sourceIface,
         m_stats.txBytes += packet->GetSize();
         // channel IDs where we have already sent broadcast:
         std::vector<uint16_t> channels;
-        for (HwmpProtocolMacMap::const_iterator plugin = m_interfaces.begin();
-             plugin != m_interfaces.end();
-             plugin++)
+        for (auto plugin = m_interfaces.begin(); plugin != m_interfaces.end(); plugin++)
         {
             bool shouldSend = true;
-            for (std::vector<uint16_t>::const_iterator chan = channels.begin();
-                 chan != channels.end();
-                 chan++)
+            for (auto chan = channels.begin(); chan != channels.end(); chan++)
             {
                 if ((*chan) == plugin->second->GetChannelId())
                 {
@@ -283,9 +277,7 @@ HwmpProtocol::RequestRoute(uint32_t sourceIface,
             }
             channels.push_back(plugin->second->GetChannelId());
             std::vector<Mac48Address> receivers = GetBroadcastReceivers(plugin->first);
-            for (std::vector<Mac48Address>::const_iterator i = receivers.begin();
-                 i != receivers.end();
-                 i++)
+            for (auto i = receivers.begin(); i != receivers.end(); i++)
             {
                 Ptr<Packet> packetCopy = packet->Copy();
                 //
@@ -396,8 +388,7 @@ HwmpProtocol::ForwardUnicast(uint32_t sourceIface,
             dst_seqno = result.seqnum;
         }
         m_stats.initiatedPreq++;
-        for (HwmpProtocolMacMap::const_iterator i = m_interfaces.begin(); i != m_interfaces.end();
-             i++)
+        for (auto i = m_interfaces.begin(); i != m_interfaces.end(); i++)
         {
             i->second->RequestDestination(destination, originator_seqno, dst_seqno);
         }
@@ -433,8 +424,7 @@ HwmpProtocol::ReceivePreq(IePreq preq,
     NS_LOG_FUNCTION(this << from << interface << fromMp << metric);
     preq.IncrementMetric(metric);
     // acceptance cretirea:
-    std::map<Mac48Address, std::pair<uint32_t, uint32_t>>::const_iterator i =
-        m_hwmpSeqnoMetricDatabase.find(preq.GetOriginatorAddress());
+    auto i = m_hwmpSeqnoMetricDatabase.find(preq.GetOriginatorAddress());
     bool freshInfo(true);
     if (i != m_hwmpSeqnoMetricDatabase.end())
     {
@@ -501,9 +491,7 @@ HwmpProtocol::ReceivePreq(IePreq preq,
         m_routeChangeTraceSource(rChange);
         ReactivePathResolved(fromMp);
     }
-    for (std::vector<Ptr<DestinationAddressUnit>>::const_iterator i = destinations.begin();
-         i != destinations.end();
-         i++)
+    for (auto i = destinations.begin(); i != destinations.end(); i++)
     {
         if ((*i)->GetDestinationAddress() == Mac48Address::GetBroadcast())
         {
@@ -603,7 +591,7 @@ HwmpProtocol::ReceivePreq(IePreq preq,
     }
     // Forward PREQ to all interfaces:
     NS_LOG_DEBUG("I am " << GetAddress() << "retransmitting PREQ:" << preq);
-    for (HwmpProtocolMacMap::const_iterator i = m_interfaces.begin(); i != m_interfaces.end(); i++)
+    for (auto i = m_interfaces.begin(); i != m_interfaces.end(); i++)
     {
         Time forwardingDelay = GetMeshPoint()->GetForwardingDelay();
         NS_LOG_DEBUG("Forwarding PREQ from " << from << " with delay "
@@ -622,8 +610,7 @@ HwmpProtocol::ReceivePrep(IePrep prep,
     NS_LOG_FUNCTION(this << from << interface << fromMp << metric);
     prep.IncrementMetric(metric);
     // acceptance cretirea:
-    std::map<Mac48Address, std::pair<uint32_t, uint32_t>>::const_iterator i =
-        m_hwmpSeqnoMetricDatabase.find(prep.GetOriginatorAddress());
+    auto i = m_hwmpSeqnoMetricDatabase.find(prep.GetOriginatorAddress());
     bool freshInfo(true);
     uint32_t sequence = prep.GetDestinationSeqNumber();
     if (i != m_hwmpSeqnoMetricDatabase.end())
@@ -711,7 +698,7 @@ HwmpProtocol::ReceivePrep(IePrep prep,
         return;
     }
     // Forward PREP
-    HwmpProtocolMacMap::const_iterator prep_sender = m_interfaces.find(result.ifIndex);
+    auto prep_sender = m_interfaces.find(result.ifIndex);
     NS_ASSERT(prep_sender != m_interfaces.end());
     Time forwardingDelay = GetMeshPoint()->GetForwardingDelay();
     NS_LOG_DEBUG("Forwarding PREP from " << from << " with delay " << forwardingDelay.As(Time::US));
@@ -768,7 +755,7 @@ HwmpProtocol::SendPrep(Mac48Address src,
     prep.SetMetric(initMetric);
     prep.SetOriginatorAddress(src);
     prep.SetOriginatorSeqNumber(originatorDsn);
-    HwmpProtocolMacMap::const_iterator prep_sender = m_interfaces.find(interface);
+    auto prep_sender = m_interfaces.find(interface);
     NS_ASSERT(prep_sender != m_interfaces.end());
     prep_sender->second->SendPrep(prep, retransmitter);
     m_stats.initiatedPrep++;
@@ -780,8 +767,7 @@ HwmpProtocol::Install(Ptr<MeshPointDevice> mp)
     NS_LOG_FUNCTION(this << mp);
     m_mp = mp;
     std::vector<Ptr<NetDevice>> interfaces = mp->GetInterfaces();
-    for (std::vector<Ptr<NetDevice>>::const_iterator i = interfaces.begin(); i != interfaces.end();
-         i++)
+    for (auto i = interfaces.begin(); i != interfaces.end(); i++)
     {
         // Checking for compatible net device
         Ptr<WifiNetDevice> wifiNetDev = (*i)->GetObject<WifiNetDevice>();
@@ -841,8 +827,7 @@ HwmpProtocol::DropDataFrame(uint32_t seqno, Mac48Address source)
         NS_LOG_DEBUG("Dropping seqno " << seqno << "; from self");
         return true;
     }
-    std::map<Mac48Address, uint32_t, std::less<Mac48Address>>::const_iterator i =
-        m_lastDataSeqno.find(source);
+    const auto i = m_lastDataSeqno.find(source);
     if (i == m_lastDataSeqno.end())
     {
         m_lastDataSeqno[source] = seqno;
@@ -889,7 +874,7 @@ void
 HwmpProtocol::InitiatePathError(PathError perr)
 {
     NS_LOG_FUNCTION(this);
-    for (HwmpProtocolMacMap::const_iterator i = m_interfaces.begin(); i != m_interfaces.end(); i++)
+    for (auto i = m_interfaces.begin(); i != m_interfaces.end(); i++)
     {
         std::vector<Mac48Address> receivers_for_interface;
         for (unsigned int j = 0; j < perr.receivers.size(); j++)
@@ -907,7 +892,7 @@ void
 HwmpProtocol::ForwardPathError(PathError perr)
 {
     NS_LOG_FUNCTION(this);
-    for (HwmpProtocolMacMap::const_iterator i = m_interfaces.begin(); i != m_interfaces.end(); i++)
+    for (auto i = m_interfaces.begin(); i != m_interfaces.end(); i++)
     {
         std::vector<Mac48Address> receivers_for_interface;
         for (unsigned int j = 0; j < perr.receivers.size(); j++)
@@ -1021,7 +1006,7 @@ HwmpProtocol::DequeueFirstPacketByDst(Mac48Address dst)
     NS_LOG_FUNCTION(this << dst);
     QueuedPacket retval;
     retval.pkt = nullptr;
-    for (std::vector<QueuedPacket>::iterator i = m_rqueue.begin(); i != m_rqueue.end(); i++)
+    for (auto i = m_rqueue.begin(); i != m_rqueue.end(); i++)
     {
         if ((*i).dst == dst)
         {
@@ -1051,7 +1036,7 @@ void
 HwmpProtocol::ReactivePathResolved(Mac48Address dst)
 {
     NS_LOG_FUNCTION(this << dst);
-    std::map<Mac48Address, PreqEvent>::iterator i = m_preqTimeouts.find(dst);
+    auto i = m_preqTimeouts.find(dst);
     if (i != m_preqTimeouts.end())
     {
         m_routeDiscoveryTimeCallback(Simulator::Now() - i->second.whenScheduled);
@@ -1106,7 +1091,7 @@ bool
 HwmpProtocol::ShouldSendPreq(Mac48Address dst)
 {
     NS_LOG_FUNCTION(this << dst);
-    std::map<Mac48Address, PreqEvent>::const_iterator i = m_preqTimeouts.find(dst);
+    auto i = m_preqTimeouts.find(dst);
     if (i == m_preqTimeouts.end())
     {
         m_preqTimeouts[dst].preqTimeout =
@@ -1132,7 +1117,7 @@ HwmpProtocol::RetryPathDiscovery(Mac48Address dst, uint8_t numOfRetry)
     }
     if (result.retransmitter != Mac48Address::GetBroadcast())
     {
-        std::map<Mac48Address, PreqEvent>::iterator i = m_preqTimeouts.find(dst);
+        auto i = m_preqTimeouts.find(dst);
         NS_ASSERT(i != m_preqTimeouts.end());
         m_preqTimeouts.erase(i);
         return;
@@ -1152,7 +1137,7 @@ HwmpProtocol::RetryPathDiscovery(Mac48Address dst, uint8_t numOfRetry)
                          HwmpRtable::MAX_METRIC);
             packet = DequeueFirstPacketByDst(dst);
         }
-        std::map<Mac48Address, PreqEvent>::iterator i = m_preqTimeouts.find(dst);
+        auto i = m_preqTimeouts.find(dst);
         NS_ASSERT(i != m_preqTimeouts.end());
         m_routeDiscoveryTimeCallback(Simulator::Now() - i->second.whenScheduled);
         m_preqTimeouts.erase(i);
@@ -1161,7 +1146,7 @@ HwmpProtocol::RetryPathDiscovery(Mac48Address dst, uint8_t numOfRetry)
     numOfRetry++;
     uint32_t originator_seqno = GetNextHwmpSeqno();
     uint32_t dst_seqno = m_rtable->LookupReactiveExpired(dst).seqnum;
-    for (HwmpProtocolMacMap::const_iterator i = m_interfaces.begin(); i != m_interfaces.end(); i++)
+    for (auto i = m_interfaces.begin(); i != m_interfaces.end(); i++)
     {
         i->second->RequestDestination(dst, originator_seqno, dst_seqno);
     }
@@ -1204,7 +1189,7 @@ HwmpProtocol::SendProactivePreq()
     preq.SetOriginatorAddress(GetAddress());
     preq.SetPreqID(GetNextPreqId());
     preq.SetOriginatorSeqNumber(GetNextHwmpSeqno());
-    for (HwmpProtocolMacMap::const_iterator i = m_interfaces.begin(); i != m_interfaces.end(); i++)
+    for (auto i = m_interfaces.begin(); i != m_interfaces.end(); i++)
     {
         i->second->SendPreq(preq);
     }
@@ -1352,9 +1337,7 @@ HwmpProtocol::Report(std::ostream& os) const
        << "doFlag=\"" << m_doFlag << "\"" << std::endl
        << "rfFlag=\"" << m_rfFlag << "\">" << std::endl;
     m_stats.Print(os);
-    for (HwmpProtocolMacMap::const_iterator plugin = m_interfaces.begin();
-         plugin != m_interfaces.end();
-         plugin++)
+    for (auto plugin = m_interfaces.begin(); plugin != m_interfaces.end(); plugin++)
     {
         plugin->second->Report(os);
     }
@@ -1366,9 +1349,7 @@ HwmpProtocol::ResetStats()
 {
     NS_LOG_FUNCTION(this);
     m_stats = Statistics();
-    for (HwmpProtocolMacMap::const_iterator plugin = m_interfaces.begin();
-         plugin != m_interfaces.end();
-         plugin++)
+    for (auto plugin = m_interfaces.begin(); plugin != m_interfaces.end(); plugin++)
     {
         plugin->second->ResetStats();
     }
