@@ -21,11 +21,12 @@
 #ifndef PEER_LINK_H
 #define PEER_LINK_H
 
+#include "ie-dot11s-beacon-timing.h"
+#include "ie-dot11s-configuration.h"
+#include "ie-dot11s-peer-management.h"
+
 #include "ns3/callback.h"
 #include "ns3/event-id.h"
-#include "ns3/ie-dot11s-beacon-timing.h"
-#include "ns3/ie-dot11s-configuration.h"
-#include "ns3/ie-dot11s-peer-management.h"
 #include "ns3/mac48-address.h"
 #include "ns3/nstime.h"
 #include "ns3/object.h"
