@@ -18,10 +18,11 @@
  *          Pavel Boyko <boyko@iitp.ru>
  */
 
-#include "ns3/mesh-l2-routing-protocol.h"
+#include "mesh-l2-routing-protocol.h"
+
+#include "mesh-point-device.h"
 
 #include "ns3/log.h"
-#include "ns3/mesh-point-device.h"
 
 namespace ns3
 {
