@@ -18,10 +18,11 @@
  *         Pavel Boyko <boyko@iitp.ru>
  */
 
-#include "ns3/mesh-point-device.h"
+#include "mesh-point-device.h"
+
+#include "mesh-wifi-interface-mac.h"
 
 #include "ns3/log.h"
-#include "ns3/mesh-wifi-interface-mac.h"
 #include "ns3/packet.h"
 #include "ns3/pointer.h"
 #include "ns3/simulator.h"
@@ -82,8 +83,7 @@ void
 MeshPointDevice::DoDispose()
 {
     NS_LOG_FUNCTION(this);
-    for (std::vector<Ptr<NetDevice>>::iterator iter = m_ifaces.begin(); iter != m_ifaces.end();
-         iter++)
+    for (auto iter = m_ifaces.begin(); iter != m_ifaces.end(); iter++)
     {
         *iter = nullptr;
     }
@@ -174,16 +174,16 @@ MeshPointDevice::ReceiveFromDevice(Ptr<NetDevice> incomingPort,
 }
 
 void
-MeshPointDevice::Forward(Ptr<NetDevice> inport,
+MeshPointDevice::Forward(Ptr<NetDevice> incomingPort,
                          Ptr<const Packet> packet,
                          uint16_t protocol,
                          const Mac48Address src,
                          const Mac48Address dst)
 {
-    NS_LOG_FUNCTION(this << inport << packet << protocol << src << dst);
+    NS_LOG_FUNCTION(this << incomingPort << packet << protocol << src << dst);
     // pass through routing protocol
     NS_LOG_DEBUG("Forwarding from " << src << " to " << dst << " at " << m_address);
-    bool result = m_routingProtocol->RequestRoute(inport->GetIfIndex(),
+    bool result = m_routingProtocol->RequestRoute(incomingPort->GetIfIndex(),
                                                   src,
                                                   dst,
                                                   packet,
@@ -398,11 +398,11 @@ Ptr<NetDevice>
 MeshPointDevice::GetInterface(uint32_t n) const
 {
     NS_LOG_FUNCTION(this << n);
-    for (std::vector<Ptr<NetDevice>>::const_iterator i = m_ifaces.begin(); i != m_ifaces.end(); i++)
+    for (auto i = m_ifaces.begin(); i != m_ifaces.end(); i++)
     {
         if ((*i)->GetIfIndex() == n)
         {
-            return (*i);
+            return *i;
         }
     }
     NS_FATAL_ERROR("Mesh point interface is not found by index");
@@ -515,7 +515,7 @@ MeshPointDevice::DoSend(bool success,
     }
     else
     {
-        for (std::vector<Ptr<NetDevice>>::iterator i = m_ifaces.begin(); i != m_ifaces.end(); i++)
+        for (auto i = m_ifaces.begin(); i != m_ifaces.end(); i++)
         {
             (*i)->SendFrom(packet->Copy(), src, dst, protocol);
         }
