@@ -18,14 +18,15 @@
  *          Pavel Boyko <boyko@iitp.ru>
  */
 
-#include "ns3/mesh-wifi-interface-mac.h"
+#include "mesh-wifi-interface-mac.h"
+
+#include "mesh-wifi-beacon.h"
 
 #include "ns3/boolean.h"
 #include "ns3/channel-access-manager.h"
 #include "ns3/double.h"
 #include "ns3/log.h"
 #include "ns3/mac-tx-middle.h"
-#include "ns3/mesh-wifi-beacon.h"
 #include "ns3/pointer.h"
 #include "ns3/qos-txop.h"
 #include "ns3/random-variable-stream.h"
@@ -166,7 +167,7 @@ MeshWifiInterfaceMac::AssignStreams(int64_t stream)
     NS_LOG_FUNCTION(this << stream);
     int64_t currentStream = stream;
     m_coefficient->SetStream(currentStream++);
-    for (PluginList::const_iterator i = m_plugins.begin(); i < m_plugins.end(); i++)
+    for (auto i = m_plugins.begin(); i < m_plugins.end(); i++)
     {
         currentStream += (*i)->AssignStreams(currentStream);
     }
@@ -239,7 +240,7 @@ MeshWifiInterfaceMac::ForwardDown(Ptr<Packet> packet, Mac48Address from, Mac48Ad
     // Address 1 is unknown here. Routing plugin is responsible to correctly set it.
     hdr.SetAddr1(Mac48Address());
     // Filter packet through all installed plugins
-    for (PluginList::const_iterator i = m_plugins.end() - 1; i != m_plugins.begin() - 1; i--)
+    for (auto i = m_plugins.end() - 1; i != m_plugins.begin() - 1; i--)
     {
         bool drop = !((*i)->UpdateOutcomingFrame(packet, hdr, from, to));
         if (drop)
@@ -285,7 +286,7 @@ MeshWifiInterfaceMac::SendManagementFrame(Ptr<Packet> packet, const WifiMacHeade
 {
     // Filter management frames:
     WifiMacHeader header = hdr;
-    for (PluginList::const_iterator i = m_plugins.end() - 1; i != m_plugins.begin() - 1; i--)
+    for (auto i = m_plugins.end() - 1; i != m_plugins.begin() - 1; i--)
     {
         bool drop = !((*i)->UpdateOutcomingFrame(packet, header, Mac48Address(), Mac48Address()));
         if (drop)
@@ -428,7 +429,7 @@ MeshWifiInterfaceMac::SendBeacon()
     MeshWifiBeacon beacon(GetSsid(), GetSupportedRates(), m_beaconInterval.GetMicroSeconds());
 
     // Ask all plugins to add their specific information elements to beacon
-    for (PluginList::const_iterator i = m_plugins.begin(); i != m_plugins.end(); ++i)
+    for (auto i = m_plugins.begin(); i != m_plugins.end(); ++i)
     {
         (*i)->UpdateBeacon(beacon);
     }
@@ -486,7 +487,7 @@ MeshWifiInterfaceMac::Receive(Ptr<const WifiMpdu> mpdu, uint8_t linkId)
         m_stats.recvFrames++;
     }
     // Filter frame through all installed plugins
-    for (PluginList::iterator i = m_plugins.begin(); i != m_plugins.end(); ++i)
+    for (auto i = m_plugins.begin(); i != m_plugins.end(); ++i)
     {
         bool drop = !((*i)->Receive(packet, *hdr));
         if (drop)
