@@ -186,8 +186,7 @@ HwmpRtableTest::TestExpire()
 void
 HwmpRtableTest::TestPrecursorAdd()
 {
-    for (std::vector<Mac48Address>::const_iterator i = precursors.begin(); i != precursors.end();
-         i++)
+    for (auto i = precursors.begin(); i != precursors.end(); i++)
     {
         table->AddPrecursor(dst, iface, *i, Seconds(100));
         // Check that duplicates are filtered
