@@ -20,8 +20,9 @@
 #ifndef APPLICATION_H
 #define APPLICATION_H
 
+#include "node.h"
+
 #include "ns3/event-id.h"
-#include "ns3/node.h"
 #include "ns3/nstime.h"
 #include "ns3/object.h"
 #include "ns3/ptr.h"
