@@ -88,7 +88,7 @@ Buffer::LocalStaticDestructor::~LocalStaticDestructor()
     NS_LOG_FUNCTION(this);
     if (IS_INITIALIZED(g_freeList))
     {
-        for (Buffer::FreeList::iterator i = g_freeList->begin(); i != g_freeList->end(); i++)
+        for (auto i = g_freeList->begin(); i != g_freeList->end(); i++)
         {
             Buffer::Deallocate(*i);
         }
@@ -173,8 +173,8 @@ Buffer::Allocate(uint32_t reqSize)
     NS_ASSERT(reqSize >= 1);
     reqSize += ALLOC_OVER_PROVISION;
     uint32_t size = reqSize - 1 + sizeof(Buffer::Data);
-    uint8_t* b = new uint8_t[size];
-    Buffer::Data* data = reinterpret_cast<Buffer::Data*>(b);
+    auto b = new uint8_t[size];
+    auto data = reinterpret_cast<Buffer::Data*>(b);
     data->m_size = reqSize;
     data->m_count = 1;
     return data;
@@ -185,7 +185,7 @@ Buffer::Deallocate(Buffer::Data* data)
 {
     NS_LOG_FUNCTION(data);
     NS_ASSERT(data->m_count == 0);
-    uint8_t* buf = reinterpret_cast<uint8_t*>(data);
+    auto buf = reinterpret_cast<uint8_t*>(data);
     delete[] buf;
 }
 
@@ -582,70 +582,64 @@ uint32_t
 Buffer::Serialize(uint8_t* buffer, uint32_t maxSize) const
 {
     NS_LOG_FUNCTION(this << &buffer << maxSize);
-    uint32_t* p = reinterpret_cast<uint32_t*>(buffer);
+    auto p = reinterpret_cast<uint32_t*>(buffer);
     uint32_t size = 0;
 
     // Add the zero data length
-    if (size + 4 <= maxSize)
-    {
-        size += 4;
-        *p++ = m_zeroAreaEnd - m_zeroAreaStart;
-    }
-    else
+    size += 4;
+
+    if (size > maxSize)
     {
         return 0;
     }
 
+    *p++ = m_zeroAreaEnd - m_zeroAreaStart;
+
     // Add the length of actual start data
-    uint32_t dataStartLength = m_zeroAreaStart - m_start;
-    if (size + 4 <= maxSize)
-    {
-        size += 4;
-        *p++ = dataStartLength;
-    }
-    else
+    size += 4;
+
+    if (size > maxSize)
     {
         return 0;
     }
 
+    uint32_t dataStartLength = m_zeroAreaStart - m_start;
+    *p++ = dataStartLength;
+
     // Add the actual data
-    if (size + ((dataStartLength + 3) & (~3)) <= maxSize)
-    {
-        size += (dataStartLength + 3) & (~3);
-        memcpy(p, m_data->m_data + m_start, dataStartLength);
-        p += (((dataStartLength + 3) & (~3)) / 4); // Advance p, insuring 4 byte boundary
-    }
-    else
+    size += (dataStartLength + 3) & (~3);
+
+    if (size > maxSize)
     {
         return 0;
     }
 
+    memcpy(p, m_data->m_data + m_start, dataStartLength);
+    p += (((dataStartLength + 3) & (~3)) / 4); // Advance p, insuring 4 byte boundary
+
     // Add the length of the actual end data
-    uint32_t dataEndLength = m_end - m_zeroAreaEnd;
-    if (size + 4 <= maxSize)
-    {
-        size += 4;
-        *p++ = dataEndLength;
-    }
-    else
+    size += 4;
+
+    if (size > maxSize)
     {
         return 0;
     }
 
+    uint32_t dataEndLength = m_end - m_zeroAreaEnd;
+    *p++ = dataEndLength;
+
     // Add the actual data
-    if (size + ((dataEndLength + 3) & (~3)) <= maxSize)
-    {
-        // The following line is unnecessary.
-        // size += (dataEndLength + 3) & (~3);
-        memcpy(p, m_data->m_data + m_zeroAreaStart, dataEndLength);
-        // The following line is unnecessary.
-        // p += (((dataEndLength + 3) & (~3))/4); // Advance p, insuring 4 byte boundary
-    }
-    else
+    size += (dataEndLength + 3) & (~3);
+
+    if (size > maxSize)
     {
         return 0;
     }
 
+    memcpy(p, m_data->m_data + m_zeroAreaStart, dataEndLength);
+    // The following line is unnecessary.
+    // p += (((dataEndLength + 3) & (~3))/4); // Advance p, insuring 4 byte boundary
+
     // Serialized everything successfully
     return 1;
 }
@@ -654,7 +648,7 @@ uint32_t
 Buffer::Deserialize(const uint8_t* buffer, uint32_t size)
 {
     NS_LOG_FUNCTION(this << &buffer << size);
-    const uint32_t* p = reinterpret_cast<const uint32_t*>(buffer);
+    auto p = reinterpret_cast<const uint32_t*>(buffer);
     uint32_t sizeCheck = size - 4;
 
     NS_ASSERT(sizeCheck >= 4);
