@@ -67,9 +67,9 @@ static uint32_t g_maxSize = 0; //!< maximum data size (used for allocation)
 ByteTagListDataFreeList::~ByteTagListDataFreeList()
 {
     NS_LOG_FUNCTION(this);
-    for (ByteTagListDataFreeList::iterator i = begin(); i != end(); i++)
+    for (auto i = begin(); i != end(); i++)
     {
-        uint8_t* buffer = (uint8_t*)(*i);
+        auto buffer = (uint8_t*)(*i);
         delete[] buffer;
     }
 }
@@ -366,11 +366,11 @@ ByteTagList::Allocate(uint32_t size)
             data->dirty = 0;
             return data;
         }
-        uint8_t* buffer = (uint8_t*)data;
+        auto buffer = (uint8_t*)data;
         delete[] buffer;
     }
-    uint8_t* buffer = new uint8_t[std::max(size, g_maxSize) + sizeof(ByteTagListData) - 4];
-    ByteTagListData* data = (ByteTagListData*)buffer;
+    auto buffer = new uint8_t[std::max(size, g_maxSize) + sizeof(ByteTagListData) - 4];
+    auto data = (ByteTagListData*)buffer;
     data->count = 1;
     data->size = size;
     data->dirty = 0;
@@ -391,7 +391,7 @@ ByteTagList::Deallocate(ByteTagListData* data)
     {
         if (g_freeList.size() > FREE_LIST_SIZE || data->size < g_maxSize)
         {
-            uint8_t* buffer = (uint8_t*)data;
+            auto buffer = (uint8_t*)data;
             delete[] buffer;
         }
         else
@@ -470,19 +470,16 @@ ByteTagList::Serialize(uint32_t* buffer, uint32_t maxSize) const
     uint32_t* p = buffer;
     uint32_t size = 0;
 
-    uint32_t* numberOfTags = nullptr;
+    size += 4;
 
-    if (size + 4 <= maxSize)
-    {
-        numberOfTags = p;
-        *p++ = 0;
-        size += 4;
-    }
-    else
+    if (size > maxSize)
     {
         return 0;
     }
 
+    uint32_t* numberOfTags = p;
+    *p++ = 0;
+
     ByteTagList::Iterator i = BeginAll();
     while (i.HasNext())
     {
@@ -492,62 +489,56 @@ ByteTagList::Serialize(uint32_t* buffer, uint32_t maxSize) const
 
         // ensure size is multiple of 4 bytes for 4 byte boundaries
         uint32_t hashSize = (sizeof(TypeId::hash_t) + 3) & (~3);
-        if (size + hashSize <= maxSize)
-        {
-            TypeId::hash_t tid = item.tid.GetHash();
-            memcpy(p, &tid, sizeof(TypeId::hash_t));
-            p += hashSize / 4;
-            size += hashSize;
-        }
-        else
+        size += hashSize;
+
+        if (size > maxSize)
         {
             return 0;
         }
 
-        if (size + 4 <= maxSize)
-        {
-            *p++ = item.size;
-            size += 4;
-        }
-        else
+        TypeId::hash_t tid = item.tid.GetHash();
+        memcpy(p, &tid, sizeof(TypeId::hash_t));
+        p += hashSize / 4;
+
+        size += 4;
+
+        if (size > maxSize)
         {
             return 0;
         }
 
-        if (size + 4 <= maxSize)
-        {
-            *p++ = item.start;
-            size += 4;
-        }
-        else
+        *p++ = item.size;
+
+        size += 4;
+
+        if (size > maxSize)
         {
             return 0;
         }
 
-        if (size + 4 <= maxSize)
-        {
-            *p++ = item.end;
-            size += 4;
-        }
-        else
+        *p++ = item.start;
+
+        size += 4;
+
+        if (size > maxSize)
         {
             return 0;
         }
 
+        *p++ = item.end;
+
         // ensure size is multiple of 4 bytes for 4 byte boundaries
         uint32_t tagWordSize = (item.size + 3) & (~3);
+        size += tagWordSize;
 
-        if (size + tagWordSize <= maxSize)
-        {
-            item.buf.Read(reinterpret_cast<uint8_t*>(p), item.size);
-            size += tagWordSize;
-            p += tagWordSize / 4;
-        }
-        else
+        if (size > maxSize)
         {
             return 0;
         }
 
+        item.buf.Read(reinterpret_cast<uint8_t*>(p), item.size);
+        p += tagWordSize / 4;
+
         (*numberOfTags)++;
     }
 
