@@ -23,13 +23,13 @@
 #include "application.h"
 #include "net-device.h"
 #include "node-list.h"
+#include "packet.h"
 
 #include "ns3/assert.h"
 #include "ns3/boolean.h"
 #include "ns3/global-value.h"
 #include "ns3/log.h"
 #include "ns3/object-vector.h"
-#include "ns3/packet.h"
 #include "ns3/simulator.h"
 #include "ns3/uinteger.h"
 
@@ -199,16 +199,14 @@ Node::DoDispose()
     NS_LOG_FUNCTION(this);
     m_deviceAdditionListeners.clear();
     m_handlers.clear();
-    for (std::vector<Ptr<NetDevice>>::iterator i = m_devices.begin(); i != m_devices.end(); i++)
+    for (auto i = m_devices.begin(); i != m_devices.end(); i++)
     {
         Ptr<NetDevice> device = *i;
         device->Dispose();
         *i = nullptr;
     }
     m_devices.clear();
-    for (std::vector<Ptr<Application>>::iterator i = m_applications.begin();
-         i != m_applications.end();
-         i++)
+    for (auto i = m_applications.begin(); i != m_applications.end(); i++)
     {
         Ptr<Application> application = *i;
         application->Dispose();
@@ -222,14 +220,12 @@ void
 Node::DoInitialize()
 {
     NS_LOG_FUNCTION(this);
-    for (std::vector<Ptr<NetDevice>>::iterator i = m_devices.begin(); i != m_devices.end(); i++)
+    for (auto i = m_devices.begin(); i != m_devices.end(); i++)
     {
         Ptr<NetDevice> device = *i;
         device->Initialize();
     }
-    for (std::vector<Ptr<Application>>::iterator i = m_applications.begin();
-         i != m_applications.end();
-         i++)
+    for (auto i = m_applications.begin(); i != m_applications.end(); i++)
     {
         Ptr<Application> application = *i;
         application->Initialize();
@@ -256,8 +252,7 @@ Node::RegisterProtocolHandler(ProtocolHandler handler,
     {
         if (!device)
         {
-            for (std::vector<Ptr<NetDevice>>::iterator i = m_devices.begin(); i != m_devices.end();
-                 i++)
+            for (auto i = m_devices.begin(); i != m_devices.end(); i++)
             {
                 Ptr<NetDevice> dev = *i;
                 dev->SetPromiscReceiveCallback(MakeCallback(&Node::PromiscReceiveFromDevice, this));
@@ -276,7 +271,7 @@ void
 Node::UnregisterProtocolHandler(ProtocolHandler handler)
 {
     NS_LOG_FUNCTION(this << &handler);
-    for (ProtocolHandlerList::iterator i = m_handlers.begin(); i != m_handlers.end(); i++)
+    for (auto i = m_handlers.begin(); i != m_handlers.end(); i++)
     {
         if (i->handler.IsEqual(handler))
         {
@@ -343,7 +338,7 @@ Node::ReceiveFromDevice(Ptr<NetDevice> device,
                          << packet->GetUid());
     bool found = false;
 
-    for (ProtocolHandlerList::iterator i = m_handlers.begin(); i != m_handlers.end(); i++)
+    for (auto i = m_handlers.begin(); i != m_handlers.end(); i++)
     {
         if (!i->device || (i->device == device))
         {
@@ -366,8 +361,7 @@ Node::RegisterDeviceAdditionListener(DeviceAdditionListener listener)
     NS_LOG_FUNCTION(this << &listener);
     m_deviceAdditionListeners.push_back(listener);
     // and, then, notify the new listener about all existing devices.
-    for (std::vector<Ptr<NetDevice>>::const_iterator i = m_devices.begin(); i != m_devices.end();
-         ++i)
+    for (auto i = m_devices.begin(); i != m_devices.end(); ++i)
     {
         listener(*i);
     }
@@ -377,9 +371,7 @@ void
 Node::UnregisterDeviceAdditionListener(DeviceAdditionListener listener)
 {
     NS_LOG_FUNCTION(this << &listener);
-    for (DeviceAdditionListenerList::iterator i = m_deviceAdditionListeners.begin();
-         i != m_deviceAdditionListeners.end();
-         i++)
+    for (auto i = m_deviceAdditionListeners.begin(); i != m_deviceAdditionListeners.end(); i++)
     {
         if ((*i).IsEqual(listener))
         {
@@ -393,9 +385,7 @@ void
 Node::NotifyDeviceAdded(Ptr<NetDevice> device)
 {
     NS_LOG_FUNCTION(this << device);
-    for (DeviceAdditionListenerList::iterator i = m_deviceAdditionListeners.begin();
-         i != m_deviceAdditionListeners.end();
-         i++)
+    for (auto i = m_deviceAdditionListeners.begin(); i != m_deviceAdditionListeners.end(); i++)
     {
         (*i)(device);
     }
