@@ -23,14 +23,14 @@
 #define NS3_SOCKET_H
 
 #include "address.h"
+#include "net-device.h"
+#include "tag.h"
 
 #include "ns3/callback.h"
 #include "ns3/inet-socket-address.h"
 #include "ns3/inet6-socket-address.h"
-#include "ns3/net-device.h"
 #include "ns3/object.h"
 #include "ns3/ptr.h"
-#include "ns3/tag.h"
 
 #include <stdint.h>
 
