@@ -1116,135 +1116,137 @@ static const uint32_t N_PACKET_BYTES = 16;
 /**
  * PCAP Packet structure
  */
-typedef struct PACKET_ENTRY
+struct PacketEntry
 {
     uint32_t tsSec;                //!< Time (seconds part)
     uint32_t tsUsec;               //!< Time (micro seconds part)
     uint32_t inclLen;              //!< Length of the entry in the PCAP
     uint32_t origLen;              //!< length of the original packet
     uint16_t data[N_PACKET_BYTES]; //!< Packet data
-} PacketEntry;
+};
 
-static const PacketEntry knownPackets[] = {{2,
-                                            3696,
-                                            46,
-                                            46,
-                                            {0x0001,
-                                             0x0800,
-                                             0x0604,
-                                             0x0001,
-                                             0x0000,
-                                             0x0000,
-                                             0x0003,
-                                             0x0a01,
-                                             0x0201,
-                                             0xffff,
-                                             0xffff,
-                                             0xffff,
-                                             0x0a01,
-                                             0x0204,
-                                             0x0000,
-                                             0x0000}},
-                                           {2,
-                                            3707,
-                                            46,
-                                            46,
-                                            {0x0001,
-                                             0x0800,
-                                             0x0604,
-                                             0x0002,
-                                             0x0000,
-                                             0x0000,
-                                             0x0006,
-                                             0x0a01,
-                                             0x0204,
-                                             0x0000,
-                                             0x0000,
-                                             0x0003,
-                                             0x0a01,
-                                             0x0201,
-                                             0x0000,
-                                             0x0000}},
-                                           {2,
-                                            3801,
-                                            1070,
-                                            1070,
-                                            {0x4500,
-                                             0x041c,
-                                             0x0000,
-                                             0x0000,
-                                             0x3f11,
-                                             0x0000,
-                                             0x0a01,
-                                             0x0101,
-                                             0x0a01,
-                                             0x0204,
-                                             0xc001,
-                                             0x0009,
-                                             0x0408,
-                                             0x0000,
-                                             0x0000,
-                                             0x0000}},
-                                           {2,
-                                            3811,
-                                            46,
-                                            46,
-                                            {0x0001,
-                                             0x0800,
-                                             0x0604,
-                                             0x0001,
-                                             0x0000,
-                                             0x0000,
-                                             0x0006,
-                                             0x0a01,
-                                             0x0204,
-                                             0xffff,
-                                             0xffff,
-                                             0xffff,
-                                             0x0a01,
-                                             0x0201,
-                                             0x0000,
-                                             0x0000}},
-                                           {2,
-                                            3822,
-                                            46,
-                                            46,
-                                            {0x0001,
-                                             0x0800,
-                                             0x0604,
-                                             0x0002,
-                                             0x0000,
-                                             0x0000,
-                                             0x0003,
-                                             0x0a01,
-                                             0x0201,
-                                             0x0000,
-                                             0x0000,
-                                             0x0006,
-                                             0x0a01,
-                                             0x0204,
-                                             0x0000,
-                                             0x0000}},
-                                           {2,
-                                            3915,
-                                            1070,
-                                            1070,
-                                            {0x4500,
-                                             0x041c,
-                                             0x0000,
-                                             0x0000,
-                                             0x4011,
-                                             0x0000,
-                                             0x0a01,
-                                             0x0204,
-                                             0x0a01,
-                                             0x0101,
-                                             0x0009,
-                                             0xc001,
-                                             0x0408,
-                                             0x0000,
-                                             0x0000,
-                                             0x0000}}};
+static const PacketEntry knownPackets[] = {
+    {2,
+     3696,
+     46,
+     46,
+     {0x0001,
+      0x0800,
+      0x0604,
+      0x0001,
+      0x0000,
+      0x0000,
+      0x0003,
+      0x0a01,
+      0x0201,
+      0xffff,
+      0xffff,
+      0xffff,
+      0x0a01,
+      0x0204,
+      0x0000,
+      0x0000}},
+    {2,
+     3707,
+     46,
+     46,
+     {0x0001,
+      0x0800,
+      0x0604,
+      0x0002,
+      0x0000,
+      0x0000,
+      0x0006,
+      0x0a01,
+      0x0204,
+      0x0000,
+      0x0000,
+      0x0003,
+      0x0a01,
+      0x0201,
+      0x0000,
+      0x0000}},
+    {2,
+     3801,
+     1070,
+     1070,
+     {0x4500,
+      0x041c,
+      0x0000,
+      0x0000,
+      0x3f11,
+      0x0000,
+      0x0a01,
+      0x0101,
+      0x0a01,
+      0x0204,
+      0xc001,
+      0x0009,
+      0x0408,
+      0x0000,
+      0x0000,
+      0x0000}},
+    {2,
+     3811,
+     46,
+     46,
+     {0x0001,
+      0x0800,
+      0x0604,
+      0x0001,
+      0x0000,
+      0x0000,
+      0x0006,
+      0x0a01,
+      0x0204,
+      0xffff,
+      0xffff,
+      0xffff,
+      0x0a01,
+      0x0201,
+      0x0000,
+      0x0000}},
+    {2,
+     3822,
+     46,
+     46,
+     {0x0001,
+      0x0800,
+      0x0604,
+      0x0002,
+      0x0000,
+      0x0000,
+      0x0003,
+      0x0a01,
+      0x0201,
+      0x0000,
+      0x0000,
+      0x0006,
+      0x0a01,
+      0x0204,
+      0x0000,
+      0x0000}},
+    {2,
+     3915,
+     1070,
+     1070,
+     {0x4500,
+      0x041c,
+      0x0000,
+      0x0000,
+      0x4011,
+      0x0000,
+      0x0a01,
+      0x0204,
+      0x0a01,
+      0x0101,
+      0x0009,
+      0xc001,
+      0x0408,
+      0x0000,
+      0x0000,
+      0x0000}},
+};
 
 void
 ReadFileTestCase::DoRun()
@@ -1282,10 +1284,10 @@ ReadFileTestCase::DoRun()
         NS_TEST_ASSERT_MSG_EQ(f.Fail(), false, "Read() of known good pcap file returns error");
         NS_TEST_ASSERT_MSG_EQ(tsSec,
                               p.tsSec,
-                              "Incorrectly read seconds timestap from known good pcap file");
+                              "Incorrectly read seconds timestamp from known good pcap file");
         NS_TEST_ASSERT_MSG_EQ(tsUsec,
                               p.tsUsec,
-                              "Incorrectly read microseconds timestap from known good pcap file");
+                              "Incorrectly read microseconds timestamp from known good pcap file");
         NS_TEST_ASSERT_MSG_EQ(inclLen,
                               p.inclLen,
                               "Incorrectly read included length from known good packet");
