@@ -35,73 +35,20 @@ NS_LOG_COMPONENT_DEFINE("Mac16Address");
 
 ATTRIBUTE_HELPER_CPP(Mac16Address);
 
-#define ASCII_a (0x41)
-#define ASCII_z (0x5a)
-#define ASCII_A (0x61)
-#define ASCII_Z (0x7a)
-#define ASCII_COLON (0x3a)
-#define ASCII_ZERO (0x30)
-
-/**
- * Converts a char to lower case.
- * \param c the char
- * \returns the lower case
- */
-static char
-AsciiToLowCase(char c)
-{
-    if (c >= ASCII_a && c <= ASCII_z)
-    {
-        return c;
-    }
-    else if (c >= ASCII_A && c <= ASCII_Z)
-    {
-        return c + (ASCII_a - ASCII_A);
-    }
-    else
-    {
-        return c;
-    }
-}
-
 uint64_t Mac16Address::m_allocationIndex = 0;
 
-Mac16Address::Mac16Address()
-{
-    NS_LOG_FUNCTION(this);
-    memset(m_address, 0, 2);
-}
-
 Mac16Address::Mac16Address(const char* str)
 {
     NS_LOG_FUNCTION(this << str);
-    int i = 0;
-    while (*str != 0 && i < 2)
-    {
-        uint8_t byte = 0;
-        while (*str != ASCII_COLON && *str != 0)
-        {
-            byte <<= 4;
-            char low = AsciiToLowCase(*str);
-            if (low >= ASCII_a)
-            {
-                byte |= low - ASCII_a + 10;
-            }
-            else
-            {
-                byte |= low - ASCII_ZERO;
-            }
-            str++;
-        }
-        m_address[i] = byte;
-        i++;
-        if (*str == 0)
-        {
-            break;
-        }
-        str++;
-    }
-    NS_ASSERT(i == 2);
+    NS_ASSERT_MSG(strlen(str) <= 5, "Mac16Address: illegal string (too long) " << str);
+
+    unsigned int bytes[2];
+    int charsRead = 0;
+
+    int i = sscanf(str, "%02x:%02x%n", bytes, bytes + 1, &charsRead);
+    NS_ASSERT_MSG(i == 2 && !str[charsRead], "Mac16Address: illegal string " << str);
+
+    std::copy(std::begin(bytes), std::end(bytes), std::begin(m_address));
 }
 
 Mac16Address::Mac16Address(uint16_t addr)
@@ -201,7 +148,7 @@ Mac16Address::GetBroadcast()
 {
     NS_LOG_FUNCTION_NOARGS();
 
-    static Mac16Address broadcast = Mac16Address("ff:ff");
+    static Mac16Address broadcast("ff:ff");
     return broadcast;
 }
 
