@@ -18,15 +18,15 @@
  */
 #include "simple-net-device.h"
 
+#include "error-model.h"
+#include "queue.h"
 #include "simple-channel.h"
 
 #include "ns3/boolean.h"
-#include "ns3/error-model.h"
 #include "ns3/log.h"
 #include "ns3/node.h"
 #include "ns3/packet.h"
 #include "ns3/pointer.h"
-#include "ns3/queue.h"
 #include "ns3/simulator.h"
 #include "ns3/string.h"
 #include "ns3/tag.h"
