@@ -25,6 +25,7 @@
 #include "ns3/ipv4-address.h"
 #include "ns3/nstime.h"
 
+#include <iostream>
 #include <set>
 #include <vector>
 
@@ -33,6 +34,52 @@ namespace ns3
 namespace olsr
 {
 
+/**
+ * \ingroup olsr
+ *
+ * Willingness for forwarding packets from other nodes.
+ * The standard defines the following set of values.
+ * Values 0 - 7 are allowed by the standard, but this is not enforced in the code.
+ *
+ * See \RFC{3626} section 18.8
+ */
+enum Willingness : uint8_t
+{
+    NEVER = 0,
+    LOW = 1,
+    DEFAULT = 3, // medium
+    HIGH = 6,
+    ALWAYS = 7,
+};
+
+/**
+ * Stream insertion operator for OLSR willingness.
+ *
+ * \param os Output stream.
+ * \param willingness Willingness.
+ * \return A reference to the output stream.
+ */
+inline std::ostream&
+operator<<(std::ostream& os, Willingness willingness)
+{
+    switch (willingness)
+    {
+    case Willingness::NEVER:
+        return (os << "NEVER");
+    case Willingness::LOW:
+        return (os << "LOW");
+    case Willingness::DEFAULT:
+        return (os << "DEFAULT");
+    case Willingness::HIGH:
+        return (os << "HIGH");
+    case Willingness::ALWAYS:
+        return (os << "ALWAYS");
+    default:
+        return (os << static_cast<uint32_t>(willingness)); // Cast to uint32_t to print correctly
+    }
+    return os;
+}
+
 /// \ingroup olsr
 /// An Interface Association Tuple.
 struct IfaceAssocTuple
@@ -45,13 +92,13 @@ struct IfaceAssocTuple
     Time time;
 };
 
-static inline bool
+inline bool
 operator==(const IfaceAssocTuple& a, const IfaceAssocTuple& b)
 {
     return (a.ifaceAddr == b.ifaceAddr && a.mainAddr == b.mainAddr);
 }
 
-static inline std::ostream&
+inline std::ostream&
 operator<<(std::ostream& os, const IfaceAssocTuple& tuple)
 {
     os << "IfaceAssocTuple(ifaceAddr=" << tuple.ifaceAddr << ", mainAddr=" << tuple.mainAddr
@@ -75,13 +122,13 @@ struct LinkTuple
     Time time;
 };
 
-static inline bool
+inline bool
 operator==(const LinkTuple& a, const LinkTuple& b)
 {
     return (a.localIfaceAddr == b.localIfaceAddr && a.neighborIfaceAddr == b.neighborIfaceAddr);
 }
 
-static inline std::ostream&
+inline std::ostream&
 operator<<(std::ostream& os, const LinkTuple& tuple)
 {
     os << "LinkTuple(localIfaceAddr=" << tuple.localIfaceAddr
@@ -102,26 +149,29 @@ struct NeighborTuple
     {
         STATUS_NOT_SYM = 0, // "not symmetric"
         STATUS_SYM = 1,     // "symmetric"
-    } status;               //!< Status of the link.
+    };
+
+    /// Status of the link.
+    Status status;
 
     /// A value between 0 and 7 specifying the node's willingness to carry traffic on behalf of
     /// other nodes.
-    uint8_t willingness;
+    Willingness willingness;
 };
 
-static inline bool
+inline bool
 operator==(const NeighborTuple& a, const NeighborTuple& b)
 {
     return (a.neighborMainAddr == b.neighborMainAddr && a.status == b.status &&
             a.willingness == b.willingness);
 }
 
-static inline std::ostream&
+inline std::ostream&
 operator<<(std::ostream& os, const NeighborTuple& tuple)
 {
     os << "NeighborTuple(neighborMainAddr=" << tuple.neighborMainAddr
        << ", status=" << (tuple.status == NeighborTuple::STATUS_SYM ? "SYM" : "NOT_SYM")
-       << ", willingness=" << (int)tuple.willingness << ")";
+       << ", willingness=" << tuple.willingness << ")";
     return os;
 }
 
@@ -137,7 +187,7 @@ struct TwoHopNeighborTuple
     Time expirationTime; // previously called 'time_'
 };
 
-static inline std::ostream&
+inline std::ostream&
 operator<<(std::ostream& os, const TwoHopNeighborTuple& tuple)
 {
     os << "TwoHopNeighborTuple(neighborMainAddr=" << tuple.neighborMainAddr
@@ -146,7 +196,7 @@ operator<<(std::ostream& os, const TwoHopNeighborTuple& tuple)
     return os;
 }
 
-static inline bool
+inline bool
 operator==(const TwoHopNeighborTuple& a, const TwoHopNeighborTuple& b)
 {
     return (a.neighborMainAddr == b.neighborMainAddr &&
@@ -163,7 +213,7 @@ struct MprSelectorTuple
     Time expirationTime; // previously called 'time_'
 };
 
-static inline bool
+inline bool
 operator==(const MprSelectorTuple& a, const MprSelectorTuple& b)
 {
     return (a.mainAddr == b.mainAddr);
@@ -188,7 +238,7 @@ struct DuplicateTuple
     Time expirationTime;
 };
 
-static inline bool
+inline bool
 operator==(const DuplicateTuple& a, const DuplicateTuple& b)
 {
     return (a.address == b.address && a.sequenceNumber == b.sequenceNumber);
@@ -208,14 +258,14 @@ struct TopologyTuple
     Time expirationTime;
 };
 
-static inline bool
+inline bool
 operator==(const TopologyTuple& a, const TopologyTuple& b)
 {
     return (a.destAddr == b.destAddr && a.lastAddr == b.lastAddr &&
             a.sequenceNumber == b.sequenceNumber);
 }
 
-static inline std::ostream&
+inline std::ostream&
 operator<<(std::ostream& os, const TopologyTuple& tuple)
 {
     os << "TopologyTuple(destAddr=" << tuple.destAddr << ", lastAddr=" << tuple.lastAddr
@@ -232,13 +282,13 @@ struct Association
     Ipv4Mask netmask;        //!< IPv4 Network mask.
 };
 
-static inline bool
+inline bool
 operator==(const Association& a, const Association& b)
 {
     return (a.networkAddr == b.networkAddr && a.netmask == b.netmask);
 }
 
-static inline std::ostream&
+inline std::ostream&
 operator<<(std::ostream& os, const Association& tuple)
 {
     os << "Association(networkAddr=" << tuple.networkAddr << ", netmask=" << tuple.netmask << ")";
@@ -259,14 +309,14 @@ struct AssociationTuple
     Time expirationTime;
 };
 
-static inline bool
+inline bool
 operator==(const AssociationTuple& a, const AssociationTuple& b)
 {
     return (a.gatewayAddr == b.gatewayAddr && a.networkAddr == b.networkAddr &&
             a.netmask == b.netmask);
 }
 
-static inline std::ostream&
+inline std::ostream&
 operator<<(std::ostream& os, const AssociationTuple& tuple)
 {
     os << "AssociationTuple(gatewayAddr=" << tuple.gatewayAddr
