@@ -139,8 +139,7 @@ HelloRegressionTest::ReceivePktProbeA(Ptr<Socket> socket)
                               "One Link message on the second and third Hello.");
     }
 
-    std::vector<olsr::MessageHeader::Hello::LinkMessage>::const_iterator iter;
-    for (iter = hello.linkMessages.begin(); iter != hello.linkMessages.end(); iter++)
+    for (auto iter = hello.linkMessages.begin(); iter != hello.linkMessages.end(); iter++)
     {
         if (m_countA == 1)
         {
@@ -193,8 +192,7 @@ HelloRegressionTest::ReceivePktProbeB(Ptr<Socket> socket)
                               "One Link message on the second and third Hello.");
     }
 
-    std::vector<olsr::MessageHeader::Hello::LinkMessage>::const_iterator iter;
-    for (iter = hello.linkMessages.begin(); iter != hello.linkMessages.end(); iter++)
+    for (auto iter = hello.linkMessages.begin(); iter != hello.linkMessages.end(); iter++)
     {
         if (m_countA == 1)
         {
