@@ -164,7 +164,7 @@ class PointToPointDumbbellHelper
      * \param lrx lower right x value
      * \param lry lower right y value
      */
-    void BoundingBox(double ulx, double uly, double lrx, double lry);
+    void BoundingBox(double ulx, double uly, double lrx, double lry) const;
 
   private:
     NodeContainer m_leftLeaf;                        //!< Left Leaf nodes
