@@ -82,7 +82,7 @@ NetDeviceContainer
 WaveformGeneratorHelper::Install(NodeContainer c) const
 {
     NetDeviceContainer devices;
-    for (NodeContainer::Iterator i = c.Begin(); i != c.End(); ++i)
+    for (auto i = c.Begin(); i != c.End(); ++i)
     {
         Ptr<Node> node = *i;
 
