@@ -20,13 +20,14 @@
 #ifndef SPECTRUM_ANALYZER_H
 #define SPECTRUM_ANALYZER_H
 
+#include "spectrum-channel.h"
+#include "spectrum-phy.h"
+#include "spectrum-value.h"
+
 #include <ns3/mobility-model.h>
 #include <ns3/net-device.h>
 #include <ns3/nstime.h>
 #include <ns3/packet.h>
-#include <ns3/spectrum-channel.h>
-#include <ns3/spectrum-phy.h>
-#include <ns3/spectrum-value.h>
 
 #include <fstream>
 #include <string>
