@@ -20,10 +20,11 @@
 #ifndef SPECTRUM_INTERFERENCE_H
 #define SPECTRUM_INTERFERENCE_H
 
+#include "spectrum-value.h"
+
 #include <ns3/nstime.h>
 #include <ns3/object.h>
 #include <ns3/packet.h>
-#include <ns3/spectrum-value.h>
 
 namespace ns3
 {
