@@ -20,7 +20,7 @@
 #ifndef FREQS_300KHZ_300GHZ_LOG_H
 #define FREQS_300KHZ_300GHZ_LOG_H
 
-#include <ns3/spectrum-value.h>
+#include "spectrum-value.h"
 
 namespace ns3
 {
