@@ -111,45 +111,114 @@ ThreeGppSpectrumPropagationLossModel::GetChannelModelAttribute(const std::string
     m_channelModel->GetAttribute(name, value);
 }
 
-PhasedArrayModel::ComplexVector
+Ptr<const MatrixBasedChannelModel::Complex3DVector>
 ThreeGppSpectrumPropagationLossModel::CalcLongTerm(
     Ptr<const MatrixBasedChannelModel::ChannelMatrix> params,
-    const PhasedArrayModel::ComplexVector& sW,
-    const PhasedArrayModel::ComplexVector& uW) const
+    Ptr<const PhasedArrayModel> sAnt,
+    Ptr<const PhasedArrayModel> uAnt) const
 {
     NS_LOG_FUNCTION(this);
 
-    size_t uAntennaNum = uW.GetSize();
-    size_t sAntennaNum = sW.GetSize();
-
-    NS_ASSERT(uAntennaNum == params->m_channel.GetNumRows());
-    NS_ASSERT(sAntennaNum == params->m_channel.GetNumCols());
-
-    NS_LOG_DEBUG("CalcLongTerm with " << uAntennaNum << " u antenna elements and " << sAntennaNum
-                                      << " s antenna elements.");
-    // store the long term part to reduce computation load
-    // only the small scale fading needs to be updated if the large scale parameters and antenna
-    // weights remain unchanged. here we calculate long term uW * Husn * sW, the result is an array
-    // of values per cluster
-    return params->m_channel.MultiplyByLeftAndRightMatrix(uW.Transpose(), sW);
+    const PhasedArrayModel::ComplexVector& sW = sAnt->GetBeamformingVectorRef();
+    const PhasedArrayModel::ComplexVector& uW = uAnt->GetBeamformingVectorRef();
+    size_t sAntNumElems = sW.GetSize();
+    size_t uAntNumElems = uW.GetSize();
+    NS_ASSERT(uAntNumElems == params->m_channel.GetNumRows());
+    NS_ASSERT(sAntNumElems == params->m_channel.GetNumCols());
+    NS_LOG_DEBUG("CalcLongTerm with " << uW.GetSize() << " u antenna elements and " << sW.GetSize()
+                                      << " s antenna elements, and with "
+                                      << " s ports: " << sAnt->GetNumPorts()
+                                      << " u ports: " << uAnt->GetNumPorts());
+    NS_ASSERT_MSG((sAnt != nullptr) && (uAnt != nullptr), "Improper call to the method");
+    size_t numClusters = params->m_channel.GetNumPages();
+    // create and initialize the size of the longTerm 3D matrix
+    Ptr<MatrixBasedChannelModel::Complex3DVector> longTerm =
+        Create<MatrixBasedChannelModel::Complex3DVector>(uAnt->GetNumPorts(),
+                                                         sAnt->GetNumPorts(),
+                                                         numClusters);
+    // Calculate long term uW * Husn * sW, the result is a matrix
+    // with the dimensions #uPorts, #sPorts, #cluster
+    for (auto sPortIdx = 0; sPortIdx < sAnt->GetNumPorts(); sPortIdx++)
+    {
+        for (auto uPortIdx = 0; uPortIdx < uAnt->GetNumPorts(); uPortIdx++)
+        {
+            for (size_t cIndex = 0; cIndex < numClusters; cIndex++)
+            {
+                longTerm->Elem(uPortIdx, sPortIdx, cIndex) =
+                    CalculateLongTermComponent(params, sAnt, uAnt, sPortIdx, uPortIdx, cIndex);
+            }
+        }
+    }
+    return longTerm;
 }
 
-Ptr<SpectrumValue>
-ThreeGppSpectrumPropagationLossModel::CalcBeamformingGain(
-    Ptr<SpectrumValue> txPsd,
-    PhasedArrayModel::ComplexVector longTerm,
-    Ptr<const MatrixBasedChannelModel::ChannelMatrix> channelMatrix,
-    Ptr<const MatrixBasedChannelModel::ChannelParams> channelParams,
-    const ns3::Vector& sSpeed,
-    const ns3::Vector& uSpeed) const
+std::complex<double>
+ThreeGppSpectrumPropagationLossModel::CalculateLongTermComponent(
+    Ptr<const MatrixBasedChannelModel::ChannelMatrix> params,
+    Ptr<const PhasedArrayModel> sAnt,
+    Ptr<const PhasedArrayModel> uAnt,
+    uint16_t sPortIdx,
+    uint16_t uPortIdx,
+    uint16_t cIndex) const
 {
     NS_LOG_FUNCTION(this);
+    const PhasedArrayModel::ComplexVector& sW = sAnt->GetBeamformingVectorRef();
+    const PhasedArrayModel::ComplexVector& uW = uAnt->GetBeamformingVectorRef();
+    auto sPortElems = sAnt->GetNumElemsPerPort();
+    auto uPortElems = uAnt->GetNumElemsPerPort();
+    auto startS = sAnt->ArrayIndexFromPortIndex(sPortIdx, 0);
+    auto startU = uAnt->ArrayIndexFromPortIndex(uPortIdx, 0);
+    std::complex<double> txSum(0, 0);
+    // limiting multiplication operations to the port location
+    auto sIndex = startS;
+    // The sub-array partition model is adopted for TXRU virtualization,
+    // as described in Section 5.2.2 of 3GPP TR 36.897,
+    // and so equal beam weights are used for all the ports.
+    // Support of the full-connection model for TXRU virtualization would need extensions.
+    for (size_t tIndex = 0; tIndex < sPortElems; tIndex++, sIndex++)
+    {
+        std::complex<double> rxSum(0, 0);
+        auto uIndex = startU;
+        for (size_t rIndex = 0; rIndex < uPortElems; rIndex++, uIndex++)
+        {
+            rxSum += uW[uIndex - startU] * params->m_channel(uIndex, sIndex, cIndex);
+            auto testV = (rIndex % uAnt->GetHElemsPerPort());
+            auto ptInc = uAnt->GetHElemsPerPort() - 1;
+            if (testV == ptInc)
+            {
+                auto incVal = uAnt->GetNumColumns() - uAnt->GetHElemsPerPort();
+                uIndex += incVal; // Increment by a factor to reach next column in a port
+            }
+        }
 
-    Ptr<SpectrumValue> tempPsd = Copy<SpectrumValue>(txPsd);
+        txSum += sW[sIndex - startS] * rxSum;
+        auto testV = (tIndex % sAnt->GetHElemsPerPort());
+        auto ptInc = sAnt->GetHElemsPerPort() - 1;
+        if (testV == ptInc)
+        {
+            size_t incVal = sAnt->GetNumColumns() - sAnt->GetHElemsPerPort();
+            sIndex += incVal; // Increment by a factor to reach next column in a port
+        }
+    }
+    return txSum;
+}
 
-    // channel[cluster][rx][tx]
-    uint16_t numCluster = channelMatrix->m_channel.GetNumPages();
+Ptr<SpectrumSignalParameters>
+ThreeGppSpectrumPropagationLossModel::CalcBeamformingGain(
+    Ptr<const SpectrumSignalParameters> params,
+    Ptr<const MatrixBasedChannelModel::Complex3DVector> longTerm,
+    Ptr<const MatrixBasedChannelModel::ChannelMatrix> channelMatrix,
+    Ptr<const MatrixBasedChannelModel::ChannelParams> channelParams,
+    const Vector& sSpeed,
+    const ns3::Vector& uSpeed,
+    uint8_t numTxPorts,
+    uint8_t numRxPorts,
+    bool isReverse) const
 
+{
+    NS_LOG_FUNCTION(this);
+    Ptr<SpectrumSignalParameters> rxParams = params->Copy();
+    size_t numCluster = channelMatrix->m_channel.GetNumPages();
     // compute the doppler term
     // NOTE the update of Doppler is simplified by only taking the center angle of
     // each cluster in to consideration.
@@ -157,18 +226,15 @@ ThreeGppSpectrumPropagationLossModel::CalcBeamformingGain(
     double factor = 2 * M_PI * slotTime * GetFrequency() / 3e8;
     PhasedArrayModel::ComplexVector doppler(numCluster);
 
-    // The following asserts might seem paranoic, but it is important to
-    // make sure that all the structures that are passed to this function
+    // Make sure that all the structures that are passed to this function
     // are of the correct dimensions before using the operator [].
-    // If you dont understand the comment read about the difference of .at()
-    // and [] operators, ...
     NS_ASSERT(numCluster <= channelParams->m_alpha.size());
     NS_ASSERT(numCluster <= channelParams->m_D.size());
     NS_ASSERT(numCluster <= channelParams->m_angle[MatrixBasedChannelModel::ZOA_INDEX].size());
     NS_ASSERT(numCluster <= channelParams->m_angle[MatrixBasedChannelModel::ZOD_INDEX].size());
     NS_ASSERT(numCluster <= channelParams->m_angle[MatrixBasedChannelModel::AOA_INDEX].size());
     NS_ASSERT(numCluster <= channelParams->m_angle[MatrixBasedChannelModel::AOD_INDEX].size());
-    NS_ASSERT(numCluster <= longTerm.GetSize());
+    NS_ASSERT(numCluster <= longTerm->GetNumPages());
 
     // check if channelParams structure is generated in direction s-to-u or u-to-s
     bool isSameDirection = (channelParams->m_nodeIds == channelMatrix->m_nodeIds);
@@ -179,7 +245,7 @@ ThreeGppSpectrumPropagationLossModel::CalcBeamformingGain(
     MatrixBasedChannelModel::DoubleVector aod;
 
     // if channel params is generated in the same direction in which we
-    // generate the channel matrix, angles and zenith od departure and arrival are ok,
+    // generate the channel matrix, angles and zenith of departure and arrival are ok,
     // just set them to corresponding variable that will be used for the generation
     // of channel matrix, otherwise we need to flip angles and zeniths of departure and arrival
     if (isSameDirection)
@@ -197,7 +263,7 @@ ThreeGppSpectrumPropagationLossModel::CalcBeamformingGain(
         aoa = channelParams->m_angle[MatrixBasedChannelModel::AOD_INDEX];
     }
 
-    for (uint16_t cIndex = 0; cIndex < numCluster; cIndex++)
+    for (size_t cIndex = 0; cIndex < numCluster; cIndex++)
     {
         // Compute alpha and D as described in 3GPP TR 37.885 v15.3.0, Sec. 6.2.3
         // These terms account for an additional Doppler contribution due to the
@@ -227,44 +293,139 @@ ThreeGppSpectrumPropagationLossModel::CalcBeamformingGain(
 
     NS_ASSERT(numCluster <= doppler.GetSize());
 
-    // apply the doppler term and the propagation delay to the long term component
-    // to obtain the beamforming gain
-    auto vit = tempPsd->ValuesBegin();      // psd iterator
-    auto sbit = tempPsd->ConstBandsBegin(); // band iterator
-    while (vit != tempPsd->ValuesEnd())
+    // set the channel matrix
+    rxParams->spectrumChannelMatrix = GenSpectrumChannelMatrix(rxParams->psd,
+                                                               longTerm,
+                                                               channelMatrix,
+                                                               channelParams,
+                                                               doppler,
+                                                               numTxPorts,
+                                                               numRxPorts,
+                                                               isReverse);
+
+    // The precoding matrix is not set
+    if (!rxParams->precodingMatrix)
+    {
+        // Update rxParams->Psd.
+        // Compute RX PSD from the channel matrix
+        auto vit = rxParams->psd->ValuesBegin(); // psd iterator
+        size_t rbIdx = 0;
+        while (vit != rxParams->psd->ValuesEnd())
+        {
+            // Calculate PSD for the first antenna port (correct for SISO)
+            *vit = std::norm(rxParams->spectrumChannelMatrix->Elem(0, 0, rbIdx));
+            vit++;
+            rbIdx++;
+        }
+    }
+    else
+    {
+        NS_ASSERT_MSG(rxParams->psd->GetValuesN() == rxParams->spectrumChannelMatrix->GetNumPages(),
+                      "RX PSD and the spectrum channel matrix should have the same number of RBs ");
+        // Calculate RX PSD from the spectrum channel matrix, H and
+        // the precoding matrix, P as:
+        // PSD = (H*P)^h * (H*P),
+        // where the dimensions are:
+        // H (rxPorts,txPorts,numRbs) x P (txPorts,txStreams, numRbs) =
+        // HxP (rxPorts,txStreams, numRbs)
+        MatrixBasedChannelModel::Complex3DVector hP =
+            *rxParams->spectrumChannelMatrix * (*rxParams->precodingMatrix);
+        // (HxP)^h dimensions are (txStreams, rxPorts, numRbs)
+        MatrixBasedChannelModel::Complex3DVector hPHerm = hP.HermitianTranspose();
+
+        // Finally, (HxP)^h x (HxP) = PSD (txStreams, txStreams, numRbs)
+        MatrixBasedChannelModel::Complex3DVector psd = hPHerm * hP;
+        // Update rxParams->Psd
+        for (uint32_t rbIdx = 0; rbIdx < rxParams->psd->GetValuesN(); ++rbIdx)
+        {
+            (*rxParams->psd)[rbIdx] = 0.0;
+
+            for (size_t txStream = 0; txStream < psd.GetNumRows(); ++txStream)
+            {
+                (*rxParams->psd)[rbIdx] += std::real(psd(txStream, txStream, rbIdx));
+            }
+        }
+    }
+    return rxParams;
+}
+
+Ptr<MatrixBasedChannelModel::Complex3DVector>
+ThreeGppSpectrumPropagationLossModel::GenSpectrumChannelMatrix(
+    Ptr<SpectrumValue> inPsd,
+    Ptr<const MatrixBasedChannelModel::Complex3DVector> longTerm,
+    Ptr<const MatrixBasedChannelModel::ChannelMatrix> channelMatrix,
+    Ptr<const MatrixBasedChannelModel::ChannelParams> channelParams,
+    PhasedArrayModel::ComplexVector doppler,
+    uint8_t numTxPorts,
+    uint8_t numRxPorts,
+    bool isReverse) const
+{
+    size_t numCluster = channelMatrix->m_channel.GetNumPages();
+    auto numRb = inPsd->GetValuesN();
+
+    auto directionalLongTerm = isReverse ? longTerm->Transpose() : (*longTerm);
+
+    Ptr<MatrixBasedChannelModel::Complex3DVector> chanSpct =
+        Create<MatrixBasedChannelModel::Complex3DVector>(numRxPorts, numTxPorts, (uint16_t)numRb);
+
+    // If "params" (ChannelMatrix) and longTerm were computed for the reverse direction (e.g. this
+    // is a DL transmission but params and longTerm were last updated during UL), then the elements
+    // in longTerm start from different offsets.
+
+    auto vit = inPsd->ValuesBegin();      // psd iterator
+    auto sbit = inPsd->ConstBandsBegin(); // band iterator
+    size_t iRb = 0;
+    // Compute the frequency-domain channel matrix
+    while (vit != inPsd->ValuesEnd())
     {
         if ((*vit) != 0.00)
         {
-            std::complex<double> subsbandGain(0.0, 0.0);
             double fsb = (*sbit).fc; // center frequency of the sub-band
-            for (uint16_t cIndex = 0; cIndex < numCluster; cIndex++)
+            for (auto rxPortIdx = 0; rxPortIdx < numRxPorts; rxPortIdx++)
             {
-                double delay = -2 * M_PI * fsb * (channelParams->m_delay[cIndex]);
-                subsbandGain = subsbandGain + longTerm[cIndex] * doppler[cIndex] *
-                                                  std::complex<double>(cos(delay), sin(delay));
+                for (auto txPortIdx = 0; txPortIdx < numTxPorts; txPortIdx++)
+                {
+                    std::complex<double> subsbandGain(0.0, 0.0);
+
+                    for (size_t cIndex = 0; cIndex < numCluster; cIndex++)
+                    {
+                        double delay = -2 * M_PI * fsb * (channelParams->m_delay[cIndex]);
+                        subsbandGain += directionalLongTerm(rxPortIdx, txPortIdx, cIndex) *
+                                        doppler[cIndex] *
+                                        std::complex<double>(cos(delay), sin(delay));
+                    }
+                    // Multiply with the square root of the input PSD so that the norm (absolute
+                    // value squared) of chanSpct will be the output PSD
+                    chanSpct->Elem(rxPortIdx, txPortIdx, iRb) = sqrt(*vit) * subsbandGain;
+                }
             }
-            *vit = (*vit) * (norm(subsbandGain));
         }
         vit++;
         sbit++;
+        iRb++;
     }
-    return tempPsd;
+    return chanSpct;
 }
 
-PhasedArrayModel::ComplexVector
+Ptr<const MatrixBasedChannelModel::Complex3DVector>
 ThreeGppSpectrumPropagationLossModel::GetLongTerm(
     Ptr<const MatrixBasedChannelModel::ChannelMatrix> channelMatrix,
     Ptr<const PhasedArrayModel> aPhasedArrayModel,
     Ptr<const PhasedArrayModel> bPhasedArrayModel) const
 {
-    PhasedArrayModel::ComplexVector
+    Ptr<const MatrixBasedChannelModel::Complex3DVector>
         longTerm; // vector containing the long term component for each cluster
 
     // check if the channel matrix was generated considering a as the s-node and
     // b as the u-node or vice-versa
+    auto isReverse =
+        channelMatrix->IsReverse(aPhasedArrayModel->GetId(), bPhasedArrayModel->GetId());
+    auto sAntenna = isReverse ? bPhasedArrayModel : aPhasedArrayModel;
+    auto uAntenna = isReverse ? aPhasedArrayModel : bPhasedArrayModel;
+
     PhasedArrayModel::ComplexVector sW;
     PhasedArrayModel::ComplexVector uW;
-    if (!channelMatrix->IsReverse(aPhasedArrayModel->GetId(), bPhasedArrayModel->GetId()))
+    if (!isReverse)
     {
         sW = aPhasedArrayModel->GetBeamformingVector();
         uW = bPhasedArrayModel->GetBeamformingVector();
@@ -305,45 +466,41 @@ ThreeGppSpectrumPropagationLossModel::GetLongTerm(
     {
         NS_LOG_DEBUG("compute the long term");
         // compute the long term component
-        longTerm = CalcLongTerm(channelMatrix, sW, uW);
-
-        // store the long term
+        longTerm = CalcLongTerm(channelMatrix, sAntenna, uAntenna);
         Ptr<LongTerm> longTermItem = Create<LongTerm>();
         longTermItem->m_longTerm = longTerm;
         longTermItem->m_channel = channelMatrix;
-        longTermItem->m_sW = sW;
-        longTermItem->m_uW = uW;
-
+        longTermItem->m_sW = std::move(sW);
+        longTermItem->m_uW = std::move(uW);
+        // store the long term to reduce computation load
+        // only the small scale fading needs to be updated if the large scale parameters and antenna
+        // weights remain unchanged.
         m_longTermMap[longTermId] = longTermItem;
     }
 
     return longTerm;
 }
 
-Ptr<SpectrumValue>
+Ptr<SpectrumSignalParameters>
 ThreeGppSpectrumPropagationLossModel::DoCalcRxPowerSpectralDensity(
-    Ptr<const SpectrumSignalParameters> params,
+    Ptr<const SpectrumSignalParameters> spectrumSignalParams,
     Ptr<const MobilityModel> a,
     Ptr<const MobilityModel> b,
     Ptr<const PhasedArrayModel> aPhasedArrayModel,
     Ptr<const PhasedArrayModel> bPhasedArrayModel) const
 {
-    NS_LOG_FUNCTION(this);
+    NS_LOG_FUNCTION(this << spectrumSignalParams << a << b << aPhasedArrayModel
+                         << bPhasedArrayModel);
+
+    if (a->GetPosition() == b->GetPosition())
+    {
+        return spectrumSignalParams->Copy();
+    }
     uint32_t aId = a->GetObject<Node>()->GetId(); // id of the node a
     uint32_t bId = b->GetObject<Node>()->GetId(); // id of the node b
-
-    NS_ASSERT(aId != bId);
-    NS_ASSERT_MSG(a->GetDistanceFrom(b) > 0.0,
-                  "The position of a and b devices cannot be the same");
-
-    Ptr<SpectrumValue> rxPsd = Copy<SpectrumValue>(params->psd);
-
-    // retrieve the antenna of device a
     NS_ASSERT_MSG(aPhasedArrayModel, "Antenna not found for node " << aId);
-    NS_LOG_DEBUG("a node " << a->GetObject<Node>() << " antenna " << aPhasedArrayModel);
-
-    // retrieve the antenna of the device b
-    NS_ASSERT_MSG(bPhasedArrayModel, "Antenna not found for device " << bId);
+    NS_LOG_DEBUG("a node " << aId << " antenna " << aPhasedArrayModel);
+    NS_ASSERT_MSG(bPhasedArrayModel, "Antenna not found for node " << bId);
     NS_LOG_DEBUG("b node " << bId << " antenna " << bPhasedArrayModel);
 
     Ptr<const MatrixBasedChannelModel::ChannelMatrix> channelMatrix =
@@ -352,18 +509,28 @@ ThreeGppSpectrumPropagationLossModel::DoCalcRxPowerSpectralDensity(
         m_channelModel->GetParams(a, b);
 
     // retrieve the long term component
-    PhasedArrayModel::ComplexVector longTerm =
+    Ptr<const MatrixBasedChannelModel::Complex3DVector> longTerm =
         GetLongTerm(channelMatrix, aPhasedArrayModel, bPhasedArrayModel);
 
-    // apply the beamforming gain
-    rxPsd = CalcBeamformingGain(rxPsd,
-                                longTerm,
-                                channelMatrix,
-                                channelParams,
-                                a->GetVelocity(),
-                                b->GetVelocity());
+    auto isReverse =
+        channelMatrix->IsReverse(aPhasedArrayModel->GetId(), bPhasedArrayModel->GetId());
 
-    return rxPsd;
+    // apply the beamforming gain
+    return CalcBeamformingGain(spectrumSignalParams,
+                               longTerm,
+                               channelMatrix,
+                               channelParams,
+                               a->GetVelocity(),
+                               b->GetVelocity(),
+                               aPhasedArrayModel->GetNumPorts(),
+                               bPhasedArrayModel->GetNumPorts(),
+                               isReverse);
+}
+
+int64_t
+ThreeGppSpectrumPropagationLossModel::DoAssignStreams(int64_t stream)
+{
+    return 0;
 }
 
 } // namespace ns3
