@@ -21,10 +21,11 @@
 #ifndef TRACE_FADING_LOSS_MODEL_H
 #define TRACE_FADING_LOSS_MODEL_H
 
+#include "spectrum-propagation-loss-model.h"
+
 #include "ns3/random-variable-stream.h"
 #include <ns3/nstime.h>
 #include <ns3/object.h>
-#include <ns3/spectrum-propagation-loss-model.h>
 
 #include <map>
 
@@ -57,15 +58,8 @@ class TraceFadingLossModel : public SpectrumPropagationLossModel
      */
     typedef std::pair<Ptr<const MobilityModel>, Ptr<const MobilityModel>> ChannelRealizationId_t;
 
-    /**
-     * Assign a fixed random variable stream number to the random variables
-     * used by this model.  Return the number of streams (possibly zero) that
-     * have been assigned.
-     *
-     * \param stream first stream index to use
-     * \return the number of stream indices assigned by this model
-     */
-    int64_t AssignStreams(int64_t stream);
+  protected:
+    int64_t DoAssignStreams(int64_t stream) override;
 
   private:
     /**
