@@ -1052,11 +1052,11 @@ TwoRaySpectrumPropagationLossModel::CalcBeamformingGain(
     std::complex<double> bArrayOverallResponse = 0;
 
     // Compute the dot products between the array responses and the beamforming vectors
-    for (size_t i = 0; i < aPhasedArrayModel->GetNumberOfElements(); i++)
+    for (size_t i = 0; i < aPhasedArrayModel->GetNumElems(); i++)
     {
         aArrayOverallResponse += aArrayResponse[i] * aBfVector[i];
     }
-    for (size_t i = 0; i < bPhasedArrayModel->GetNumberOfElements(); i++)
+    for (size_t i = 0; i < bPhasedArrayModel->GetNumElems(); i++)
     {
         bArrayOverallResponse += bArrayResponse[i] * bBfVector[i];
     }
@@ -1112,7 +1112,7 @@ TwoRaySpectrumPropagationLossModel::GetFtrFastFading(const FtrParams& params) co
     return norm(h);
 }
 
-Ptr<SpectrumValue>
+Ptr<SpectrumSignalParameters>
 TwoRaySpectrumPropagationLossModel::DoCalcRxPowerSpectralDensity(
     Ptr<const SpectrumSignalParameters> params,
     Ptr<const MobilityModel> a,
@@ -1128,8 +1128,6 @@ TwoRaySpectrumPropagationLossModel::DoCalcRxPowerSpectralDensity(
     NS_ASSERT_MSG(a->GetDistanceFrom(b) > 0.0,
                   "The position of a and b devices cannot be the same");
 
-    Ptr<SpectrumValue> rxPsd = Copy<SpectrumValue>(params->psd);
-
     // Retrieve the antenna of device a
     NS_ASSERT_MSG(aPhasedArrayModel, "Antenna not found for node " << aId);
     NS_LOG_DEBUG("a node " << a->GetObject<Node>() << " antenna " << aPhasedArrayModel);
@@ -1147,10 +1145,11 @@ TwoRaySpectrumPropagationLossModel::DoCalcRxPowerSpectralDensity(
     // Compute the beamforming gain
     double bfGain = CalcBeamformingGain(a, b, aPhasedArrayModel, bPhasedArrayModel);
 
-    // Apply the above terms to the TX PSD
-    *rxPsd *= (fading * bfGain);
+    Ptr<SpectrumSignalParameters> rxParams = params->Copy();
+    // Apply the above terms to the TX PSD to calculate RX PSD
+    (*(rxParams->psd)) *= (fading * bfGain);
 
-    return rxPsd;
+    return rxParams;
 }
 
 std::size_t
@@ -1166,7 +1165,7 @@ TwoRaySpectrumPropagationLossModel::SearchClosestFc(const std::vector<double>& f
 }
 
 int64_t
-TwoRaySpectrumPropagationLossModel::AssignStreams(int64_t stream)
+TwoRaySpectrumPropagationLossModel::DoAssignStreams(int64_t stream)
 {
     NS_LOG_FUNCTION(this << stream);
     m_normalRv->SetStream(stream);
