@@ -20,14 +20,15 @@
 #ifndef WAVEFORM_GENERATOR_H
 #define WAVEFORM_GENERATOR_H
 
+#include "spectrum-channel.h"
+#include "spectrum-phy.h"
+#include "spectrum-value.h"
+
 #include <ns3/event-id.h>
 #include <ns3/mobility-model.h>
 #include <ns3/net-device.h>
 #include <ns3/nstime.h>
 #include <ns3/packet.h>
-#include <ns3/spectrum-channel.h>
-#include <ns3/spectrum-phy.h>
-#include <ns3/spectrum-value.h>
 #include <ns3/trace-source-accessor.h>
 
 namespace ns3
