@@ -10,7 +10,7 @@ cpp_examples = [
     ("adhoc-aloha-ideal-phy", "True", "True"),
     ("adhoc-aloha-ideal-phy-with-microwave-oven", "True", "True"),
     ("adhoc-aloha-ideal-phy-matrix-propagation-loss-model", "True", "True"),
-    ("three-gpp-channel-example", "True", "True")
+    ("three-gpp-channel-example", "True", "True"),
 ]
 
 # A list of Python examples to run in order to ensure that they remain
