@@ -44,7 +44,7 @@ class SpectrumInterferenceTestCase : public TestCase
      * Constructor
      * \param s Spectrum value
      * \param txBytes number of bytes to transmit
-     * \param rxCorrect extected Rx bytes
+     * \param rxCorrect expected Rx bytes
      * \param name test name
      */
     SpectrumInterferenceTestCase(Ptr<SpectrumValue> s,
@@ -62,7 +62,7 @@ class SpectrumInterferenceTestCase : public TestCase
   private:
     Ptr<SpectrumValue> m_s;                     //!< Spectrum value
     uint32_t m_txBytes;                         //!< number of bytes to transmit
-    uint32_t m_rxCorrectKnownOutcome;           //!< expected Rx bytes
+    bool m_rxCorrectKnownOutcome;               //!< expected Rx bytes
     Ptr<const SpectrumModel> m_mySpectrumModel; //!< Spectrum model pointer
 };
 
