@@ -153,8 +153,10 @@ FtrFadingModelAverageTest::DoRun()
     // Generate a set of values for the FTR model parameters
     for (uint8_t j = 0; j < NUM_VALUES; j++)
     {
-        sigma[j] = std::pow(2, j);
-        k[j] = std::pow(2, j);
+        double power = std::pow(2, j);
+
+        sigma[j] = power;
+        k[j] = power;
         delta[j] = double(j) / NUM_VALUES; // Delta must be in [0, 1]
     }
 
@@ -257,7 +259,7 @@ ArrayResponseTest::ArrayResponseTest(Ptr<AntennaModel> txAntElem,
                                      double expectedGain)
     // TODO: Create a string with the test parameters as the test case name like in
     // test-uniform-planar-array ?
-    : TestCase("Check that the overall array response gain has the proper trend with respect to"
+    : TestCase("Check that the overall array response gain has the proper trend with respect to "
                "the number of antennas and the type of single element antenna"),
       m_txAntElem(txAntElem),
       m_rxAntElem(rxAntElem),
@@ -559,15 +561,15 @@ OverallGainAverageTest::DoRun()
         auto rxBfVec = rxArray->GetBeamformingVector(Angles(txPosVec, rxPosVec));
         rxArray->SetBeamformingVector(rxBfVec);
 
-        auto twoRayRxPsd =
+        auto twoRayRxParams =
             twoRaySplm->DoCalcRxPowerSpectralDensity(signalParams, txMob, rxMob, txArray, rxArray);
-        auto threeGppRayRxPsd = threeGppSplm->DoCalcRxPowerSpectralDensity(signalParams,
-                                                                           txMob,
-                                                                           rxMob,
-                                                                           txArray,
-                                                                           rxArray);
-        double twoRayRxPower = ComputePowerSpectralDensityOverallPower(twoRayRxPsd);
-        double threeGppRxPower = ComputePowerSpectralDensityOverallPower(threeGppRayRxPsd);
+        auto threeGppRayRxParams = threeGppSplm->DoCalcRxPowerSpectralDensity(signalParams,
+                                                                              txMob,
+                                                                              rxMob,
+                                                                              txArray,
+                                                                              rxArray);
+        double twoRayRxPower = ComputePowerSpectralDensityOverallPower(twoRayRxParams->psd);
+        double threeGppRxPower = ComputePowerSpectralDensityOverallPower(threeGppRayRxParams->psd);
 
         twoRayGainMean += (twoRayRxPower / txPower);
         threeGppGainMean += (threeGppRxPower / txPower);
