@@ -288,8 +288,7 @@ FileHelper::GetProbe(std::string probeName) const
     NS_LOG_FUNCTION(this << probeName);
 
     // Look for the probe.
-    std::map<std::string, std::pair<Ptr<Probe>, std::string>>::const_iterator mapIterator =
-        m_probeMap.find(probeName);
+    auto mapIterator = m_probeMap.find(probeName);
 
     // Return the probe if it has been added.
     if (mapIterator != m_probeMap.end())
