@@ -47,7 +47,7 @@
  */
 
 #include "ns3/applications-module.h"
-#include "ns3/config-store-module.h"
+#include "ns3/config-store.h"
 #include "ns3/core-module.h"
 #include "ns3/enum.h"
 #include "ns3/error-model.h"
@@ -260,7 +260,7 @@ TraceDroppingState(std::string dropStateTrFileName)
  *
  * \param remoteAddress Remote address.
  * \param sender Sender node.
- * \param pktSize Pakcet size.
+ * \param pktSize Packet size.
  * \param stopTime Stop time.
  */
 void
