@@ -497,7 +497,7 @@ FqPieQueueDisc::CheckConfig()
     if (m_useL4s)
     {
         NS_ABORT_MSG_IF(m_ceThreshold == Time::Max(), "CE threshold not set");
-        if (m_useEcn == false)
+        if (!m_useEcn)
         {
             NS_LOG_WARN("Enabling ECN as L4S mode is enabled");
         }
