@@ -437,7 +437,7 @@ PieQueueDisc::CalculateP()
         m_burstAllowance -= m_tUpdate;
     }
 
-    uint32_t burstResetLimit = static_cast<uint32_t>(BURST_RESET_TIMEOUT / m_tUpdate.GetSeconds());
+    auto burstResetLimit = static_cast<uint32_t>(BURST_RESET_TIMEOUT / m_tUpdate.GetSeconds());
     if ((qDelay.GetSeconds() < 0.5 * m_qDelayRef.GetSeconds()) &&
         (m_qDelayOld.GetSeconds() < (0.5 * m_qDelayRef.GetSeconds())) && (m_dropProb == 0) &&
         !missingInitFlag)
