@@ -33,7 +33,6 @@ using namespace ns3;
 
 /**
  * \ingroup traffic-control-test
- * \ingroup tests
  *
  * \brief Pie Queue Disc Test Item
  */
@@ -94,16 +93,11 @@ PieQueueDiscTestItem::AddHeader()
 bool
 PieQueueDiscTestItem::Mark()
 {
-    if (m_ecnCapablePacket)
-    {
-        return true;
-    }
-    return false;
+    return m_ecnCapablePacket;
 }
 
 /**
  * \ingroup traffic-control-test
- * \ingroup tests
  *
  * \brief Pie Queue Disc Test Case
  */
@@ -849,7 +843,6 @@ PieQueueDiscTestCase::DoRun()
 
 /**
  * \ingroup traffic-control-test
- * \ingroup tests
  *
  * \brief Pie Queue Disc Test Suite
  */
