@@ -32,7 +32,6 @@ using namespace ns3;
 
 /**
  * \ingroup traffic-control-test
- * \ingroup tests
  *
  * \brief Red Queue Disc Test Item
  */
@@ -74,16 +73,11 @@ RedQueueDiscTestItem::AddHeader()
 bool
 RedQueueDiscTestItem::Mark()
 {
-    if (m_ecnCapablePacket)
-    {
-        return true;
-    }
-    return false;
+    return m_ecnCapablePacket;
 }
 
 /**
  * \ingroup traffic-control-test
- * \ingroup tests
  *
  * \brief Red Queue Disc Test Case
  */
@@ -621,7 +615,6 @@ RedQueueDiscTestCase::DoRun()
 
 /**
  * \ingroup traffic-control-test
- * \ingroup tests
  *
  * \brief Red Queue Disc Test Suite
  */
