@@ -73,8 +73,7 @@ Reservation::Reservation(std::list<std::pair<Ptr<Packet>, Mac8Address>>& list,
 
 Reservation::~Reservation()
 {
-    std::list<std::pair<Ptr<Packet>, Mac8Address>>::iterator it;
-    for (it = m_pktList.begin(); it != m_pktList.end(); it++)
+    for (auto it = m_pktList.begin(); it != m_pktList.end(); it++)
     {
         it->first = Ptr<Packet>((Packet*)nullptr);
     }
@@ -185,8 +184,7 @@ UanMacRc::Clear()
         m_phy->Clear();
         m_phy = nullptr;
     }
-    std::list<std::pair<Ptr<Packet>, Mac8Address>>::iterator it;
-    for (it = m_pktQueue.begin(); it != m_pktQueue.end(); it++)
+    for (auto it = m_pktQueue.begin(); it != m_pktQueue.end(); it++)
     {
         it->first = nullptr;
     }
@@ -424,7 +422,7 @@ UanMacRc::ScheduleData(const UanHeaderRcCts& ctsh,
 {
     NS_ASSERT(m_state == RTSSENT || m_state == GWPSENT);
 
-    std::list<Reservation>::iterator it = m_resList.begin();
+    auto it = m_resList.begin();
     for (; it != m_resList.end(); it++)
     {
         if (it->GetFrameNo() == ctsh.GetFrameNo())
@@ -455,8 +453,7 @@ UanMacRc::ScheduleData(const UanHeaderRcCts& ctsh,
     Time frameDelay = Seconds(0);
 
     const std::list<std::pair<Ptr<Packet>, Mac8Address>> l = it->GetPktList();
-    std::list<std::pair<Ptr<Packet>, Mac8Address>>::const_iterator pit;
-    pit = l.begin();
+    auto pit = l.begin();
 
     for (uint8_t i = 0; i < it->GetNoFrames(); i++, pit++)
     {
@@ -544,7 +541,7 @@ UanMacRc::ProcessAck(Ptr<Packet> ack)
     UanHeaderRcAck ah;
     ack->RemoveHeader(ah);
 
-    std::list<Reservation>::iterator it = m_resList.begin();
+    auto it = m_resList.begin();
     for (; it != m_resList.end(); it++)
     {
         if (it->GetFrameNo() == ah.GetFrameNo())
@@ -565,11 +562,10 @@ UanMacRc::ProcessAck(Ptr<Packet> ack)
     if (ah.GetNoNacks() > 0)
     {
         const std::list<std::pair<Ptr<Packet>, Mac8Address>> l = it->GetPktList();
-        std::list<std::pair<Ptr<Packet>, Mac8Address>>::const_iterator pit;
-        pit = l.begin();
+        auto pit = l.begin();
 
         const std::set<uint8_t>& nacks = ah.GetNackedFrames();
-        std::set<uint8_t>::iterator nit = nacks.begin();
+        auto nit = nacks.begin();
         uint8_t pnum = 0;
         for (; nit != nacks.end(); nit++)
         {
@@ -617,7 +613,7 @@ UanMacRc::Associate()
     m_resList.push_back(res);
     Ptr<UanPhyDual> phyDual = m_phy->GetObject<UanPhyDual>();
     bool phy1ok = IsPhy1Ok();
-    if (phy1ok && !phyDual->IsPhy2Tx() & !m_rtsBlocked)
+    if (phy1ok && !phyDual->IsPhy2Tx() && !m_rtsBlocked)
     {
         Ptr<Packet> pkt = Create<Packet>(0);
         pkt->AddHeader(CreateRtsHeader(res));
