@@ -20,11 +20,12 @@
 
 #include "uan-phy-gen.h"
 
+#include "acoustic-modem-energy-model.h"
 #include "uan-channel.h"
 #include "uan-net-device.h"
 #include "uan-transducer.h"
+#include "uan-tx-mode.h"
 
-#include "ns3/acoustic-modem-energy-model.h"
 #include "ns3/double.h"
 #include "ns3/energy-source-container.h"
 #include "ns3/log.h"
@@ -34,7 +35,6 @@
 #include "ns3/string.h"
 #include "ns3/trace-source-accessor.h"
 #include "ns3/traced-callback.h"
-#include "ns3/uan-tx-mode.h"
 #include "ns3/uinteger.h"
 
 namespace ns3
@@ -83,7 +83,7 @@ UanPhyCalcSinrDefault::CalcSinrDb(Ptr<Packet> pkt,
     }
 
     double intKp = -DbToKp(rxPowerDb); // This packet is in the arrivalList
-    UanTransducer::ArrivalList::const_iterator it = arrivalList.begin();
+    auto it = arrivalList.begin();
     for (; it != arrivalList.end(); it++)
     {
         intKp += DbToKp(it->GetRxPowerDb());
@@ -143,7 +143,7 @@ UanPhyCalcSinrFhFsk::CalcSinrDb(Ptr<Packet> pkt,
     // Get maximum arrival offset
     double maxAmp = -1;
     Time maxTapDelay(0);
-    UanPdp::Iterator pit = pdp.GetBegin();
+    auto pit = pdp.GetBegin();
     for (; pit != pdp.GetEnd(); pit++)
     {
         if (std::abs(pit->GetAmp()) > maxAmp)
@@ -161,7 +161,7 @@ UanPhyCalcSinrFhFsk::CalcSinrDb(Ptr<Packet> pkt,
     //  eq. 14
     double isiUpa =
         DbToKp(rxPowerDb) * pdp.SumTapsFromMaxNc(ts + clearingTime, ts); // added DpToKp()
-    UanTransducer::ArrivalList::const_iterator it = arrivalList.begin();
+    auto it = arrivalList.begin();
     double intKp = -DbToKp(effRxPowerDb);
     for (; it != arrivalList.end(); it++)
     {
@@ -312,7 +312,7 @@ UanPhyPerCommonModes::CalcPer(Ptr<Packet> pkt, double sinrDb, UanTxMode mode)
         // generic EbNo
         EbNo *= mode.GetDataRateBps() / mode.GetBandwidthHz();
 
-        double M = (double)mode.GetConstellationSize();
+        auto M = (double)mode.GetConstellationSize();
 
         // standard squared quantized QAM, even number of bits per symbol supported
         int log2sqrtM = (int)::std::log2(sqrt(M));
@@ -1086,7 +1086,7 @@ UanPhyGen::GetInterferenceDb(Ptr<Packet> pkt)
 {
     const UanTransducer::ArrivalList& arrivalList = m_transducer->GetArrivalList();
 
-    UanTransducer::ArrivalList::const_iterator it = arrivalList.begin();
+    auto it = arrivalList.begin();
 
     double interfPower = 0;
 
@@ -1116,7 +1116,7 @@ UanPhyGen::KpToDb(double kp)
 void
 UanPhyGen::NotifyListenersRxStart()
 {
-    ListenerList::const_iterator it = m_listeners.begin();
+    auto it = m_listeners.begin();
     for (; it != m_listeners.end(); it++)
     {
         (*it)->NotifyRxStart();
@@ -1126,7 +1126,7 @@ UanPhyGen::NotifyListenersRxStart()
 void
 UanPhyGen::NotifyListenersRxGood()
 {
-    ListenerList::const_iterator it = m_listeners.begin();
+    auto it = m_listeners.begin();
     for (; it != m_listeners.end(); it++)
     {
         (*it)->NotifyRxEndOk();
@@ -1136,7 +1136,7 @@ UanPhyGen::NotifyListenersRxGood()
 void
 UanPhyGen::NotifyListenersRxBad()
 {
-    ListenerList::const_iterator it = m_listeners.begin();
+    auto it = m_listeners.begin();
     for (; it != m_listeners.end(); it++)
     {
         (*it)->NotifyRxEndError();
@@ -1146,7 +1146,7 @@ UanPhyGen::NotifyListenersRxBad()
 void
 UanPhyGen::NotifyListenersCcaStart()
 {
-    ListenerList::const_iterator it = m_listeners.begin();
+    auto it = m_listeners.begin();
     for (; it != m_listeners.end(); it++)
     {
         (*it)->NotifyCcaStart();
@@ -1156,7 +1156,7 @@ UanPhyGen::NotifyListenersCcaStart()
 void
 UanPhyGen::NotifyListenersCcaEnd()
 {
-    ListenerList::const_iterator it = m_listeners.begin();
+    auto it = m_listeners.begin();
     for (; it != m_listeners.end(); it++)
     {
         (*it)->NotifyCcaEnd();
@@ -1166,7 +1166,7 @@ UanPhyGen::NotifyListenersCcaEnd()
 void
 UanPhyGen::NotifyListenersTxStart(Time duration)
 {
-    ListenerList::const_iterator it = m_listeners.begin();
+    auto it = m_listeners.begin();
     for (; it != m_listeners.end(); it++)
     {
         (*it)->NotifyTxStart(duration);
@@ -1176,7 +1176,7 @@ UanPhyGen::NotifyListenersTxStart(Time duration)
 void
 UanPhyGen::NotifyListenersTxEnd()
 {
-    ListenerList::const_iterator it = m_listeners.begin();
+    auto it = m_listeners.begin();
     for (; it != m_listeners.end(); it++)
     {
         (*it)->NotifyTxEnd();
