@@ -20,11 +20,11 @@
 #ifndef UAN_TRANSDUCER_H
 #define UAN_TRANSDUCER_H
 
+#include "uan-prop-model.h"
 #include "uan-tx-mode.h"
 
 #include "ns3/object.h"
 #include "ns3/packet.h"
-#include "ns3/uan-prop-model.h"
 
 #include <list>
 
