@@ -51,7 +51,7 @@ PathSplit(std::string str)
         }
         str = str.substr(cutAt + 1);
     }
-    if (str.length() > 0)
+    if (!str.empty())
     {
         results.push_back(str);
     }
@@ -298,8 +298,7 @@ PyViz::SimulatorRunUntil(Time time)
     Time expirationTime = Simulator::Now() - Seconds(10);
 
     // Clear very old transmission records
-    for (std::map<TxRecordKey, TxRecordValue>::iterator iter = m_txRecords.begin();
-         iter != m_txRecords.end();)
+    for (auto iter = m_txRecords.begin(); iter != m_txRecords.end();)
     {
         if (iter->second.time < expirationTime)
         {
@@ -312,8 +311,7 @@ PyViz::SimulatorRunUntil(Time time)
     }
 
     // Clear very old packets of interest
-    for (std::map<uint32_t, Time>::iterator iter = m_packetsOfInterest.begin();
-         iter != m_packetsOfInterest.end();)
+    for (auto iter = m_packetsOfInterest.begin(); iter != m_packetsOfInterest.end();)
     {
         if (iter->second < expirationTime)
         {
@@ -385,8 +383,7 @@ PyViz::TransmissionSampleKey::operator==(const PyViz::TransmissionSampleKey& oth
 PyViz::NetDeviceStatistics&
 PyViz::FindNetDeviceStatistics(int node, int interface)
 {
-    std::map<uint32_t, std::vector<NetDeviceStatistics>>::iterator nodeStatsIter =
-        m_nodesStatistics.find(node);
+    auto nodeStatsIter = m_nodesStatistics.find(node);
     std::vector<NetDeviceStatistics>* stats;
     if (nodeStatsIter == m_nodesStatistics.end())
     {
@@ -404,8 +401,7 @@ PyViz::FindNetDeviceStatistics(int node, int interface)
 bool
 PyViz::GetPacketCaptureOptions(uint32_t nodeId, const PacketCaptureOptions** outOptions) const
 {
-    std::map<uint32_t, PacketCaptureOptions>::const_iterator iter =
-        m_packetCaptureOptions.find(nodeId);
+    auto iter = m_packetCaptureOptions.find(nodeId);
     if (iter == m_packetCaptureOptions.end())
     {
         return false;
@@ -444,7 +440,7 @@ PyViz::FilterPacket(Ptr<const Packet> packet, const PacketCaptureOptions& option
         while (metadataIterator.HasNext())
         {
             PacketMetadata::Item item = metadataIterator.Next();
-            std::set<TypeId>::iterator missingIter = missingHeaders.find(item.tid);
+            auto missingIter = missingHeaders.find(item.tid);
             if (missingIter != missingHeaders.end())
             {
                 missingHeaders.erase(missingIter);
@@ -495,7 +491,7 @@ PyViz::TraceDevQueueDrop(std::string context, Ptr<const Packet> packet)
         }
     }
 
-    std::map<Ptr<Node>, uint32_t>::iterator iter = m_packetDrops.find(node);
+    auto iter = m_packetDrops.find(node);
     if (iter == m_packetDrops.end())
     {
         m_packetDrops[node] = packet->GetSize();
@@ -698,8 +694,7 @@ PyViz::TraceNetDevRxCommon(const std::string& context,
 
     Ptr<Channel> channel = device->GetChannel();
 
-    std::map<TxRecordKey, TxRecordValue>::iterator recordIter =
-        m_txRecords.find(TxRecordKey(channel, uid));
+    auto recordIter = m_txRecords.find(TxRecordKey(channel, uid));
 
     if (recordIter == m_txRecords.end())
     {
@@ -722,10 +717,7 @@ PyViz::TraceNetDevRxCommon(const std::string& context,
     NS_LOG_DEBUG("m_transmissionSamples begin:");
     if (g_log.IsEnabled(ns3::LOG_DEBUG))
     {
-        for (std::map<TransmissionSampleKey, TransmissionSampleValue>::const_iterator iter =
-                 m_transmissionSamples.begin();
-             iter != m_transmissionSamples.end();
-             iter++)
+        for (auto iter = m_transmissionSamples.begin(); iter != m_transmissionSamples.end(); iter++)
         {
             NS_LOG_DEBUG(iter->first.transmitter
                          << "/" << iter->first.transmitter->GetId() << ", " << iter->first.receiver
@@ -736,8 +728,7 @@ PyViz::TraceNetDevRxCommon(const std::string& context,
     NS_LOG_DEBUG("m_transmissionSamples end.");
 #endif
 
-    std::map<TransmissionSampleKey, TransmissionSampleValue>::iterator iter =
-        m_transmissionSamples.find(key);
+    auto iter = m_transmissionSamples.find(key);
 
     if (iter == m_transmissionSamples.end())
     {
@@ -867,10 +858,7 @@ PyViz::GetTransmissionSamples() const
 {
     NS_LOG_DEBUG("GetTransmissionSamples BEGIN");
     TransmissionSampleList list;
-    for (std::map<TransmissionSampleKey, TransmissionSampleValue>::const_iterator iter =
-             m_transmissionSamples.begin();
-         iter != m_transmissionSamples.end();
-         iter++)
+    for (auto iter = m_transmissionSamples.begin(); iter != m_transmissionSamples.end(); iter++)
     {
         TransmissionSample sample;
         sample.transmitter = iter->first.transmitter;
@@ -890,9 +878,7 @@ PyViz::GetPacketDropSamples() const
 {
     NS_LOG_DEBUG("GetPacketDropSamples BEGIN");
     PacketDropSampleList list;
-    for (std::map<Ptr<Node>, uint32_t>::const_iterator iter = m_packetDrops.begin();
-         iter != m_packetDrops.end();
-         iter++)
+    for (auto iter = m_packetDrops.begin(); iter != m_packetDrops.end(); iter++)
     {
         PacketDropSample sample;
         sample.transmitter = iter->first;
@@ -915,10 +901,7 @@ std::vector<PyViz::NodeStatistics>
 PyViz::GetNodesStatistics() const
 {
     std::vector<PyViz::NodeStatistics> retval;
-    for (std::map<uint32_t, std::vector<NetDeviceStatistics>>::const_iterator iter =
-             m_nodesStatistics.begin();
-         iter != m_nodesStatistics.end();
-         iter++)
+    for (auto iter = m_nodesStatistics.begin(); iter != m_nodesStatistics.end(); iter++)
     {
         NodeStatistics stats = {iter->first, iter->second};
         retval.push_back(stats);
@@ -931,7 +914,7 @@ PyViz::GetLastPackets(uint32_t nodeId) const
 {
     NS_LOG_DEBUG("GetLastPackets: " << nodeId);
 
-    std::map<uint32_t, LastPacketsSample>::const_iterator iter = m_lastPackets.find(nodeId);
+    auto iter = m_lastPackets.find(nodeId);
     if (iter != m_lastPackets.end())
     {
         return iter->second;
