@@ -21,7 +21,7 @@
 
 #include "ctrl-headers.h"
 #include "mac-rx-middle.h"
-#include "mgt-headers.h"
+#include "mgt-action-headers.h"
 #include "qos-utils.h"
 #include "wifi-mac-queue.h"
 #include "wifi-tx-vector.h"
@@ -30,6 +30,7 @@
 #include "ns3/log.h"
 #include "ns3/simulator.h"
 
+#include <algorithm>
 #include <optional>
 
 namespace ns3
@@ -689,21 +690,6 @@ BlockAckManager::ScheduleBar(const CtrlBAckRequestHeader& reqHdr, const WifiMacH
     m_queue->Enqueue(Create<WifiMpdu>(pkt, hdr));
 }
 
-void
-BlockAckManager::ScheduleMuBar(Ptr<WifiMpdu> muBar)
-{
-    NS_LOG_FUNCTION(this << *muBar);
-    NS_ASSERT(muBar->GetHeader().IsTrigger());
-
-#ifdef NS3_BUILD_PROFILE_DEBUG
-    CtrlTriggerHeader triggerHdr;
-    muBar->GetPacket()->PeekHeader(triggerHdr);
-    NS_ASSERT(triggerHdr.IsMuBar());
-#endif
-
-    m_queue->Enqueue(muBar);
-}
-
 const std::list<BlockAckManager::AgreementKey>&
 BlockAckManager::GetSendBarIfDataQueuedList() const
 {
@@ -770,6 +756,7 @@ BlockAckManager::NotifyOriginatorAgreementRejected(const Mac48Address& recipient
                                    OriginatorBlockAckAgreement::REJECTED);
     }
     it->second.first.SetState(OriginatorBlockAckAgreement::REJECTED);
+    m_unblockPackets(recipient, tid);
 }
 
 void
