@@ -19,14 +19,17 @@
 
 #include "channel-access-manager.h"
 
-#include "frame-exchange-manager.h"
 #include "txop.h"
+#include "wifi-mac-queue.h"
 #include "wifi-phy-listener.h"
 #include "wifi-phy.h"
 
+#include "ns3/eht-frame-exchange-manager.h"
 #include "ns3/log.h"
 #include "ns3/simulator.h"
 
+#include <sstream>
+
 #undef NS_LOG_APPEND_CONTEXT
 #define NS_LOG_APPEND_CONTEXT std::clog << "[link=" << +m_linkId << "] "
 
@@ -35,8 +38,14 @@ namespace ns3
 
 NS_LOG_COMPONENT_DEFINE("ChannelAccessManager");
 
+NS_OBJECT_ENSURE_REGISTERED(ChannelAccessManager);
+
 /**
- * Listener for PHY events. Forwards to ChannelAccessManager
+ * Listener for PHY events. Forwards to ChannelAccessManager.
+ * The ChannelAccessManager may handle multiple PHY listeners connected to distinct PHYs,
+ * but only one listener at a time can be active. Notifications from inactive listeners are
+ * ignored by the ChannelAccessManager, except for the channel switch notification.
+ * Inactive PHY listeners are typically configured by 11be EMLSR clients.
  */
 class PhyListener : public ns3::WifiPhyListener
 {
@@ -47,7 +56,8 @@ class PhyListener : public ns3::WifiPhyListener
      * \param cam the ChannelAccessManager
      */
     PhyListener(ns3::ChannelAccessManager* cam)
-        : m_cam(cam)
+        : m_cam(cam),
+          m_active(true)
     {
     }
 
@@ -55,77 +65,143 @@ class PhyListener : public ns3::WifiPhyListener
     {
     }
 
+    /**
+     * Set this listener to be active or not.
+     *
+     * \param active whether this listener is active or not
+     */
+    void SetActive(bool active)
+    {
+        m_active = active;
+    }
+
+    /**
+     * \return whether this listener is active or not
+     */
+    bool IsActive() const
+    {
+        return m_active;
+    }
+
     void NotifyRxStart(Time duration) override
     {
-        m_cam->NotifyRxStartNow(duration);
+        if (m_active)
+        {
+            m_cam->NotifyRxStartNow(duration);
+        }
     }
 
     void NotifyRxEndOk() override
     {
-        m_cam->NotifyRxEndOkNow();
+        if (m_active)
+        {
+            m_cam->NotifyRxEndOkNow();
+        }
     }
 
     void NotifyRxEndError() override
     {
-        m_cam->NotifyRxEndErrorNow();
+        if (m_active)
+        {
+            m_cam->NotifyRxEndErrorNow();
+        }
     }
 
     void NotifyTxStart(Time duration, double txPowerDbm) override
     {
-        m_cam->NotifyTxStartNow(duration);
+        if (m_active)
+        {
+            m_cam->NotifyTxStartNow(duration);
+        }
     }
 
     void NotifyCcaBusyStart(Time duration,
                             WifiChannelListType channelType,
                             const std::vector<Time>& per20MhzDurations) override
     {
-        m_cam->NotifyCcaBusyStartNow(duration, channelType, per20MhzDurations);
+        if (m_active)
+        {
+            m_cam->NotifyCcaBusyStartNow(duration, channelType, per20MhzDurations);
+        }
     }
 
     void NotifySwitchingStart(Time duration) override
     {
-        m_cam->NotifySwitchingStartNow(duration);
+        m_cam->NotifySwitchingStartNow(this, duration);
     }
 
     void NotifySleep() override
     {
-        m_cam->NotifySleepNow();
+        if (m_active)
+        {
+            m_cam->NotifySleepNow();
+        }
     }
 
     void NotifyOff() override
     {
-        m_cam->NotifyOffNow();
+        if (m_active)
+        {
+            m_cam->NotifyOffNow();
+        }
     }
 
     void NotifyWakeup() override
     {
-        m_cam->NotifyWakeupNow();
+        if (m_active)
+        {
+            m_cam->NotifyWakeupNow();
+        }
     }
 
     void NotifyOn() override
     {
-        m_cam->NotifyOnNow();
+        if (m_active)
+        {
+            m_cam->NotifyOnNow();
+        }
     }
 
   private:
     ns3::ChannelAccessManager* m_cam; //!< ChannelAccessManager to forward events to
+    bool m_active;                    //!< whether this PHY listener is active
 };
 
 /****************************************************************
  *      Implement the channel access manager of all Txop holders
  ****************************************************************/
 
+TypeId
+ChannelAccessManager::GetTypeId()
+{
+    static TypeId tid =
+        TypeId("ns3::ChannelAccessManager")
+            .SetParent<ns3::Object>()
+            .SetGroupName("Wifi")
+            .AddConstructor<ChannelAccessManager>()
+            .AddAttribute("GenerateBackoffIfTxopWithoutTx",
+                          "Specify whether the backoff should be invoked when the AC gains the "
+                          "right to start a TXOP but it does not transmit any frame "
+                          "(e.g., due to constraints associated with EMLSR operations), "
+                          "provided that the queue is not actually empty.",
+                          BooleanValue(false),
+                          MakeBooleanAccessor(&ChannelAccessManager::SetGenerateBackoffOnNoTx,
+                                              &ChannelAccessManager::GetGenerateBackoffOnNoTx),
+                          MakeBooleanChecker());
+    return tid;
+}
+
 ChannelAccessManager::ChannelAccessManager()
-    : m_lastAckTimeoutEnd(MicroSeconds(0)),
-      m_lastCtsTimeoutEnd(MicroSeconds(0)),
-      m_lastNavEnd(MicroSeconds(0)),
+    : m_lastAckTimeoutEnd(0),
+      m_lastCtsTimeoutEnd(0),
+      m_lastNavEnd(0),
       m_lastRx({MicroSeconds(0), MicroSeconds(0)}),
       m_lastRxReceivedOk(true),
-      m_lastTxEnd(MicroSeconds(0)),
-      m_lastSwitchingEnd(MicroSeconds(0)),
+      m_lastTxEnd(0),
+      m_lastSwitchingEnd(0),
+      m_usingOtherEmlsrLink(false),
       m_sleeping(false),
       m_off(false),
-      m_phyListener(nullptr),
       m_linkId(0)
 {
     NS_LOG_FUNCTION(this);
@@ -135,8 +211,6 @@ ChannelAccessManager::ChannelAccessManager()
 ChannelAccessManager::~ChannelAccessManager()
 {
     NS_LOG_FUNCTION(this);
-    delete m_phyListener;
-    m_phyListener = nullptr;
 }
 
 void
@@ -157,32 +231,93 @@ ChannelAccessManager::DoDispose()
     }
     m_phy = nullptr;
     m_feManager = nullptr;
+    m_phyListeners.clear();
+}
+
+std::shared_ptr<PhyListener>
+ChannelAccessManager::GetPhyListener(Ptr<WifiPhy> phy) const
+{
+    if (auto listenerIt = m_phyListeners.find(phy); listenerIt != m_phyListeners.end())
+    {
+        return listenerIt->second;
+    }
+    return nullptr;
 }
 
 void
 ChannelAccessManager::SetupPhyListener(Ptr<WifiPhy> phy)
 {
     NS_LOG_FUNCTION(this << phy);
-    NS_ASSERT(m_phyListener == nullptr);
-    m_phyListener = new PhyListener(this);
-    phy->RegisterListener(m_phyListener);
-    m_phy = phy;
+
+    if (auto phyListener = GetPhyListener(phy))
+    {
+        // a PHY listener for the given PHY already exists, it must be inactive
+        NS_ASSERT_MSG(!phyListener->IsActive(),
+                      "There is already an active listener registered for given PHY");
+        NS_ASSERT_MSG(!m_phy, "Cannot reactivate a listener if another PHY is active");
+        phyListener->SetActive(true);
+    }
+    else
+    {
+        phyListener = std::make_shared<PhyListener>(this);
+        m_phyListeners.emplace(phy, phyListener);
+        phy->RegisterListener(phyListener);
+    }
+    if (m_phy)
+    {
+        DeactivatePhyListener(m_phy);
+    }
+    m_phy = phy; // this is the new active PHY
     InitLastBusyStructs();
+    if (phy->IsStateSwitching())
+    {
+        auto duration = phy->GetDelayUntilIdle();
+        NS_LOG_DEBUG("switching start for " << duration);
+        m_lastSwitchingEnd = Simulator::Now() + duration;
+    }
 }
 
 void
 ChannelAccessManager::RemovePhyListener(Ptr<WifiPhy> phy)
 {
     NS_LOG_FUNCTION(this << phy);
-    if (m_phyListener != nullptr)
+    if (auto phyListener = GetPhyListener(phy))
+    {
+        phy->UnregisterListener(phyListener);
+        m_phyListeners.erase(phy);
+        // reset m_phy if we are removing listener registered for the active PHY
+        if (m_phy == phy)
+        {
+            m_phy = nullptr;
+        }
+    }
+}
+
+void
+ChannelAccessManager::DeactivatePhyListener(Ptr<WifiPhy> phy)
+{
+    NS_LOG_FUNCTION(this << phy);
+    if (auto listener = GetPhyListener(phy))
+    {
+        listener->SetActive(false);
+    }
+    if (m_phy == phy)
     {
-        phy->UnregisterListener(m_phyListener);
-        delete m_phyListener;
-        m_phyListener = nullptr;
         m_phy = nullptr;
     }
 }
 
+void
+ChannelAccessManager::NotifySwitchingEmlsrLink(Ptr<WifiPhy> phy,
+                                               const WifiPhyOperatingChannel& channel,
+                                               uint8_t linkId)
+{
+    NS_LOG_FUNCTION(this << phy << channel << linkId);
+    NS_ASSERT_MSG(m_switchingEmlsrLinks.count(phy) == 0,
+                  "The given PHY is already expected to switch channel");
+    m_switchingEmlsrLinks.emplace(phy, EmlsrLinkSwitchInfo{channel, linkId});
+}
+
 void
 ChannelAccessManager::SetLinkId(uint8_t linkId)
 {
@@ -278,12 +413,15 @@ ChannelAccessManager::IsBusy() const
 }
 
 bool
-ChannelAccessManager::NeedBackoffUponAccess(Ptr<Txop> txop)
+ChannelAccessManager::NeedBackoffUponAccess(Ptr<Txop> txop,
+                                            bool hadFramesToTransmit,
+                                            bool checkMediumBusy)
 {
-    NS_LOG_FUNCTION(this << txop);
+    NS_LOG_FUNCTION(this << txop << hadFramesToTransmit << checkMediumBusy);
 
-    // No backoff needed if in sleep mode or off
-    if (m_sleeping || m_off)
+    // No backoff needed if in sleep mode or off. Checking if m_phy is nullptr is a workaround
+    // needed for EMLSR and may be removed in the future
+    if (m_sleeping || m_off || !m_phy)
     {
         return false;
     }
@@ -311,10 +449,10 @@ ChannelAccessManager::NeedBackoffUponAccess(Ptr<Txop> txop)
      *    with that AC has now become non-empty and any other transmit queues
      *    associated with that AC are empty; the medium is busy on the primary channel
      */
-    if (!txop->HasFramesToTransmit(m_linkId) && txop->GetAccessStatus(m_linkId) != Txop::GRANTED &&
-        txop->GetBackoffSlots(m_linkId) == 0)
+    if (!hadFramesToTransmit && txop->HasFramesToTransmit(m_linkId) &&
+        txop->GetAccessStatus(m_linkId) != Txop::GRANTED && txop->GetBackoffSlots(m_linkId) == 0)
     {
-        if (!IsBusy())
+        if (checkMediumBusy && !IsBusy())
         {
             // medium idle. If this is a DCF, use immediate access (we can transmit
             // in a DIFS if the medium remains idle). If this is an EDCAF, update
@@ -338,12 +476,13 @@ void
 ChannelAccessManager::RequestAccess(Ptr<Txop> txop)
 {
     NS_LOG_FUNCTION(this << txop);
-    if (m_phy)
+    if (m_phy && txop->HasFramesToTransmit(m_linkId))
     {
         m_phy->NotifyChannelAccessRequested();
     }
-    // Deny access if in sleep mode or off
-    if (m_sleeping || m_off)
+    // Deny access if in sleep mode or off. Checking if m_phy is nullptr is a workaround
+    // needed for EMLSR and may be removed in the future
+    if (m_sleeping || m_off || !m_phy)
     {
         return;
     }
@@ -375,7 +514,7 @@ ChannelAccessManager::DoGrantDcfAccess()
     NS_LOG_FUNCTION(this);
     uint32_t k = 0;
     Time now = Simulator::Now();
-    for (Txops::iterator i = m_txops.begin(); i != m_txops.end(); k++)
+    for (auto i = m_txops.begin(); i != m_txops.end(); k++)
     {
         Ptr<Txop> txop = *i;
         if (txop->GetAccessStatus(m_linkId) == Txop::REQUESTED &&
@@ -391,7 +530,7 @@ ChannelAccessManager::DoGrantDcfAccess()
             i++; // go to the next item in the list.
             k++;
             std::vector<Ptr<Txop>> internalCollisionTxops;
-            for (Txops::iterator j = i; j != m_txops.end(); j++, k++)
+            for (auto j = i; j != m_txops.end(); j++, k++)
             {
                 Ptr<Txop> otherTxop = *j;
                 if (otherTxop->GetAccessStatus(m_linkId) == Txop::REQUESTED &&
@@ -438,6 +577,9 @@ ChannelAccessManager::DoGrantDcfAccess()
             }
             else
             {
+                // this TXOP did not transmit anything, make sure that backoff counter starts
+                // decreasing in a slot again
+                txop->UpdateBackoffSlotsNow(0, now, m_linkId);
                 // reset the current state to the EDCAF that won the contention
                 // but did not transmit anything
                 i--;
@@ -495,10 +637,13 @@ ChannelAccessManager::GetAccessGrantStart(bool ignoreNav) const
                                        ctsTimeoutAccessStart,
                                        switchingAccessStart});
     }
-    NS_LOG_INFO("access grant start=" << accessGrantedStart << ", rx access start=" << rxAccessStart
-                                      << ", busy access start=" << busyAccessStart
-                                      << ", tx access start=" << txAccessStart
-                                      << ", nav access start=" << navAccessStart);
+    NS_LOG_INFO("access grant start=" << accessGrantedStart.As(Time::US)
+                                      << ", rx access start=" << rxAccessStart.As(Time::US)
+                                      << ", busy access start=" << busyAccessStart.As(Time::US)
+                                      << ", tx access start=" << txAccessStart.As(Time::US)
+                                      << ", nav access start=" << navAccessStart.As(Time::US)
+                                      << ", switching access start="
+                                      << switchingAccessStart.As(Time::US));
     return accessGrantedStart;
 }
 
@@ -509,7 +654,8 @@ ChannelAccessManager::GetBackoffStartFor(Ptr<Txop> txop)
     Time mostRecentEvent =
         std::max({txop->GetBackoffStart(m_linkId),
                   GetAccessGrantStart() + (txop->GetAifsn(m_linkId) * GetSlot())});
-    NS_LOG_DEBUG("Backoff start: " << mostRecentEvent.As(Time::US));
+    NS_LOG_DEBUG("Backoff start for " << txop->GetWifiMacQueue()->GetAc() << ": "
+                                      << mostRecentEvent.As(Time::US));
 
     return mostRecentEvent;
 }
@@ -519,7 +665,8 @@ ChannelAccessManager::GetBackoffEndFor(Ptr<Txop> txop)
 {
     NS_LOG_FUNCTION(this << txop);
     Time backoffEnd = GetBackoffStartFor(txop) + (txop->GetBackoffSlots(m_linkId) * GetSlot());
-    NS_LOG_DEBUG("Backoff end: " << backoffEnd.As(Time::US));
+    NS_LOG_DEBUG("Backoff end for " << txop->GetWifiMacQueue()->GetAc() << ": "
+                                    << backoffEnd.As(Time::US));
 
     return backoffEnd;
 }
@@ -672,6 +819,19 @@ ChannelAccessManager::DisableEdcaFor(Ptr<Txop> qosTxop, Time duration)
     DoRestartAccessTimeoutIfNeeded();
 }
 
+void
+ChannelAccessManager::SetGenerateBackoffOnNoTx(bool enable)
+{
+    NS_LOG_FUNCTION(this << enable);
+    m_generateBackoffOnNoTx = enable;
+}
+
+bool
+ChannelAccessManager::GetGenerateBackoffOnNoTx() const
+{
+    return m_generateBackoffOnNoTx;
+}
+
 void
 ChannelAccessManager::NotifyRxStartNow(Time duration)
 {
@@ -751,13 +911,61 @@ ChannelAccessManager::NotifyCcaBusyStartNow(Time duration,
 }
 
 void
-ChannelAccessManager::NotifySwitchingStartNow(Time duration)
+ChannelAccessManager::NotifySwitchingStartNow(PhyListener* phyListener, Time duration)
 {
-    NS_LOG_FUNCTION(this << duration);
+    NS_LOG_FUNCTION(this << phyListener << duration);
+
     Time now = Simulator::Now();
     NS_ASSERT(m_lastTxEnd <= now);
     NS_ASSERT(m_lastSwitchingEnd <= now);
 
+    if (phyListener) // to make tests happy
+    {
+        // check if the PHY switched channel to operate on another EMLSR link
+
+        for (const auto& [phyRef, listener] : m_phyListeners)
+        {
+            Ptr<WifiPhy> phy = phyRef;
+            auto emlsrInfoIt = m_switchingEmlsrLinks.find(phy);
+
+            if (listener.get() == phyListener && emlsrInfoIt != m_switchingEmlsrLinks.cend() &&
+                phy->GetOperatingChannel() == emlsrInfoIt->second.channel)
+            {
+                // the PHY associated with the given PHY listener switched channel to
+                // operate on another EMLSR link as expected. We don't need this listener
+                // anymore. The MAC will connect a new listener to the ChannelAccessManager
+                // instance associated with the link the PHY is now operating on
+                RemovePhyListener(phy);
+                auto ehtFem = DynamicCast<EhtFrameExchangeManager>(m_feManager);
+                NS_ASSERT(ehtFem);
+                ehtFem->NotifySwitchingEmlsrLink(phy, emlsrInfoIt->second.linkId, duration);
+                m_switchingEmlsrLinks.erase(emlsrInfoIt);
+                return;
+            }
+        }
+    }
+
+    ResetState();
+
+    // Reset backoffs
+    for (const auto& txop : m_txops)
+    {
+        ResetBackoff(txop);
+    }
+
+    // Notify the FEM, which will in turn notify the MAC
+    m_feManager->NotifySwitchingStartNow(duration);
+
+    NS_LOG_DEBUG("switching start for " << duration);
+    m_lastSwitchingEnd = now + duration;
+}
+
+void
+ChannelAccessManager::ResetState()
+{
+    NS_LOG_FUNCTION(this);
+
+    Time now = Simulator::Now();
     m_lastRxReceivedOk = true;
     UpdateLastIdlePeriod();
     m_lastRx.end = std::min(m_lastRx.end, now);
@@ -765,7 +973,6 @@ ChannelAccessManager::NotifySwitchingStartNow(Time duration)
     m_lastAckTimeoutEnd = std::min(m_lastAckTimeoutEnd, now);
     m_lastCtsTimeoutEnd = std::min(m_lastCtsTimeoutEnd, now);
 
-    // the new operating channel may have a different width than the previous one
     InitLastBusyStructs();
 
     // Cancel timeout
@@ -773,25 +980,33 @@ ChannelAccessManager::NotifySwitchingStartNow(Time duration)
     {
         m_accessTimeout.Cancel();
     }
+}
 
-    // Notify the FEM, which will in turn notify the MAC
-    m_feManager->NotifySwitchingStartNow(duration);
+void
+ChannelAccessManager::ResetBackoff(Ptr<Txop> txop)
+{
+    NS_LOG_FUNCTION(this << txop);
 
-    // Reset backoffs
-    for (auto txop : m_txops)
+    uint32_t remainingSlots = txop->GetBackoffSlots(m_linkId);
+    if (remainingSlots > 0)
     {
-        uint32_t remainingSlots = txop->GetBackoffSlots(m_linkId);
-        if (remainingSlots > 0)
-        {
-            txop->UpdateBackoffSlotsNow(remainingSlots, now, m_linkId);
-            NS_ASSERT(txop->GetBackoffSlots(m_linkId) == 0);
-        }
-        txop->ResetCw(m_linkId);
-        txop->GetLink(m_linkId).access = Txop::NOT_REQUESTED;
+        txop->UpdateBackoffSlotsNow(remainingSlots, Simulator::Now(), m_linkId);
+        NS_ASSERT(txop->GetBackoffSlots(m_linkId) == 0);
     }
+    txop->ResetCw(m_linkId);
+    txop->GetLink(m_linkId).access = Txop::NOT_REQUESTED;
+}
 
-    NS_LOG_DEBUG("switching start for " << duration);
-    m_lastSwitchingEnd = now + duration;
+void
+ChannelAccessManager::ResetAllBackoffs()
+{
+    NS_LOG_FUNCTION(this);
+
+    for (const auto& txop : m_txops)
+    {
+        ResetBackoff(txop);
+    }
+    m_accessTimeout.Cancel();
 }
 
 void
@@ -837,14 +1052,7 @@ ChannelAccessManager::NotifyWakeupNow()
     m_sleeping = false;
     for (auto txop : m_txops)
     {
-        uint32_t remainingSlots = txop->GetBackoffSlots(m_linkId);
-        if (remainingSlots > 0)
-        {
-            txop->UpdateBackoffSlotsNow(remainingSlots, Simulator::Now(), m_linkId);
-            NS_ASSERT(txop->GetBackoffSlots(m_linkId) == 0);
-        }
-        txop->ResetCw(m_linkId);
-        txop->GetLink(m_linkId).access = Txop::NOT_REQUESTED;
+        ResetBackoff(txop);
         txop->NotifyWakeUp(m_linkId);
     }
 }
@@ -856,14 +1064,7 @@ ChannelAccessManager::NotifyOnNow()
     m_off = false;
     for (auto txop : m_txops)
     {
-        uint32_t remainingSlots = txop->GetBackoffSlots(m_linkId);
-        if (remainingSlots > 0)
-        {
-            txop->UpdateBackoffSlotsNow(remainingSlots, Simulator::Now(), m_linkId);
-            NS_ASSERT(txop->GetBackoffSlots(m_linkId) == 0);
-        }
-        txop->ResetCw(m_linkId);
-        txop->GetLink(m_linkId).access = Txop::NOT_REQUESTED;
+        ResetBackoff(txop);
         txop->NotifyOn();
     }
 }
@@ -872,6 +1073,14 @@ void
 ChannelAccessManager::NotifyNavResetNow(Time duration)
 {
     NS_LOG_FUNCTION(this << duration);
+
+    if (!m_phy)
+    {
+        NS_LOG_DEBUG("Do not reset NAV, CTS may have been missed due to the main PHY switching "
+                     "to another link to take over a TXOP while receiving the CTS");
+        return;
+    }
+
     NS_LOG_DEBUG("nav reset for=" << duration);
     UpdateBackoff();
     m_lastNavEnd = Simulator::Now() + duration;
@@ -924,6 +1133,20 @@ ChannelAccessManager::NotifyCtsTimeoutResetNow()
     DoRestartAccessTimeoutIfNeeded();
 }
 
+void
+ChannelAccessManager::NotifyStartUsingOtherEmlsrLink()
+{
+    NS_LOG_FUNCTION(this);
+    m_usingOtherEmlsrLink = true;
+}
+
+void
+ChannelAccessManager::NotifyStopUsingOtherEmlsrLink()
+{
+    NS_LOG_FUNCTION(this);
+    m_usingOtherEmlsrLink = false;
+}
+
 void
 ChannelAccessManager::UpdateLastIdlePeriod()
 {
