@@ -110,13 +110,16 @@ class EhtPpdu : public HePpdu
      * \param channelWidth the channel width occupied by the PPDU (in MHz)
      * \param ehtPpduType the EHT_PPDU_TYPE used by the PPDU
      * \param ruAllocation 8 bit RU_ALLOCATION per 20 MHz
-
+     * \param compression flag whether compression mode is used by the PPDU
+     * \param numMuMimoUsers the number of MU-MIMO users addressed by the PPDU
      * \return a pair containing the number of RUs in each EHT-SIG-B content channel (resp. 1 and 2)
      */
     static std::pair<std::size_t, std::size_t> GetNumRusPerEhtSigBContentChannel(
         uint16_t channelWidth,
         uint8_t ehtPpduType,
-        const std::vector<uint8_t>& ruAllocation);
+        const std::vector<uint8_t>& ruAllocation,
+        bool compression,
+        std::size_t numMuMimoUsers);
 
     /**
      * Get the EHT-SIG content channels for a given PPDU
@@ -134,11 +137,15 @@ class EhtPpdu : public HePpdu
      * \param channelWidth the channel width occupied by the PPDU (in MHz)
      * \param ruAllocation 8 bit RU_ALLOCATION per 20 MHz
      * \param ehtPpduType the EHT_PPDU_TYPE used by the PPDU
+     * \param compression flag whether compression mode is used by the PPDU
+     * \param numMuMimoUsers the number of MU-MIMO users addressed by the PPDU
      * \return field size in bytes
      */
     static uint32_t GetEhtSigFieldSize(uint16_t channelWidth,
                                        const std::vector<uint8_t>& ruAllocation,
-                                       uint8_t ehtPpduType);
+                                       uint8_t ehtPpduType,
+                                       bool compression,
+                                       std::size_t numMuMimoUsers);
 
   private:
     bool IsDlMu() const override;
