@@ -415,12 +415,6 @@ FrameExchangeManager::SendMpduWithProtection(Ptr<WifiMpdu> mpdu, WifiTxParameter
     }
 
     StartProtection(m_txParams);
-
-    if (m_txParams.m_acknowledgment->method == WifiAcknowledgment::NONE)
-    {
-        // we are done with frames that do not require acknowledgment
-        m_mpdu = nullptr;
-    }
 }
 
 void
@@ -473,14 +467,17 @@ FrameExchangeManager::SendMpdu()
 
     if (m_txParams.m_acknowledgment->method == WifiAcknowledgment::NONE)
     {
-        Simulator::Schedule(txDuration, &FrameExchangeManager::TransmissionSucceeded, this);
-
         if (!m_mpdu->GetHeader().IsQosData() ||
             m_mpdu->GetHeader().GetQosAckPolicy() == WifiMacHeader::NO_ACK)
         {
             // No acknowledgment, hence dequeue the MPDU if it is stored in a queue
             DequeueMpdu(m_mpdu);
         }
+
+        Simulator::Schedule(txDuration, [=, this]() {
+            TransmissionSucceeded();
+            m_mpdu = nullptr;
+        });
     }
     else if (m_txParams.m_acknowledgment->method == WifiAcknowledgment::NORMAL_ACK)
     {
@@ -493,8 +490,7 @@ FrameExchangeManager::SendMpdu()
         // the timeout duration is "aSIFSTime + aSlotTime + aRxPHYStartDelay, starting
         // at the PHY-TXEND.confirm primitive" (section 10.3.2.9 or 10.22.2.2 of 802.11-2016).
         // aRxPHYStartDelay equals the time to transmit the PHY header.
-        WifiNormalAck* normalAcknowledgment =
-            static_cast<WifiNormalAck*>(m_txParams.m_acknowledgment.get());
+        auto normalAcknowledgment = static_cast<WifiNormalAck*>(m_txParams.m_acknowledgment.get());
 
         Time timeout =
             txDuration + m_phy->GetSifs() + m_phy->GetSlot() +
@@ -502,6 +498,7 @@ FrameExchangeManager::SendMpdu()
         NS_ASSERT(!m_txTimer.IsRunning());
         m_txTimer.Set(WifiTxTimer::WAIT_NORMAL_ACK,
                       timeout,
+                      {m_mpdu->GetHeader().GetAddr1()},
                       &FrameExchangeManager::NormalAckTimeout,
                       this,
                       m_mpdu,
@@ -525,6 +522,7 @@ FrameExchangeManager::ForwardMpduDown(Ptr<WifiMpdu> mpdu, WifiTxVector& txVector
 
     auto psdu = Create<WifiPsdu>(mpdu, false);
     FinalizeMacHeader(psdu);
+    m_allowedWidth = std::min(m_allowedWidth, txVector.GetChannelWidth());
     m_phy->Send(psdu, txVector);
 }
 
@@ -587,7 +585,7 @@ FrameExchangeManager::CalculateProtectionTime(WifiProtection* protection) const
     }
     else if (protection->method == WifiProtection::RTS_CTS)
     {
-        WifiRtsCtsProtection* rtsCtsProtection = static_cast<WifiRtsCtsProtection*>(protection);
+        auto rtsCtsProtection = static_cast<WifiRtsCtsProtection*>(protection);
         rtsCtsProtection->protectionTime = m_phy->CalculateTxDuration(GetRtsSize(),
                                                                       rtsCtsProtection->rtsTxVector,
                                                                       m_phy->GetPhyBand()) +
@@ -598,8 +596,7 @@ FrameExchangeManager::CalculateProtectionTime(WifiProtection* protection) const
     }
     else if (protection->method == WifiProtection::CTS_TO_SELF)
     {
-        WifiCtsToSelfProtection* ctsToSelfProtection =
-            static_cast<WifiCtsToSelfProtection*>(protection);
+        auto ctsToSelfProtection = static_cast<WifiCtsToSelfProtection*>(protection);
         ctsToSelfProtection->protectionTime =
             m_phy->CalculateTxDuration(GetCtsSize(),
                                        ctsToSelfProtection->ctsTxVector,
@@ -620,7 +617,7 @@ FrameExchangeManager::CalculateAcknowledgmentTime(WifiAcknowledgment* acknowledg
     }
     else if (acknowledgment->method == WifiAcknowledgment::NORMAL_ACK)
     {
-        WifiNormalAck* normalAcknowledgment = static_cast<WifiNormalAck*>(acknowledgment);
+        auto normalAcknowledgment = static_cast<WifiNormalAck*>(acknowledgment);
         normalAcknowledgment->acknowledgmentTime =
             m_phy->GetSifs() + m_phy->CalculateTxDuration(GetAckSize(),
                                                           normalAcknowledgment->ackTxVector,
@@ -706,8 +703,7 @@ FrameExchangeManager::SendRts(const WifiTxParameters& txParams)
     rts.SetAddr2(m_self);
 
     NS_ASSERT(txParams.m_protection && txParams.m_protection->method == WifiProtection::RTS_CTS);
-    WifiRtsCtsProtection* rtsCtsProtection =
-        static_cast<WifiRtsCtsProtection*>(txParams.m_protection.get());
+    auto rtsCtsProtection = static_cast<WifiRtsCtsProtection*>(txParams.m_protection.get());
 
     NS_ASSERT(txParams.m_txDuration != Time::Min());
     rts.SetDuration(GetRtsDurationId(rtsCtsProtection->rtsTxVector,
@@ -726,6 +722,7 @@ FrameExchangeManager::SendRts(const WifiTxParameters& txParams)
     NS_ASSERT(!m_txTimer.IsRunning());
     m_txTimer.Set(WifiTxTimer::WAIT_CTS,
                   timeout,
+                  {receiver},
                   &FrameExchangeManager::CtsTimeout,
                   this,
                   mpdu,
@@ -807,8 +804,7 @@ FrameExchangeManager::SendCtsToSelf(const WifiTxParameters& txParams)
 
     NS_ASSERT(txParams.m_protection &&
               txParams.m_protection->method == WifiProtection::CTS_TO_SELF);
-    WifiCtsToSelfProtection* ctsToSelfProtection =
-        static_cast<WifiCtsToSelfProtection*>(txParams.m_protection.get());
+    auto ctsToSelfProtection = static_cast<WifiCtsToSelfProtection*>(txParams.m_protection.get());
 
     NS_ASSERT(txParams.m_txDuration != Time::Min());
     cts.SetDuration(GetCtsToSelfDurationId(ctsToSelfProtection->ctsTxVector,
