@@ -29,6 +29,8 @@
 #include "ns3/wifi-psdu.h"
 #include "ns3/wifi-utils.h"
 
+#include <algorithm>
+
 namespace ns3
 {
 
@@ -129,10 +131,15 @@ HePpdu::SetHeSigHeader(const WifiTxVector& txVector)
     else if (ns3::IsDlMu(m_preamble))
     {
         const auto p20Index = m_operatingChannel.GetPrimaryChannelIndex(20);
+        const uint8_t noMuMimoUsers{0};
         m_heSig.emplace<HeMuSigHeader>(HeMuSigHeader{
             .m_bssColor = bssColor,
             .m_bandwidth = GetChannelWidthEncodingFromMhz(txVector.GetChannelWidth()),
             .m_sigBMcs = txVector.GetSigBMode().GetMcsValue(),
+            .m_muMimoUsers = (txVector.IsSigBCompression()
+                                  ? GetMuMimoUsersEncoding(txVector.GetHeMuUserInfoMap().size())
+                                  : noMuMimoUsers),
+            .m_sigBCompression = txVector.IsSigBCompression(),
             .m_giLtfSize = GetGuardIntervalAndNltfEncoding(txVector.GetGuardInterval(),
                                                            2 /*NLTF currently unused*/),
             .m_ruAllocation = txVector.GetRuAllocation(p20Index),
@@ -194,7 +201,11 @@ HePpdu::SetTxVectorFromPhyHeaders(WifiTxVector& txVector) const
         txVector.SetChannelWidth(GetChannelWidthMhzFromEncoding(heSigHeader->m_bandwidth));
         txVector.SetGuardInterval(GetGuardIntervalFromEncoding(heSigHeader->m_giLtfSize));
         txVector.SetBssColor(heSigHeader->m_bssColor);
-        SetHeMuUserInfos(txVector, heSigHeader->m_ruAllocation, heSigHeader->m_contentChannels);
+        SetHeMuUserInfos(txVector,
+                         heSigHeader->m_ruAllocation,
+                         heSigHeader->m_contentChannels,
+                         heSigHeader->m_sigBCompression,
+                         GetMuMimoUsersFromEncoding(heSigHeader->m_muMimoUsers));
         txVector.SetSigBMode(HePhy::GetVhtMcs(heSigHeader->m_sigBMcs));
         const auto p20Index = m_operatingChannel.GetPrimaryChannelIndex(20);
         txVector.SetRuAllocation(heSigHeader->m_ruAllocation, p20Index);
@@ -202,25 +213,37 @@ HePpdu::SetTxVectorFromPhyHeaders(WifiTxVector& txVector) const
         {
             txVector.SetCenter26ToneRuIndication(heSigHeader->m_center26ToneRuIndication.value());
         }
+        if (heSigHeader->m_sigBCompression)
+        {
+            NS_ASSERT(GetMuMimoUsersFromEncoding(heSigHeader->m_muMimoUsers) ==
+                      txVector.GetHeMuUserInfoMap().size());
+        }
     }
 }
 
 void
 HePpdu::SetHeMuUserInfos(WifiTxVector& txVector,
                          const RuAllocation& ruAllocation,
-                         const HeSigBContentChannels& contentChannels) const
+                         const HeSigBContentChannels& contentChannels,
+                         bool sigBcompression,
+                         uint8_t numMuMimoUsers) const
 {
-    auto contentChannelIndex = 0;
+    std::size_t contentChannelIndex = 0;
     for (const auto& contentChannel : contentChannels)
     {
-        auto numRusLeft = 0;
-        auto ruAllocIndex = contentChannelIndex;
+        std::size_t numRusLeft = 0;
+        std::size_t numUsersLeft = 0;
+        std::size_t ruAllocIndex = contentChannelIndex;
         for (const auto& userInfo : contentChannel)
         {
             if (userInfo.staId == NO_USER_STA_ID)
             {
                 continue;
             }
+            if (ruAllocIndex >= ruAllocation.size())
+            {
+                break;
+            }
             auto ruSpecs = HeRu::GetRuSpecs(ruAllocation.at(ruAllocIndex));
             if (ruSpecs.empty())
             {
@@ -230,14 +253,27 @@ HePpdu::SetHeMuUserInfos(WifiTxVector& txVector,
             {
                 numRusLeft = ruSpecs.size();
             }
+            if (numUsersLeft == 0)
+            {
+                if (sigBcompression)
+                {
+                    numUsersLeft = numMuMimoUsers;
+                }
+                else
+                {
+                    // not MU-MIMO
+                    numUsersLeft = 1;
+                }
+            }
             auto ruIndex = (ruSpecs.size() - numRusLeft);
             auto ruSpec = ruSpecs.at(ruIndex);
             auto ruType = ruSpec.GetRuType();
             if ((ruAllocation.size() == 8) && (ruType == HeRu::RU_996_TONE) &&
-                (std::all_of(
-                    contentChannel.cbegin(),
-                    contentChannel.cend(),
-                    [&userInfo](const auto& item) { return userInfo.staId == item.staId; })))
+                (((txVector.GetChannelWidth() == 160) && sigBcompression) ||
+                 std::all_of(
+                     contentChannel.cbegin(),
+                     contentChannel.cend(),
+                     [&userInfo](const auto& item) { return userInfo.staId == item.staId; })))
             {
                 NS_ASSERT(txVector.GetChannelWidth() == 160);
                 ruType = HeRu::RU_2x996_TONE;
@@ -259,12 +295,13 @@ HePpdu::SetHeMuUserInfos(WifiTxVector& txVector,
                                           userInfo.mcs,
                                           userInfo.nss});
             }
-            if (ruType == HeRu::RU_2x996_TONE)
+            if ((ruType == HeRu::RU_2x996_TONE) && !sigBcompression)
             {
                 return;
             }
             numRusLeft--;
-            if (numRusLeft == 0)
+            numUsersLeft--;
+            if (numRusLeft == 0 && numUsersLeft == 0)
             {
                 ruAllocIndex += (2 * numRuAllocsInContentChannel);
             }
@@ -277,7 +314,7 @@ Time
 HePpdu::GetTxDuration() const
 {
     Time ppduDuration = Seconds(0);
-    const WifiTxVector& txVector = GetTxVector();
+    const auto& txVector = GetTxVector();
     const auto length = m_lSig.GetLength();
     const auto tSymbol = NanoSeconds(12800 + txVector.GetGuardInterval());
     const auto preambleDuration = WifiPhy::CalculatePhyPreambleAndHeaderDuration(txVector);
@@ -378,10 +415,10 @@ HePpdu::GetStaId() const
 }
 
 uint16_t
-HePpdu::GetTransmissionChannelWidth() const
+HePpdu::GetTxChannelWidth() const
 {
-    const WifiTxVector& txVector = GetTxVector();
-    if (txVector.IsUlMu() && GetStaId() != SU_STA_ID)
+    if (const auto& txVector = GetTxVector();
+        txVector.IsValid() && txVector.IsUlMu() && GetStaId() != SU_STA_ID)
     {
         TxPsdFlag flag = GetTxPsdFlag();
         uint16_t ruWidth = HeRu::GetBandwidth(txVector.GetRu(GetStaId()).GetRuType());
@@ -392,7 +429,7 @@ HePpdu::GetTransmissionChannelWidth() const
     }
     else
     {
-        return OfdmPpdu::GetTransmissionChannelWidth();
+        return OfdmPpdu::GetTxChannelWidth();
     }
 }
 
@@ -446,17 +483,37 @@ HePpdu::UpdateTxVectorForUlMu(const std::optional<WifiTxVector>& trigVector) con
 }
 
 std::pair<std::size_t, std::size_t>
-HePpdu::GetNumRusPerHeSigBContentChannel(uint16_t channelWidth, const RuAllocation& ruAllocation)
+HePpdu::GetNumRusPerHeSigBContentChannel(uint16_t channelWidth,
+                                         const RuAllocation& ruAllocation,
+                                         bool sigBCompression,
+                                         uint8_t numMuMimoUsers)
 {
-    // MU-MIMO is not handled for now, i.e. one station per RU
-    NS_ASSERT_MSG(!ruAllocation.empty(), "RU allocation is not set");
-    NS_ASSERT_MSG(ruAllocation.size() == channelWidth / 20,
-                  "RU allocation is not consistent with packet bandwidth");
-
     std::pair<std::size_t /* number of RUs in content channel 1 */,
               std::size_t /* number of RUs in content channel 2 */>
         chSize{0, 0};
 
+    if (sigBCompression)
+    {
+        // If the HE-SIG-B Compression field in the HE-SIG-A field of an HE MU PPDU is 1,
+        // for bandwidths larger than 20 MHz, the AP performs an equitable split of
+        // the User fields between two HE-SIG-B content channels
+        if (channelWidth == 20)
+        {
+            return {numMuMimoUsers, 0};
+        }
+        chSize.first = numMuMimoUsers / 2;
+        chSize.second = numMuMimoUsers / 2;
+        if (numMuMimoUsers != (chSize.first + chSize.second))
+        {
+            chSize.first++;
+        }
+        return chSize;
+    }
+
+    NS_ASSERT_MSG(!ruAllocation.empty(), "RU allocation is not set");
+    NS_ASSERT_MSG(ruAllocation.size() == channelWidth / 20,
+                  "RU allocation is not consistent with packet bandwidth");
+
     switch (channelWidth)
     {
     case 40:
@@ -505,19 +562,20 @@ HePpdu::GetHeSigBContentChannels(const WifiTxVector& txVector, uint8_t p20Index)
     }
 
     const auto& orderedMap = txVector.GetUserInfoMapOrderedByRus(p20Index);
-    for (const auto& [ru, staId] : orderedMap)
+    for (const auto& [ru, staIds] : orderedMap)
     {
-        auto ruType = ru.GetRuType();
-        auto ruIdx = ru.GetIndex();
-        const auto& userInfo = txVector.GetHeMuUserInfo(staId);
-        NS_ASSERT(ru == userInfo.ru);
-
-        if (ruType > HeRu::RU_242_TONE)
+        const auto ruType = ru.GetRuType();
+        if ((ruType > HeRu::RU_242_TONE) && !txVector.IsSigBCompression())
         {
             for (auto i = 0; i < ((ruType == HeRu::RU_2x996_TONE) ? 2 : 1); ++i)
             {
-                contentChannels[0].push_back({staId, userInfo.nss, userInfo.mcs});
-                contentChannels[1].push_back({staId, userInfo.nss, userInfo.mcs});
+                for (auto staId : staIds)
+                {
+                    const auto& userInfo = txVector.GetHeMuUserInfo(staId);
+                    NS_ASSERT(ru == userInfo.ru);
+                    contentChannels[0].push_back({staId, userInfo.nss, userInfo.mcs});
+                    contentChannels[1].push_back({staId, userInfo.nss, userInfo.mcs});
+                }
             }
             continue;
         }
@@ -525,55 +583,84 @@ HePpdu::GetHeSigBContentChannels(const WifiTxVector& txVector, uint8_t p20Index)
         std::size_t numRus = (ruType >= HeRu::RU_242_TONE)
                                  ? 1
                                  : HeRu::m_heRuSubcarrierGroups.at({20, ruType}).size();
-        if (((ruIdx - 1) / numRus) % 2 == 0)
+        const auto ruIdx = ru.GetIndex();
+        for (auto staId : staIds)
         {
-            contentChannels.at(0).push_back({staId, userInfo.nss, userInfo.mcs});
-        }
-        else
-        {
-            contentChannels.at(1).push_back({staId, userInfo.nss, userInfo.mcs});
+            const auto& userInfo = txVector.GetHeMuUserInfo(staId);
+            NS_ASSERT(ru == userInfo.ru);
+            std::size_t ccIndex{0};
+            if (channelWidth < 40)
+            {
+                // only one content channel
+                ccIndex = 0;
+            }
+            else if (txVector.IsSigBCompression())
+            {
+                // equal split
+                ccIndex = (contentChannels.at(0).size() <= contentChannels.at(1).size()) ? 0 : 1;
+            }
+            else // MU-MIMO
+            {
+                ccIndex = (((ruIdx - 1) / numRus) % 2 == 0) ? 0 : 1;
+            }
+            contentChannels.at(ccIndex).push_back({staId, userInfo.nss, userInfo.mcs});
         }
     }
 
-    // Add unassigned RUs
-    auto numNumRusPerHeSigBContentChannel =
-        GetNumRusPerHeSigBContentChannel(channelWidth, txVector.GetRuAllocation(p20Index));
-    std::size_t contentChannelIndex = 1;
-    for (auto& contentChannel : contentChannels)
+    const auto isSigBCompression = txVector.IsSigBCompression();
+    if (!isSigBCompression)
     {
-        const auto totalUsersInContentChannel = (contentChannelIndex == 1)
-                                                    ? numNumRusPerHeSigBContentChannel.first
-                                                    : numNumRusPerHeSigBContentChannel.second;
-        NS_ASSERT(contentChannel.size() <= totalUsersInContentChannel);
-        std::size_t unallocatedRus = totalUsersInContentChannel - contentChannel.size();
-        for (std::size_t i = 0; i < unallocatedRus; i++)
+        // Add unassigned RUs
+        auto numNumRusPerHeSigBContentChannel = GetNumRusPerHeSigBContentChannel(
+            channelWidth,
+            txVector.GetRuAllocation(p20Index),
+            isSigBCompression,
+            isSigBCompression ? txVector.GetHeMuUserInfoMap().size() : 0);
+        std::size_t contentChannelIndex = 1;
+        for (auto& contentChannel : contentChannels)
         {
-            contentChannel.push_back({NO_USER_STA_ID, 0, 0});
+            const auto totalUsersInContentChannel = (contentChannelIndex == 1)
+                                                        ? numNumRusPerHeSigBContentChannel.first
+                                                        : numNumRusPerHeSigBContentChannel.second;
+            NS_ASSERT(contentChannel.size() <= totalUsersInContentChannel);
+            std::size_t unallocatedRus = totalUsersInContentChannel - contentChannel.size();
+            for (std::size_t i = 0; i < unallocatedRus; i++)
+            {
+                contentChannel.push_back({NO_USER_STA_ID, 0, 0});
+            }
+            contentChannelIndex++;
         }
-        contentChannelIndex++;
     }
 
     return contentChannels;
 }
 
 uint32_t
-HePpdu::GetSigBFieldSize(uint16_t channelWidth, const RuAllocation& ruAllocation)
+HePpdu::GetSigBFieldSize(uint16_t channelWidth,
+                         const RuAllocation& ruAllocation,
+                         bool sigBCompression,
+                         std::size_t numMuMimoUsers)
 {
     // Compute the number of bits used by common field.
-    // Assume that compression bit in HE-SIG-A is not set (i.e. not
-    // full band MU-MIMO); the field is present.
-    auto commonFieldSize = 4 /* CRC */ + 6 /* tail */;
-    if (channelWidth <= 40)
+    uint32_t commonFieldSize = 0;
+    if (!sigBCompression)
     {
-        commonFieldSize += 8; // only one allocation subfield
-    }
-    else
-    {
-        commonFieldSize +=
-            8 * (channelWidth / 40) /* one allocation field per 40 MHz */ + 1 /* center RU */;
+        commonFieldSize = 4 /* CRC */ + 6 /* tail */;
+        if (channelWidth <= 40)
+        {
+            commonFieldSize += 8; // only one allocation subfield
+        }
+        else
+        {
+            commonFieldSize +=
+                8 * (channelWidth / 40) /* one allocation field per 40 MHz */ + 1 /* center RU */;
+        }
     }
 
-    auto numRusPerContentChannel = GetNumRusPerHeSigBContentChannel(channelWidth, ruAllocation);
+    auto numRusPerContentChannel = GetNumRusPerHeSigBContentChannel(channelWidth,
+                                                                    ruAllocation,
+                                                                    sigBCompression,
+                                                                    numMuMimoUsers);
     auto maxNumRusPerContentChannel =
         std::max(numRusPerContentChannel.first, numRusPerContentChannel.second);
     auto maxNumUserBlockFields = maxNumRusPerContentChannel /
@@ -698,4 +785,17 @@ HePpdu::GetNssFromNstsEncoding(uint8_t nsts)
     return nsts + 1;
 }
 
+uint8_t
+HePpdu::GetMuMimoUsersEncoding(uint8_t nUsers)
+{
+    NS_ASSERT(nUsers <= 8);
+    return (nUsers - 1);
+}
+
+uint8_t
+HePpdu::GetMuMimoUsersFromEncoding(uint8_t encoding)
+{
+    return (encoding + 1);
+}
+
 } // namespace ns3
