@@ -89,10 +89,12 @@ class HePpdu : public OfdmPpdu
     struct HeMuSigHeader
     {
         // HE-SIG-A fields
-        uint8_t m_bssColor{0};  ///< BSS color field
-        uint8_t m_bandwidth{0}; ///< Bandwidth field
-        uint8_t m_sigBMcs{0};   ///< HE-SIG-B MCS
-        uint8_t m_giLtfSize{0}; ///< GI+LTF Size field
+        uint8_t m_bssColor{0};        ///< BSS color field
+        uint8_t m_bandwidth{0};       ///< Bandwidth field
+        uint8_t m_sigBMcs{0};         ///< HE-SIG-B MCS
+        uint8_t m_muMimoUsers;        ///< MU-MIMO users
+        uint8_t m_sigBCompression{0}; ///< SIG-B compression
+        uint8_t m_giLtfSize{0};       ///< GI+LTF Size field
 
         // HE-SIG-B fields
         RuAllocation m_ruAllocation; //!< RU allocations that are going to be carried in SIG-B
@@ -152,7 +154,7 @@ class HePpdu : public OfdmPpdu
     Ptr<WifiPpdu> Copy() const override;
     WifiPpduType GetType() const override;
     uint16_t GetStaId() const override;
-    uint16_t GetTransmissionChannelWidth() const override;
+    uint16_t GetTxChannelWidth() const override;
 
     /**
      * Get the payload of the PPDU.
@@ -187,18 +189,21 @@ class HePpdu : public OfdmPpdu
     void UpdateTxVectorForUlMu(const std::optional<WifiTxVector>& trigVector) const;
 
     /**
-     * Get the number of RUs per HE-SIG-B content channel.
-     * This is applicable only for MU. MU-MIMO (i.e. multiple stations
-     * per RU) is not supported yet.
+     * Get the number of STAs per HE-SIG-B content channel.
+     * This is applicable only for MU.
      * See section 27.3.10.8.3 of IEEE 802.11ax draft 4.0.
      *
      * \param channelWidth the channel width occupied by the PPDU (in MHz)
      * \param ruAllocation 8 bit RU_ALLOCATION per 20 MHz
+     * \param sigBCompression flag whether SIG-B compression is used by the PPDU
+     * \param numMuMimoUsers the number of MU-MIMO users addressed by the PPDU
      * \return a pair containing the number of RUs in each HE-SIG-B content channel (resp. 1 and 2)
      */
     static std::pair<std::size_t, std::size_t> GetNumRusPerHeSigBContentChannel(
         uint16_t channelWidth,
-        const RuAllocation& ruAllocation);
+        const RuAllocation& ruAllocation,
+        bool sigBCompression,
+        uint8_t numMuMimoUsers);
 
     /**
      * Get the HE SIG-B content channels for a given PPDU
@@ -215,9 +220,14 @@ class HePpdu : public OfdmPpdu
      * Get variable length HE SIG-B field size
      * \param channelWidth the channel width occupied by the PPDU (in MHz)
      * \param ruAllocation 8 bit RU_ALLOCATION per 20 MHz
+     * \param sigBCompression flag whether SIG-B compression is used by the PPDU
+     * \param numMuMimoUsers the number of MU-MIMO users addressed by the PPDU
      * \return field size in bytes
      */
-    static uint32_t GetSigBFieldSize(uint16_t channelWidth, const RuAllocation& ruAllocation);
+    static uint32_t GetSigBFieldSize(uint16_t channelWidth,
+                                     const RuAllocation& ruAllocation,
+                                     bool sigBCompression,
+                                     std::size_t numMuMimoUsers);
 
   protected:
     /**
@@ -233,10 +243,14 @@ class HePpdu : public OfdmPpdu
      * \param txVector the TXVECTOR to set its HeMuUserInfoMap
      * \param ruAllocation the RU_ALLOCATION per 20 MHz
      * \param contentChannels the HE-SIG-B content channels
+     * \param sigBCompression flag whether SIG-B compression is used by the PPDU
+     * \param numMuMimoUsers the number of MU-MIMO users addressed by the PPDU
      */
     void SetHeMuUserInfos(WifiTxVector& txVector,
                           const RuAllocation& ruAllocation,
-                          const HeSigBContentChannels& contentChannels) const;
+                          const HeSigBContentChannels& contentChannels,
+                          bool sigBCompression,
+                          uint8_t numMuMimoUsers) const;
 
     /**
      * Convert channel width expressed in MHz to bandwidth field encoding in HE-SIG-A.
@@ -287,6 +301,22 @@ class HePpdu : public OfdmPpdu
      */
     static uint16_t GetGuardIntervalFromEncoding(uint8_t giAndNltfSize);
 
+    /**
+     * Convert number of MU-MIMO users to its encoding in HE-SIG-A.
+     *
+     * \param nUsers the number of MU-MIMO users
+     * \return the number of MU-MIMO users to its encoding in HE-SIG-A
+     */
+    static uint8_t GetMuMimoUsersEncoding(uint8_t nUsers);
+
+    /**
+     * Convert number of MU-MIMO users from its encoding in HE-SIG-A.
+     *
+     * \param encoding the number of MU-MIMO users encoded in HE-SIG-A
+     * \return the number of MU-MIMO users from its encoding in HE-SIG-A
+     */
+    static uint8_t GetMuMimoUsersFromEncoding(uint8_t encoding);
+
     mutable TxPsdFlag m_txPsdFlag; //!< the transmit power spectral density flag
 
   private:
