@@ -320,7 +320,8 @@ RrMultiUserScheduler::TrySendingBsrpTf()
     m_txParams.Clear();
     // set the TXVECTOR used to send the Trigger Frame
     m_txParams.m_txVector =
-        m_apMac->GetWifiRemoteStationManager(m_linkId)->GetRtsTxVector(m_triggerMacHdr.GetAddr1());
+        m_apMac->GetWifiRemoteStationManager(m_linkId)->GetRtsTxVector(m_triggerMacHdr.GetAddr1(),
+                                                                       m_allowedWidth);
 
     if (!GetHeFem(m_linkId)->TryAddMpdu(item, m_txParams, m_availableTime))
     {
@@ -442,7 +443,8 @@ RrMultiUserScheduler::TrySendingBasicTf()
     m_txParams.Clear();
     // set the TXVECTOR used to send the Trigger Frame
     m_txParams.m_txVector =
-        m_apMac->GetWifiRemoteStationManager(m_linkId)->GetRtsTxVector(m_triggerMacHdr.GetAddr1());
+        m_apMac->GetWifiRemoteStationManager(m_linkId)->GetRtsTxVector(m_triggerMacHdr.GetAddr1(),
+                                                                       m_allowedWidth);
 
     if (!GetHeFem(m_linkId)->TryAddMpdu(item, m_txParams, m_availableTime))
     {
@@ -708,8 +710,17 @@ RrMultiUserScheduler::TrySendingDlMuPpdu()
                     WifiTxVector suTxVector =
                         GetWifiRemoteStationManager(m_linkId)->GetDataTxVector(mpdu->GetHeader(),
                                                                                m_allowedWidth);
+
                     WifiTxVector txVectorCopy = m_txParams.m_txVector;
 
+                    // the first candidate STA determines the preamble type for the DL MU PPDU
+                    if (m_candidates.empty() &&
+                        suTxVector.GetPreambleType() == WIFI_PREAMBLE_EHT_MU)
+                    {
+                        m_txParams.m_txVector.SetPreambleType(WIFI_PREAMBLE_EHT_MU);
+                        m_txParams.m_txVector.SetEhtPpduType(0); // indicates DL OFDMA transmission
+                    }
+
                     m_txParams.m_txVector.SetHeMuUserInfo(staIt->aid,
                                                           {{currRuType, 1, true},
                                                            suTxVector.GetMode().GetMcsValue(),
@@ -737,17 +748,6 @@ RrMultiUserScheduler::TrySendingDlMuPpdu()
             }
         }
 
-        // the first candidate STA determines the preamble type for the DL MU PPDU
-        if (m_candidates.size() == 1)
-        {
-            if (m_apMac->GetEhtSupported() && m_apMac->GetEhtSupported(staIt->address))
-            {
-                m_txParams.m_txVector.SetPreambleType(WIFI_PREAMBLE_EHT_MU);
-                m_txParams.m_txVector.SetEhtPpduType(0); // indicates DL OFDMA transmission
-            }
-            // TODO otherwise, make sure the TX width does not exceed 160 MHz
-        }
-
         // move to the next station in the list
         staIt++;
     }
