@@ -26,8 +26,6 @@
 #include "ns3/wifi-psdu.h"
 
 class AmpduAggregationTest;
-class TwoLevelAggregationTest;
-class HeAggregationTest;
 
 namespace ns3
 {
@@ -46,10 +44,6 @@ class HtFrameExchangeManager : public QosFrameExchangeManager
   public:
     /// allow AmpduAggregationTest class access
     friend class ::AmpduAggregationTest;
-    /// allow TwoLevelAggregationTest class access
-    friend class ::TwoLevelAggregationTest;
-    /// allow HeAggregationTest class access
-    friend class ::HeAggregationTest;
 
     /**
      * \brief Get the type ID.
@@ -148,13 +142,6 @@ class HtFrameExchangeManager : public QosFrameExchangeManager
      * \param originator the MAC address of the originator.
      */
     void SendAddBaResponse(const MgtAddBaRequestHeader* reqHdr, Mac48Address originator);
-    /**
-     * Get the maximum supported buffer size for a Block Ack agreement. This value
-     * is typically included in ADDBA Response frames.
-     *
-     * \return the maximum supported buffer size for a Block Ack agreement
-     */
-    virtual uint16_t GetSupportedBaBufferSize() const;
 
     /**
      * Sends DELBA frame to cancel a block ack agreement with STA
