@@ -31,7 +31,6 @@
 #include "ns3/event-id.h"
 #include "ns3/nstime.h"
 #include "ns3/simple-ref-count.h"
-#include "ns3/wifi-spectrum-value-helper.h"
 
 #include <list>
 #include <map>
@@ -438,11 +437,9 @@ class PhyEntity : public SimpleRefCount<PhyEntity>
      */
     bool NoEndPreambleDetectionEvents() const;
     /**
-     * Cancel and eventually clear all end preamble detection events.
-     *
-     * \param clear whether to clear the end preamble detection events' list
+     * Cancel all end preamble detection events.
      */
-    void CancelRunningEndPreambleDetectionEvents(bool clear = false);
+    void CancelRunningEndPreambleDetectionEvents();
 
     /**
      * Return the STA ID that has been assigned to the station this PHY belongs to.
@@ -458,11 +455,10 @@ class PhyEntity : public SimpleRefCount<PhyEntity>
      * given PPDU.
      *
      * \param ppdu the PPDU
-     * \param txChannelWidth the channel width (MHz) used to transmit the PPDU
      * \return true if the PHY shall issue a PHY-RXSTART.indication primitive in response to a PPDU,
      * false otherwise
      */
-    virtual bool CanStartRx(Ptr<const WifiPpdu> ppdu, uint16_t txChannelWidth) const;
+    virtual bool CanStartRx(Ptr<const WifiPpdu> ppdu) const;
 
     /**
      * Check if PHY state should move to CCA busy state based on current
@@ -839,22 +835,30 @@ class PhyEntity : public SimpleRefCount<PhyEntity>
      * \param ppdu the PPDU
      * \param duration the PPDU duration
      * \param rxPower received power per band (W)
-     * \param isStartOfdmaRxing flag whether the event corresponds to the start of the OFDMA payload
-     * reception (only used for UL-OFDMA)
-     * \return the created event
+     * \param isStartHePortionRxing flag whether the event corresponds to the start of the OFDMA
+     * payload reception (only used for UL-OFDMA) \return the created event
      */
     Ptr<Event> CreateInterferenceEvent(Ptr<const WifiPpdu> ppdu,
                                        Time duration,
                                        RxPowerWattPerChannelBand& rxPower,
-                                       bool isStartOfdmaRxing = false);
+                                       bool isStartHePortionRxing = false);
     /**
-     * Update an event in WifiPhy's InterferenceHelper class.
-     * Wrapper used by child classes.
+     * Handle reception of a PPDU that carries the same content of another PPDU.
+     * This is typically called upon reception of preambles of HE MU PPDUs or reception
+     * of non-HT duplicate control frames that carries the exact same content sent from different
+     * STAs. If the delay between the PPDU and the first PPDU carrying the same content is small
+     * enough, PPDU can be decoded and its power is added constructively, and the TXVECTOR is
+     * updated accordingly. Otherwise, a new interference event is created and PPDU is dropped by
+     * the PHY.
      *
-     * \param event the event to be updated
-     * \param rxPower the received power (W) per band to be added to the current event
+     * \param event the event of the ongoing reception
+     * \param ppdu the newly received PPDU (UL MU or non-HT duplicate)
+     * \param rxPower the received power (W) per band of the newly received PPDU
      */
-    void UpdateInterferenceEvent(Ptr<Event> event, const RxPowerWattPerChannelBand& rxPower);
+    virtual void HandleRxPpduWithSameContent(Ptr<Event> event,
+                                             Ptr<const WifiPpdu> ppdu,
+                                             RxPowerWattPerChannelBand& rxPower);
+
     /**
      * Notify WifiPhy's InterferenceHelper of the end of the reception,
      * clear maps and end of MPDU event, and eventually reset WifiPhy.
