@@ -25,7 +25,7 @@
 #include "channel-access-manager.h"
 #include "ctrl-headers.h"
 #include "mac-tx-middle.h"
-#include "mgt-headers.h"
+#include "mgt-action-headers.h"
 #include "mpdu-aggregator.h"
 #include "msdu-aggregator.h"
 #include "wifi-mac-queue-scheduler.h"
@@ -72,7 +72,7 @@ QosTxop::GetTypeId()
             .AddAttribute("AddBaResponseTimeout",
                           "The timeout to wait for ADDBA response after the Ack to "
                           "ADDBA request is received.",
-                          TimeValue(MilliSeconds(1)),
+                          TimeValue(MilliSeconds(5)),
                           MakeTimeAccessor(&QosTxop::SetAddBaResponseTimeout,
                                            &QosTxop::GetAddBaResponseTimeout),
                           MakeTimeChecker())
@@ -121,12 +121,25 @@ QosTxop::QosTxop(AcIndex ac)
         }));
     m_baManager->SetUnblockDestinationCallback(
         Callback<void, Mac48Address, uint8_t>([this](Mac48Address recipient, uint8_t tid) {
+            // save the status of AC queues before unblocking the transmissions to the recipient
+            std::map<uint8_t, bool> hasFramesToTransmit;
+            for (const auto& [id, link] : GetLinks())
+            {
+                hasFramesToTransmit[id] = HasFramesToTransmit(id);
+            }
+
             m_mac->GetMacQueueScheduler()->UnblockQueues(WifiQueueBlockedReason::WAITING_ADDBA_RESP,
                                                          m_ac,
                                                          {WIFI_QOSDATA_QUEUE},
                                                          recipient,
                                                          m_mac->GetLocalAddress(recipient),
                                                          {tid});
+
+            // start access (if needed) on all the links
+            for (const auto& [id, link] : GetLinks())
+            {
+                StartAccessAfterEvent(id, hasFramesToTransmit.at(id), CHECK_MEDIUM_BUSY);
+            }
         }));
     m_queue->TraceConnectWithoutContext(
         "Expired",
@@ -520,9 +533,11 @@ QosTxop::GetNextMpdu(uint8_t linkId,
                       GetBaStartingSequence(peekedItem->GetOriginal()->GetHeader().GetAddr1(), tid),
                       GetBaBufferSize(peekedItem->GetOriginal()->GetHeader().GetAddr1(), tid)));
 
-        // try A-MSDU aggregation
+        // try A-MSDU aggregation if the MPDU does not contain an A-MSDU and does not already
+        // have a sequence number assigned (may be a retransmission)
         if (m_mac->GetHtSupported() && !recipient.IsBroadcast() &&
-            !peekedItem->HasSeqNoAssigned() && !peekedItem->IsFragment())
+            !peekedItem->GetHeader().IsQosAmsdu() && !peekedItem->HasSeqNoAssigned() &&
+            !peekedItem->IsFragment())
         {
             auto htFem = StaticCast<HtFrameExchangeManager>(qosFem);
             mpdu = htFem->GetMsduAggregator()->GetNextAmsdu(peekedItem, txParams, availableTime);
@@ -572,12 +587,12 @@ QosTxop::NotifyChannelAccessed(uint8_t linkId, Time txopDuration)
     Txop::NotifyChannelAccessed(linkId);
 }
 
-bool
-QosTxop::IsTxopStarted(uint8_t linkId) const
+std::optional<Time>
+QosTxop::GetTxopStartTime(uint8_t linkId) const
 {
     auto& link = GetLink(linkId);
-    NS_LOG_FUNCTION(this << !link.startTxop.IsZero());
-    return (!link.startTxop.IsZero());
+    NS_LOG_FUNCTION(this << link.startTxop.has_value());
+    return link.startTxop;
 }
 
 void
@@ -586,23 +601,45 @@ QosTxop::NotifyChannelReleased(uint8_t linkId)
     NS_LOG_FUNCTION(this << +linkId);
     auto& link = GetLink(linkId);
 
-    if (link.startTxop.IsStrictlyPositive())
+    if (link.startTxop)
     {
-        NS_LOG_DEBUG("Terminating TXOP. Duration = " << Simulator::Now() - link.startTxop);
-        m_txopTrace(link.startTxop, Simulator::Now() - link.startTxop, linkId);
+        NS_LOG_DEBUG("Terminating TXOP. Duration = " << Simulator::Now() - *link.startTxop);
+        m_txopTrace(*link.startTxop, Simulator::Now() - *link.startTxop, linkId);
     }
-    link.startTxop = Seconds(0);
-    Txop::NotifyChannelReleased(linkId);
+
+    // generate a new backoff value if either the TXOP duration is not null (i.e., some frames
+    // were transmitted) or no frame was transmitted but the queue actually contains frame to
+    // transmit and the user indicated that a backoff value should be generated in this situation.
+    // This behavior reflects the following specs text (Sec. 35.3.16.4 of 802.11be D4.0):
+    // An AP or non-AP STA affiliated with an MLD that has gained the right to initiate the
+    // transmission of a frame as described in 10.23.2.4 (Obtaining an EDCA TXOP) for an AC but
+    // does not transmit any frame corresponding to that AC for the reasons stated above may:
+    // - invoke a backoff for the EDCAF associated with that AC as allowed per h) of 10.23.2.2
+    //   (EDCA backoff procedure).
+    auto hasTransmitted = link.startTxop.has_value() && Simulator::Now() > *link.startTxop;
+
+    m_queue->WipeAllExpiredMpdus();
+    if ((hasTransmitted) ||
+        (!m_queue->IsEmpty() && m_mac->GetChannelAccessManager(linkId)->GetGenerateBackoffOnNoTx()))
+    {
+        GenerateBackoff(linkId);
+        if (!m_queue->IsEmpty())
+        {
+            Simulator::ScheduleNow(&QosTxop::RequestAccess, this, linkId);
+        }
+    }
+    link.startTxop.reset();
+    GetLink(linkId).access = NOT_REQUESTED;
 }
 
 Time
 QosTxop::GetRemainingTxop(uint8_t linkId) const
 {
     auto& link = GetLink(linkId);
-    NS_ASSERT(link.startTxop.IsStrictlyPositive());
+    NS_ASSERT(link.startTxop.has_value());
 
     Time remainingTxop = link.txopDuration;
-    remainingTxop -= (Simulator::Now() - link.startTxop);
+    remainingTxop -= (Simulator::Now() - *link.startTxop);
     if (remainingTxop.IsStrictlyNegative())
     {
         remainingTxop = Seconds(0);
@@ -616,6 +653,7 @@ QosTxop::GotAddBaResponse(const MgtAddBaResponseHeader& respHdr, Mac48Address re
 {
     NS_LOG_FUNCTION(this << respHdr << recipient);
     uint8_t tid = respHdr.GetTid();
+
     if (respHdr.GetStatusCode().IsSuccess())
     {
         NS_LOG_DEBUG("block ack agreement established with " << recipient << " tid " << +tid);
@@ -639,11 +677,6 @@ QosTxop::GotAddBaResponse(const MgtAddBaResponseHeader& respHdr, Mac48Address re
         NS_LOG_DEBUG("discard ADDBA response" << recipient);
         m_baManager->NotifyOriginatorAgreementRejected(recipient, tid);
     }
-
-    for (uint8_t linkId = 0; linkId < GetNLinks(); linkId++)
-    {
-        StartAccessIfNeeded(linkId);
-    }
 }
 
 void
@@ -658,14 +691,7 @@ void
 QosTxop::NotifyOriginatorAgreementNoReply(const Mac48Address& recipient, uint8_t tid)
 {
     NS_LOG_FUNCTION(this << recipient << tid);
-
     m_baManager->NotifyOriginatorAgreementNoReply(recipient, tid);
-    // the recipient has been "unblocked" and transmissions can resume using normal
-    // acknowledgment, hence start access (if needed) on all the links
-    for (uint8_t linkId = 0; linkId < GetNLinks(); linkId++)
-    {
-        StartAccessIfNeeded(linkId);
-    }
 }
 
 void
