@@ -123,7 +123,7 @@ WifiRemoteStation*
 AarfWifiManager::DoCreateStation() const
 {
     NS_LOG_FUNCTION(this);
-    AarfWifiRemoteStation* station = new AarfWifiRemoteStation();
+    auto station = new AarfWifiRemoteStation();
 
     station->m_successThreshold = m_minSuccessThreshold;
     station->m_timerTimeout = m_minTimerThreshold;
@@ -157,7 +157,7 @@ void
 AarfWifiManager::DoReportDataFailed(WifiRemoteStation* st)
 {
     NS_LOG_FUNCTION(this << st);
-    AarfWifiRemoteStation* station = static_cast<AarfWifiRemoteStation*>(st);
+    auto station = static_cast<AarfWifiRemoteStation*>(st);
     station->m_timer++;
     station->m_failed++;
     station->m_success = 0;
@@ -224,7 +224,7 @@ AarfWifiManager::DoReportDataOk(WifiRemoteStation* st,
                                 uint8_t dataNss)
 {
     NS_LOG_FUNCTION(this << st << ackSnr << ackMode << dataSnr << dataChannelWidth << +dataNss);
-    AarfWifiRemoteStation* station = static_cast<AarfWifiRemoteStation*>(st);
+    auto station = static_cast<AarfWifiRemoteStation*>(st);
     station->m_timer++;
     station->m_success++;
     station->m_failed = 0;
@@ -259,7 +259,7 @@ WifiTxVector
 AarfWifiManager::DoGetDataTxVector(WifiRemoteStation* st, uint16_t allowedWidth)
 {
     NS_LOG_FUNCTION(this << st << allowedWidth);
-    AarfWifiRemoteStation* station = static_cast<AarfWifiRemoteStation*>(st);
+    auto station = static_cast<AarfWifiRemoteStation*>(st);
     uint16_t channelWidth = GetChannelWidth(station);
     if (channelWidth > 20 && channelWidth != 22)
     {
@@ -290,7 +290,7 @@ AarfWifiManager::DoGetRtsTxVector(WifiRemoteStation* st)
     NS_LOG_FUNCTION(this << st);
     /// \todo we could/should implement the AARF algorithm for
     /// RTS only by picking a single rate within the BasicRateSet.
-    AarfWifiRemoteStation* station = static_cast<AarfWifiRemoteStation*>(st);
+    auto station = static_cast<AarfWifiRemoteStation*>(st);
     uint16_t channelWidth = GetChannelWidth(station);
     if (channelWidth > 20 && channelWidth != 22)
     {
