@@ -178,7 +178,7 @@ WifiRemoteStation*
 MinstrelWifiManager::DoCreateStation() const
 {
     NS_LOG_FUNCTION(this);
-    MinstrelWifiRemoteStation* station = new MinstrelWifiRemoteStation();
+    auto station = new MinstrelWifiRemoteStation();
 
     station->m_nextStatsUpdate = Simulator::Now() + m_updateStats;
     station->m_col = 0;
@@ -644,7 +644,7 @@ MinstrelWifiManager::UpdateStats(MinstrelWifiRemoteStation* station)
 
             // calculating throughput
             station->m_minstrelTable[i].throughput =
-                tempProb * static_cast<uint32_t>((1000000 / txTime.GetMicroSeconds()));
+                tempProb * static_cast<uint32_t>(1000000 / txTime.GetMicroSeconds());
         }
         else
         {
@@ -779,7 +779,7 @@ void
 MinstrelWifiManager::DoReportRtsFailed(WifiRemoteStation* st)
 {
     NS_LOG_FUNCTION(this << st);
-    MinstrelWifiRemoteStation* station = static_cast<MinstrelWifiRemoteStation*>(st);
+    auto station = static_cast<MinstrelWifiRemoteStation*>(st);
     NS_LOG_DEBUG("DoReportRtsFailed m_txrate=" << station->m_txrate);
     station->m_shortRetry++;
 }
@@ -797,7 +797,7 @@ void
 MinstrelWifiManager::DoReportFinalRtsFailed(WifiRemoteStation* st)
 {
     NS_LOG_FUNCTION(this << st);
-    MinstrelWifiRemoteStation* station = static_cast<MinstrelWifiRemoteStation*>(st);
+    auto station = static_cast<MinstrelWifiRemoteStation*>(st);
     UpdateRetry(station);
 }
 
@@ -805,7 +805,7 @@ void
 MinstrelWifiManager::DoReportDataFailed(WifiRemoteStation* st)
 {
     NS_LOG_FUNCTION(this << st);
-    MinstrelWifiRemoteStation* station = static_cast<MinstrelWifiRemoteStation*>(st);
+    auto station = static_cast<MinstrelWifiRemoteStation*>(st);
     NS_LOG_DEBUG("DoReportDataFailed " << station << "\t rate " << station->m_txrate
                                        << "\tlongRetry \t" << station->m_longRetry);
     CheckInit(station);
@@ -826,7 +826,7 @@ MinstrelWifiManager::DoReportDataOk(WifiRemoteStation* st,
                                     uint8_t dataNss)
 {
     NS_LOG_FUNCTION(this << st << ackSnr << ackMode << dataSnr << dataChannelWidth << +dataNss);
-    MinstrelWifiRemoteStation* station = static_cast<MinstrelWifiRemoteStation*>(st);
+    auto station = static_cast<MinstrelWifiRemoteStation*>(st);
 
     CheckInit(station);
     if (!station->m_initialized)
@@ -865,7 +865,7 @@ void
 MinstrelWifiManager::DoReportFinalDataFailed(WifiRemoteStation* st)
 {
     NS_LOG_FUNCTION(this << st);
-    MinstrelWifiRemoteStation* station = static_cast<MinstrelWifiRemoteStation*>(st);
+    auto station = static_cast<MinstrelWifiRemoteStation*>(st);
 
     CheckInit(station);
     if (!station->m_initialized)
@@ -939,7 +939,7 @@ WifiTxVector
 MinstrelWifiManager::DoGetDataTxVector(WifiRemoteStation* st, uint16_t allowedWidth)
 {
     NS_LOG_FUNCTION(this << st << allowedWidth);
-    MinstrelWifiRemoteStation* station = static_cast<MinstrelWifiRemoteStation*>(st);
+    auto station = static_cast<MinstrelWifiRemoteStation*>(st);
     return GetDataTxVector(station);
 }
 
@@ -947,7 +947,7 @@ WifiTxVector
 MinstrelWifiManager::DoGetRtsTxVector(WifiRemoteStation* st)
 {
     NS_LOG_FUNCTION(this << st);
-    MinstrelWifiRemoteStation* station = static_cast<MinstrelWifiRemoteStation*>(st);
+    auto station = static_cast<MinstrelWifiRemoteStation*>(st);
     return GetRtsTxVector(station);
 }
 
@@ -957,7 +957,7 @@ MinstrelWifiManager::DoNeedRetransmission(WifiRemoteStation* st,
                                           bool normally)
 {
     NS_LOG_FUNCTION(this << st << packet << normally);
-    MinstrelWifiRemoteStation* station = static_cast<MinstrelWifiRemoteStation*>(st);
+    auto station = static_cast<MinstrelWifiRemoteStation*>(st);
 
     CheckInit(station);
     if (!station->m_initialized)
