@@ -42,6 +42,9 @@ struct SpectrumSignalParameters;
 class WifiSpectrumPhyInterface;
 struct WifiSpectrumSignalParameters;
 
+/// Map a spectrum band associated with an RU to the RU specification
+using HeRuBands = std::map<WifiSpectrumBandInfo, HeRu::RuSpec>;
+
 /**
  * \brief 802.11 PHY layer model
  * \ingroup wifi
@@ -131,9 +134,17 @@ class SpectrumWifiPhy : public WifiPhy
                                           double rxPower,
                                           Time duration);
 
-    // The following method calls the base WifiPhy class method
-    // but also generates a new SpectrumModel if called during runtime
-    void DoChannelSwitch() override;
+    /**
+     * Configure a non-active spectrum PHY interface to operate on a given frequency with a given
+     * width. The function searches for the non-active PHY interface that operates on the frequency
+     * range corresponding to the spectrum portion specified by the caller. It takes care to
+     * configure the RX spectrum model of the PHY interface and to update the bands tracked in
+     * interference helper.
+     *
+     * \param frequency the center frequency in MHz the PHY interface should use
+     * \param width the channel width in MHz the PHY interface should use
+     */
+    void ConfigureInterface(uint16_t frequency, uint16_t width);
 
     /**
      * This function is sending the signal to the Spectrum channel
@@ -158,10 +169,26 @@ class SpectrumWifiPhy : public WifiPhy
      */
     Ptr<WifiSpectrumPhyInterface> GetCurrentInterface() const;
 
+    /**
+     * Get the map of interfaces attached to this spectrum PHY
+     *
+     * \return the map of interfaces attached to this spectrum PHY
+     */
+    const std::map<FrequencyRange, Ptr<WifiSpectrumPhyInterface>>& GetSpectrumPhyInterfaces() const;
+
+    /**
+     * \param callback the callback to invoke when operating channel has switched.
+     */
+    void SetChannelSwitchedCallback(Callback<void> callback);
+
   protected:
     void DoDispose() override;
     void DoInitialize() override;
 
+    // The following method calls the base WifiPhy class method
+    // but also generates a new SpectrumModel if called during runtime
+    void DoChannelSwitch() override;
+
     std::map<FrequencyRange, Ptr<WifiSpectrumPhyInterface>>
         m_spectrumPhyInterfaces; //!< Spectrum PHY interfaces
 
@@ -171,26 +198,72 @@ class SpectrumWifiPhy : public WifiPhy
 
   private:
     /**
-     * Perform run-time spectrum model change if the one used by the current Spectrum PHY interface
-     * has changed
+     * Perform run-time spectrum model change
+     * \param spectrumPhyInterface the spectrum PHY interface for which the spectrum model should be
+     * changed \param centerFrequency the center frequency in MHz the PHY interface should use
+     * \param channelWidth the channel width in MHz the PHY interface should use
      */
-    void ResetSpectrumModelIfNeeded();
+    void ResetSpectrumModel(Ptr<WifiSpectrumPhyInterface> spectrumPhyInterface,
+                            uint16_t centerFrequency,
+                            uint16_t channelWidth);
 
     /**
      * This function is called to update the bands handled by the InterferenceHelper.
+     * \param spectrumPhyInterface the spectrum PHY interface for which the bands should be updated
      */
-    void UpdateInterferenceHelperBands();
+    void UpdateInterferenceHelperBands(Ptr<WifiSpectrumPhyInterface> spectrumPhyInterface);
+
+    /**
+     * This function computes the RU bands that belong to a given spectrum PHY interface.
+     *
+     * \param spectrumPhyInterface the spectrum PHY interface to consider to compute the RU bands
+     * \param guardBandwidth width of the guard band in MHz
+     * \returns the computed RU bands for the spectrum PHY interface
+     */
+    HeRuBands GetHeRuBands(Ptr<WifiSpectrumPhyInterface> spectrumPhyInterface,
+                           uint16_t guardBandwidth);
+
+    /**
+     * This function computes the bands that belong to a given spectrum PHY interface.
+     *
+     * \param spectrumPhyInterface the spectrum PHY interface to consider to compute the bands
+     * \returns the computed bands for the spectrum PHY interface
+     */
+    WifiSpectrumBands ComputeBands(Ptr<WifiSpectrumPhyInterface> spectrumPhyInterface);
+
+    /**
+     * Get the info of a given band that belongs to a given spectrum PHY interface
+     *
+     * \param spectrumPhyInterface the spectrum PHY interface
+     * \param bandWidth the width of the band to be returned (MHz)
+     * \param bandIndex the index of the band to be returned
+     *
+     * \return the info that defines the band
+     */
+    WifiSpectrumBandInfo GetBandForInterface(Ptr<WifiSpectrumPhyInterface> spectrumPhyInterface,
+                                             uint16_t bandWidth,
+                                             uint8_t bandIndex = 0);
+
+    /**
+     * This is a helper function to convert start and stop indices to start and stop frequencies.
+     *
+     * \param spectrumPhyInterface the spectrum PHY interface to consider for the calculations
+     * \param indices the start/stop indices to convert
+     * \return the converted frequencies
+     */
+    WifiSpectrumBandFrequencies ConvertIndicesToFrequenciesForInterface(
+        Ptr<WifiSpectrumPhyInterface> spectrumPhyInterface,
+        const WifiSpectrumBandIndices& indices) const;
 
     /**
      * Determine whether the PHY shall issue a PHY-RXSTART.indication primitive in response to a
      * given PPDU.
      *
      * \param ppdu the PPDU
-     * \param txChannelWidth the channel width (MHz) used to transmit the PPDU
      * \return true if the PHY shall issue a PHY-RXSTART.indication primitive in response to a PPDU,
      * false otherwise
      */
-    bool CanStartRx(Ptr<const WifiPpdu> ppdu, uint16_t txChannelWidth) const;
+    bool CanStartRx(Ptr<const WifiPpdu> ppdu) const;
 
     /**
      * Get the spectrum PHY interface that covers a band portion of the RF channel
@@ -202,6 +275,11 @@ class SpectrumWifiPhy : public WifiPhy
     Ptr<WifiSpectrumPhyInterface> GetInterfaceCoveringChannelBand(uint16_t frequency,
                                                                   uint16_t width) const;
 
+    /**
+     * Notify the spectrum channel has switched
+     */
+    void NotifyChannelSwitched();
+
     Ptr<AntennaModel> m_antenna; //!< antenna model
 
     bool m_disableWifiReception;           //!< forces this PHY to fail to sync on any signal
@@ -216,6 +294,8 @@ class SpectrumWifiPhy : public WifiPhy
                                               //!< of the transmit spectrum mask
     double m_txMaskOuterBandMaximumRejection; //!< The maximum rejection (in dBr) for the outer band
                                               //!< of the transmit spectrum mask
+
+    Callback<void> m_channelSwitchedCallback; //!< Callback when channel switched
 };
 
 } // namespace ns3
