@@ -23,6 +23,7 @@
 
 #include "channel-access-manager.h"
 #include "frame-exchange-manager.h"
+#include "mgt-action-headers.h"
 #include "mgt-headers.h"
 #include "qos-txop.h"
 #include "snr-tag.h"
@@ -31,6 +32,7 @@
 #include "wifi-net-device.h"
 #include "wifi-phy.h"
 
+#include "ns3/attribute-container.h"
 #include "ns3/eht-configuration.h"
 #include "ns3/emlsr-manager.h"
 #include "ns3/he-configuration.h"
@@ -134,7 +136,9 @@ StaWifiMac::GetTypeId()
                             "A link setup in the context of ML setup with an AP MLD was torn down. "
                             "Provides ID of the setup link and AP MAC address",
                             MakeTraceSourceAccessor(&StaWifiMac::m_setupCanceled),
-                            "ns3::StaWifiMac::LinkSetupCallback")
+                            "ns3::StaWifiMac::LinkSetupCallback",
+                            TypeId::OBSOLETE,
+                            "Disassociation only occurs at MLD level; use DeAssoc trace.")
             .AddTraceSource("BeaconArrival",
                             "Time of beacons arrival from associated AP",
                             MakeTraceSourceAccessor(&StaWifiMac::m_beaconArrival),
@@ -162,6 +166,20 @@ void
 StaWifiMac::DoInitialize()
 {
     NS_LOG_FUNCTION(this);
+    // an EMLSR client must perform ML setup by using its main PHY
+    if (m_assocManager && m_emlsrManager)
+    {
+        auto mainPhyId = m_emlsrManager->GetMainPhyId();
+        auto linkId = GetLinkForPhy(mainPhyId);
+        NS_ASSERT(linkId);
+        m_assocManager->SetAttribute(
+            "AllowedLinks",
+            AttributeContainerValue<UintegerValue>(std::list<uint8_t>{*linkId}));
+    }
+    if (m_emlsrManager)
+    {
+        m_emlsrManager->Initialize();
+    }
     StartScanning();
     NS_ABORT_IF(!TraceConnectWithoutContext("AckedMpdu", MakeCallback(&StaWifiMac::TxOk, this)));
     WifiMac::DoInitialize();
@@ -206,6 +224,12 @@ StaWifiMac::GetLink(uint8_t linkId) const
     return static_cast<StaLinkEntity&>(WifiMac::GetLink(linkId));
 }
 
+StaWifiMac::StaLinkEntity&
+StaWifiMac::GetStaLink(const std::unique_ptr<WifiMac::LinkEntity>& link) const
+{
+    return static_cast<StaLinkEntity&>(*link);
+}
+
 int64_t
 StaWifiMac::AssignStreams(int64_t stream)
 {
@@ -282,6 +306,39 @@ StaWifiMac::GetCurrentChannel(uint8_t linkId) const
     return {ch, phy->GetPhyBand()};
 }
 
+void
+StaWifiMac::NotifyEmlsrModeChanged(const std::set<uint8_t>& linkIds)
+{
+    NS_LOG_FUNCTION(this << linkIds.size());
+
+    for (const auto& [linkId, lnk] : GetLinks())
+    {
+        auto& link = GetStaLink(lnk);
+
+        if (linkIds.count(linkId) > 0)
+        {
+            // EMLSR mode enabled
+            link.emlsrEnabled = true;
+            link.pmMode = WIFI_PM_ACTIVE;
+        }
+        else
+        {
+            // EMLSR mode disabled
+            if (link.emlsrEnabled)
+            {
+                link.pmMode = WIFI_PM_POWERSAVE;
+            }
+            link.emlsrEnabled = false;
+        }
+    }
+}
+
+bool
+StaWifiMac::IsEmlsrLink(uint8_t linkId) const
+{
+    return GetLink(linkId).emlsrEnabled;
+}
+
 void
 StaWifiMac::SendProbeRequest(uint8_t linkId)
 {
@@ -409,16 +466,37 @@ StaWifiMac::GetMultiLinkElement(bool isReassoc, uint8_t linkId) const
         // When the Transition Timeout subfield is included in a frame sent by a non-AP STA
         // affiliated with a non-AP MLD, the Transition Timeout subfield is reserved
         // (Section 9.4.2.312.2.3 of 802.11be D2.3)
+        // The Medium Synchronization Delay Information subfield in the Common Info subfield is
+        // not present if the Basic Multi-Link element is sent by a non-AP STA. (Section
+        // 9.4.2.312.2.3 of 802.11be D3.1)
     }
 
+    // The MLD Capabilities And Operations subfield is present in the Common Info field of the
+    // Basic Multi-Link element carried in Beacon, Probe Response, (Re)Association Request, and
+    // (Re)Association Response frames. (Sec. 9.4.2.312.2.3 of 802.11be D3.1)
+    auto& mldCapabilities = multiLinkElement.GetCommonInfoBasic().m_mldCapabilities;
+    mldCapabilities.emplace();
+    mldCapabilities->maxNSimultaneousLinks = GetNLinks() - 1; // assuming STR for now
+    mldCapabilities->srsSupport = 0;
+
+    auto ehtConfiguration = GetEhtConfiguration();
+    NS_ASSERT(ehtConfiguration);
+    EnumValue<WifiTidToLinkMappingNegSupport> negSupport;
+    ehtConfiguration->GetAttributeFailSafe("TidToLinkMappingNegSupport", negSupport);
+
+    mldCapabilities->tidToLinkMappingSupport = negSupport.Get();
+    mldCapabilities->freqSepForStrApMld = 0; // not supported yet
+    mldCapabilities->aarSupport = 0;         // not supported yet
+
     // For each requested link in addition to the link on which the (Re)Association Request
     // frame is transmitted, the Link Info field of the Basic Multi-Link element carried
     // in the (Re)Association Request frame shall contain the corresponding Per-STA Profile
     // subelement(s).
-    for (uint8_t index = 0; index < GetNLinks(); index++)
+    for (const auto& [index, link] : GetLinks())
     {
-        auto& link = GetLink(index);
-        if (index != linkId && link.apLinkId.has_value())
+        const auto& staLink = GetStaLink(link);
+
+        if (index != linkId && staLink.bssid.has_value())
         {
             multiLinkElement.AddPerStaProfileSubelement();
             auto& perStaProfile = multiLinkElement.GetPerStaProfile(
@@ -427,7 +505,7 @@ StaWifiMac::GetMultiLinkElement(bool isReassoc, uint8_t linkId) const
             // for the corresponding non-AP STA that requests a link for multi-link (re)setup
             // with the AP MLD is set to the link ID of the AP affiliated with the AP MLD that
             // is operating on that link. The link ID is obtained during multi-link discovery
-            perStaProfile.SetLinkId(link.apLinkId.value());
+            perStaProfile.SetLinkId(index);
             // For each Per-STA Profile subelement included in the Link Info field, the
             // Complete Profile subfield of the STA Control field shall be set to 1
             perStaProfile.SetCompleteProfile();
@@ -435,7 +513,7 @@ StaWifiMac::GetMultiLinkElement(bool isReassoc, uint8_t linkId) const
             // subfield in the STA Info field and is set to 1 if the STA MAC Address subfield
             // is present in the STA Info field; otherwise set to 0. An STA sets this subfield
             // to 1 when the element carries complete profile.
-            perStaProfile.SetStaMacAddress(link.feManager->GetAddress());
+            perStaProfile.SetStaMacAddress(staLink.feManager->GetAddress());
             perStaProfile.SetAssocRequest(GetAssociationRequest(isReassoc, index));
         }
     }
@@ -443,20 +521,92 @@ StaWifiMac::GetMultiLinkElement(bool isReassoc, uint8_t linkId) const
     return multiLinkElement;
 }
 
+std::vector<TidToLinkMapping>
+StaWifiMac::GetTidToLinkMappingElements(uint8_t apNegSupport)
+{
+    NS_LOG_FUNCTION(this << apNegSupport);
+
+    auto ehtConfig = GetEhtConfiguration();
+    NS_ASSERT(ehtConfig);
+
+    EnumValue<WifiTidToLinkMappingNegSupport> negSupport;
+    ehtConfig->GetAttributeFailSafe("TidToLinkMappingNegSupport", negSupport);
+
+    NS_ABORT_MSG_IF(negSupport.Get() == 0,
+                    "Cannot request TID-to-Link Mapping if negotiation is not supported");
+
+    // store the mappings, so that we can enforce them when the AP MLD accepts them
+    m_dlTidLinkMappingInAssocReq = ehtConfig->GetTidLinkMapping(WifiDirection::DOWNLINK);
+    m_ulTidLinkMappingInAssocReq = ehtConfig->GetTidLinkMapping(WifiDirection::UPLINK);
+
+    bool mappingValidForNegType1 = TidToLinkMappingValidForNegType1(m_dlTidLinkMappingInAssocReq,
+                                                                    m_ulTidLinkMappingInAssocReq);
+    NS_ABORT_MSG_IF(
+        negSupport.Get() == 1 && !mappingValidForNegType1,
+        "Mapping TIDs to distinct link sets is incompatible with negotiation support of 1");
+
+    if (apNegSupport == 1 && !mappingValidForNegType1)
+    {
+        // If the TID-to-link Mapping Negotiation Support subfield value received from a peer
+        // MLD is equal to 1, the MLD that initiates a TID-to-link mapping negotiation with the
+        // peer MLD shall send only the TID-to-link Mapping element where all TIDs are mapped to
+        // the same link set (Sec. 35.3.7.1.3 of 802.11be D3.1). We use default mapping to meet
+        // this requirement.
+        NS_LOG_DEBUG("Using default mapping because AP MLD advertised negotiation support of 1");
+        m_dlTidLinkMappingInAssocReq.clear();
+        m_ulTidLinkMappingInAssocReq.clear();
+    }
+
+    std::vector<TidToLinkMapping> ret(1);
+
+    ret.back().m_control.direction = WifiDirection::DOWNLINK;
+
+    // lambda to fill the last TID-to-Link Mapping IE in the vector to return
+    auto fillIe = [&ret](const auto& mapping) {
+        ret.back().m_control.defaultMapping = mapping.empty();
+
+        for (const auto& [tid, linkSet] : mapping)
+        {
+            // At any point in time, a TID shall always be mapped to at least one setup link both
+            // in DL and UL, which means that a TID-to-link mapping change is only valid and
+            // successful if it will not result in having any TID for which the link set for DL
+            // or UL is made of zero setup links (Sec. 35.3.7.1.1 of 802.11be D3.1)
+            NS_ABORT_MSG_IF(linkSet.empty(), "Cannot map a TID to an empty link set");
+            ret.back().SetLinkMappingOfTid(tid, linkSet);
+        }
+    };
+
+    fillIe(m_dlTidLinkMappingInAssocReq);
+
+    if (m_ulTidLinkMappingInAssocReq == m_dlTidLinkMappingInAssocReq)
+    {
+        ret.back().m_control.direction = WifiDirection::BOTH_DIRECTIONS;
+        return ret;
+    }
+
+    ret.emplace_back();
+    ret.back().m_control.direction = WifiDirection::UPLINK;
+    fillIe(m_ulTidLinkMappingInAssocReq);
+
+    return ret;
+}
+
 void
 StaWifiMac::SendAssociationRequest(bool isReassoc)
 {
     // find the link where the (Re)Association Request has to be sent
-    uint8_t linkId = 0;
-    while (linkId < GetNLinks())
+    auto it = GetLinks().cbegin();
+    while (it != GetLinks().cend())
     {
-        if (GetLink(linkId).sendAssocReq)
+        if (GetStaLink(it->second).sendAssocReq)
         {
             break;
         }
-        linkId++;
+        it++;
     }
-    NS_ABORT_MSG_IF(linkId == GetNLinks(), "No link selected to send the (Re)Association Request");
+    NS_ABORT_MSG_IF(it == GetLinks().cend(),
+                    "No link selected to send the (Re)Association Request");
+    uint8_t linkId = it->first;
     auto& link = GetLink(linkId);
     NS_ABORT_MSG_IF(!link.bssid.has_value(),
                     "No BSSID set for the link on which the (Re)Association Request is to be sent");
@@ -474,7 +624,9 @@ StaWifiMac::SendAssociationRequest(bool isReassoc)
     auto frame = GetAssociationRequest(isReassoc, linkId);
 
     // include a Multi-Link Element if this device has multiple links (independently
-    // of how many links will be setup) and the AP is a multi-link device
+    // of how many links will be setup) and the AP is a multi-link device;
+    // if the AP MLD  has indicated a support of TID-to-link mapping negotiation, also
+    // include the TID-to-link Mapping element(s)
     if (GetNLinks() > 1 &&
         GetWifiRemoteStationManager(linkId)->GetMldAddress(*link.bssid).has_value())
     {
@@ -482,6 +634,17 @@ StaWifiMac::SendAssociationRequest(bool isReassoc)
             frame.template Get<MultiLinkElement>() = GetMultiLinkElement(isReassoc, linkId);
         };
         std::visit(addMle, frame);
+
+        uint8_t negSupport;
+        if (const auto& mldCapabilities =
+                GetWifiRemoteStationManager(linkId)->GetStationMldCapabilities(*link.bssid);
+            mldCapabilities && (negSupport = mldCapabilities->get().tidToLinkMappingSupport) > 0)
+        {
+            auto addTlm = [&](auto&& frame) {
+                frame.template Get<TidToLinkMapping>() = GetTidToLinkMappingElements(negSupport);
+            };
+            std::visit(addTlm, frame);
+        }
     }
 
     if (!isReassoc)
@@ -567,12 +730,11 @@ StaWifiMac::StartScanning()
 
     WifiScanParams scanParams;
     scanParams.ssid = GetSsid();
-    for (uint8_t linkId = 0; linkId < GetNLinks(); linkId++)
+    for (const auto& [id, link] : GetLinks())
     {
         WifiScanParams::ChannelList channel{
-            (GetWifiPhy(linkId)->HasFixedPhyBand())
-                ? WifiScanParams::Channel{0, GetWifiPhy(linkId)->GetPhyBand()}
-                : WifiScanParams::Channel{0, WIFI_PHY_BAND_UNSPECIFIED}};
+            (link->phy->HasFixedPhyBand()) ? WifiScanParams::Channel{0, link->phy->GetPhyBand()}
+                                           : WifiScanParams::Channel{0, WIFI_PHY_BAND_UNSPECIFIED}};
 
         scanParams.channelList.push_back(channel);
     }
@@ -606,34 +768,37 @@ StaWifiMac::ScanningTimeout(const std::optional<ApInfo>& bestAp)
     NS_LOG_DEBUG("Attempting to associate with AP: " << *bestAp);
     UpdateApInfo(bestAp->m_frame, bestAp->m_apAddr, bestAp->m_bssid, bestAp->m_linkId);
     // reset info on links to setup
-    for (uint8_t linkId = 0; linkId < GetNLinks(); linkId++)
+    for (auto& [id, link] : GetLinks())
     {
-        auto& link = GetLink(linkId);
-        link.sendAssocReq = false;
-        link.apLinkId = std::nullopt;
-        link.bssid = std::nullopt;
+        auto& staLink = GetStaLink(link);
+        staLink.sendAssocReq = false;
+        staLink.bssid = std::nullopt;
     }
     // send Association Request on the link where the Beacon/Probe Response was received
     GetLink(bestAp->m_linkId).sendAssocReq = true;
     GetLink(bestAp->m_linkId).bssid = bestAp->m_bssid;
+    std::shared_ptr<CommonInfoBasicMle> mleCommonInfo;
     // update info on links to setup (11be MLDs only)
-    for (const auto& [localLinkId, apLinkId] : bestAp->m_setupLinks)
+    const auto& mle =
+        std::visit([](auto&& frame) { return frame.template Get<MultiLinkElement>(); },
+                   bestAp->m_frame);
+    std::map<uint8_t, uint8_t> swapInfo;
+    for (const auto& [localLinkId, apLinkId, bssid] : bestAp->m_setupLinks)
     {
+        NS_ASSERT_MSG(mle, "We get here only for ML setup");
         NS_LOG_DEBUG("Setting up link (local ID=" << +localLinkId << ", AP ID=" << +apLinkId
                                                   << ")");
-        GetLink(localLinkId).apLinkId = apLinkId;
-        if (localLinkId == bestAp->m_linkId)
+        GetLink(localLinkId).bssid = bssid;
+        if (!mleCommonInfo)
         {
-            continue;
+            mleCommonInfo = std::make_shared<CommonInfoBasicMle>(mle->GetCommonInfoBasic());
         }
-        auto mldAddress =
-            GetWifiRemoteStationManager(bestAp->m_linkId)->GetMldAddress(bestAp->m_bssid);
-        NS_ABORT_MSG_IF(!mldAddress.has_value(), "AP MLD address not set");
-        auto bssid = GetWifiRemoteStationManager(localLinkId)->GetAffiliatedStaAddress(*mldAddress);
-        NS_ABORT_MSG_IF(!mldAddress.has_value(),
-                        "AP link address not set for local link " << +localLinkId);
-        GetLink(localLinkId).bssid = *bssid;
+        GetWifiRemoteStationManager(localLinkId)->AddStationMleCommonInfo(bssid, mleCommonInfo);
+        swapInfo.emplace(localLinkId, apLinkId);
     }
+
+    SwapLinks(swapInfo);
+
     // lambda to get beacon interval from Beacon or Probe Response
     auto getBeaconInterval = [](auto&& frame) {
         using T = std::decay_t<decltype(frame)>;
@@ -650,14 +815,9 @@ StaWifiMac::ScanningTimeout(const std::optional<ApInfo>& bestAp)
     };
     Time beaconInterval = std::visit(getBeaconInterval, bestAp->m_frame);
     Time delay = beaconInterval * m_maxMissedBeacons;
-    // restart beacon watchdog for all links to setup
-    for (uint8_t linkId = 0; linkId < GetNLinks(); linkId++)
-    {
-        if (GetLink(linkId).apLinkId.has_value() || GetNLinks() == 1)
-        {
-            RestartBeaconWatchdog(delay, linkId);
-        }
-    }
+    // restart beacon watchdog
+    RestartBeaconWatchdog(delay);
+
     SetState(WAIT_ASSOC_RESP);
     SendAssociationRequest(false);
 }
@@ -671,93 +831,73 @@ StaWifiMac::AssocRequestTimeout()
 }
 
 void
-StaWifiMac::MissedBeacons(uint8_t linkId)
+StaWifiMac::MissedBeacons()
 {
-    NS_LOG_FUNCTION(this << +linkId);
-    auto& link = GetLink(linkId);
-    if (link.beaconWatchdogEnd > Simulator::Now())
+    NS_LOG_FUNCTION(this);
+
+    if (m_beaconWatchdogEnd > Simulator::Now())
     {
-        if (link.beaconWatchdog.IsRunning())
+        if (m_beaconWatchdog.IsRunning())
         {
-            link.beaconWatchdog.Cancel();
+            m_beaconWatchdog.Cancel();
         }
-        link.beaconWatchdog = Simulator::Schedule(link.beaconWatchdogEnd - Simulator::Now(),
-                                                  &StaWifiMac::MissedBeacons,
-                                                  this,
-                                                  linkId);
+        m_beaconWatchdog = Simulator::Schedule(m_beaconWatchdogEnd - Simulator::Now(),
+                                               &StaWifiMac::MissedBeacons,
+                                               this);
         return;
     }
     NS_LOG_DEBUG("beacon missed");
-    // We need to switch to the UNASSOCIATED state. However, if we are receiving
-    // a frame, wait until the RX is completed (otherwise, crashes may occur if
-    // we are receiving a MU frame because its reception requires the STA-ID)
+    // We need to switch to the UNASSOCIATED state. However, if we are receiving a frame, wait
+    // until the RX is completed (otherwise, crashes may occur if we are receiving a MU frame
+    // because its reception requires the STA-ID). We need to check that a PHY is operating on
+    // the given link, because this may (temporarily) not be the case for EMLSR clients.
     Time delay = Seconds(0);
-    if (GetWifiPhy(linkId)->IsStateRx())
+    for (const auto& [id, link] : GetLinks())
     {
-        delay = GetWifiPhy(linkId)->GetDelayUntilIdle();
+        if (link->phy && link->phy->IsStateRx())
+        {
+            delay = std::max(delay, link->phy->GetDelayUntilIdle());
+        }
     }
-    Simulator::Schedule(delay, &StaWifiMac::Disassociated, this, linkId);
+    Simulator::Schedule(delay, &StaWifiMac::Disassociated, this);
 }
 
 void
-StaWifiMac::Disassociated(uint8_t linkId)
+StaWifiMac::Disassociated()
 {
-    NS_LOG_FUNCTION(this << +linkId);
+    NS_LOG_FUNCTION(this);
 
-    auto& link = GetLink(linkId);
-    if (link.apLinkId.has_value())
+    Mac48Address apAddr; // the AP address to trace (MLD address in case of ML setup)
+
+    for (const auto& [id, link] : GetLinks())
     {
-        // this is a link setup in an ML setup
-        m_setupCanceled(linkId, GetBssid(linkId));
-    }
-
-    // disable the given link
-    link.apLinkId = std::nullopt;
-    link.bssid = std::nullopt;
-    link.phy->SetOffMode();
-
-    for (uint8_t id = 0; id < GetNLinks(); id++)
-    {
-        if (GetLink(id).apLinkId.has_value())
+        auto& bssid = GetStaLink(link).bssid;
+        if (bssid)
         {
-            // found an enabled link
-            return;
+            apAddr = GetWifiRemoteStationManager(id)->GetMldAddress(*bssid).value_or(*bssid);
         }
+        bssid = std::nullopt; // link is no longer setup
     }
 
     NS_LOG_DEBUG("Set state to UNASSOCIATED and start scanning");
     SetState(UNASSOCIATED);
     // cancel the association request timer (see issue #862)
     m_assocRequestEvent.Cancel();
-    auto mldAddress = GetWifiRemoteStationManager(linkId)->GetMldAddress(GetBssid(linkId));
-    if (GetNLinks() > 1 && mldAddress.has_value())
-    {
-        // trace the AP MLD address
-        m_deAssocLogger(*mldAddress);
-    }
-    else
-    {
-        m_deAssocLogger(GetBssid(linkId));
-    }
+    m_deAssocLogger(apAddr);
     m_aid = 0; // reset AID
-    // ensure all links are on
-    for (uint8_t id = 0; id < GetNLinks(); id++)
-    {
-        GetLink(id).phy->ResumeFromOff();
-    }
     TryToEnsureAssociated();
 }
 
 void
-StaWifiMac::RestartBeaconWatchdog(Time delay, uint8_t linkId)
+StaWifiMac::RestartBeaconWatchdog(Time delay)
 {
-    NS_LOG_FUNCTION(this << delay << +linkId);
-    auto& link = GetLink(linkId);
-    link.beaconWatchdogEnd = std::max(Simulator::Now() + delay, link.beaconWatchdogEnd);
-    if (Simulator::GetDelayLeft(link.beaconWatchdog) < delay && link.beaconWatchdog.IsExpired())
+    NS_LOG_FUNCTION(this << delay);
+
+    m_beaconWatchdogEnd = std::max(Simulator::Now() + delay, m_beaconWatchdogEnd);
+    if (Simulator::GetDelayLeft(m_beaconWatchdog) < delay && m_beaconWatchdog.IsExpired())
     {
         NS_LOG_DEBUG("really restart watchdog.");
-        link.beaconWatchdog = Simulator::Schedule(delay, &StaWifiMac::MissedBeacons, this, linkId);
+        m_beaconWatchdog = Simulator::Schedule(delay, &StaWifiMac::MissedBeacons, this);
     }
 }
 
@@ -782,22 +922,16 @@ StaWifiMac::GetSetupLinkIds() const
     }
 
     std::set<uint8_t> linkIds;
-    for (uint8_t linkId = 0; linkId < GetNLinks(); linkId++)
+    for (const auto& [id, link] : GetLinks())
     {
-        if (GetLink(linkId).bssid)
+        if (GetStaLink(link).bssid)
         {
-            linkIds.insert(linkId);
+            linkIds.insert(id);
         }
     }
     return linkIds;
 }
 
-std::optional<uint8_t>
-StaWifiMac::GetApLinkId(uint8_t linkId) const
-{
-    return GetLink(linkId).apLinkId;
-}
-
 Mac48Address
 StaWifiMac::DoGetLocalAddress(const Mac48Address& remoteAddr) const
 {
@@ -810,7 +944,7 @@ StaWifiMac::DoGetLocalAddress(const Mac48Address& remoteAddr) const
 bool
 StaWifiMac::CanForwardPacketsTo(Mac48Address to) const
 {
-    return (IsAssociated());
+    return IsAssociated();
 }
 
 void
@@ -898,6 +1032,50 @@ StaWifiMac::Enqueue(Ptr<Packet> packet, Mac48Address to)
     }
 }
 
+void
+StaWifiMac::BlockTxOnLink(uint8_t linkId, WifiQueueBlockedReason reason)
+{
+    NS_LOG_FUNCTION(this << linkId << reason);
+
+    auto bssid = GetBssid(linkId);
+    auto apAddress = GetWifiRemoteStationManager(linkId)->GetMldAddress(bssid).value_or(bssid);
+
+    BlockUnicastTxOnLinks(reason, apAddress, {linkId});
+    // the only type of broadcast frames that a non-AP STA can send are management frames
+    for (const auto& [acIndex, ac] : wifiAcList)
+    {
+        GetMacQueueScheduler()->BlockQueues(reason,
+                                            acIndex,
+                                            {WIFI_MGT_QUEUE},
+                                            Mac48Address::GetBroadcast(),
+                                            GetFrameExchangeManager(linkId)->GetAddress(),
+                                            {},
+                                            {linkId});
+    }
+}
+
+void
+StaWifiMac::UnblockTxOnLink(uint8_t linkId, WifiQueueBlockedReason reason)
+{
+    NS_LOG_FUNCTION(this << linkId << reason);
+
+    auto bssid = GetBssid(linkId);
+    auto apAddress = GetWifiRemoteStationManager(linkId)->GetMldAddress(bssid).value_or(bssid);
+
+    UnblockUnicastTxOnLinks(reason, apAddress, {linkId});
+    // the only type of broadcast frames that a non-AP STA can send are management frames
+    for (const auto& [acIndex, ac] : wifiAcList)
+    {
+        GetMacQueueScheduler()->UnblockQueues(reason,
+                                              acIndex,
+                                              {WIFI_MGT_QUEUE},
+                                              Mac48Address::GetBroadcast(),
+                                              GetFrameExchangeManager(linkId)->GetAddress(),
+                                              {},
+                                              {linkId});
+    }
+}
+
 void
 StaWifiMac::Receive(Ptr<const WifiMpdu> mpdu, uint8_t linkId)
 {
@@ -1067,7 +1245,7 @@ StaWifiMac::ReceiveBeacon(Ptr<const WifiMpdu> mpdu, uint8_t linkId)
         m_beaconArrival(Simulator::Now());
         Time delay = MicroSeconds(std::get<MgtBeaconHeader>(apInfo.m_frame).GetBeaconIntervalUs() *
                                   m_maxMissedBeacons);
-        RestartBeaconWatchdog(delay, linkId);
+        RestartBeaconWatchdog(delay);
         UpdateApInfo(apInfo.m_frame, hdr.GetAddr2(), hdr.GetAddr3(), linkId);
     }
     else
@@ -1128,22 +1306,57 @@ StaWifiMac::ReceiveAssocResp(Ptr<const WifiMpdu> mpdu, uint8_t linkId)
         UpdateApInfo(assocResp, hdr.GetAddr2(), hdr.GetAddr3(), linkId);
         NS_ASSERT(GetLink(linkId).bssid.has_value() && *GetLink(linkId).bssid == hdr.GetAddr3());
         SetBssid(hdr.GetAddr3(), linkId);
+        SetState(ASSOCIATED);
         if ((GetNLinks() > 1) && assocResp.Get<MultiLinkElement>().has_value())
         {
             // this is an ML setup, trace the setup link
             m_setupCompleted(linkId, hdr.GetAddr3());
             apMldAddress = GetWifiRemoteStationManager(linkId)->GetMldAddress(hdr.GetAddr3());
+            NS_ASSERT(apMldAddress);
+
+            if (const auto& mldCapabilities =
+                    GetWifiRemoteStationManager(linkId)->GetStationMldCapabilities(hdr.GetAddr3());
+                mldCapabilities && mldCapabilities->get().tidToLinkMappingSupport > 0)
+            {
+                // the AP MLD supports TID-to-Link Mapping negotiation, hence we included
+                // TID-to-Link Mapping element(s) in the Association Request.
+                if (assocResp.Get<TidToLinkMapping>().empty())
+                {
+                    // The AP MLD did not include a TID-to-Link Mapping element in the Association
+                    // Response, hence it accepted the mapping, which we can now store.
+                    UpdateTidToLinkMapping(*apMldAddress,
+                                           WifiDirection::DOWNLINK,
+                                           m_dlTidLinkMappingInAssocReq);
+                    UpdateTidToLinkMapping(*apMldAddress,
+                                           WifiDirection::UPLINK,
+                                           m_ulTidLinkMappingInAssocReq);
+
+                    // Apply the negotiated TID-to-Link Mapping (if any) for UL direction
+                    ApplyTidLinkMapping(*apMldAddress, WifiDirection::UPLINK);
+                }
+            }
         }
         else
         {
             m_assocLogger(hdr.GetAddr3());
         }
-        SetState(ASSOCIATED);
         if (!m_linkUp.IsNull())
         {
             m_linkUp();
         }
     }
+    else
+    {
+        // If the link on which the (Re)Association Request frame was received cannot be
+        // accepted by the AP MLD, the AP MLD shall treat the multi-link (re)setup as a
+        // failure and shall not accept any requested links. If the link on which the
+        // (Re)Association Request frame was received is accepted by the AP MLD, the
+        // multi-link (re)setup is successful. (Sec. 35.3.5.1 of 802.11be D3.1)
+        NS_LOG_DEBUG("association refused");
+        SetState(REFUSED);
+        StartScanning();
+        return;
+    }
 
     // if this is an MLD, check if we can setup (other) links
     if (GetNLinks() > 1)
@@ -1151,8 +1364,11 @@ StaWifiMac::ReceiveAssocResp(Ptr<const WifiMpdu> mpdu, uint8_t linkId)
         // create a list of all local Link IDs. IDs are removed as we find a corresponding
         // Per-STA Profile Subelements indicating successful association. Links with
         // remaining IDs are not setup
-        std::list<uint8_t> setupLinks(GetNLinks());
-        std::iota(setupLinks.begin(), setupLinks.end(), 0);
+        std::list<uint8_t> setupLinks;
+        for (const auto& [id, link] : GetLinks())
+        {
+            setupLinks.push_back(id);
+        }
         if (assocResp.GetStatusCode().IsSuccess())
         {
             setupLinks.remove(linkId);
@@ -1161,10 +1377,10 @@ StaWifiMac::ReceiveAssocResp(Ptr<const WifiMpdu> mpdu, uint8_t linkId)
         // if a Multi-Link Element is present, check its content
         if (const auto& mle = assocResp.Get<MultiLinkElement>())
         {
-            NS_ABORT_MSG_IF(!GetLink(linkId).apLinkId.has_value(),
+            NS_ABORT_MSG_IF(!GetLink(linkId).bssid.has_value(),
                             "The link on which the Association Response was received "
                             "is not a link we requested to setup");
-            NS_ABORT_MSG_IF(*GetLink(linkId).apLinkId != mle->GetLinkIdInfo(),
+            NS_ABORT_MSG_IF(linkId != mle->GetLinkIdInfo(),
                             "The link ID of the AP that transmitted the Association "
                             "Response does not match the stored link ID");
             NS_ABORT_MSG_IF(GetWifiRemoteStationManager(linkId)->GetMldAddress(hdr.GetAddr2()) !=
@@ -1177,18 +1393,11 @@ StaWifiMac::ReceiveAssocResp(Ptr<const WifiMpdu> mpdu, uint8_t linkId)
             {
                 auto& perStaProfile = mle->GetPerStaProfile(elem);
                 uint8_t apLinkId = perStaProfile.GetLinkId();
+                auto it = GetLinks().find(apLinkId);
                 uint8_t staLinkid = 0;
-                while (staLinkid < GetNLinks())
-                {
-                    if (GetLink(staLinkid).apLinkId == apLinkId)
-                    {
-                        break;
-                    }
-                    staLinkid++;
-                }
                 std::optional<Mac48Address> bssid;
-                NS_ABORT_MSG_IF(staLinkid == GetNLinks() ||
-                                    !(bssid = GetLink(staLinkid).bssid).has_value(),
+                NS_ABORT_MSG_IF(it == GetLinks().cend() ||
+                                    !(bssid = GetLink((staLinkid = it->first)).bssid).has_value(),
                                 "Setup for AP link ID " << apLinkId << " was not requested");
                 NS_ABORT_MSG_IF(*bssid != perStaProfile.GetStaMacAddress(),
                                 "The BSSID in the Per-STA Profile for link ID "
@@ -1224,13 +1433,8 @@ StaWifiMac::ReceiveAssocResp(Ptr<const WifiMpdu> mpdu, uint8_t linkId)
         // remaining links in setupLinks are not setup and hence must be disabled
         for (const auto& id : setupLinks)
         {
-            GetLink(id).apLinkId = std::nullopt;
             GetLink(id).bssid = std::nullopt;
-            // if at least one link was setup, disable the links that were not setup (if any)
-            if (m_state == ASSOCIATED)
-            {
-                GetLink(id).phy->SetOffMode();
-            }
+            GetLink(id).phy->SetOffMode();
         }
         if (apMldAddress)
         {
@@ -1239,13 +1443,29 @@ StaWifiMac::ReceiveAssocResp(Ptr<const WifiMpdu> mpdu, uint8_t linkId)
         }
     }
 
-    if (m_state == WAIT_ASSOC_RESP)
+    // the station that associated with the AP may have dissociated and then associated again.
+    // In this case, the station may store packets from the previous period in which it was
+    // associated. Have the station restart access if it has packets queued.
+    for (const auto& [id, link] : GetLinks())
     {
-        // if we didn't transition to ASSOCIATED, the request was refused
-        NS_LOG_DEBUG("association refused");
-        SetState(REFUSED);
-        StartScanning();
-        return;
+        if (GetStaLink(link).bssid)
+        {
+            if (const auto txop = GetTxop())
+            {
+                txop->StartAccessAfterEvent(id,
+                                            Txop::DIDNT_HAVE_FRAMES_TO_TRANSMIT,
+                                            Txop::CHECK_MEDIUM_BUSY);
+            }
+            for (const auto [acIndex, ac] : wifiAcList)
+            {
+                if (const auto edca = GetQosTxop(acIndex))
+                {
+                    edca->StartAccessAfterEvent(id,
+                                                Txop::DIDNT_HAVE_FRAMES_TO_TRANSMIT,
+                                                Txop::CHECK_MEDIUM_BUSY);
+                }
+            }
+        }
     }
 
     SetPmModeAfterAssociation(linkId);
@@ -1260,7 +1480,7 @@ StaWifiMac::SetPmModeAfterAssociation(uint8_t linkId)
     // acknowledgement of the Association Response. For this purpose, we connect a callback to
     // the PHY TX begin trace to catch the Ack transmitted after the Association Response.
     CallbackBase cb = Callback<void, WifiConstPsduMap, WifiTxVector, double>(
-        [=](WifiConstPsduMap psduMap, WifiTxVector txVector, double /* txPowerW */) {
+        [=, this](WifiConstPsduMap psduMap, WifiTxVector txVector, double /* txPowerW */) {
             NS_ASSERT_MSG(psduMap.size() == 1 && psduMap.begin()->second->GetNMpdus() == 1 &&
                               psduMap.begin()->second->GetHeader(0).IsAck(),
                           "Expected a Normal Ack after Association Response frame");
@@ -1268,9 +1488,9 @@ StaWifiMac::SetPmModeAfterAssociation(uint8_t linkId)
             auto ackDuration =
                 WifiPhy::CalculateTxDuration(psduMap, txVector, GetLink(linkId).phy->GetPhyBand());
 
-            for (uint8_t id = 0; id < GetNLinks(); id++)
+            for (const auto& [id, lnk] : GetLinks())
             {
-                auto& link = GetLink(id);
+                auto& link = GetStaLink(lnk);
 
                 if (!link.bssid)
                 {
@@ -1569,10 +1789,18 @@ StaWifiMac::UpdateApInfo(const MgtFrameType& frame,
         // is supported by the peer
         GetWifiRemoteStationManager(linkId)->AddStationEhtCapabilities(apAddr, *ehtCapabilities);
 
-        if (const auto& mle = frame.template Get<MultiLinkElement>();
-            mle && mle->HasEmlCapabilities() && m_emlsrManager)
+        if (const auto& mle = frame.template Get<MultiLinkElement>(); mle && m_emlsrManager)
         {
-            m_emlsrManager->SetTransitionTimeout(mle->GetTransitionTimeout());
+            if (mle->HasEmlCapabilities())
+            {
+                m_emlsrManager->SetTransitionTimeout(mle->GetTransitionTimeout());
+            }
+            if (const auto& common = mle->GetCommonInfoBasic(); common.m_mediumSyncDelayInfo)
+            {
+                m_emlsrManager->SetMediumSyncDuration(common.GetMediumSyncDelayTimer());
+                m_emlsrManager->SetMediumSyncOfdmEdThreshold(common.GetMediumSyncOfdmEdThreshold());
+                m_emlsrManager->SetMediumSyncMaxNTxops(common.GetMediumSyncMaxNTxops());
+            }
         }
     };
 
@@ -1753,6 +1981,101 @@ StaWifiMac::PhyCapabilitiesChanged()
     }
 }
 
+/**
+ * Initial configuration:
+ *
+ *        ┌───┬───┬───┐        ┌────┐       ┌───────┐
+ * Link A │FEM│RSM│CAM│◄──────►│Main├──────►│Channel│
+ *        │   │   │   │        │PHY │       │   A   │
+ *        └───┴───┴───┘        └────┘       └───────┘
+ *
+ *        ┌───┬───┬───┐        ┌────┐       ┌───────┐
+ * Link B │FEM│RSM│CAM│        │Aux │       │Channel│
+ *        │   │   │   │◄──────►│PHY ├──────►│   B   │
+ *        └───┴───┴───┘        └────┘       └───────┘
+ *
+ * A link switching/swapping is notified by the EMLSR Manager and the Channel Access Manager
+ * (CAM) notifies us that a first PHY (i.e., the Main PHY) switches to Channel B. We connect
+ * the Main PHY to the MAC stack B:
+ *
+ *
+ *        ┌───┬───┬───┐        ┌────┐       ┌───────┐
+ * Link A │FEM│RSM│CAM│   ┌───►│Main├───┐   │Channel│
+ *        │   │   │   │   │    │PHY │   │   │   A   │
+ *        └───┴───┴───┘   │    └────┘   │   └───────┘
+ *                        │             │
+ *        ┌───┬───┬───┐   │    ┌────┐   │   ┌───────┐
+ * Link B │FEM│RSM│CAM│◄──┘    │Aux │   └──►│Channel│
+ *        │   │   │   │◄─ ─ ─ ─│PHY ├──────►│   B   │
+ *        └───┴───┴───┘INACTIVE└────┘       └───────┘
+ *
+ * MAC stack B keeps a PHY listener associated with the Aux PHY, even though it is inactive,
+ * meaning that the PHY listener will only notify channel switches (no CCA, no RX).
+ * If the EMLSR Manager requested a link switching, this configuration will be kept until
+ * further requests. If the EMLSR Manager requested a link swapping, link B's CAM will be
+ * notified by its (inactive) PHY listener upon the channel switch performed by the Aux PHY.
+ * In this case, we remove the inactive PHY listener and connect the Aux PHY to MAC stack A:
+ *
+ *        ┌───┬───┬───┐        ┌────┐       ┌───────┐
+ * Link A │FEM│RSM│CAM│◄─┐ ┌──►│Main├───┐   │Channel│
+ *        │   │   │   │  │ │   │PHY │ ┌─┼──►│   A   │
+ *        └───┴───┴───┘  │ │   └────┘ │ │   └───────┘
+ *                       │ │          │ │
+ *        ┌───┬───┬───┐  │ │   ┌────┐ │ │   ┌───────┐
+ * Link B │FEM│RSM│CAM│◄─┼─┘   │Aux │ │ └──►│Channel│
+ *        │   │   │   │  └────►│PHY ├─┘     │   B   │
+ *        └───┴───┴───┘        └────┘       └───────┘
+ */
+
+void
+StaWifiMac::NotifySwitchingEmlsrLink(Ptr<WifiPhy> phy, uint8_t linkId, Time delay)
+{
+    NS_LOG_FUNCTION(this << phy << linkId << delay.As(Time::US));
+
+    // If the PHY is switching channel to operate on another link, then it is no longer operating
+    // on the current link. If any link (other than the current link) points to the PHY that is
+    // switching channel, reset the phy pointer of the link
+    for (auto& [id, link] : GetLinks())
+    {
+        if (link->phy == phy && id != linkId)
+        {
+            link->phy = nullptr;
+        }
+    }
+
+    // lambda to connect the PHY to the new link
+    auto connectPhy = [=, this]() mutable {
+        auto& newLink = GetLink(linkId);
+        // The MAC stack associated with the new link uses the given PHY
+        newLink.phy = phy;
+        // Setup a PHY listener for the given PHY on the CAM associated with the new link
+        newLink.channelAccessManager->SetupPhyListener(phy);
+        NS_ASSERT(m_emlsrManager);
+        if (m_emlsrManager->GetCamStateReset())
+        {
+            newLink.channelAccessManager->ResetState();
+        }
+        // Disconnect the FEM on the new link from the current PHY
+        newLink.feManager->ResetPhy();
+        // Connect the FEM on the new link to the given PHY
+        newLink.feManager->SetWifiPhy(phy);
+        // Connect the station manager on the new link to the given PHY
+        newLink.stationManager->SetupPhy(phy);
+    };
+
+    // if there is no PHY operating on the new link, connect the PHY to the new link now.
+    // Otherwise, wait until the channel switch is completed, so that the PHY operating on the new
+    // link can possibly continue receiving frames in the meantime.
+    if (!GetLink(linkId).phy)
+    {
+        connectPhy();
+    }
+    else
+    {
+        Simulator::Schedule(delay, connectPhy);
+    }
+}
+
 void
 StaWifiMac::NotifyChannelSwitching(uint8_t linkId)
 {
@@ -1762,7 +2085,7 @@ StaWifiMac::NotifyChannelSwitching(uint8_t linkId)
 
     if (IsInitialized() && IsAssociated())
     {
-        Disassociated(linkId);
+        Disassociated();
     }
 
     // notify association manager
