@@ -169,15 +169,33 @@ Txop::CreateLinkEntity() const
 Txop::LinkEntity&
 Txop::GetLink(uint8_t linkId) const
 {
-    NS_ASSERT(linkId < m_links.size());
-    NS_ASSERT(m_links.at(linkId)); // check that the pointer owns an object
-    return *m_links.at(linkId);
+    auto it = m_links.find(linkId);
+    NS_ASSERT(it != m_links.cend());
+    NS_ASSERT(it->second); // check that the pointer owns an object
+    return *it->second;
 }
 
-uint8_t
-Txop::GetNLinks() const
+const std::map<uint8_t, std::unique_ptr<Txop::LinkEntity>>&
+Txop::GetLinks() const
 {
-    return m_links.size();
+    return m_links;
+}
+
+void
+Txop::SwapLinks(std::map<uint8_t, uint8_t> links)
+{
+    NS_LOG_FUNCTION(this);
+
+    decltype(m_links) tmp;
+    tmp.swap(m_links); // move all links to temporary map
+    for (const auto& [from, to] : links)
+    {
+        auto nh = tmp.extract(from);
+        nh.key() = to;
+        m_links.insert(std::move(nh));
+    }
+    // move links remaining in tmp to m_links
+    m_links.merge(tmp);
 }
 
 void
@@ -192,12 +210,9 @@ Txop::SetWifiMac(const Ptr<WifiMac> mac)
 {
     NS_LOG_FUNCTION(this << mac);
     m_mac = mac;
-    m_links.resize(m_mac->GetNLinks());
-    uint8_t linkId = 0;
-    for (auto& link : m_links)
+    for (const auto linkId : m_mac->GetLinkIds())
     {
-        link = CreateLinkEntity();
-        link->id = linkId++;
+        m_links.emplace(linkId, CreateLinkEntity());
     }
 }
 
@@ -215,7 +230,6 @@ Txop::SetDroppedMpduCallback(DroppedMpdu callback)
 Ptr<WifiMacQueue>
 Txop::GetWifiMacQueue() const
 {
-    NS_LOG_FUNCTION(this);
     return m_queue;
 }
 
@@ -229,9 +243,10 @@ void
 Txop::SetMinCws(std::vector<uint32_t> minCws)
 {
     NS_ABORT_IF(minCws.size() != m_links.size());
-    for (std::size_t linkId = 0; linkId < minCws.size(); linkId++)
+    std::size_t i = 0;
+    for (const auto& [id, link] : m_links)
     {
-        SetMinCw(minCws[linkId], linkId);
+        SetMinCw(minCws[i++], id);
     }
 }
 
@@ -258,9 +273,10 @@ void
 Txop::SetMaxCws(std::vector<uint32_t> maxCws)
 {
     NS_ABORT_IF(maxCws.size() != m_links.size());
-    for (std::size_t linkId = 0; linkId < maxCws.size(); linkId++)
+    std::size_t i = 0;
+    for (const auto& [id, link] : m_links)
     {
-        SetMaxCw(maxCws[linkId], linkId);
+        SetMaxCw(maxCws[i++], id);
     }
 }
 
@@ -355,9 +371,10 @@ void
 Txop::SetAifsns(std::vector<uint8_t> aifsns)
 {
     NS_ABORT_IF(aifsns.size() != m_links.size());
-    for (std::size_t linkId = 0; linkId < aifsns.size(); linkId++)
+    std::size_t i = 0;
+    for (const auto& [id, link] : m_links)
     {
-        SetAifsn(aifsns[linkId], linkId);
+        SetAifsn(aifsns[i++], id);
     }
 }
 
@@ -381,9 +398,10 @@ Txop::SetTxopLimits(const std::vector<Time>& txopLimits)
                     "The size of the given vector (" << txopLimits.size()
                                                      << ") does not match the number of links ("
                                                      << m_links.size() << ")");
-    for (std::size_t linkId = 0; linkId < txopLimits.size(); linkId++)
+    std::size_t i = 0;
+    for (const auto& [id, link] : m_links)
     {
-        SetTxopLimit(txopLimits[linkId], linkId);
+        SetTxopLimit(txopLimits[i++], id);
     }
 }
 
@@ -406,9 +424,10 @@ std::vector<uint32_t>
 Txop::GetMinCws() const
 {
     std::vector<uint32_t> ret;
-    for (std::size_t linkId = 0; linkId < m_links.size(); linkId++)
+    ret.reserve(m_links.size());
+    for (const auto& [id, link] : m_links)
     {
-        ret.push_back(GetMinCw(linkId));
+        ret.push_back(link->cwMin);
     }
     return ret;
 }
@@ -429,9 +448,10 @@ std::vector<uint32_t>
 Txop::GetMaxCws() const
 {
     std::vector<uint32_t> ret;
-    for (std::size_t linkId = 0; linkId < m_links.size(); linkId++)
+    ret.reserve(m_links.size());
+    for (const auto& [id, link] : m_links)
     {
-        ret.push_back(GetMaxCw(linkId));
+        ret.push_back(link->cwMax);
     }
     return ret;
 }
@@ -452,9 +472,10 @@ std::vector<uint8_t>
 Txop::GetAifsns() const
 {
     std::vector<uint8_t> ret;
-    for (std::size_t linkId = 0; linkId < m_links.size(); linkId++)
+    ret.reserve(m_links.size());
+    for (const auto& [id, link] : m_links)
     {
-        ret.push_back(GetAifsn(linkId));
+        ret.push_back(link->aifsn);
     }
     return ret;
 }
@@ -475,9 +496,10 @@ std::vector<Time>
 Txop::GetTxopLimits() const
 {
     std::vector<Time> ret;
-    for (std::size_t linkId = 0; linkId < m_links.size(); linkId++)
+    ret.reserve(m_links.size());
+    for (const auto& [id, link] : m_links)
     {
-        ret.push_back(GetTxopLimit(linkId));
+        ret.push_back(link->txopLimit);
     }
     return ret;
 }
@@ -512,17 +534,29 @@ Txop::Queue(Ptr<WifiMpdu> mpdu)
 {
     NS_LOG_FUNCTION(this << *mpdu);
     const auto linkIds = m_mac->GetMacQueueScheduler()->GetLinkIds(m_queue->GetAc(), mpdu);
+    std::map<uint8_t, bool> hasFramesToTransmit;
+
+    // save the status of the AC queues before enqueuing the MPDU (required to determine if
+    // backoff is needed)
     for (const auto linkId : linkIds)
     {
-        if (m_mac->GetChannelAccessManager(linkId)->NeedBackoffUponAccess(this))
-        {
-            GenerateBackoff(linkId);
-        }
+        hasFramesToTransmit[linkId] = HasFramesToTransmit(linkId);
     }
     m_queue->Enqueue(mpdu);
     for (const auto linkId : linkIds)
     {
-        StartAccessIfNeeded(linkId);
+        // schedule a call to StartAccessIfNeeded() to request channel access after that all the
+        // packets of a burst have been enqueued, instead of requesting channel access right after
+        // the first packet. The call to StartAccessIfNeeded() is scheduled only after the first
+        // packet
+        if (auto& event = GetLink(linkId).accessRequest.event; !event.IsRunning())
+        {
+            event = Simulator::ScheduleNow(&Txop::StartAccessAfterEvent,
+                                           this,
+                                           linkId,
+                                           hasFramesToTransmit.at(linkId),
+                                           CHECK_MEDIUM_BUSY);
+        }
     }
 }
 
@@ -535,23 +569,34 @@ Txop::AssignStreams(int64_t stream)
 }
 
 void
-Txop::StartAccessIfNeeded(uint8_t linkId)
+Txop::StartAccessAfterEvent(uint8_t linkId, bool hadFramesToTransmit, bool checkMediumBusy)
 {
-    NS_LOG_FUNCTION(this << +linkId);
-    if (HasFramesToTransmit(linkId) && GetLink(linkId).access == NOT_REQUESTED)
+    NS_LOG_FUNCTION(this << +linkId << hadFramesToTransmit << checkMediumBusy);
+
+    if (GetLink(linkId).access != NOT_REQUESTED || !HasFramesToTransmit(linkId))
     {
-        m_mac->GetChannelAccessManager(linkId)->RequestAccess(this);
+        NS_LOG_DEBUG("No need to request channel access on link " << +linkId);
+        return;
     }
+
+    if (m_mac->GetChannelAccessManager(linkId)->NeedBackoffUponAccess(this,
+                                                                      hadFramesToTransmit,
+                                                                      checkMediumBusy))
+    {
+        GenerateBackoff(linkId);
+    }
+
+    m_mac->GetChannelAccessManager(linkId)->RequestAccess(this);
 }
 
 void
 Txop::DoInitialize()
 {
     NS_LOG_FUNCTION(this);
-    for (std::size_t linkId = 0; linkId < m_links.size(); linkId++)
+    for (const auto& [id, link] : m_links)
     {
-        ResetCw(linkId);
-        GenerateBackoff(linkId);
+        ResetCw(id);
+        GenerateBackoff(id);
     }
 }
 
@@ -623,16 +668,18 @@ void
 Txop::NotifyWakeUp(uint8_t linkId)
 {
     NS_LOG_FUNCTION(this << +linkId);
-    StartAccessIfNeeded(linkId);
+    // before wake up, no packet can be transmitted
+    StartAccessAfterEvent(linkId, DIDNT_HAVE_FRAMES_TO_TRANSMIT, DONT_CHECK_MEDIUM_BUSY);
 }
 
 void
 Txop::NotifyOn()
 {
     NS_LOG_FUNCTION(this);
-    for (std::size_t linkId = 0; linkId < m_links.size(); linkId++)
+    for (const auto& [id, link] : m_links)
     {
-        StartAccessIfNeeded(linkId);
+        // before being turned on, no packet can be transmitted
+        StartAccessAfterEvent(id, DIDNT_HAVE_FRAMES_TO_TRANSMIT, DONT_CHECK_MEDIUM_BUSY);
     }
 }
 
