@@ -26,9 +26,12 @@
 #include "ns3/object.h"
 #include "ns3/traced-value.h"
 
+#include <map>
 #include <memory>
 #include <vector>
 
+class EmlsrUlTxopTest;
+
 namespace ns3
 {
 
@@ -392,6 +395,32 @@ class Txop : public Object
      */
     virtual ChannelAccessStatus GetAccessStatus(uint8_t linkId) const;
 
+    /**
+     * Request channel access on the given link after the occurrence of an event that possibly
+     * requires to generate a new backoff value. Examples of such an event are: a packet has been
+     * enqueued by the upper layer; the given link has been unblocked after being blocked for some
+     * reason (e.g., wait for ADDBA Response, wait for TX on another EMLSR link to finish, etc.);
+     * the PHY operating on the given link just woke up from sleep mode. The <i>checkMediumBusy</i>
+     * argument is forwarded to the NeedBackoffUponAccess method of the ChannelAccessManager.
+     *
+     * \param linkId the ID of the given link
+     * \param hadFramesToTransmit whether packets available for transmission were queued just
+     *                            before the occurrence of the event causing this channel access
+     *                            request
+     * \param checkMediumBusy whether generation of backoff (also) depends on the busy/idle state
+     *                        of the medium
+     */
+    void StartAccessAfterEvent(uint8_t linkId, bool hadFramesToTransmit, bool checkMediumBusy);
+
+    static constexpr bool HAD_FRAMES_TO_TRANSMIT =
+        true; //!< packets available for transmission were in the queue
+    static constexpr bool DIDNT_HAVE_FRAMES_TO_TRANSMIT =
+        false; //!< no packet available for transmission was in the queue
+    static constexpr bool CHECK_MEDIUM_BUSY =
+        true; //!< generation of backoff (also) depends on the busy/idle state of the medium
+    static constexpr bool DONT_CHECK_MEDIUM_BUSY =
+        false; //!< generation of backoff is independent of the busy/idle state of the medium
+
     /**
      * \param nSlots the number of slots of the backoff.
      * \param linkId the ID of the given link
@@ -408,9 +437,20 @@ class Txop : public Object
      */
     virtual bool HasFramesToTransmit(uint8_t linkId);
 
+    /**
+     * Swap the links based on the information included in the given map. This method
+     * is normally called by the WifiMac of a non-AP MLD upon completing ML setup to have
+     * its link IDs match AP MLD's link IDs.
+     *
+     * \param links a set of pairs (from, to) each mapping a current link ID to the
+     *              link ID it has to become (i.e., link 'from' becomes link 'to')
+     */
+    void SwapLinks(std::map<uint8_t, uint8_t> links);
+
   protected:
     ///< ChannelAccessManager associated class
     friend class ChannelAccessManager;
+    friend class ::EmlsrUlTxopTest;
 
     void DoDispose() override;
     void DoInitialize() override;
@@ -429,12 +469,6 @@ class Txop : public Object
      * \param linkId the ID of the given link
      */
     virtual void GenerateBackoff(uint8_t linkId);
-    /**
-     * Request access from Txop on the given link if needed.
-     *
-     * \param linkId the ID of the given link
-     */
-    virtual void StartAccessIfNeeded(uint8_t linkId);
     /**
      * Request access to the ChannelAccessManager associated with the given link
      *
@@ -483,7 +517,6 @@ class Txop : public Object
         /// Destructor (a virtual method is needed to make this struct polymorphic)
         virtual ~LinkEntity() = default;
 
-        uint8_t id{0};                             //!< Link ID (starting at 0)
         uint32_t backoffSlots{0};                  //!< the number of backoff slots
         Time backoffStart{0};                      /**< the backoffStart variable is used to keep
                                                         track of the time at which a backoff was
@@ -495,6 +528,12 @@ class Txop : public Object
         uint8_t aifsn{0};                          //!< the AIFSN
         Time txopLimit{0};                         //!< the TXOP limit time
         ChannelAccessStatus access{NOT_REQUESTED}; //!< channel access status
+
+        mutable class
+        {
+            friend void Txop::Queue(Ptr<WifiMpdu>);
+            EventId event;
+        } accessRequest; //!< access request event, to be used by Txop::Queue() only
     };
 
     /**
@@ -504,12 +543,11 @@ class Txop : public Object
      * \return a reference to the link associated with the given ID
      */
     LinkEntity& GetLink(uint8_t linkId) const;
+
     /**
-     * Get the number of links.
-     *
-     * \return the number of links
+     * \return a const reference to the map of link entities
      */
-    uint8_t GetNLinks() const;
+    const std::map<uint8_t, std::unique_ptr<LinkEntity>>& GetLinks() const;
 
     DroppedMpdu m_droppedMpduCallback; //!< the dropped MPDU callback
     Ptr<WifiMacQueue> m_queue;         //!< the wifi MAC queue
@@ -533,7 +571,8 @@ class Txop : public Object
      */
     virtual std::unique_ptr<LinkEntity> CreateLinkEntity() const;
 
-    std::vector<std::unique_ptr<LinkEntity>> m_links; //!< vector of LinkEntity objects
+    std::map<uint8_t, std::unique_ptr<LinkEntity>>
+        m_links; //!< ID-indexed map of LinkEntity objects
 };
 
 } // namespace ns3
