@@ -314,7 +314,7 @@ PhyEntity::PhyFieldRxStatus
 VhtPhy::ProcessSig(Ptr<Event> event, PhyFieldRxStatus status, WifiPpduField field)
 {
     NS_LOG_FUNCTION(this << *event << status << field);
-    NS_ASSERT(event->GetTxVector().GetPreambleType() >= WIFI_PREAMBLE_VHT_SU);
+    NS_ASSERT(event->GetPpdu()->GetTxVector().GetPreambleType() >= WIFI_PREAMBLE_VHT_SU);
     // TODO see if something should be done here once MU-MIMO is supported
     return status; // nothing special for VHT
 }
@@ -369,7 +369,7 @@ VhtPhy::GetVhtMcs(uint8_t index)
     {                                                                                              \
         static WifiMode mcs = CreateVhtMcs(x);                                                     \
         return mcs;                                                                                \
-    };
+    }
 
 GET_VHT_MCS(0)
 GET_VHT_MCS(1)
