@@ -60,16 +60,17 @@ WifiDefaultAckManager::GetTypeId()
                           DoubleValue(0.0),
                           MakeDoubleAccessor(&WifiDefaultAckManager::m_baThreshold),
                           MakeDoubleChecker<double>(0.0, 1.0))
-            .AddAttribute("DlMuAckSequenceType",
-                          "Type of the acknowledgment sequence for DL MU PPDUs.",
-                          EnumValue(WifiAcknowledgment::DL_MU_BAR_BA_SEQUENCE),
-                          MakeEnumAccessor(&WifiDefaultAckManager::m_dlMuAckType),
-                          MakeEnumChecker(WifiAcknowledgment::DL_MU_BAR_BA_SEQUENCE,
-                                          "DL_MU_BAR_BA_SEQUENCE",
-                                          WifiAcknowledgment::DL_MU_TF_MU_BAR,
-                                          "DL_MU_TF_MU_BAR",
-                                          WifiAcknowledgment::DL_MU_AGGREGATE_TF,
-                                          "DL_MU_AGGREGATE_TF"))
+            .AddAttribute(
+                "DlMuAckSequenceType",
+                "Type of the acknowledgment sequence for DL MU PPDUs.",
+                EnumValue(WifiAcknowledgment::DL_MU_BAR_BA_SEQUENCE),
+                MakeEnumAccessor<WifiAcknowledgment::Method>(&WifiDefaultAckManager::m_dlMuAckType),
+                MakeEnumChecker(WifiAcknowledgment::DL_MU_BAR_BA_SEQUENCE,
+                                "DL_MU_BAR_BA_SEQUENCE",
+                                WifiAcknowledgment::DL_MU_TF_MU_BAR,
+                                "DL_MU_TF_MU_BAR",
+                                WifiAcknowledgment::DL_MU_AGGREGATE_TF,
+                                "DL_MU_AGGREGATE_TF"))
             .AddAttribute("MaxBlockAckMcs",
                           "The MCS used to send a BlockAck in a TB PPDU is the minimum between "
                           "the MCS used for the PSDU sent in the preceding DL MU PPDU and the "
@@ -572,7 +573,9 @@ WifiDefaultAckManager::GetAckInfoIfTfMuBar(Ptr<const WifiMpdu> mpdu,
                                           m_mac->GetBaTypeAsOriginator(receiver, tid)});
 
         acknowledgment->barTypes.push_back(m_mac->GetBarTypeAsOriginator(receiver, tid));
-        acknowledgment->muBarTxVector = GetWifiRemoteStationManager()->GetRtsTxVector(receiver);
+        acknowledgment->muBarTxVector =
+            GetWifiRemoteStationManager()->GetRtsTxVector(receiver,
+                                                          txParams.m_txVector.GetChannelWidth());
         acknowledgment->SetQosAckPolicy(receiver, tid, WifiMacHeader::BLOCK_ACK);
         return std::unique_ptr<WifiDlMuTfMuBar>(acknowledgment);
     }
