@@ -21,10 +21,12 @@
 
 #include "ap-wifi-mac.h"
 #include "frame-exchange-manager.h"
+#include "sta-wifi-mac.h"
 #include "wifi-mpdu.h"
 #include "wifi-tx-parameters.h"
 
 #include "ns3/boolean.h"
+#include "ns3/emlsr-manager.h"
 #include "ns3/erp-ofdm-phy.h"
 #include "ns3/log.h"
 
@@ -188,11 +190,26 @@ WifiDefaultProtectionManager::GetPsduProtection(const WifiMacHeader& hdr,
         return std::make_unique<WifiNoProtection>();
     }
 
+    // when an EMLSR client starts an UL TXOP on a link while the MediumSyncDelay timer is running
+    // or on a link on which the main PHY is not operating, it needs to send an RTS frame
+    bool emlsrNeedRts = false;
+
+    if (auto staMac = DynamicCast<StaWifiMac>(m_mac))
+    {
+        auto emlsrManager = staMac->GetEmlsrManager();
+
+        emlsrNeedRts = emlsrManager && staMac->IsEmlsrLink(m_linkId) &&
+                       (emlsrManager->GetElapsedMediumSyncDelayTimer(m_linkId) ||
+                        m_mac->GetLinkForPhy(emlsrManager->GetMainPhyId()) != m_linkId);
+    }
+
     // check if RTS/CTS is needed
-    if (GetWifiRemoteStationManager()->NeedRts(hdr, size))
+    if (emlsrNeedRts || GetWifiRemoteStationManager()->NeedRts(hdr, size))
     {
         auto protection = std::make_unique<WifiRtsCtsProtection>();
-        protection->rtsTxVector = GetWifiRemoteStationManager()->GetRtsTxVector(hdr.GetAddr1());
+        protection->rtsTxVector =
+            GetWifiRemoteStationManager()->GetRtsTxVector(hdr.GetAddr1(),
+                                                          txVector.GetChannelWidth());
         protection->ctsTxVector =
             GetWifiRemoteStationManager()->GetCtsTxVector(hdr.GetAddr1(),
                                                           protection->rtsTxVector.GetMode());
@@ -286,7 +303,8 @@ WifiDefaultProtectionManager::TryAddMpduToMuPpdu(Ptr<const WifiMpdu> mpdu,
             }
 
             // compute the TXVECTOR to use to send the MU-RTS Trigger Frame
-            protection->muRtsTxVector = GetWifiRemoteStationManager()->GetRtsTxVector(receiver);
+            protection->muRtsTxVector =
+                GetWifiRemoteStationManager()->GetRtsTxVector(receiver, txWidth);
             // The transmitter of an MU-RTS Trigger frame shall not request a non-AP STA to send
             // a CTS frame response in a 20 MHz channel that is not occupied by the PPDU that
             // contains the MU-RTS Trigger frame. (Sec. 26.2.6.2 of 802.11ax)
@@ -345,7 +363,6 @@ WifiDefaultProtectionManager::TryUlMuTransmission(Ptr<const WifiMpdu> mpdu,
 
     NS_ABORT_MSG_IF(m_mac->GetTypeOfStation() != AP, "HE APs only can send DL MU PPDUs");
     const auto& staList = StaticCast<ApWifiMac>(m_mac)->GetStaList(m_linkId);
-    std::remove_reference_t<decltype(staList)>::const_iterator staIt;
 
     bool allProtected = true;
     bool isUnprotectedEmlsrDst = false;
@@ -355,7 +372,7 @@ WifiDefaultProtectionManager::TryUlMuTransmission(Ptr<const WifiMpdu> mpdu,
         // Add a User Info field to the MU-RTS for this solicited station
         // The UL HE-MCS, UL FEC Coding Type, UL DCM, SS Allocation and UL Target RSSI fields
         // in the User Info field are reserved (Sec. 9.3.1.22.5 of 802.11ax)
-        staIt = staList.find(userInfo.GetAid12());
+        auto staIt = staList.find(userInfo.GetAid12());
         NS_ASSERT(staIt != staList.cend());
         AddUserInfoToMuRts(protection->muRts, txWidth, staIt->second);
         bool isProtected =
@@ -377,7 +394,7 @@ WifiDefaultProtectionManager::TryUlMuTransmission(Ptr<const WifiMpdu> mpdu,
 
     // compute the TXVECTOR to use to send the MU-RTS Trigger Frame
     protection->muRtsTxVector =
-        GetWifiRemoteStationManager()->GetRtsTxVector(mpdu->GetHeader().GetAddr1());
+        GetWifiRemoteStationManager()->GetRtsTxVector(mpdu->GetHeader().GetAddr1(), txWidth);
     // The transmitter of an MU-RTS Trigger frame shall not request a non-AP STA to send
     // a CTS frame response in a 20 MHz channel that is not occupied by the PPDU that
     // contains the MU-RTS Trigger frame. (Sec. 26.2.6.2 of 802.11ax)
