@@ -308,7 +308,7 @@ WifiMacHeader::SetRawDuration(uint16_t duration)
 void
 WifiMacHeader::SetDuration(Time duration)
 {
-    int64_t duration_us =
+    auto duration_us =
         static_cast<int64_t>(ceil(static_cast<double>(duration.GetNanoSeconds()) / 1000));
     NS_ASSERT(duration_us >= 0 && duration_us <= 0x7fff);
     m_duration = static_cast<uint16_t>(duration_us);
