@@ -24,6 +24,7 @@
 #include "wifi-mac-queue.h"
 #include "wifi-mac.h"
 
+#include <algorithm>
 #include <functional>
 #include <list>
 #include <map>
@@ -66,11 +67,14 @@ class WifiMacQueueSchedulerImpl : public WifiMacQueueScheduler
 
     /** \copydoc ns3::WifiMacQueueScheduler::SetWifiMac */
     void SetWifiMac(Ptr<WifiMac> mac) final;
-    /** \copydoc ns3::WifiMacQueueScheduler::GetNext(AcIndex,uint8_t) */
-    std::optional<WifiContainerQueueId> GetNext(AcIndex ac, uint8_t linkId) final;
-    /** \copydoc ns3::WifiMacQueueScheduler::GetNext(AcIndex,uint8_t,const WifiContainerQueueId&) */
+    /** \copydoc ns3::WifiMacQueueScheduler::GetNext(AcIndex,std::optional<uint8_t>) */
+    std::optional<WifiContainerQueueId> GetNext(AcIndex ac, std::optional<uint8_t> linkId) final;
+    /**
+     *  \copydoc ns3::WifiMacQueueScheduler::GetNext(AcIndex,std::optional<uint8_t>,
+     *           const WifiContainerQueueId&)
+     */
     std::optional<WifiContainerQueueId> GetNext(AcIndex ac,
-                                                uint8_t linkId,
+                                                std::optional<uint8_t> linkId,
                                                 const WifiContainerQueueId& prevQueueId) final;
     /** \copydoc ns3::WifiMacQueueScheduler::GetLinkIds */
     std::list<uint8_t> GetLinkIds(AcIndex ac, Ptr<const WifiMpdu> mpdu) final;
@@ -202,12 +206,13 @@ class WifiMacQueueSchedulerImpl : public WifiMacQueueScheduler
      * Queues containing MPDUs that cannot be sent over the given link are ignored.
      *
      * \param ac the Access Category that we want to serve
-     * \param linkId the ID of the link on which we got channel access
+     * \param linkId the ID of the link on which MPDUs contained in the returned queue must be
+     *               allowed to be sent
      * \param sortedQueuesIt iterator pointing to the queue we start the search from
      * \return the ID of the selected container queue (if any)
      */
     std::optional<WifiContainerQueueId> DoGetNext(AcIndex ac,
-                                                  uint8_t linkId,
+                                                  std::optional<uint8_t> linkId,
                                                   typename SortedQueues::iterator sortedQueuesIt);
 
     /**
@@ -352,16 +357,15 @@ WifiMacQueueSchedulerImpl<Priority, Compare>::InitQueueInfo(AcIndex ac, Ptr<cons
 
         // this assert checks that the RA field also contain an MLD address, unless
         // it contains the broadcast address
-        NS_ASSERT_MSG(rxAddr.IsGroup() || GetMac()->GetMldAddress(rxAddr),
+        NS_ASSERT_MSG(rxAddr.IsGroup() || GetMac()->GetMldAddress(rxAddr) == rxAddr,
                       "Address 1 (" << rxAddr << ") is not an MLD address");
 
         // this assert checks that association (ML setup) has been established
         // between sender and receiver (unless the receiver is the broadcast address)
         NS_ASSERT_MSG(GetMac()->CanForwardPacketsTo(rxAddr), "Cannot forward frame to " << rxAddr);
-
         // we have to include all the links in case of broadcast frame (we are an AP)
         // and the links that have been setup with the receiver in case of unicast frame
-        for (uint8_t linkId = 0; linkId < GetMac()->GetNLinks(); linkId++)
+        for (const auto linkId : GetMac()->GetLinkIds())
         {
             if (rxAddr.IsGroup() ||
                 GetMac()->GetWifiRemoteStationManager(linkId)->GetAffiliatedStaAddress(rxAddr))
@@ -446,7 +450,7 @@ WifiMacQueueSchedulerImpl<Priority, Compare>::GetLinkIds(AcIndex ac, Ptr<const W
     std::list<uint8_t> linkIds;
 
     // include only links that are not blocked in the returned list
-    for (const auto [linkId, mask] : queueInfoIt->second.linkIds)
+    for (const auto& [linkId, mask] : queueInfoIt->second.linkIds)
     {
         if (mask.none())
         {
@@ -567,19 +571,19 @@ WifiMacQueueSchedulerImpl<Priority, Compare>::GetQueueLinkMask(AcIndex ac,
 
 template <class Priority, class Compare>
 std::optional<WifiContainerQueueId>
-WifiMacQueueSchedulerImpl<Priority, Compare>::GetNext(AcIndex ac, uint8_t linkId)
+WifiMacQueueSchedulerImpl<Priority, Compare>::GetNext(AcIndex ac, std::optional<uint8_t> linkId)
 {
-    NS_LOG_FUNCTION(this << +ac << +linkId);
+    NS_LOG_FUNCTION(this << +ac << linkId.has_value());
     return DoGetNext(ac, linkId, m_perAcInfo[ac].sortedQueues.begin());
 }
 
 template <class Priority, class Compare>
 std::optional<WifiContainerQueueId>
 WifiMacQueueSchedulerImpl<Priority, Compare>::GetNext(AcIndex ac,
-                                                      uint8_t linkId,
+                                                      std::optional<uint8_t> linkId,
                                                       const WifiContainerQueueId& prevQueueId)
 {
-    NS_LOG_FUNCTION(this << +ac << +linkId);
+    NS_LOG_FUNCTION(this << +ac << linkId.has_value());
 
     auto queueInfoIt = m_perAcInfo[ac].queueInfoMap.find(prevQueueId);
     NS_ABORT_IF(queueInfoIt == m_perAcInfo[ac].queueInfoMap.end() ||
@@ -595,19 +599,20 @@ template <class Priority, class Compare>
 std::optional<WifiContainerQueueId>
 WifiMacQueueSchedulerImpl<Priority, Compare>::DoGetNext(
     AcIndex ac,
-    uint8_t linkId,
+    std::optional<uint8_t> linkId,
     typename SortedQueues::iterator sortedQueuesIt)
 {
-    NS_LOG_FUNCTION(this << +ac << +linkId);
+    NS_LOG_FUNCTION(this << +ac << linkId.has_value());
     NS_ASSERT(static_cast<uint8_t>(ac) < AC_UNDEF);
 
     while (sortedQueuesIt != m_perAcInfo[ac].sortedQueues.end())
     {
         const auto& queueInfoPair = sortedQueuesIt->second.get();
         const auto& linkIds = queueInfoPair.second.linkIds;
+        typename std::decay_t<decltype(linkIds)>::const_iterator linkIt;
 
-        if (const auto linkIt = linkIds.find(linkId);
-            linkIt != linkIds.cend() && linkIt->second.none())
+        if (!linkId.has_value() ||
+            ((linkIt = linkIds.find(*linkId)) != linkIds.cend() && linkIt->second.none()))
         {
             // Packets in this queue can be sent over the link we got channel access on.
             // Now remove packets with expired lifetime from this queue.
