@@ -23,7 +23,7 @@
 #include "extended-capabilities.h"
 #include "mac-rx-middle.h"
 #include "mac-tx-middle.h"
-#include "mgt-headers.h"
+#include "mgt-action-headers.h"
 #include "qos-txop.h"
 #include "ssid.h"
 #include "wifi-mac-queue.h"
@@ -38,6 +38,8 @@
 #include "ns3/pointer.h"
 #include "ns3/vht-configuration.h"
 
+#include <algorithm>
+
 namespace ns3
 {
 
@@ -118,6 +120,14 @@ WifiMac::GetTypeId()
                           PointerValue(),
                           MakePointerAccessor(&WifiMac::GetBKQueue),
                           MakePointerChecker<QosTxop>())
+            .AddAttribute(
+                "MpduBufferSize",
+                "The size (in number of MPDUs) of the buffer used for each BlockAck "
+                "agreement in which this node is a recipient. The provided value is "
+                "capped to the maximum allowed value based on the supported standard.",
+                UintegerValue(1024),
+                MakeUintegerAccessor(&WifiMac::GetMpduBufferSize, &WifiMac::SetMpduBufferSize),
+                MakeUintegerChecker<uint16_t>(1, 1024))
             .AddAttribute("VO_MaxAmsduSize",
                           "Maximum length in bytes of an A-MSDU for AC_VO access class "
                           "(capped to 7935 for HT PPDUs and 11398 for VHT/HE/EHT PPDUs). "
@@ -287,19 +297,6 @@ WifiMac::GetTypeId()
                             "up from the physical layer.",
                             MakeTraceSourceAccessor(&WifiMac::m_macRxDropTrace),
                             "ns3::Packet::TracedCallback")
-            .AddTraceSource("TxOkHeader",
-                            "The header of successfully transmitted packet.",
-                            MakeTraceSourceAccessor(&WifiMac::m_txOkCallback),
-                            "ns3::WifiMacHeader::TracedCallback",
-                            TypeId::OBSOLETE,
-                            "Use the AckedMpdu trace instead.")
-            .AddTraceSource("TxErrHeader",
-                            "The header of unsuccessfuly transmitted packet.",
-                            MakeTraceSourceAccessor(&WifiMac::m_txErrCallback),
-                            "ns3::WifiMacHeader::TracedCallback",
-                            TypeId::OBSOLETE,
-                            "Depending on the failure type, use the NAckedMpdu trace, the "
-                            "DroppedMpdu trace or one of the traces associated with TX timeouts.")
             .AddTraceSource("AckedMpdu",
                             "An MPDU that was successfully acknowledged, via either a "
                             "Normal Ack or a Block Ack.",
@@ -363,7 +360,7 @@ WifiMac::DoInitialize()
         it->second->Initialize();
     }
 
-    for (auto& link : m_links)
+    for (const auto& [id, link] : m_links)
     {
         if (auto cam = link->channelAccessManager)
         {
@@ -431,6 +428,11 @@ void
 WifiMac::SetDevice(const Ptr<WifiNetDevice> device)
 {
     m_device = device;
+    if (GetHtSupported())
+    {
+        // the configured BlockAck buffer size can now be capped
+        m_mpduBufferSize = std::min(m_mpduBufferSize, GetMaxBaBufferSize());
+    }
 }
 
 Ptr<WifiNetDevice>
@@ -481,7 +483,7 @@ WifiMac::GetBssid(uint8_t linkId) const
 void
 WifiMac::SetPromisc()
 {
-    for (auto& link : m_links)
+    for (auto& [id, link] : m_links)
     {
         link->feManager->SetPromisc();
     }
@@ -585,10 +587,8 @@ WifiMac::NotifyChannelSwitching(uint8_t linkId)
     // the PHY dependent parameters. In any case, this makes no harm
     ConfigurePhyDependentParameters(linkId);
 
-    // SetupPhy not only resets the remote station manager, but also sets the
-    // default TX mode and MCS, which is required when switching to a channel
-    // in a different band
-    GetLink(linkId).stationManager->SetupPhy(GetLink(linkId).phy);
+    // Reset remote station manager
+    GetLink(linkId).stationManager->Reset();
 }
 
 void
@@ -646,7 +646,7 @@ void
 WifiMac::ConfigureContentionWindow(uint32_t cwMin, uint32_t cwMax)
 {
     std::list<bool> isDsssOnly;
-    for (const auto& link : m_links)
+    for (const auto& [id, link] : m_links)
     {
         isDsssOnly.push_back(link->dsssSupported && !link->erpSupported);
     }
@@ -751,11 +751,11 @@ WifiMac::ConfigureStandard(WifiStandard standard)
     NS_ABORT_IF(standard >= WIFI_STANDARD_80211n && !m_qosSupported);
     NS_ABORT_MSG_IF(m_links.empty(), "No PHY configured yet");
 
-    for (auto& link : m_links)
+    for (auto& [id, link] : m_links)
     {
         NS_ABORT_MSG_IF(
             !link->phy || !link->phy->GetOperatingChannel().IsSet(),
-            "[LinkID " << link->id
+            "[LinkID " << +id
                        << "] PHY must have been set and an operating channel must have been set");
 
         // do not create a ChannelAccessManager and a FrameExchangeManager if they
@@ -772,8 +772,8 @@ WifiMac::ConfigureStandard(WifiStandard standard)
         }
         link->feManager->SetWifiPhy(link->phy);
         link->feManager->SetWifiMac(this);
-        link->feManager->SetLinkId(link->id);
-        link->channelAccessManager->SetLinkId(link->id);
+        link->feManager->SetLinkId(id);
+        link->channelAccessManager->SetLinkId(id);
         link->channelAccessManager->SetupFrameExchangeManager(link->feManager);
 
         if (m_txop)
@@ -787,7 +787,7 @@ WifiMac::ConfigureStandard(WifiStandard standard)
             link->channelAccessManager->Add(it->second);
         }
 
-        ConfigurePhyDependentParameters(link->id);
+        ConfigurePhyDependentParameters(id);
     }
 }
 
@@ -896,13 +896,9 @@ WifiMac::SetWifiRemoteStationManagers(
     for (std::size_t i = 0; i < stationManagers.size(); i++)
     {
         // the link may already exist in case PHY objects were configured first
-        if (i == m_links.size())
-        {
-            m_links.push_back(CreateLinkEntity());
-            m_links.back()->id = i;
-        }
-        NS_ABORT_IF(i != m_links[i]->id);
-        m_links[i]->stationManager = stationManagers[i];
+        auto [it, inserted] = m_links.emplace(i, CreateLinkEntity());
+        m_linkIds.insert(i);
+        it->second->stationManager = stationManagers[i];
     }
 }
 
@@ -918,12 +914,19 @@ WifiMac::CreateLinkEntity() const
     return std::make_unique<LinkEntity>();
 }
 
+const std::map<uint8_t, std::unique_ptr<WifiMac::LinkEntity>>&
+WifiMac::GetLinks() const
+{
+    return m_links;
+}
+
 WifiMac::LinkEntity&
 WifiMac::GetLink(uint8_t linkId) const
 {
-    NS_ASSERT(linkId < m_links.size());
-    NS_ASSERT(m_links.at(linkId)); // check that the pointer owns an object
-    return *m_links.at(linkId);
+    auto it = m_links.find(linkId);
+    NS_ASSERT(it != m_links.cend());
+    NS_ASSERT(it->second); // check that the pointer owns an object
+    return *it->second;
 }
 
 uint8_t
@@ -932,19 +935,213 @@ WifiMac::GetNLinks() const
     return m_links.size();
 }
 
+const std::set<uint8_t>&
+WifiMac::GetLinkIds() const
+{
+    return m_linkIds;
+}
+
+void
+WifiMac::UpdateLinkId(uint8_t id)
+{
+    NS_LOG_FUNCTION(this << id);
+
+    auto& link = GetLink(id);
+    if (link.feManager)
+    {
+        link.feManager->SetLinkId(id);
+    }
+    if (link.channelAccessManager)
+    {
+        link.channelAccessManager->SetLinkId(id);
+    }
+}
+
 std::optional<uint8_t>
 WifiMac::GetLinkIdByAddress(const Mac48Address& address) const
 {
-    for (std::size_t ret = 0; ret < m_links.size(); ++ret)
+    for (const auto& [id, link] : m_links)
     {
-        if (m_links[ret]->feManager->GetAddress() == address)
+        if (link->feManager->GetAddress() == address)
         {
-            return ret;
+            return id;
         }
     }
     return std::nullopt;
 }
 
+std::optional<uint8_t>
+WifiMac::GetLinkForPhy(Ptr<const WifiPhy> phy) const
+{
+    for (const auto& [id, link] : m_links)
+    {
+        if (link->phy == phy)
+        {
+            return id;
+        }
+    }
+    return std::nullopt;
+}
+
+std::optional<uint8_t>
+WifiMac::GetLinkForPhy(std::size_t phyId) const
+{
+    NS_ABORT_UNLESS(phyId < m_device->GetNPhys());
+    auto phy = m_device->GetPhy(phyId);
+    return GetLinkForPhy(phy);
+}
+
+void
+WifiMac::SwapLinks(std::map<uint8_t, uint8_t> links)
+{
+    NS_LOG_FUNCTION(this);
+
+    std::map<uint8_t, uint8_t> actualPairs;
+
+    while (!links.empty())
+    {
+        auto from = links.cbegin()->first;
+        auto to = links.cbegin()->second;
+
+        if (from == to)
+        {
+            // nothing to do
+            links.erase(links.cbegin());
+            continue;
+        }
+
+        std::unique_ptr<LinkEntity> linkToMove;
+        NS_ASSERT(m_links.find(from) != m_links.cend());
+        linkToMove.swap(m_links.at(from)); // from is now out of m_links
+        auto empty = from;                 // track empty cell in m_links
+
+        do
+        {
+            auto [it, inserted] =
+                m_links.emplace(to, nullptr); // insert an element with key to if not present
+            m_links[to].swap(linkToMove);     // to is the link to move now
+            actualPairs.emplace(from, to);
+            UpdateLinkId(to);
+            links.erase(from);
+            if (!linkToMove)
+            {
+                if (inserted)
+                {
+                    m_links.erase(empty);
+                }
+                break;
+            }
+
+            auto nextTo = links.find(to);
+            if (nextTo == links.cend())
+            {
+                // no new position specified for 'to', use the current empty cell
+                m_links[empty].swap(linkToMove);
+                actualPairs.emplace(to, empty);
+                break;
+            }
+
+            from = to;
+            to = nextTo->second;
+        } while (true);
+    }
+
+    m_linkIds.clear();
+    for (const auto& [id, link] : m_links)
+    {
+        m_linkIds.insert(id);
+    }
+
+    if (m_txop)
+    {
+        m_txop->SwapLinks(actualPairs);
+    }
+    for (auto& [ac, edca] : m_edca)
+    {
+        edca->SwapLinks(actualPairs);
+    }
+}
+
+void
+WifiMac::UpdateTidToLinkMapping(const Mac48Address& mldAddr,
+                                WifiDirection dir,
+                                const WifiTidLinkMapping& mapping)
+{
+    NS_LOG_FUNCTION(this << mldAddr);
+
+    NS_ABORT_MSG_IF(dir == WifiDirection::BOTH_DIRECTIONS,
+                    "DL and UL directions for TID-to-Link mapping must be set separately");
+
+    auto& mappings = (dir == WifiDirection::DOWNLINK ? m_dlTidLinkMappings : m_ulTidLinkMappings);
+
+    auto [it, inserted] = mappings.emplace(mldAddr, mapping);
+
+    if (inserted)
+    {
+        // we are done
+        return;
+    }
+
+    // a previous mapping is stored for this MLD
+    if (mapping.empty())
+    {
+        // the default mapping has been now negotiated
+        it->second.clear();
+        return;
+    }
+
+    for (const auto& [tid, linkSet] : mapping)
+    {
+        it->second[tid] = linkSet;
+    }
+}
+
+std::optional<std::reference_wrapper<const WifiTidLinkMapping>>
+WifiMac::GetTidToLinkMapping(Mac48Address mldAddr, WifiDirection dir) const
+{
+    NS_ABORT_MSG_IF(dir == WifiDirection::BOTH_DIRECTIONS,
+                    "Cannot request TID-to-Link mapping for both directions");
+
+    const auto& mappings =
+        (dir == WifiDirection::DOWNLINK ? m_dlTidLinkMappings : m_ulTidLinkMappings);
+
+    if (const auto it = mappings.find(mldAddr); it != mappings.cend())
+    {
+        return it->second;
+    }
+    return std::nullopt;
+}
+
+bool
+WifiMac::TidMappedOnLink(Mac48Address mldAddr, WifiDirection dir, uint8_t tid, uint8_t linkId) const
+{
+    NS_ABORT_MSG_IF(dir == WifiDirection::BOTH_DIRECTIONS,
+                    "Cannot request TID-to-Link mapping for both directions");
+
+    const auto& mappings =
+        (dir == WifiDirection::DOWNLINK ? m_dlTidLinkMappings : m_ulTidLinkMappings);
+
+    const auto it = mappings.find(mldAddr);
+
+    if (it == mappings.cend())
+    {
+        // TID-to-link mapping was not negotiated, TIDs are mapped to all setup links
+        return GetWifiRemoteStationManager(linkId)->GetMldAddress(mldAddr).has_value();
+    }
+
+    auto linkSetIt = it->second.find(tid);
+
+    if (linkSetIt == it->second.cend())
+    {
+        // If there is no successfully negotiated TID-to-link mapping for a TID, then the TID
+        // is mapped to all setup links for DL and UL (Sec. 35.3.7.1.3 of 802.11be D3.1)
+        return GetWifiRemoteStationManager(linkId)->GetMldAddress(mldAddr).has_value();
+    }
+
+    return std::find(linkSetIt->second.cbegin(), linkSetIt->second.cend(), linkId) !=
+           linkSetIt->second.cend();
+}
+
 void
 WifiMac::SetWifiPhys(const std::vector<Ptr<WifiPhy>>& phys)
 {
@@ -964,20 +1161,15 @@ WifiMac::SetWifiPhys(const std::vector<Ptr<WifiPhy>>& phys)
         // the link may already exist in case we are setting new PHY objects
         // (ResetWifiPhys just nullified the PHY(s) but left the links)
         // or the remote station managers were configured first
-        if (i == m_links.size())
-        {
-            m_links.push_back(CreateLinkEntity());
-            m_links.back()->id = i;
-        }
-        NS_ABORT_IF(i != m_links[i]->id);
-        m_links[i]->phy = phys[i];
+        auto [it, inserted] = m_links.emplace(i, CreateLinkEntity());
+        m_linkIds.insert(i);
+        it->second->phy = phys[i];
     }
 }
 
 Ptr<WifiPhy>
 WifiMac::GetWifiPhy(uint8_t linkId) const
 {
-    NS_LOG_FUNCTION(this << +linkId);
     return GetLink(linkId).phy;
 }
 
@@ -985,7 +1177,7 @@ void
 WifiMac::ResetWifiPhys()
 {
     NS_LOG_FUNCTION(this);
-    for (auto& link : m_links)
+    for (auto& [id, link] : m_links)
     {
         if (link->feManager)
         {
@@ -1109,6 +1301,88 @@ WifiMac::SetLinkDownCallback(Callback<void> linkDown)
     m_linkDown = linkDown;
 }
 
+void
+WifiMac::ApplyTidLinkMapping(const Mac48Address& mldAddr, WifiDirection dir)
+{
+    NS_LOG_FUNCTION(this << mldAddr);
+
+    NS_ABORT_MSG_IF(
+        dir == WifiDirection::BOTH_DIRECTIONS,
+        "This method can be used to enforce TID-to-Link mapping for one direction at a time");
+
+    const auto& mappings =
+        (dir == WifiDirection::DOWNLINK ? m_dlTidLinkMappings : m_ulTidLinkMappings);
+
+    auto it = mappings.find(mldAddr);
+
+    if (it == mappings.cend())
+    {
+        // no mapping has been ever negotiated with the given MLD, the default mapping is used
+        return;
+    }
+
+    std::set<uint8_t> setupLinks;
+
+    // find the IDs of the links setup with the given MLD
+    for (const auto& [id, link] : m_links)
+    {
+        if (link->stationManager->GetMldAddress(mldAddr))
+        {
+            setupLinks.insert(id);
+        }
+    }
+
+    auto linkMapping = it->second;
+
+    if (linkMapping.empty())
+    {
+        // default link mapping, each TID mapped on all setup links
+        for (uint8_t tid = 0; tid < 8; tid++)
+        {
+            linkMapping.emplace(tid, setupLinks);
+        }
+    }
+
+    for (const auto& [tid, linkSet] : linkMapping)
+    {
+        decltype(setupLinks) mappedLinks; // empty
+        auto notMappedLinks = setupLinks; // all setup links
+
+        for (const auto id : linkSet)
+        {
+            if (setupLinks.find(id) != setupLinks.cend())
+            {
+                // link is mapped
+                mappedLinks.insert(id);
+                notMappedLinks.erase(id);
+            }
+        }
+
+        // unblock mapped links
+        NS_ABORT_MSG_IF(mappedLinks.empty(), "Every TID must be mapped to at least a link");
+
+        m_scheduler->UnblockQueues(WifiQueueBlockedReason::TID_NOT_MAPPED,
+                                   QosUtilsMapTidToAc(tid),
+                                   {WIFI_QOSDATA_QUEUE},
+                                   mldAddr,
+                                   GetAddress(),
+                                   {tid},
+                                   mappedLinks);
+
+        // block unmapped links
+        if (!notMappedLinks.empty())
+        {
+            m_scheduler->BlockQueues(WifiQueueBlockedReason::TID_NOT_MAPPED,
+                                     QosUtilsMapTidToAc(tid),
+                                     {WIFI_QOSDATA_QUEUE},
+                                     mldAddr,
+                                     GetAddress(),
+                                     {tid},
+                                     notMappedLinks);
+        }
+    }
+}
+
 void
 WifiMac::BlockUnicastTxOnLinks(WifiQueueBlockedReason reason,
                                const Mac48Address& address,
@@ -1128,7 +1402,7 @@ WifiMac::BlockUnicastTxOnLinks(WifiQueueBlockedReason reason,
             continue;
         }
 
-        for (const auto [acIndex, ac] : wifiAcList)
+        for (const auto& [acIndex, ac] : wifiAcList)
         {
             // block queues storing QoS data frames and control frames that use MLD addresses
             m_scheduler->BlockQueues(reason,
@@ -1169,8 +1443,11 @@ WifiMac::UnblockUnicastTxOnLinks(WifiQueueBlockedReason reason,
             continue;
         }
 
-        for (const auto [acIndex, ac] : wifiAcList)
+        for (const auto& [acIndex, ac] : wifiAcList)
         {
+            // save the status of the AC queues before unblocking the requested queues
+            auto hasFramesToTransmit = GetQosTxop(acIndex)->HasFramesToTransmit(linkId);
+
             // unblock queues storing QoS data frames and control frames that use MLD addresses
             m_scheduler->UnblockQueues(reason,
                                        acIndex,
@@ -1189,14 +1466,11 @@ WifiMac::UnblockUnicastTxOnLinks(WifiQueueBlockedReason reason,
                                        {linkId});
             // request channel access if needed (schedule now because multiple invocations
             // of this method may be done in a loop at the caller)
-            auto qosTxop = GetQosTxop(acIndex);
-            Simulator::ScheduleNow([=]() {
-                if (qosTxop->GetAccessStatus(linkId) == Txop::NOT_REQUESTED &&
-                    qosTxop->HasFramesToTransmit(linkId))
-                {
-                    GetLink(linkId).channelAccessManager->RequestAccess(qosTxop);
-                }
-            });
+            Simulator::ScheduleNow(&Txop::StartAccessAfterEvent,
+                                   GetQosTxop(acIndex),
+                                   linkId,
+                                   hasFramesToTransmit,
+                                   Txop::CHECK_MEDIUM_BUSY); // generate backoff if medium busy
         }
     }
 }
@@ -1357,9 +1631,9 @@ WifiMac::DeaggregateAmsduAndForward(Ptr<const WifiMpdu> mpdu)
 std::optional<Mac48Address>
 WifiMac::GetMldAddress(const Mac48Address& remoteAddr) const
 {
-    for (std::size_t linkId = 0; linkId < m_links.size(); linkId++)
+    for (const auto& [id, link] : m_links)
     {
-        if (auto mldAddress = m_links[linkId]->stationManager->GetMldAddress(remoteAddr))
+        if (auto mldAddress = link->stationManager->GetMldAddress(remoteAddr))
         {
             return *mldAddress;
         }
@@ -1370,7 +1644,7 @@ WifiMac::GetMldAddress(const Mac48Address& remoteAddr) const
 Mac48Address
 WifiMac::GetLocalAddress(const Mac48Address& remoteAddr) const
 {
-    for (const auto& link : m_links)
+    for (const auto& [id, link] : m_links)
     {
         if (auto mldAddress = link->stationManager->GetMldAddress(remoteAddr))
         {
@@ -1511,7 +1785,7 @@ WifiMac::GetEhtSupported() const
 bool
 WifiMac::GetHtSupported(const Mac48Address& address) const
 {
-    for (const auto& link : m_links)
+    for (const auto& [id, link] : m_links)
     {
         if (link->stationManager->GetHtSupported(address))
         {
@@ -1524,7 +1798,7 @@ WifiMac::GetHtSupported(const Mac48Address& address) const
 bool
 WifiMac::GetVhtSupported(const Mac48Address& address) const
 {
-    for (const auto& link : m_links)
+    for (const auto& [id, link] : m_links)
     {
         if (link->stationManager->GetVhtSupported(address))
         {
@@ -1537,7 +1811,7 @@ WifiMac::GetVhtSupported(const Mac48Address& address) const
 bool
 WifiMac::GetHeSupported(const Mac48Address& address) const
 {
-    for (const auto& link : m_links)
+    for (const auto& [id, link] : m_links)
     {
         if (link->stationManager->GetHeSupported(address))
         {
@@ -1550,7 +1824,7 @@ WifiMac::GetHeSupported(const Mac48Address& address) const
 bool
 WifiMac::GetEhtSupported(const Mac48Address& address) const
 {
-    for (const auto& link : m_links)
+    for (const auto& [id, link] : m_links)
     {
         if (link->stationManager->GetEhtSupported(address))
         {
@@ -1560,6 +1834,36 @@ WifiMac::GetEhtSupported(const Mac48Address& address) const
     return false;
 }
 
+uint16_t
+WifiMac::GetMaxBaBufferSize(std::optional<Mac48Address> address) const
+{
+    if (address ? GetEhtSupported(*address) : GetEhtSupported())
+    {
+        return 1024;
+    }
+    if (address ? GetHeSupported(*address) : GetHeSupported())
+    {
+        return 256;
+    }
+    NS_ASSERT(address ? GetHtSupported(*address) : GetHtSupported());
+    return 64;
+}
+
+void
+WifiMac::SetMpduBufferSize(uint16_t size)
+{
+    NS_LOG_FUNCTION(this << size);
+
+    // the cap can be computed if the device has been configured
+    m_mpduBufferSize = m_device ? std::min(size, GetMaxBaBufferSize()) : size;
+}
+
+uint16_t
+WifiMac::GetMpduBufferSize() const
+{
+    return m_mpduBufferSize;
+}
+
 void
 WifiMac::SetVoBlockAckThreshold(uint8_t threshold)
 {
@@ -1664,7 +1968,7 @@ WifiMac::GetHtCapabilities(uint8_t linkId) const
     capabilities.SetLdpc(htConfiguration->GetLdpcSupported());
     capabilities.SetSupportedChannelWidth(htConfiguration->Get40MHzOperationSupported() ? 1 : 0);
     capabilities.SetShortGuardInterval20(sgiSupported);
-    capabilities.SetShortGuardInterval40(phy->GetChannelWidth() >= 40 && sgiSupported);
+    capabilities.SetShortGuardInterval40(sgiSupported);
     // Set Maximum A-MSDU Length subfield
     uint16_t maxAmsduSize =
         std::max({m_voMaxAmsduSize, m_viMaxAmsduSize, m_beMaxAmsduSize, m_bkMaxAmsduSize});
@@ -1690,7 +1994,9 @@ WifiMac::GetHtCapabilities(uint8_t linkId) const
         capabilities.SetRxMcsBitmask(mcs.GetMcsValue());
         uint8_t nss = (mcs.GetMcsValue() / 8) + 1;
         NS_ASSERT(nss > 0 && nss < 5);
-        uint64_t dataRate = mcs.GetDataRate(phy->GetChannelWidth(), sgiSupported ? 400 : 800, nss);
+        uint64_t dataRate = mcs.GetDataRate(htConfiguration->Get40MHzOperationSupported() ? 40 : 20,
+                                            sgiSupported ? 400 : 800,
+                                            nss);
         if (dataRate > maxSupportedRate)
         {
             maxSupportedRate = dataRate;
@@ -1746,8 +2052,8 @@ WifiMac::GetVhtCapabilities(uint8_t linkId) const
     capabilities.SetMaxAmpduLength(std::min(std::max(maxAmpduLength, 8191U), 1048575U));
 
     capabilities.SetRxLdpc(htConfiguration->GetLdpcSupported());
-    capabilities.SetShortGuardIntervalFor80Mhz((phy->GetChannelWidth() == 80) && sgiSupported);
-    capabilities.SetShortGuardIntervalFor160Mhz((phy->GetChannelWidth() == 160) && sgiSupported);
+    capabilities.SetShortGuardIntervalFor80Mhz(sgiSupported);
+    capabilities.SetShortGuardIntervalFor160Mhz(sgiSupported);
     uint8_t maxMcs = 0;
     for (const auto& mcs : phy->GetMcsList(WIFI_MOD_CLASS_VHT))
     {
@@ -1766,15 +2072,16 @@ WifiMac::GetVhtCapabilities(uint8_t linkId) const
         capabilities.SetTxMcsMap(maxMcs, nss);
     }
     uint64_t maxSupportedRateLGI = 0; // in bit/s
+    uint16_t maxWidth = vhtConfiguration->Get160MHzOperationSupported() ? 160 : 80;
     for (const auto& mcs : phy->GetMcsList(WIFI_MOD_CLASS_VHT))
     {
-        if (!mcs.IsAllowed(phy->GetChannelWidth(), 1))
+        if (!mcs.IsAllowed(maxWidth, 1))
         {
             continue;
         }
-        if (mcs.GetDataRate(phy->GetChannelWidth()) > maxSupportedRateLGI)
+        if (mcs.GetDataRate(maxWidth) > maxSupportedRateLGI)
         {
-            maxSupportedRateLGI = mcs.GetDataRate(phy->GetChannelWidth());
+            maxSupportedRateLGI = mcs.GetDataRate(maxWidth);
             NS_LOG_DEBUG("Updating maxSupportedRateLGI to " << maxSupportedRateLGI);
         }
     }
@@ -1798,18 +2105,20 @@ WifiMac::GetHeCapabilities(uint8_t linkId) const
 
     Ptr<WifiPhy> phy = GetLink(linkId).phy;
     Ptr<HtConfiguration> htConfiguration = GetHtConfiguration();
+    Ptr<VhtConfiguration> vhtConfiguration = GetVhtConfiguration();
     Ptr<HeConfiguration> heConfiguration = GetHeConfiguration();
     uint8_t channelWidthSet = 0;
-    if ((phy->GetChannelWidth() >= 40) && (phy->GetPhyBand() == WIFI_PHY_BAND_2_4GHZ))
+    if ((htConfiguration->Get40MHzOperationSupported()) &&
+        (phy->GetPhyBand() == WIFI_PHY_BAND_2_4GHZ))
     {
         channelWidthSet |= 0x01;
     }
-    if (((phy->GetChannelWidth() >= 80) || GetEhtSupported()) &&
-        ((phy->GetPhyBand() == WIFI_PHY_BAND_5GHZ) || (phy->GetPhyBand() == WIFI_PHY_BAND_6GHZ)))
+    // we assume that HE stations support 80 MHz operations
+    if ((phy->GetPhyBand() == WIFI_PHY_BAND_5GHZ) || (phy->GetPhyBand() == WIFI_PHY_BAND_6GHZ))
     {
         channelWidthSet |= 0x02;
     }
-    if ((phy->GetChannelWidth() >= 160) &&
+    if ((vhtConfiguration->Get160MHzOperationSupported()) &&
         ((phy->GetPhyBand() == WIFI_PHY_BAND_5GHZ) || (phy->GetPhyBand() == WIFI_PHY_BAND_6GHZ)))
     {
         channelWidthSet |= 0x04;
@@ -1891,7 +2200,7 @@ WifiMac::GetEhtCapabilities(uint8_t linkId) const
 
     const uint8_t maxTxNss = phy->GetMaxSupportedTxSpatialStreams();
     const uint8_t maxRxNss = phy->GetMaxSupportedRxSpatialStreams();
-    if (phy->GetChannelWidth() == 20)
+    if (auto htConfig = GetHtConfiguration(); !htConfig->Get40MHzOperationSupported())
     {
         for (auto maxMcs : {7, 9, 11, 13})
         {
@@ -1919,7 +2228,7 @@ WifiMac::GetEhtCapabilities(uint8_t linkId) const
                 phy->IsMcsSupported(WIFI_MOD_CLASS_EHT, maxMcs) ? maxTxNss : 0);
         }
     }
-    if (phy->GetChannelWidth() >= 160)
+    if (auto vhtConfig = GetVhtConfiguration(); vhtConfig->Get160MHzOperationSupported())
     {
         for (auto maxMcs : {9, 11, 13})
         {
