@@ -48,6 +48,9 @@ class WifiNetDevice;
 class WifiMode;
 class Time;
 
+/// maximum propagation delay
+static constexpr uint8_t MAX_PROPAGATION_DELAY_USEC = 1;
+
 /**
  * typedef for a pair of start and stop frequencies in Hz to represent a band
  */
@@ -60,6 +63,9 @@ struct WifiSpectrumBandInfo
     WifiSpectrumBandFrequencies frequencies; //!< the start and stop frequencies of the band
 };
 
+/// vector of spectrum bands
+using WifiSpectrumBands = std::vector<WifiSpectrumBandInfo>;
+
 /**
  * \ingroup wifi
  * Compare two bands.
