@@ -71,9 +71,9 @@ WifiRemoteStationManager::GetTypeId()
                           "If the size of the PSDU is bigger than this value, we use an RTS/CTS "
                           "handshake before sending the data frame."
                           "This value will not have any effect on some rate control algorithms.",
-                          UintegerValue(65535),
+                          UintegerValue(4692480),
                           MakeUintegerAccessor(&WifiRemoteStationManager::SetRtsCtsThreshold),
-                          MakeUintegerChecker<uint32_t>())
+                          MakeUintegerChecker<uint32_t>(0, 4692480))
             .AddAttribute(
                 "FragmentationThreshold",
                 "If the size of the PSDU is bigger than this value, we fragment it such that the "
@@ -100,7 +100,8 @@ WifiRemoteStationManager::GetTypeId()
                           "Protection mode used when non-ERP STAs are connected to an ERP AP: "
                           "Rts-Cts or Cts-To-Self",
                           EnumValue(WifiRemoteStationManager::CTS_TO_SELF),
-                          MakeEnumAccessor(&WifiRemoteStationManager::m_erpProtectionMode),
+                          MakeEnumAccessor<WifiRemoteStationManager::ProtectionMode>(
+                              &WifiRemoteStationManager::m_erpProtectionMode),
                           MakeEnumChecker(WifiRemoteStationManager::RTS_CTS,
                                           "Rts-Cts",
                                           WifiRemoteStationManager::CTS_TO_SELF,
@@ -109,7 +110,8 @@ WifiRemoteStationManager::GetTypeId()
                           "Protection mode used when non-HT STAs are connected to a HT AP: Rts-Cts "
                           "or Cts-To-Self",
                           EnumValue(WifiRemoteStationManager::CTS_TO_SELF),
-                          MakeEnumAccessor(&WifiRemoteStationManager::m_htProtectionMode),
+                          MakeEnumAccessor<WifiRemoteStationManager::ProtectionMode>(
+                              &WifiRemoteStationManager::m_htProtectionMode),
                           MakeEnumChecker(WifiRemoteStationManager::RTS_CTS,
                                           "Rts-Cts",
                                           WifiRemoteStationManager::CTS_TO_SELF,
@@ -142,6 +144,8 @@ WifiRemoteStationManager::WifiRemoteStationManager()
       m_shortSlotTimeEnabled(false)
 {
     NS_LOG_FUNCTION(this);
+    m_ssrc.fill(0);
+    m_slrc.fill(0);
 }
 
 WifiRemoteStationManager::~WifiRemoteStationManager()
@@ -166,13 +170,6 @@ WifiRemoteStationManager::SetupPhy(const Ptr<WifiPhy> phy)
     // transmit rate for automatic control responses like
     // acknowledgments.
     m_wifiPhy = phy;
-    m_defaultTxMode = phy->GetDefaultMode();
-    NS_ASSERT(m_defaultTxMode.IsMandatory());
-    if (GetHtSupported())
-    {
-        m_defaultTxMcs = HtPhy::GetHtMcs(0);
-    }
-    Reset();
 }
 
 void
@@ -182,7 +179,6 @@ WifiRemoteStationManager::SetupMac(const Ptr<WifiMac> mac)
     // We need to track our MAC because it is the object that knows the
     // full set of interframe spaces.
     m_wifiMac = mac;
-    Reset();
 }
 
 int64_t
@@ -390,11 +386,9 @@ WifiRemoteStationManager::AddAllSupportedMcs(Mac48Address address)
     NS_LOG_FUNCTION(this << address);
     NS_ASSERT(!address.IsGroup());
     auto state = LookupState(address);
-    state->m_operationalMcsSet.clear();
-    for (const auto& mcs : m_wifiPhy->GetMcsList())
-    {
-        state->m_operationalMcsSet.push_back(mcs);
-    }
+
+    const auto& mcsList = m_wifiPhy->GetMcsList();
+    state->m_operationalMcsSet = WifiModeList(mcsList.begin(), mcsList.end());
 }
 
 void
@@ -565,21 +559,16 @@ WifiRemoteStationManager::SetPsMode(const Mac48Address& address, bool isInPsMode
     LookupState(address)->m_isInPsMode = isInPsMode;
 }
 
-void
-WifiRemoteStationManager::SetMldAddress(const Mac48Address& address, const Mac48Address& mldAddress)
-{
-    NS_LOG_FUNCTION(this << address << mldAddress);
-
-    auto state = LookupState(address);
-    state->m_mldAddress = mldAddress;
-    // insert another entry in m_states indexed by the MLD address and pointing to the same state
-    const_cast<WifiRemoteStationManager*>(this)->m_states.insert({mldAddress, state});
-}
-
 std::optional<Mac48Address>
 WifiRemoteStationManager::GetMldAddress(const Mac48Address& address) const
 {
-    return LookupState(address)->m_mldAddress;
+    if (auto stateIt = m_states.find(address);
+        stateIt != m_states.end() && stateIt->second->m_mleCommonInfo)
+    {
+        return stateIt->second->m_mleCommonInfo->m_mldMacAddress;
+    }
+
+    return std::nullopt;
 }
 
 std::optional<Mac48Address>
@@ -587,13 +576,13 @@ WifiRemoteStationManager::GetAffiliatedStaAddress(const Mac48Address& mldAddress
 {
     auto stateIt = m_states.find(mldAddress);
 
-    if (stateIt == m_states.end() || !stateIt->second->m_mldAddress)
+    if (stateIt == m_states.end() || !stateIt->second->m_mleCommonInfo)
     {
         // MLD address not found
         return std::nullopt;
     }
 
-    NS_ASSERT(*stateIt->second->m_mldAddress == mldAddress);
+    NS_ASSERT(stateIt->second->m_mleCommonInfo->m_mldMacAddress == mldAddress);
     return stateIt->second->m_address;
 }
 
@@ -652,7 +641,7 @@ WifiRemoteStationManager::GetDataTxVector(const WifiMacHeader& header, uint16_t
     {
         txVector = DoGetDataTxVector(Lookup(address), allowedWidth);
         txVector.SetLdpc(txVector.GetMode().GetModulationClass() < WIFI_MOD_CLASS_HT
-                             ? 0
+                             ? false
                              : UseLdpcForDestination(address));
     }
     Ptr<HeConfiguration> heConfiguration = m_wifiPhy->GetDevice()->GetHeConfiguration();
@@ -708,13 +697,13 @@ WifiRemoteStationManager::GetCtsToSelfTxVector()
 }
 
 WifiTxVector
-WifiRemoteStationManager::GetRtsTxVector(Mac48Address address)
+WifiRemoteStationManager::GetRtsTxVector(Mac48Address address, uint16_t allowedWidth)
 {
-    NS_LOG_FUNCTION(this << address);
+    NS_LOG_FUNCTION(this << address << allowedWidth);
+    WifiTxVector v;
     if (address.IsGroup())
     {
         WifiMode mode = GetNonUnicastMode();
-        WifiTxVector v;
         v.SetMode(mode);
         v.SetPreambleType(
             GetPreambleForTransmission(mode.GetModulationClass(), GetShortPreambleEnabled()));
@@ -724,9 +713,31 @@ WifiRemoteStationManager::GetRtsTxVector(Mac48Address address)
         v.SetNTx(GetNumberOfAntennas());
         v.SetNss(1);
         v.SetNess(0);
-        return v;
     }
-    return DoGetRtsTxVector(Lookup(address));
+    else
+    {
+        v = DoGetRtsTxVector(Lookup(address));
+    }
+    auto modulation = v.GetModulationClass();
+
+    if (allowedWidth >= 40 &&
+        (modulation == WIFI_MOD_CLASS_DSSS || modulation == WIFI_MOD_CLASS_HR_DSSS))
+    {
+        // RTS must be sent in a non-HT duplicate PPDU because it must protect a frame being
+        // transmitted on at least 40 MHz. Change the modulation class to ERP-OFDM and the rate
+        // to 6 Mbps
+        v.SetMode(ErpOfdmPhy::GetErpOfdmRate6Mbps());
+        modulation = v.GetModulationClass();
+    }
+    // do not set allowedWidth as the TX width if the modulation class is (HR-)DSSS (allowedWidth
+    // may be >= 40 MHz) or allowedWidth is 22 MHz (the selected modulation class may be OFDM)
+    if (modulation != WIFI_MOD_CLASS_DSSS && modulation != WIFI_MOD_CLASS_HR_DSSS &&
+        allowedWidth != 22)
+    {
+        v.SetChannelWidth(allowedWidth);
+    }
+
+    return v;
 }
 
 WifiTxVector
@@ -1169,7 +1180,7 @@ WifiRemoteStationManager::NeedCtsToSelf(WifiTxVector txVector)
     {
         // search for the BSS Basic Rate set, if the used mode is in the basic set then there is no
         // need for CTS To Self
-        for (WifiModeListIterator i = m_bssBasicRateSet.begin(); i != m_bssBasicRateSet.end(); i++)
+        for (auto i = m_bssBasicRateSet.begin(); i != m_bssBasicRateSet.end(); i++)
         {
             if (mode == *i)
             {
@@ -1181,8 +1192,7 @@ WifiRemoteStationManager::NeedCtsToSelf(WifiTxVector txVector)
         {
             // search for the BSS Basic MCS set, if the used mode is in the basic set then there is
             // no need for CTS To Self
-            for (WifiModeListIterator i = m_bssBasicMcsSet.begin(); i != m_bssBasicMcsSet.end();
-                 i++)
+            for (auto i = m_bssBasicMcsSet.begin(); i != m_bssBasicMcsSet.end(); i++)
             {
                 if (mode == *i)
                 {
@@ -1422,7 +1432,7 @@ WifiRemoteStationManager::LookupState(Mac48Address address) const
     state->m_vhtCapabilities = nullptr;
     state->m_heCapabilities = nullptr;
     state->m_ehtCapabilities = nullptr;
-    state->m_emlCapabilities = nullptr;
+    state->m_mleCommonInfo = nullptr;
     state->m_emlsrEnabled = false;
     state->m_channelWidth = m_wifiPhy->GetChannelWidth();
     state->m_guardInterval = GetGuardInterval();
@@ -1439,6 +1449,8 @@ WifiRemoteStation*
 WifiRemoteStationManager::Lookup(Mac48Address address) const
 {
     NS_LOG_FUNCTION(this << address);
+    NS_ASSERT(!address.IsGroup());
+    NS_ASSERT(address != m_wifiMac->GetAddress());
     auto stationIt = m_stations.find(address);
 
     if (stationIt != m_stations.end())
@@ -1557,7 +1569,7 @@ WifiRemoteStationManager::AddStationHeCapabilities(Mac48Address from, HeCapabili
             state->m_channelWidth = 20;
         }
     }
-    if (heCapabilities.GetHeSuPpdu1xHeLtf800nsGi() == 1)
+    if (heCapabilities.GetHeSuPpdu1xHeLtf800nsGi())
     {
         state->m_guardInterval = 800;
     }
@@ -1600,12 +1612,16 @@ WifiRemoteStationManager::AddStationEhtCapabilities(Mac48Address from,
 }
 
 void
-WifiRemoteStationManager::AddStationEmlCapabilities(
+WifiRemoteStationManager::AddStationMleCommonInfo(
     Mac48Address from,
-    const std::shared_ptr<CommonInfoBasicMle::EmlCapabilities>& emlCapabilities)
+    const std::shared_ptr<CommonInfoBasicMle>& mleCommonInfo)
 {
     NS_LOG_FUNCTION(this << from);
-    LookupState(from)->m_emlCapabilities = emlCapabilities;
+    auto state = LookupState(from);
+    state->m_mleCommonInfo = mleCommonInfo;
+    // insert another entry in m_states indexed by the MLD address and pointing to the same state
+    const_cast<WifiRemoteStationManager*>(this)->m_states.insert(
+        {mleCommonInfo->m_mldMacAddress, state});
 }
 
 Ptr<const HtCapabilities>
@@ -1632,10 +1648,26 @@ WifiRemoteStationManager::GetStationEhtCapabilities(Mac48Address from)
     return LookupState(from)->m_ehtCapabilities;
 }
 
-std::shared_ptr<CommonInfoBasicMle::EmlCapabilities>
+std::optional<std::reference_wrapper<CommonInfoBasicMle::EmlCapabilities>>
 WifiRemoteStationManager::GetStationEmlCapabilities(const Mac48Address& from)
 {
-    return LookupState(from)->m_emlCapabilities;
+    if (auto state = LookupState(from);
+        state->m_mleCommonInfo && state->m_mleCommonInfo->m_emlCapabilities)
+    {
+        return state->m_mleCommonInfo->m_emlCapabilities.value();
+    }
+    return std::nullopt;
+}
+
+std::optional<std::reference_wrapper<CommonInfoBasicMle::MldCapabilities>>
+WifiRemoteStationManager::GetStationMldCapabilities(const Mac48Address& from)
+{
+    if (auto state = LookupState(from);
+        state->m_mleCommonInfo && state->m_mleCommonInfo->m_mldCapabilities)
+    {
+        return state->m_mleCommonInfo->m_mldCapabilities.value();
+    }
+    return std::nullopt;
 }
 
 bool
@@ -1663,13 +1695,16 @@ WifiRemoteStationManager::GetLdpcSupported(Mac48Address address) const
 WifiMode
 WifiRemoteStationManager::GetDefaultMode() const
 {
-    return m_defaultTxMode;
+    NS_ASSERT(m_wifiPhy);
+    auto defaultTxMode = m_wifiPhy->GetDefaultMode();
+    NS_ASSERT(defaultTxMode.IsMandatory());
+    return defaultTxMode;
 }
 
 WifiMode
 WifiRemoteStationManager::GetDefaultMcs() const
 {
-    return m_defaultTxMcs;
+    return HtPhy::GetHtMcs0();
 }
 
 WifiMode
@@ -1748,7 +1783,7 @@ uint32_t
 WifiRemoteStationManager::GetNNonErpBasicModes() const
 {
     uint32_t size = 0;
-    for (WifiModeListIterator i = m_bssBasicRateSet.begin(); i != m_bssBasicRateSet.end(); i++)
+    for (auto i = m_bssBasicRateSet.begin(); i != m_bssBasicRateSet.end(); i++)
     {
         if (i->GetModulationClass() == WIFI_MOD_CLASS_ERP_OFDM)
         {
@@ -1765,7 +1800,7 @@ WifiRemoteStationManager::GetNonErpBasicMode(uint8_t i) const
     NS_ASSERT(i < GetNNonErpBasicModes());
     uint32_t index = 0;
     bool found = false;
-    for (WifiModeListIterator j = m_bssBasicRateSet.begin(); j != m_bssBasicRateSet.end();)
+    for (auto j = m_bssBasicRateSet.begin(); j != m_bssBasicRateSet.end();)
     {
         if (i == index)
         {
@@ -1889,7 +1924,7 @@ WifiRemoteStationManager::GetNonErpSupported(const WifiRemoteStation* station, u
     // moved in case it breaks standard rules.
     uint32_t index = 0;
     bool found = false;
-    for (WifiModeListIterator j = station->m_state->m_operationalRateSet.begin();
+    for (auto j = station->m_state->m_operationalRateSet.begin();
          j != station->m_state->m_operationalRateSet.end();)
     {
         if (i == index)
@@ -2014,8 +2049,9 @@ WifiRemoteStationManager::GetEhtSupported(const WifiRemoteStation* station) cons
 bool
 WifiRemoteStationManager::GetEmlsrSupported(const WifiRemoteStation* station) const
 {
-    auto emlCapabilities = station->m_state->m_emlCapabilities;
-    return emlCapabilities && emlCapabilities->emlsrSupport == 1;
+    auto mleCommonInfo = station->m_state->m_mleCommonInfo;
+    return mleCommonInfo && mleCommonInfo->m_emlCapabilities &&
+           mleCommonInfo->m_emlCapabilities->emlsrSupport == 1;
 }
 
 bool
@@ -2034,7 +2070,7 @@ uint32_t
 WifiRemoteStationManager::GetNNonErpSupported(const WifiRemoteStation* station) const
 {
     uint32_t size = 0;
-    for (WifiModeListIterator i = station->m_state->m_operationalRateSet.begin();
+    for (auto i = station->m_state->m_operationalRateSet.begin();
          i != station->m_state->m_operationalRateSet.end();
          i++)
     {
@@ -2128,8 +2164,9 @@ WifiRemoteStationManager::GetEhtSupported(Mac48Address address) const
 bool
 WifiRemoteStationManager::GetEmlsrSupported(const Mac48Address& address) const
 {
-    auto emlCapabilities = LookupState(address)->m_emlCapabilities;
-    return emlCapabilities && emlCapabilities->emlsrSupport == 1;
+    auto mleCommonInfo = LookupState(address)->m_mleCommonInfo;
+    return mleCommonInfo && mleCommonInfo->m_emlCapabilities &&
+           mleCommonInfo->m_emlCapabilities->emlsrSupport == 1;
 }
 
 bool
