@@ -22,12 +22,14 @@
 #define WIFI_TX_VECTOR_H
 
 #include "wifi-mode.h"
+#include "wifi-phy-band.h"
 #include "wifi-phy-common.h"
 
 #include "ns3/he-ru.h"
 
 #include <list>
 #include <optional>
+#include <set>
 #include <vector>
 
 namespace ns3
@@ -113,7 +115,6 @@ class WifiTxVector
         HeMuUserInfoMap;
 
     WifiTxVector();
-    ~WifiTxVector();
     /**
      * Create a TXVECTOR with the given parameters.
      *
@@ -248,9 +249,13 @@ class WifiTxVector
      */
     uint8_t GetNss(uint16_t staId = SU_STA_ID) const;
     /**
-     * \returns the maximum number of Nss (namely if MU)
+     * \returns the maximum number of Nss over all RUs of an HE MU (used for OFDMA)
      */
     uint8_t GetNssMax() const;
+    /**
+     * \returns the total number of Nss for a given RU of an HE MU (used for full bandwidth MU-MIMO)
+     */
+    uint8_t GetNssTotal() const;
     /**
      * Sets the number of Nss
      *
@@ -352,10 +357,13 @@ class WifiTxVector
      * The standard disallows certain combinations of WifiMode, number of
      * spatial streams, and channel widths.  This method can be used to
      * check whether this WifiTxVector contains an invalid combination.
+     * If a PHY band is specified, it is checked that the PHY band is appropriate for
+     * the modulation class of the TXVECTOR, in case the latter is OFDM or ERP-OFDM.
      *
+     * \param band the PHY band
      * \return true if the WifiTxVector parameters are allowed by the standard
      */
-    bool IsValid() const;
+    bool IsValid(WifiPhyBand band = WIFI_PHY_BAND_UNSPECIFIED) const;
     /**
      * \return true if this TX vector is used for a multi-user (OFDMA and/or MU-MIMO) transmission
      */
@@ -370,6 +378,18 @@ class WifiTxVector
      * transmission
      */
     bool IsUlMu() const;
+    /**
+     * Return true if this TX vector is used for a downlink multi-user transmission using OFDMA.
+     *
+     * \return true if this TX vector is used for a downlink multi-user transmission using OFDMA
+     */
+    bool IsDlOfdma() const;
+    /**
+     * Return true if this TX vector is used for a downlink multi-user transmission using MU-MIMO.
+     *
+     * \return true if this TX vector is used for a downlink multi-user transmission using MU-MIMO
+     */
+    bool IsDlMuMimo() const;
     /**
      * Check if STA ID is allocated
      * \param staId STA ID
@@ -424,7 +444,7 @@ class WifiTxVector
     HeMuUserInfoMap& GetHeMuUserInfoMap();
 
     /// map of specific user info parameters ordered per increasing frequency RUs
-    using UserInfoMapOrderedByRus = std::map<HeRu::RuSpec, uint16_t, HeRu::RuSpecCompare>;
+    using UserInfoMapOrderedByRus = std::map<HeRu::RuSpec, std::set<uint16_t>, HeRu::RuSpecCompare>;
 
     /**
      * Get the map of specific user info parameters ordered per increasing frequency RUs.
@@ -434,6 +454,13 @@ class WifiTxVector
      */
     UserInfoMapOrderedByRus GetUserInfoMapOrderedByRus(uint8_t p20Index) const;
 
+    /**
+     * Indicate whether the Common field is present in the HE-SIG-B field.
+     *
+     * \return true if the Common field is present in the HE-SIG-B, false otherwise
+     */
+    bool IsSigBCompression() const;
+
     /**
      * Set the 20 MHz subchannels that are punctured.
      *
@@ -523,6 +550,14 @@ class WifiTxVector
      */
     Center26ToneRuIndication DeriveCenter26ToneRuIndication() const;
 
+    /**
+     * Get the number of STAs in a given RU.
+     *
+     * \param ru the RU specification
+     * \return the number of STAs in the RU
+     */
+    uint8_t GetNumStasInRu(const HeRu::RuSpec& ru) const;
+
     WifiMode m_mode;          /**< The DATARATE parameter in Table 15-4.
                               It is the value that will be passed
                               to PMD_RATE.request */
