@@ -650,7 +650,7 @@ ChannelAccessManagerTest<TxopType>::EndTest()
 {
     Simulator::Run();
 
-    for (typename TxopTests::const_iterator i = m_txop.begin(); i != m_txop.end(); i++)
+    for (auto i = m_txop.begin(); i != m_txop.end(); i++)
     {
         Ptr<TxopTest<TxopType>> state = *i;
         NS_TEST_EXPECT_MSG_EQ(state->m_expectedGrants.empty(), true, "Have no expected grants");
@@ -806,11 +806,12 @@ ChannelAccessManagerTest<TxopType>::DoAccessRequest(uint64_t txTime,
                                                     uint64_t expectedGrantTime,
                                                     Ptr<TxopTest<TxopType>> state)
 {
-    if (m_ChannelAccessManager->NeedBackoffUponAccess(state))
+    auto hadFramesToTransmit = state->HasFramesToTransmit(SINGLE_LINK_OP_ID);
+    state->QueueTx(txTime, expectedGrantTime);
+    if (m_ChannelAccessManager->NeedBackoffUponAccess(state, hadFramesToTransmit, true))
     {
         state->GenerateBackoff(0);
     }
-    state->QueueTx(txTime, expectedGrantTime);
     m_ChannelAccessManager->RequestAccess(state);
 }
 
@@ -836,6 +837,7 @@ ChannelAccessManagerTest<TxopType>::AddSwitchingEvt(uint64_t at, uint64_t durati
     Simulator::Schedule(MicroSeconds(at) - Now(),
                         &ChannelAccessManager::NotifySwitchingStartNow,
                         m_ChannelAccessManager,
+                        nullptr,
                         MicroSeconds(duration));
 }
 
@@ -1396,7 +1398,7 @@ LargestIdlePrimaryChannelTest::RunOne(uint16_t chWidth, WifiChannelListType busy
                              : ((1 << (busyChannel - 1)) * 20);
 
     Time checkTime1 = start + ccaBusyStartDelay + ccaBusyDuration / 2;
-    Simulator::Schedule(checkTime1 - start, [=]() {
+    Simulator::Schedule(checkTime1 - start, [=, this]() {
         Time interval1 = (ccaBusyStartDelay + ccaBusyDuration) / 2;
         NS_TEST_EXPECT_MSG_EQ(m_cam->GetLargestIdlePrimaryChannel(interval1, checkTime1),
                               idleWidth,
@@ -1409,7 +1411,7 @@ LargestIdlePrimaryChannelTest::RunOne(uint16_t chWidth, WifiChannelListType busy
     // same as the previous case
     Time ccaBusyRxInterval = MilliSeconds(1);
     Time checkTime2 = start + ccaBusyStartDelay + ccaBusyDuration + ccaBusyRxInterval / 2;
-    Simulator::Schedule(checkTime2 - start, [=]() {
+    Simulator::Schedule(checkTime2 - start, [=, this]() {
         Time interval2 = (ccaBusyDuration + ccaBusyRxInterval) / 2;
         NS_TEST_EXPECT_MSG_EQ(m_cam->GetLargestIdlePrimaryChannel(interval2, checkTime2),
                               idleWidth,
@@ -1428,7 +1430,7 @@ LargestIdlePrimaryChannelTest::RunOne(uint16_t chWidth, WifiChannelListType busy
     // At RX end, we check the status of the channel during an interval immediately
     // preceding RX start and overlapping the CCA_BUSY period.
     Time checkTime3 = start + ccaBusyStartDelay + ccaBusyDuration + ccaBusyRxInterval + rxDuration;
-    Simulator::Schedule(checkTime3 - start, [=]() {
+    Simulator::Schedule(checkTime3 - start, [=, this]() {
         Time interval3 = ccaBusyDuration / 2 + ccaBusyRxInterval;
         Time end3 = checkTime3 - rxDuration;
         NS_TEST_EXPECT_MSG_EQ(m_cam->GetLargestIdlePrimaryChannel(interval3, end3),
@@ -1442,7 +1444,7 @@ LargestIdlePrimaryChannelTest::RunOne(uint16_t chWidth, WifiChannelListType busy
     // At RX end, we check the status of the channel during the interval following
     // the CCA_BUSY period and preceding RX start. The entire operating channel is idle.
     const Time& checkTime4 = checkTime3;
-    Simulator::Schedule(checkTime4 - start, [=]() {
+    Simulator::Schedule(checkTime4 - start, [=, this]() {
         const Time& interval4 = ccaBusyRxInterval;
         Time end4 = checkTime4 - rxDuration;
         NS_TEST_EXPECT_MSG_EQ(m_cam->GetLargestIdlePrimaryChannel(interval4, end4),
@@ -1457,7 +1459,7 @@ LargestIdlePrimaryChannelTest::RunOne(uint16_t chWidth, WifiChannelListType busy
     // overlap the RX period
     Time interval5 = MilliSeconds(1);
     Time checkTime5 = checkTime4 + interval5;
-    Simulator::Schedule(checkTime5 - start, [=]() {
+    Simulator::Schedule(checkTime5 - start, [=, this]() {
         NS_TEST_EXPECT_MSG_EQ(m_cam->GetLargestIdlePrimaryChannel(interval5, checkTime5),
                               chWidth,
                               "Incorrect width of the idle channel in an interval "
@@ -1467,7 +1469,7 @@ LargestIdlePrimaryChannelTest::RunOne(uint16_t chWidth, WifiChannelListType busy
 
     // After RX end, no channel is idle if the interval overlaps the RX period
     const Time& checkTime6 = checkTime5;
-    Simulator::Schedule(checkTime6 - start, [=]() {
+    Simulator::Schedule(checkTime6 - start, [=, this]() {
         Time interval6 = interval5 + rxDuration / 2;
         NS_TEST_EXPECT_MSG_EQ(m_cam->GetLargestIdlePrimaryChannel(interval6, checkTime6),
                               0,
@@ -1491,7 +1493,7 @@ LargestIdlePrimaryChannelTest::DoRun()
 
         for (const auto busyChannel : busyChannels)
         {
-            Simulator::Schedule(Seconds(delay), [this, chWidth, busyChannel]() {
+            Simulator::Schedule(Seconds(delay), [=, this]() {
                 // reset PHY
                 if (m_phy)
                 {
