@@ -257,7 +257,7 @@ BSLinkManager::VerifyInvitedRanging(Cid cid, uint8_t uiuc)
 
             if (ssRecord->GetInvitedRangRetries() == m_bs->GetMaxInvitedRangRetries())
             {
-                RngRsp* rngrsp = new RngRsp();
+                auto rngrsp = new RngRsp();
                 AbortRanging(ssRecord->GetBasicCid(), rngrsp, ssRecord, true);
             } // else keep polling
         }
