@@ -851,9 +851,7 @@ BaseStationNetDevice::DoReceive(Ptr<Packet> packet)
 
                     // DEFRAGMENTATION
                     NS_LOG_INFO("\t BS PACKET DEFRAGMENTATION" << std::endl);
-                    for (std::list<Ptr<const Packet>>::const_iterator iter = fragmentsQueue.begin();
-                         iter != fragmentsQueue.end();
-                         ++iter)
+                    for (auto iter = fragmentsQueue.begin(); iter != fragmentsQueue.end(); ++iter)
                     {
                         // Create the whole Packet
                         fullPacket->AddAtEnd(*iter);
@@ -1029,10 +1027,7 @@ BaseStationNetDevice::CreateDlMap()
     std::list<std::pair<OfdmDlMapIe*, Ptr<PacketBurst>>>* downlinkBursts =
         m_scheduler->GetDownlinkBursts();
 
-    for (std::list<std::pair<OfdmDlMapIe*, Ptr<PacketBurst>>>::iterator iter =
-             downlinkBursts->begin();
-         iter != downlinkBursts->end();
-         ++iter)
+    for (auto iter = downlinkBursts->begin(); iter != downlinkBursts->end(); ++iter)
     {
         iter->first->SetPreamblePresent(0);
         iter->first->SetStartTime(0);
@@ -1096,9 +1091,7 @@ BaseStationNetDevice::CreateUlMap()
 
     std::list<OfdmUlMapIe> uplinkAllocations = m_uplinkScheduler->GetUplinkAllocations();
 
-    for (std::list<OfdmUlMapIe>::iterator iter = uplinkAllocations.begin();
-         iter != uplinkAllocations.end();
-         ++iter)
+    for (auto iter = uplinkAllocations.begin(); iter != uplinkAllocations.end(); ++iter)
     {
         ulmap.AddUlMapElement(*iter);
     }
@@ -1197,9 +1190,7 @@ BaseStationNetDevice::MarkUplinkAllocations()
 {
     uint16_t symbolsToAllocation = 0;
     std::list<OfdmUlMapIe> uplinkAllocations = m_uplinkScheduler->GetUplinkAllocations();
-    for (std::list<OfdmUlMapIe>::iterator iter = uplinkAllocations.begin();
-         iter != uplinkAllocations.end();
-         ++iter)
+    for (auto iter = uplinkAllocations.begin(); iter != uplinkAllocations.end(); ++iter)
     {
         OfdmUlMapIe uplinkAllocation = *iter;
 
