@@ -239,8 +239,7 @@ VectorTlvValue::VectorTlvValue()
 
 VectorTlvValue::~VectorTlvValue()
 {
-    for (std::vector<Tlv*>::const_iterator iter = m_tlvList->begin(); iter != m_tlvList->end();
-         ++iter)
+    for (auto iter = m_tlvList->begin(); iter != m_tlvList->end(); ++iter)
     {
         delete (*iter);
     }
@@ -252,8 +251,7 @@ uint32_t
 VectorTlvValue::GetSerializedSize() const
 {
     uint32_t size = 0;
-    for (std::vector<Tlv*>::const_iterator iter = m_tlvList->begin(); iter != m_tlvList->end();
-         ++iter)
+    for (auto iter = m_tlvList->begin(); iter != m_tlvList->end(); ++iter)
     {
         size += (*iter)->GetSerializedSize();
     }
@@ -263,8 +261,7 @@ VectorTlvValue::GetSerializedSize() const
 void
 VectorTlvValue::Serialize(Buffer::Iterator i) const
 {
-    for (std::vector<Tlv*>::const_iterator iter = m_tlvList->begin(); iter != m_tlvList->end();
-         ++iter)
+    for (auto iter = m_tlvList->begin(); iter != m_tlvList->end(); ++iter)
     {
         (*iter)->Serialize(i);
         i.Next((*iter)->GetSerializedSize());
@@ -297,8 +294,8 @@ SfVectorTlvValue::SfVectorTlvValue()
 SfVectorTlvValue*
 SfVectorTlvValue::Copy() const
 {
-    SfVectorTlvValue* tmp = new SfVectorTlvValue();
-    for (std::vector<Tlv*>::const_iterator iter = Begin(); iter != End(); ++iter)
+    auto tmp = new SfVectorTlvValue();
+    for (auto iter = Begin(); iter != End(); ++iter)
     {
         tmp->Add(Tlv((*iter)->GetType(), (*iter)->GetLength(), *(*iter)->PeekValue()));
     }
@@ -528,7 +525,7 @@ U8TlvValue::GetValue() const
 U8TlvValue*
 U8TlvValue::Copy() const
 {
-    U8TlvValue* tmp = new U8TlvValue(m_value);
+    auto tmp = new U8TlvValue(m_value);
     return tmp;
 }
 
@@ -581,7 +578,7 @@ U16TlvValue::GetValue() const
 U16TlvValue*
 U16TlvValue::Copy() const
 {
-    U16TlvValue* tmp = new U16TlvValue(m_value);
+    auto tmp = new U16TlvValue(m_value);
     return tmp;
 }
 
@@ -634,7 +631,7 @@ U32TlvValue::GetValue() const
 U32TlvValue*
 U32TlvValue::Copy() const
 {
-    U32TlvValue* tmp = new U32TlvValue(m_value);
+    auto tmp = new U32TlvValue(m_value);
     return tmp;
 }
 
@@ -693,8 +690,8 @@ CsParamVectorTlvValue::CsParamVectorTlvValue()
 CsParamVectorTlvValue*
 CsParamVectorTlvValue::Copy() const
 {
-    CsParamVectorTlvValue* tmp = new CsParamVectorTlvValue();
-    for (std::vector<Tlv*>::const_iterator iter = Begin(); iter != End(); ++iter)
+    auto tmp = new CsParamVectorTlvValue();
+    for (auto iter = Begin(); iter != End(); ++iter)
     {
         tmp->Add(Tlv((*iter)->GetType(), (*iter)->GetLength(), *(*iter)->PeekValue()));
     }
@@ -710,8 +707,8 @@ ClassificationRuleVectorTlvValue::ClassificationRuleVectorTlvValue()
 ClassificationRuleVectorTlvValue*
 ClassificationRuleVectorTlvValue::Copy() const
 {
-    ClassificationRuleVectorTlvValue* tmp = new ClassificationRuleVectorTlvValue();
-    for (std::vector<Tlv*>::const_iterator iter = Begin(); iter != End(); ++iter)
+    auto tmp = new ClassificationRuleVectorTlvValue();
+    for (auto iter = Begin(); iter != End(); ++iter)
     {
         tmp->Add(Tlv((*iter)->GetType(), (*iter)->GetLength(), *(*iter)->PeekValue()));
     }
@@ -888,9 +885,7 @@ PortRangeTlvValue::GetSerializedSize() const
 void
 PortRangeTlvValue::Serialize(Buffer::Iterator i) const
 {
-    for (std::vector<PortRange>::const_iterator iter = m_portRange->begin();
-         iter != m_portRange->end();
-         ++iter)
+    for (auto iter = m_portRange->begin(); iter != m_portRange->end(); ++iter)
     {
         i.WriteHtonU16((*iter).PortLow);
         i.WriteHtonU16((*iter).PortHigh);
@@ -935,10 +930,8 @@ PortRangeTlvValue::End() const
 PortRangeTlvValue*
 PortRangeTlvValue::Copy() const
 {
-    PortRangeTlvValue* tmp = new PortRangeTlvValue();
-    for (std::vector<PortRange>::const_iterator iter = m_portRange->begin();
-         iter != m_portRange->end();
-         ++iter)
+    auto tmp = new PortRangeTlvValue();
+    for (auto iter = m_portRange->begin(); iter != m_portRange->end(); ++iter)
     {
         tmp->Add((*iter).PortLow, (*iter).PortHigh);
     }
@@ -971,10 +964,9 @@ ProtocolTlvValue::GetSerializedSize() const
 void
 ProtocolTlvValue::Serialize(Buffer::Iterator i) const
 {
-    for (std::vector<uint8_t>::const_iterator iter = m_protocol->begin(); iter != m_protocol->end();
-         ++iter)
+    for (auto iter = m_protocol->begin(); iter != m_protocol->end(); ++iter)
     {
-        i.WriteU8((*iter));
+        i.WriteU8(*iter);
     }
 }
 
@@ -1011,11 +1003,10 @@ ProtocolTlvValue::End() const
 ProtocolTlvValue*
 ProtocolTlvValue::Copy() const
 {
-    ProtocolTlvValue* tmp = new ProtocolTlvValue();
-    for (std::vector<uint8_t>::const_iterator iter = m_protocol->begin(); iter != m_protocol->end();
-         ++iter)
+    auto tmp = new ProtocolTlvValue();
+    for (auto iter = m_protocol->begin(); iter != m_protocol->end(); ++iter)
     {
-        tmp->Add((*iter));
+        tmp->Add(*iter);
     }
     return tmp;
 }
@@ -1046,9 +1037,7 @@ Ipv4AddressTlvValue::GetSerializedSize() const
 void
 Ipv4AddressTlvValue::Serialize(Buffer::Iterator i) const
 {
-    for (std::vector<Ipv4Addr>::const_iterator iter = m_ipv4Addr->begin();
-         iter != m_ipv4Addr->end();
-         ++iter)
+    for (auto iter = m_ipv4Addr->begin(); iter != m_ipv4Addr->end(); ++iter)
     {
         i.WriteHtonU32((*iter).Address.Get());
         i.WriteHtonU32((*iter).Mask.Get());
@@ -1090,10 +1079,8 @@ Ipv4AddressTlvValue::End() const
 Ipv4AddressTlvValue*
 Ipv4AddressTlvValue::Copy() const
 {
-    Ipv4AddressTlvValue* tmp = new Ipv4AddressTlvValue();
-    for (std::vector<Ipv4Addr>::const_iterator iter = m_ipv4Addr->begin();
-         iter != m_ipv4Addr->end();
-         ++iter)
+    auto tmp = new Ipv4AddressTlvValue();
+    for (auto iter = m_ipv4Addr->begin(); iter != m_ipv4Addr->end(); ++iter)
     {
         tmp->Add((*iter).Address, (*iter).Mask);
     }
